<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - affiliate_payments.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage affiliate_payments
|
*/

class Affiliate_Payments extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load affiliate_payments model
		$this->load->model('affiliate_payments_model');
		$this->load->model('credits_model');
		$this->load->model('coupons_model');
		
		//load css body style
		$this->config->set_item('css_body', 'UZ');
		
		//load country helper
		$this->load->helper('country');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		$this->config->set_item('uri2', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/make_payments_table');
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/affiliate_payments/view_affiliate_payments');
	}
	
	
	// ------------------------------------------------------------------------
	
	function delete_affiliate_payment()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->affiliate_payments_model->_delete_payment((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/affiliate_payments/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
			
				redirect(ADMIN_ROUTE . '/affiliates/update_affiliate/' .  $affiliate[0]['affiliate_id'] . '#fragment-4');
			}
		}
		else
		{
			redirect(ADMIN_ROUTE . '/affiliates/view_affiliates');
		}
	
	}
	
	
	// ------------------------------------------------------------------------
	
	function view_affiliate_payments()
	{
		/*
		| -----------------------------------------
		| view affiliate_payments
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_affiliate_payments');
		
		//set page title
		if ($this->uri->segment(4) && $this->uri->segment(5))
		{
			//get member name
			$member = $this->db_validation_model->_get_details('members', 'fname, lname', 'member_id', $this->uri->segment(5));
			
			$data['page_title'] = $this->lang->line('view_payments_to') . ' ' . $member[0]['fname'] . ' ' . $member[0]['lname'];
		}
		
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_affiliate_payments', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function generate_affiliate_payments()
	{
		/*
		| -----------------------------------------
		| generate mass payment files
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if (empty($_POST['user']))
		{
			show_error($this->lang->line('no_members_selected'));
		}
		
		$num_options = get_default_currency($data['sts_store_default_currency']);
		
		/*
		|-------------------------------------
		| let's see what file needs to be run
		|-------------------------------------
		*/
		
		
		if ($this->input->post('payment_type') == 'jrox_mark_as_paid')
		{
			//get the member details first
			foreach ($this->input->post('user') as $mid => $amount)
			{		
				$sdata = $this->affiliate_payments_model->_mark_commissions_paid($mid, $amount, $this->input->post('affiliate_note'));
			}
			
			/*
			|-------------------------------------
			| now let's send out any email alerts
			|-------------------------------------
			*/
			
			//check if emailing is enabled
			if ($this->config->item('sts_affiliate_alert_payment_sent') == 1)
			{
				$this->load->model('emailing_model');
				
				foreach ($this->input->post('user') as $mid => $amount)
				{
					$member = $this->db_validation_model->_get_details('members', '*', 'member_id', $mid);
					
					//send out alerts
					if ($member[0]['alert_payment_sent'] != '0') //only send out the email if the user allows it
					{
						//format the array
						$v = $member[0];
						$v['payment_amount'] = format_amounts($amount, $num_options);
						$v['affiliate_note'] = $this->input->post('affiliate_note');
						
						$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_payment_sent_template', true); //queue it!
					}	
				}
			}
			
			$this->session->set_flashdata('success', $this->lang->line('commissions_paid_successfully'));
		
			//go back to the page
			redirect(ADMIN_ROUTE . '/affiliate_payments/make_affiliate_payments');
		}
		else //run the payment module
		{
			$vpath = 'modules/module_affiliate_payment_' . $this->input->post('payment_type') . '_model';
			
			if (file_exists(APPPATH . 'models/' . $vpath.'.php'))
			{
				
				$this->load->model($vpath, 'payment_model');
				
				//set the member array
				$members = array();
				
				//get the member details first
				foreach ($this->input->post('user') as $mid => $amount)
				{
					
					$member = $this->db_validation_model->_get_details('members', '*', 'member_id', $mid);
					
					//format the array
					$v = $member[0];
					$v['payment_amount'] = format_amounts($amount, $num_options, true);
					$v['affiliate_note'] = $this->input->post('affiliate_note');
					$v['num_options'] = $num_options;
					array_push($members, $v);
				}
				
				/*
				|-------------------------------------
				| generate the mass payment file now
				|-------------------------------------
				*/
				
				$this->payment_model->_generate_payments($members);
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get affiliate_payments via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '450';
		$data['width'] = '700';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//get affiliate_payments
		$row = $this->affiliate_payments_model->_get_payment_history($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_column'], $data['where_value']);

		//add the data to the array
		$data['affiliate_payments'] = $row;	
		
		//count the rows
		if (!empty($data['where_column']) && !empty($data['where_value']))
		{

			$sql = 'WHERE ' . $data['where_column'] .' = \'' . $data['where_value'] . '\'';	
			
			$total_rows = $this->db_validation_model->_get_count('affiliate_payments', $sql);
		}
		else
		{
			$total_rows = $this->db_validation_model->_get_count('affiliate_payments');
		}
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'affiliate_payments', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_affiliate_payments_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function make_affiliate_payments()
	{
		/*
		| -----------------------------------------
		| view affiliate_payments
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('make_affiliate_payments');
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_make_affiliate_payments', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function make_payments_table()
	{	
		/*
		| ---------------------
		| get affiliate_payments via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'ASC' ? 'DESC' : 'ASC';
		$data['sort_header'] = $data['uri2'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '450';
		$data['width'] = '700';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//get affiliate_payments
		$row = $this->affiliate_payments_model->_get_affiliate_payments($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		$data['payment_options'] = $this->affiliate_payments_model->_get_payment_options();
		
		//add the data to the array
		$data['affiliate_payments'] = $row['payments'];
		
		$total_rows = $row['total_rows'];	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri2'], 'affiliate_payments', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_make_affiliate_payments_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_affiliate_payment()
	{
		/*
		| -----------------------------------------
		| add a new affiliate_payment
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_affiliate_payment');
		$data['submit_url'] = jrox_admin_url().'affiliate_payments/update_affiliate_payment/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_affiliate_payment';
		$data['update_link'] = 'affiliate_payments';
		
		//run admin validation check
		if ($this->_check_affiliate_payment() == false)
		{		
			//reload add affiliate_payment form
			if (empty($_POST))
			{
				$mdata = $this->affiliate_payments_model->_get_affiliate_payment_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$fdate = explode(':', $this->config->item('sts_admin_date_format'));
					$data['curdate'] = $fdate[0];
					$data['format_date'] = $fdate[1];
					
					$data['payment_options'] = $this->affiliate_payments_model->_get_payment_options();
					
					$this->validation->payment_date =  date($fdate[1], $this->validation->payment_date);
					
					//load template
					load_form('admin', 'tpl_adm_manage_affiliate_payment', $data);
				}
				else
				{
					//load add affiliate_payment page
					redirect(ADMIN_ROUTE . '/affiliate_payments/view_affiliate_payments');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the affiliate_payment into db
			$data = $this->affiliate_payments_model->_update_payment((int)$this->uri->segment(4));	
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('affiliate_payments_updated_successfully') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------
	
	function _check_username()
	{
		if ($this->db_validation_model->_validate_field('members', 'username', $this->validation->username) == false)
		{
			$this->validation->set_message('_check_username', $this->lang->line('invalid_referring_affiliate'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_affiliate_payment()
	{
		//set form validation rules
		
		$rules['payment_date'] = 'trim|required';
		$rules['payment_amount'] = 'trim|required|numeric';
		
		$rules['username'] = 'trim|required|callback__check_username';
		$rules['payment_details'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['payment_date'] = $this->lang->line('date');
		$fields['payment_amount'] = $this->lang->line('payment_amount');
		
		$fields['username'] = $this->lang->line('username');
		$fields['payment_details'] = $this->lang->line('payment_details');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
}
?>