<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - attributes.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage product attributes
|
*/
class Attributes extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load product_categories model
		$this->load->model('attributes_model', 'att');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/attributes/view_attributes');
	}
	
	// ------------------------------------------------------------------------
	
	function add_attribute()
	{
		/*
		| -----------------------------------------
		| add a new attribute
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_attribute');
		$data['submit_url'] = jrox_admin_url().'attributes/add_attribute';
		$data['add_link'] = 'add_attribute';
		$data['options'] = array();
		
		//get attribute callbacks
		$data['callbacks'] = $this->att->_get_attribute_callbacks();
		
		$this->validation->attribute_id_redirect = '';
		$this->validation->attribute_id = '';
		
		//run admin validation check
		if ($this->_check_attribute() == false)
		{		
			//reload add category form
			if (empty($_POST))
			{
				
				//load template
				load_form('admin', 'tpl_adm_manage_attribute', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the category into db
			$data = $this->att->_add_attribute();		
			
			//set flash data
			$this->session->set_flashdata('div_class', 'success');	
			$this->session->set_flashdata('message', $this->lang->line('attribute') . ' ID ' . $data . ' ' . $this->lang->line('added_successfully'));	
			
			//ajax message
			//echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('attribute') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			
			echo '<script>window.location = "' . jrox_admin_url().'attributes/update_attribute/' . $data . '"</script>';
			
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the module
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->att->_change_status((int)$this->uri->segment(4)))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/attributes/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('delete_product_success'));
				
				redirect(ADMIN_ROUTE . '/attributes/view_attributes');
			}
		}	
		
		redirect(ADMIN_ROUTE . '/attributes/view_attributes');
	}
	
	// ------------------------------------------------------------------------
	
	function delete_attribute()
	{
		/*
		| --------------------------------------------
		| delete the attribute from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->att->_delete_attribute((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/attributes/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/attribute/view_attribute');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get product_attributes via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '450';
		$data['width'] = '650';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get product_categories
		$row = $this->att->_get_attributes($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
	 	
		//add the data to the array
		$data['attributes'] = $row;	

		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'products_attributes', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_attributes_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function mass_update_attribute()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_attribute');
		$data['submit_url'] = jrox_admin_url().'attributes/update_attribute/'.$this->uri->segment(4);
		$data['add_link'] = 'update_attribute';
		$data['options'] = array();
		
		echo $this->att->_mass_update_attributes();
	}
	
	// ------------------------------------------------------------------------
	
	function update_attribute()
	{
		/*
		| -----------------------------------------
		| add a new attribute
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_attribute');
		$data['submit_url'] = jrox_admin_url().'attributes/update_attribute/'.$this->uri->segment(4);
		$data['add_link'] = 'update_attribute';
		$data['options'] = array();
		
		//get attribute callbacks
		$data['callbacks'] = $this->att->_get_attribute_callbacks();
		
		$this->validation->attribute_id_redirect = '';
		$this->validation->attribute_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_attribute() == false)
		{		
			//reload add category form
			if (empty($_POST))
			{
				$mdata = $this->att->_get_attribute_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//format the options
					$row_options = array();
					
					if ($mdata['attribute_type'] == 'dropdown')
					{
						if (!empty($mdata['attribute_options']))
						{
							$format = explode('|', $mdata['attribute_options']);
							
							foreach ($format as $k => $v)
							{								
								$rows = explode(':', $v);
								if (!empty($v))
								{
									
									array_push($row_options, $rows);
								}							
							}
						}
					}
					
					$data['row_options'] = $row_options;
					
					
					//load template
					load_form('admin', 'tpl_adm_manage_attribute', $data);
			
				}
				else
				{
					//load add category page
					redirect(ADMIN_ROUTE . '/attributes/add_attribute');
					exit();
				}
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the category into db
			$data = $this->att->_update_attribute((int)$this->uri->segment(4), $_POST);		
			
			//set flash data
			$this->session->set_flashdata('div_class', 'success');	
			$this->session->set_flashdata('message', $this->lang->line('attribute_updated_successfully'));	
			
			//ajax message
			//echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('attribute') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			
			echo '<script>window.location = "' . jrox_admin_url().'attributes/update_attribute/' . $data . '"</script>';
			
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function view_attributes()
	{
		/*
		| -----------------------------------------
		| view product_categories
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['module_name'] = 'attributes';
		$data['function_name'] = 'view_attributes';
		$data['height'] = '450';
		$data['width'] = '600';
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_product_attributes');
		$data['add_title'] = $this->lang->line('add_attribute');
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);

		$data['delete_link'] = 'delete_attribute';
		$data['add_link'] = jrox_admin_url().'attributes/add_attribute';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_attributes', $data);	
	}
	
	// ------------------------------------------------------------------------

	
	function mass_assign()
	{
		//mass assign this attribute to certain products
	}
	
	// ------------------------------------------------------------------------
	
	function mass_remove()
	{
		//mass remove this attribute from certain products
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_attribute()
	{
		//set form validation rules
		
		$rules['attribute_name'] = 'trim|required|min_length[2]|max_length[255]';
		$rules['attribute_type'] = 'trim';
		$rules['attribute_status'] = 'trim|integer';
		$rules['attribute_required'] = 'trim';
		$rules['attribute_options'] = 'trim';
		$rules['attribute_callback'] = 'trim|integer';
		
		if ($this->input->post('attribute_type') == 'dropdown')
		{
			//check for correct options
			if (!empty($_POST['option_name']))
			{
				foreach ($this->input->post('option_name') as $k => $v)
				{
					if (ereg('[^A-Za-z0-9., ]', $v)) {
						//echo '<div class="error" id="error-messages">'.$this->lang->line('option_names_must_be_alphanumeric').'</div>';
						//echo '<script>showResponse();<//script>';
						//exit();				
					}
				}
			}
			
			if (!empty($_POST['price_amount']))
			{
				foreach ($this->input->post('price_amount') as $k => $v)
				{
					if ($_POST['add_price'][$k] != 'none')
					{
						if (!is_numeric($v)) {
							echo '<div class="error" id="error-messages">'.$this->lang->line('price_must_be_numeric').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}
				}	
			}
			
			if (!empty($_POST['weight_amount']))
			{
				foreach ($this->input->post('weight_amount') as $k => $v)
				{
					if ($_POST['add_weight'][$k] != 'none')
					{
					if (!is_numeric($v)) {
						echo '<div class="error" id="error-messages">'.$this->lang->line('weight_must_be_numeric').'</div>';
						echo '<script>showResponse();</script>';
						exit();
					}
					}
				}	
			}
			
			if (!empty($_POST['sort']))
			{
				foreach ($this->input->post('sort') as $k => $v)
				{
					if (!empty($v))
					{
						if (!is_numeric($v)) {
							'<div class="error" id="error-messages">'.$this->lang->line('sort_order_must_be_numeric').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}
				}	
			}
		}		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['attribute_name'] = $this->lang->line('attribute_name');
		$fields['attribute_type'] = $this->lang->line('attribute_type');
		$fields['attribute_status'] = $this->lang->line('attribute_status');
		$fields['attribute_required'] = $this->lang->line('attribute_required');
		$fields['attribute_options'] = $this->lang->line('attribute_options');
		$fields['attribute_callback'] = $this->lang->line('attribute_callback');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
}
?>