<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - commissions.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage commissions
|
*/

class Commissions extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load commissions model
		$this->load->model('commissions_model');
		
		//load members model
		$this->load->model('members_model');
		
		//load css body style
		$this->config->set_item('css_body', 'UZ');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/commissions/view_commissions');
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status of the commission
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('affiliate_commissions', 'comm_id', (int)$this->uri->segment(4), 'approved'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				
				redirect(ADMIN_ROUTE . '/commissions/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(6,0) . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('commission_updated_successfully'));
				
				redirect(ADMIN_ROUTE . '/commissions/view_commissions');
			}
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function update_commissions()
	{
		/*
		| ---------------------------
		| mass update commissions details
		| ---------------------------
		*/
		
		//check if there are any users checked for update
		if ($this->input->post('commission') AND count($this->input->post('commission')) > 0)
		{
			$this->commissions_model->_change_status($this->input->post('commission'), $this->input->post('change-status'));
		}
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('commissions_updated_successfully'));
		echo '<script>self.parent.location.reload(true);</script>';	
	}
	
	// ------------------------------------------------------------------------
	
	function add_commission()
	{
		/*
		| -----------------------------------------
		| add a new commission
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('add_commission');
		$data['submit_url'] = jrox_admin_url().'commissions/add_commission/';
		$data['add_link'] = 'add_commission';
		$data['update_link'] = 'commissions';
		
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
		$data['format_date'] = $fdate[1];
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);

		
		//run validation check
		if ($this->_check_commission() == false)
		{		
			//reload add commission form
			if (empty($_POST))
			{
				//get num options
				$this->load->helper('number');
				
				//check if there is an invoice number
				$this->validation->invoice_id = $this->uri->segment(4);
				
				//get number of levels
				for ($i = 1; $i<=$data['sts_affiliate_commission_levels']; $i++)
				{
					$data['commission_levels'][$i] = $i;
				}
				
				$this->validation->username = '';
				
				$this->validation->date =  date($fdate[1], time());
				
				load_admin_tpl('admin', 'tpl_adm_manage_commission', $data);
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			$num_options = $data['num_options'];
			
			//get affiliate id if any and generate the commission
			if (!empty($_POST['referring_affiliate']))
			{
				$member = $this->db_validation_model->_get_details('members', '*', 'username', $this->input->post('referring_affiliate'));
			}
			else
			{
				show_error($this->lang->line('no_member_found'));
			}
			
			//format the date
			switch ($fdate[0])
			{
				case 'mm/dd/yyyy':
						
					//format date
					$pub = explode('/', $this->input->post('date'));
					$data['date'] = mktime(date('H'),date('i'),date('s'), $pub[0], $pub[1], $pub[2]);
					
					
					if (!empty($_POST['date_paid']))
					{
						//format date
						$pub = explode('/', $this->input->post('date_paid'));
						$data['date_paid'] = mktime(date('H'),date('i'),date('s'), $pub[0], $pub[1], $pub[2]);
					}
					else
					{
						$data['date_paid'] = '';
					}
				break;
			}		
			
			//set the commission level
			$level = $this->input->post('commission_level');
			$data['commission_amount'] = $this->input->post('commission_amount');
			
			//calculate the amounts from the affiliate group
			if ($this->input->post('use_group_defaults') == 1)
			{
				
				$group = $this->members_model->_get_member_group_data('affiliate', $member[0]['member_id']);
				
				if ($group['commission_type'] == 'percent')
				{
					
					$data['commission_amount'] = $this->input->post('sale_amount') * $group['commission_level_' . $level];
				}
				else
				{
					$data['commission_amount'] = $group['commission_level_' . $level];
				}
			}
			
			//set the email options
			$email_sent = $this->input->post('send_email_alert') == 1 ? 1 : 0;
			
			//set all the required data
			$insert = array(	'member_id' 				=> 			$member[0]['member_id'],			
								'invoice_id'				=>			(int)$this->input->post('invoice_id'),
								'comm_status'					=>			$this->input->post('comm_status'),
								'approved'					=>			$this->input->post('approved'),
								'date'						=>			$data['date'],
								'commission_amount'			=>			$data['commission_amount'],
								'sale_amount'				=>			$this->input->post('sale_amount'),
								'commission_level'			=>			(int)$level,
								'referrer'					=>			$this->input->post('referrer'),
								'trans_id'					=>			$this->input->post('trans_id'),
								'ip_address'				=>			$this->input->ip_address(),
								'date_paid'					=>			$data['date_paid'],
								'commission_notes'			=>			$this->input->post('commission_notes'),
								'performance_paid'			=>			'0',
								'email_sent'				=>			$email_sent,
							);	
			
			//load emailing model
			$this->load->model('emailing_model');
			
			//set the commission status
			switch ($this->config->item('sts_affiliate_new_commission'))
			{
				case 'no_pending':
				case 'alert_pending':
					
					$comm_status = 'pending';
					
				break;
				
				case 'no_unpaid':
				case 'alert_unpaid':
				
					$comm_status = 'unpaid';
					
				break;
			}
							
			
			//add only one commission
			if ($this->input->post('credit_upline') == 0) 
			{
				//add the one commission
				$data = $this->commissions_model->_add_commission($insert);	
				
				//check performance bonuses
				if ($this->config->item('sts_affiliate_enable_performance_bonus') == 1)
				{
					//generate bonuses if any
					$unpaid_bonus = $this->commissions_model->_get_commissions_for_bonus($this->config->item('sts_affiliate_performance_bonus_required'), $member[0]['member_id']);
					
					//calculate whether the user has made enough commissions
					if ($unpaid_bonus >= $this->config->item('sts_affiliate_performance_bonus_required_amount'))
					{
						//check if performance is group upgrade or an amount
						if ($this->config->item('sts_affiliate_performance_bonus_type') == 'payment_amount')
						{
							//insert a commission amount
							
							$comm_notes = $this->lang->line('performance_bonus_earned') . "\n";
							$v['bonus_amount'] = format_amounts($this->config->item('sts_affiliate_performance_bonus_amount'), $num_options, true);
							
							//set all the required data
							$new_bonus = array(	'member_id' 		=> 			$member[0]['member_id'],			
												'invoice_id'		=>			'0',
												'comm_status'			=>			$this->input->post('comm_status'),
												'approved'			=>			'0',
												'date'				=>			$data['date'],
												'commission_amount'	=>			format_amounts($this->config->item('sts_affiliate_performance_bonus_amount'), $num_options),
												'sale_amount'		=>			'0',
												'commission_level'	=>			'1',
												'referrer'			=>			'',
												'trans_id'			=>			$this->lang->line('trans_id_performance_bonus'),
												'ip_address'		=>			$this->input->ip_address(),
												'date_paid'			=>			'',
												'commission_notes'	=>			$comm_notes,
												'performance_paid'	=>			'1',
												'email_sent'		=>			'1',
											);	
						
							//add the commission
							$this->commissions_model->_add_commission($new_bonus);
							
							//send out alerts
							if ($v['alert_new_commission'] != '0') //only send out the email if the user allows it
							{
								$v = $member[0];
								$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_bonus_amount_template', true);
							}
						}
						else //upgrade to group
						{
							$v = $member[0];
							$group_upgrade = $this->commissions_model->_upgrade_bonus_group($v['member_id']);
							
							if (!empty($group_upgrade))
							{
								$v['upgraded_affiliate_group'] = $group_upgrade['aff_group_name'];
								
								//send out alerts
								if ($v['alert_new_commission'] != '0')
								{
									$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_group_upgrade_template', true);
								}
							}
						}
						
						//now mark all commissions to performance paid
						$this->commissions_model->_update_commissions_for_bonus($v['member_id']);	
					}
				}
			
				//check if emailing is enabled
				if ($this->input->post('send_email_alert') == 1)
				{
					//send out alerts
					if ($member[0]['alert_new_commission'] != '0') //only send out the email if the user allows it
					{
						//format the array
						$v = $member[0];
						$v['commission_amount'] = format_amounts($data['commission_amount'], $num_options);
						
						$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_commission_generated_template'); //send it!
					}
				}
			}
			else //generate commissions for the upline
			{
				//load the downline model to get the upline
				$this->load->model('downline_model');
				
				//generate the downline array of members
				$members = $this->downline_model->_get_upline($member[0]['member_id']);
				
				foreach ($members as $k => $v)
				{
					if ($v['status'] == 1) //only add a commission if the member has an active status
					{
						//set default levels and commissions
						$level = $k;
						
						$insert['commission_amount'] = $this->input->post('commission_amount');
						
						//calculate the amounts from the affiliate group
						if ($this->input->post('use_group_defaults') == 1)
						{
							//calculate the commission amount
							$insert['commission_amount'] = $this->commissions_model->_calculate_commission($v['commission_type'], $level, $v['commission_level_' . $k], $this->input->post('sale_amount'));
							
						}

						//add the commission
						$insert['member_id'] = $v['member_id'];
						$insert['commission_level'] = $level;
						
						$data = $this->commissions_model->_add_commission($insert);	
						
						//send out alert email if set
						if ($this->input->post('send_email_alert') == 1)
						{
							if ($v['alert_new_commission'] != '0') //send out the email only if the user wants it
							{
								$v['commission_amount'] = format_amounts($insert['commission_amount'], $num_options);
								$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_commission_generated_template');
							}
						}
						
						//check performance bonuses
						if ($this->config->item('sts_affiliate_enable_performance_bonus') == 1)
						{
							//generate bonuses if any
							$unpaid_bonus = $this->commissions_model->_get_commissions_for_bonus($this->config->item('sts_affiliate_performance_bonus_required'), $v['member_id']);
							
							//calculate whether the user has made enough commissions
							if ($unpaid_bonus >= $this->config->item('sts_affiliate_performance_bonus_required_amount'))
							{
								//check if performance is group upgrade or an amount
								if ($this->config->item('sts_affiliate_performance_bonus_type') == 'payment_amount')
								{
									//insert a commission amount
									
									$comm_notes = $this->lang->line('performance_bonus_earned') . "\n";
									$v['bonus_amount'] = format_amounts($this->config->item('sts_affiliate_performance_bonus_amount'), $num_options, true);
									
									//set all the required data
									$new_bonus = array(	'member_id' 		=> 			$v['member_id'],			
														'invoice_id'		=>			'0',
														'comm_status'		=>			$comm_status,
														'approved'			=>			'0',
														'date'				=>			$data['date'],
														'commission_amount'	=>			format_amounts($this->config->item('sts_affiliate_performance_bonus_amount'), $num_options),
														'sale_amount'		=>			'0',
														'commission_level'	=>			'1',
														'referrer'			=>			'',
														'trans_id'			=>			$this->lang->line('trans_id_performance_bonus'),
														'ip_address'		=>			$this->input->ip_address(),
														'date_paid'			=>			'',
														'commission_notes'	=>			$comm_notes,
														'performance_paid'	=>			'1',
														'email_sent'		=>			'1',
													);	
								
									//add the commission
									$this->commissions_model->_add_commission($new_bonus);
									
									//send out alerts
									if ($v['alert_new_commission'] != '0') //only send out the email if the user allows it
									{
										$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_bonus_amount_template');
									}
								}
								else //upgrade to group
								{
									$group_upgrade = $this->commissions_model->_upgrade_bonus_group($v['member_id']);
									
									if (!empty($group_upgrade))
									{
										$v['upgraded_affiliate_group'] = $group_upgrade['aff_group_name'];
										
										//send out alerts
										if ($v['alert_new_commission'] != '0')
										{
											$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_group_upgrade_template');
										}
									}
								}
								
								//now mark all commissions to performance paid
								$this->commissions_model->_update_commissions_for_bonus($v['member_id']);	
							}
						}
					}
				}
			}
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('commission_added_successfully'));	
			
			//redirect to member details form
			echo '<script>window.location = "' . jrox_admin_url() .'/commissions/update_commission/' . $data['comm_id'] . '"</script>';
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_commission()
	{
		/*
		| --------------------------------------------
		| delete the commission from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->commissions_model->_delete_commission((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/commissions/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/commissions/view_commissions');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_commissions()
	{
		/*
		| -----------------------------------------
		| view commissions
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_commissions');

		//set page title
		if ($this->uri->segment(4) && $this->uri->segment(4) != 'search')
		{
			//get member name
			$member = $this->db_validation_model->_get_details('members', 'fname, lname', 'member_id', $this->uri->segment(4));
			
			$data['page_title'] = $this->lang->line('view_commissions_for') . ' ' . $member[0]['fname'] . ' ' . $member[0]['lname'];
		}

		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_commissions', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get commissions via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'ASC' ? 'DESC' : 'ASC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '400';
		$data['width'] = '700';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//load currency options
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		if ($data['where_column'] == 'search')
		{
			//load convert library
			$this->load->library('convert');
			
			$data['where_value'] = base64_decode($this->convert->HexToAscii($data['where_value'])); 
		}
		
		//get invoices
		$row = $this->commissions_model->_get_commissions($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_column'], $data['where_value']);

	 
		//add the data to the array
		$data['commissions'] = $row;	
		
		//check if search is on
		if ($data['where_column'] == 'search')
		{
			$this->db->join('members', 'affiliate_commissions.member_id = members.member_id', 'left');
			$this->db->like('affiliate_commissions.trans_id', $data['where_value']);
			$this->db->or_like('affiliate_commissions.commission_amount', $data['where_value']); 
			$this->db->or_like('affiliate_commissions.sale_amount', $data['where_value']);
			$this->db->or_like('members.fname', $data['where_value']);
			$this->db->or_like('members.lname', $data['where_value']);
			$this->db->or_like('members.username', $data['where_value']); 
			$this->db->from('affiliate_commissions');
			
			$total_rows = $this->db->count_all_results();

			$data['filter_category'] = $this->lang->line('search');
			$data['filter_name'] = str_replace('_', ' ', $data['where_value']);
		}
		else
		{
		
			//count the rows
			if (!empty($data['where_value']))
			{
				
				if (!empty($data['where_column']))
				{
					$sql = 'WHERE comm_status = \'' . $data['where_value'] . '\' AND member_id = \'' . $data['where_column'] . '\'';
				}
				else
				{	
					$sql = 'WHERE comm_status = \'' . $data['where_value'] . '\'';
				}	
				
				$total_rows = $this->db_validation_model->_get_count('affiliate_commissions', $sql);
			}
			else
			{
				if (!empty($data['where_column']))
				{
					$sql = 'WHERE member_id = \'' . $data['where_column'] . '\'';
				
					$total_rows = $this->db_validation_model->_get_count('affiliate_commissions', $sql);
				}
				else
				{	
					$total_rows = $total_rows = $this->db->count_all('affiliate_commissions');
				}	
	
			}
		}
		
		//set pagination
		$data['where_value'] = $this->uri->segment(9,0);
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'invoices', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_commissions_table', $data, false, false);


	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_commission()
	{
		/*
		| -----------------------------------------
		| update commission
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_commission');
		$data['submit_url'] = jrox_admin_url().'commissions/update_commission/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_commission';
		$data['update_link'] = 'commissions';
		
		//run validation check
		if ($this->_check_commission() == false)
		{		
			//reload update commission form
			if (empty($_POST))
			{
				$mdata = $this->commissions_model->_get_commission_details((int)$this->uri->segment(4));
				
				$fdate = explode(':', $this->config->item('sts_admin_date_format'));
				$data['curdate'] = $fdate[0];
				$data['format_date'] = $fdate[1];
				
				//get num options
				$this->load->helper('number');
				$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
				
				//get number of levels
				for ($i = 1; $i<=$data['sts_affiliate_commission_levels']; $i++)
				{
					$data['commission_levels'][$i] = $i;
				}
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
		
					$this->validation->date =  date($fdate[1], $this->validation->date);
					
					if (!empty($mdata[0]['date_paid']))
					{
						$this->validation->date_paid =  date($fdate[1], $this->validation->date_paid);
					}
					
					//load template
					load_admin_tpl('admin', 'tpl_adm_manage_commission', $data);
				}
				else
				{
					redirect(ADMIN_ROUTE . '/commissions/view_commissions');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the commission into db
			$data = $this->commissions_model->_update_commission((int)$this->uri->segment(4));	
			
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('commission_updated_successfully'));	
			
			//redirect to member details form
			echo '<script>window.location = "' . jrox_admin_url() .'/commissions/update_commission/' . (int)$this->uri->segment(4) . '"</script>';
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_commission()
	{
		//set form validation rules
		
		$rules['comm_status'] = 'trim|required';
		$rules['approved'] = 'trim|required';
		$rules['date'] = 'trim|required';
		$rules['date_paid'] = 'trim';
		$rules['invoice_id'] = 'trim|integer|callback__check_invoice_id';
		
		if ($this->input->post('use_group_defaults') == 1)
		{
			$rules['commission_amount'] = 'trim|numeric';
		}
		else
		{
			$rules['commission_amount'] = 'trim|required|numeric';
		}
		
		$rules['sale_amount'] = 'trim|required|numeric';
		$rules['referring_affiliate'] = 'trim|required|callback__check_username';
		$rules['commission_level'] = 'trim|required|integer';
		$rules['referrer'] = 'trim|prep_url';
		$rules['trans_id'] = 'trim|max_length[255]';
		$rules['commission_notes'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['comm_status'] = $this->lang->line('status');
		$fields['approved'] = $this->lang->line('approved');
		$fields['date'] = $this->lang->line('date_created');
		$fields['date_paid'] = $this->lang->line('date_paid');
		$fields['invoice_id'] = $this->lang->line('invoice_id');
		
		$fields['sale_amount'] = $this->lang->line('sale_amount');
		$fields['commission_amount'] = $this->lang->line('commission_amount');
		$fields['referring_affiliate'] = $this->lang->line('referring_affiliate');
		$fields['commission_level'] = $this->lang->line('commission_level');
		$fields['referrer'] = $this->lang->line('referrer');
		$fields['trans_id'] = $this->lang->line('transaction_id');
		$fields['commission_notes'] = $this->lang->line('commission_notes');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_username()
	{
		if ($this->db_validation_model->_validate_field('members', 'username', $this->validation->referring_affiliate) == false)
		{
			$this->validation->set_message('_check_username', $this->lang->line('invalid_referring_affiliate'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_invoice_id()
	{
		$invoice_id = (int)($this->validation->invoice_id);
		
		if (!empty($invoice_id))
		{
			if ($this->db_validation_model->_validate_field('invoices', 'invoice_id', $this->validation->invoice_id) == false)
			{
				$this->validation->set_message('_check_invoice_id', $this->lang->line('invalid_invoice_id'));
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	
}
?>