<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - content_articles.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage content
|
*/

class Content_Articles extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load content model
		$this->load->model('content_model', 'content');
		
		//load css body style
		$this->config->set_item('css_body', 'ST');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/content_articles/view_content_articles');
	}
	
	// ------------------------------------------------------------------------
	
	function add_content_article()
	{
		/*
		| -----------------------------------------
		| add a new content_article
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_content');
		$data['submit_url'] = jrox_admin_url().'content_articles/add_content_article';
		$data['content_options'] = 'content_options';
		$data['manage_content'] = 'manage_content';
		
		
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
		
		//format url
		$data['url'] = '';
		
		//run admin validation check
		if ($this->_check_content_article() == false)
		{		
			//reload add content_article form
			if (empty($_POST))
			{
				$this->validation->id = '';
				$this->validation->category_id = '';
				$this->validation->article_id = '';
				$this->validation->date_published = date($fdate[1], time());
				$this->validation->content_type = '1';
				$this->validation->content_path = '';
				
				//get content categories
				$data['categories'] = $this->content->_get_content_categories();
				
				//get affiliate groups
				$this->load->model('groups_model');
				$aff_groups = $this->groups_model->_get_all_affiliate_groups();
				$data['aff_groups'] = format_array($aff_groups, 'group_id', 'aff_group_name');
				$data['article_to_groups'] = '';
				
				//check if html editor is disabled
				$data['disable_wysiwyg'] = _check_wysiwyg_disable('content_articles-add_content_article/');
					
				//initialize HTML editor
				$options = array(	'instance'	=> 'oEdit1',
									'type' => 'email',
									'content' => '',
									'height'	=> '400',
									'width'	=> '100%',
									'editor_type'	=> 'Default',
									'textarea'	=>	'content_body',
									'tags'	=> true,
								);
				$check_editor = _initialize_html_editor($options);
			
				$data['editor'] = $check_editor['editor'];
				$data['editor_path'] = $check_editor['editor_path'];
				
				//get membership products
				$this->load->model('products_model');
				$data['membership_products'] = $this->products_model->_get_membership_products(true, 'select_membership_product');
				
				//load template
				load_admin_tpl('admin', 'tpl_adm_manage_content_article', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the content_article into db
			$sdata = $this->content->_add_content_article($_POST);
			
			
			//format url
			$sdata['url'] =  _format_url(CONTENT_ROUTE, $sdata['article_id'], $sdata['content_title']);
			
			//run update services
			if ($sdata['ping'] == 1)
			{
				$this->load->model('xml_rpc_model', 'rpc');
				
				$this->rpc->_notify_update_services($sdata);
				
				if ($this->config->item('sts_content_enable_ping_fm') == 1)
				{
					//initialize PingFM class
					require_once(APPPATH.'/libraries/PingFM.php');
					
					$this->PingFM = new PingFM(JEM_PING_FM_DEVELOPER_KEY,  $this->config->item('sts_content_ping_fm_app_key'));
					
					if (!empty($_POST['status_update']))
					{
						$status_text = $this->input->post('status_update') . ' ' . $sdata['url'];
					}
					else
					{
						$status_text = $this->input->post('content_title') . ' ' . $sdata['url'];
					}
					
					$posted = $this->PingFM->post("microblog", $status_text);	
					//echo $posted; exit();
				}
			}
			
			if ($this->input->post('content_type') == 1)
			{
				if ($this->input->post('publish_wordpress') == 1)
				{
					//publish to WordPress
					
					$this->load->library('xmlrpc');
					//$this->xmlrpc->set_debug(TRUE);
					$this->xmlrpc->server($this->config->item('sts_content_wordpress_url'), 80);
					$this->xmlrpc->method('metaWeblog.newPost');

					$request = array(
									array(1, 'int'), 
									array($this->config->item('sts_content_wordpress_username'), 'string'),
									array($this->config->item('sts_content_wordpress_password'), 'string'),
									array(
											array(	'title' => $this->input->post('content_title'),
													'description'	=>	str_replace('{more}', '<!--more-->', $this->input->post('content_body')),
												), 	'struct',
										),
									array('publish', 'string'), 
									); 
							
				
					$this->xmlrpc->request($request);	
			
					if ($this->xmlrpc->send_request())
					{
						$id = $this->xmlrpc->display_response();
						//echo $this->xmlrpc->display_response();
						//now update the article with the blog ID
						$this->content->_update_blog_id($sdata['article_id'], $id);
						log_message('info', 'blog published to remote site successfully');
					}
					else
					{
						//log error
						//echo $this->xmlrpc->display_error();
						log_message('error', $this->xmlrpc->display_error());
					}
				}
			}
			
			if (!empty($sdata['article_id']))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('content_article_added_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url() .'content_articles/update_content_article/'. $sdata['article_id'] .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('content_articles', 'article_id', (int)$this->uri->segment(4), 'status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/content_articles/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('content_article_updated_successfully'));
				
				redirect(ADMIN_ROUTE . '/content_articles/view_content_articles');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function delete_content_article()
	{
		/*
		| --------------------------------------------
		| delete the content_article from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->content->_delete_content_article((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/content_articles/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/content_articles/view_content_articles');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_content_articles()
	{
		/*
		| -----------------------------------------
		| view content_articles
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['manage_content'] = 'manage_content';
		$data['page_title'] = $this->lang->line('manage_content');
		$data['height'] = '500';
		$data['width'] = '700';
		$data['jrox_controller'] = 'content_articles';
		$data['jrox_method'] = 'view_content_articles';
		$data['add_link'] = 'add_content';
		$data['add_content_article'] = 'add_content_article';
		$data['jrox_delete_method'] = 'content';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_content_articles', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get content_articles via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '700';
		$data['jrox_controller'] = 'content_articles';
		$data['jrox_method'] = 'update_content_article';
		$data['jrox_cat_method'] = 'update_content_category';
		$data['jrox_delete_method'] = 'content';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		
		//get content_articles
		$row = $this->content->_get_content_articles($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		$data['categories'] = $this->content->_get_content_categories();
		
		$this->load->model('groups_model');
		$aff_groups = $this->groups_model->_get_all_affiliate_groups();
		$data['affiliate_groups'] = format_array($aff_groups, 'group_id', 'aff_group_name');
		
		//get membership products
		$this->load->model('products_model');
		$data['memberships'] = $this->products_model->_get_membership_products();
		
				
		//add the data to the array
		$data['content_articles'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'content_articles', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_content_articles_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function update_articles()
	{
		/*
		| ---------------------------
		| mass update content articles
		| ---------------------------
		*/
		//echo '<pre>'; print_r($_POST); exit();
		//check if there are any users checked for update
		if ($this->input->post('change-status'))
		{			
			if (count($_POST['article']) > 0)
			{
				$this->content->_mass_update_articles($this->input->post('article'), $this->input->post('change-status'));
					   
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('content_updated_successfully'));
			}
		}
		
		
		
		echo '<script>self.parent.location.reload(true);</script>';	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_content_article()
	{
		/*
		| -----------------------------------------
		| add a new content_article
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_content');
		$data['submit_url'] = jrox_admin_url().'content_articles/update_content_article/' . $this->uri->segment(4);
		$data['content_options'] = 'content_options';
		$data['manage_content'] = 'manage_content';
		
		//format date
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
			
		//run admin validation check
		if ($this->_check_content_article() == false)
		{		
			//reload add content_article form
			if (empty($_POST))
			{
				//get content categories
				$data['categories'] = $this->content->_get_content_categories();
				
				$mdata = $this->content->_get_content_article_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//get affiliate groups
					$this->load->model('groups_model');
					$aff_groups = $this->groups_model->_get_all_affiliate_groups();
					$data['aff_groups'] = format_array($aff_groups, 'group_id', 'aff_group_name');
					
					//get permissions
					$data['article_to_groups'] = $this->content->_get_affiliate_groups((int)$this->uri->segment(4));
					
					$this->validation->content_body = html_entity_decode($this->validation->content_body);
					
					//format url 
					if ($this->uri->segment(4) == 1)
					{
						$data['url'] = '<a href="' . base_url() . '" target="_blank" class="show-url">' . limit_chars(base_url(), 120) . '</a>';
					}
					elseif ($this->validation->category_id == 5 || $this->validation->category_id == 6)
					{
						$data['url'] = $this->lang->line('members_area');
					}
					else
					{
						$u = _format_url(CONTENT_ROUTE . '/article', (int)$this->uri->segment(4), $mdata[0]['content_title']);
						
						$data['url'] ='<a href="' . $u . '" target="_blank" class="show-url">' . limit_chars($u, 120) . '</a>';
					}
					
					if (!empty($mdata[0]['date_published']))
					{
						$this->validation->date_published = date($fdate[1], $mdata[0]['date_published']);
					}
					else
					{
						$this->validation->date_published = date($fdate[1], now());
					}
					
					//check if html editor is disabled
					$data['disable_wysiwyg'] = _check_wysiwyg_disable('content_articles-update_content_article-' . $this->uri->segment(4));		
					
					
					//initialize HTML editor
					$options = array(	'instance'	=> 'oEdit1',
										'type' => 'email',
										'content' => $this->validation->content_body,
										'height'	=> '400',
										'width'	=> '100%',
										'editor_type'	=> 'Default',
										'textarea'	=>	'content_body',
										'tags'	=> true,
									);
					$check_editor = _initialize_html_editor($options);
				
					$data['editor'] = $check_editor['editor'];
					$data['editor_path'] = $check_editor['editor_path'];
					
					//get membership products
					$this->load->model('products_model');
					$data['membership_products'] = $this->products_model->_get_membership_products(true, 'select_membership_product');
					
					
					//load template
					load_admin_tpl('admin', 'tpl_adm_manage_content_article', $data);
				}
				else
				{
					//load add content_article page
					redirect(ADMIN_ROUTE . '/content_articles/view_content_articles');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the content_article into db
			$sdata = $this->content->_update_content_article((int)$this->uri->segment(4), $_POST);
			
			if (!empty($sdata))
			{
				//format url
				$sdata['url'] =  _format_url(CONTENT_ROUTE . '/article/', $sdata['article_id'], $sdata['content_title']);
				
				//run update services
				if ($sdata['ping'] == 1)
				{
					$this->load->model('xml_rpc_model', 'rpc');
					
					$this->rpc->_notify_update_services($sdata);
					
					if ($this->config->item('sts_content_enable_ping_fm') == 1)
					{
						//initialize PingFM class
						require_once(APPPATH.'/libraries/PingFM.php');
						
						$this->PingFM = new PingFM(JEM_PING_FM_DEVELOPER_KEY,  $this->config->item('sts_content_ping_fm_app_key'));
						
						if (!empty($_POST['status_update']))
						{
							$status_text = $this->input->post('status_update') . ' ' . $sdata['url'];
						}
						else
						{
							$status_text = $this->input->post('content_title') . ' ' . $sdata['url'];
						}
						
						$posted = $this->PingFM->post("microblog", $status_text);	
					}
				}
				
				if ($this->config->item('sts_content_enable_wordpress_publishing') == 1 && $this->input->post('publish_wordpress') == 1)
				{
					//publish to WordPress
					
					//get the remote blog ID
					$blog_id = $this->db_validation_model->_get_details('content_articles', 'remote_blog_id', 'article_id', (int)$this->uri->segment(4));
					
					$this->load->library('xmlrpc');
					//$this->xmlrpc->set_debug(TRUE);
					$this->xmlrpc->server($this->config->item('sts_content_wordpress_url'), 80);
					$this->xmlrpc->method('metaWeblog.editPost');

					$request = array(
									array($blog_id[0]['remote_blog_id'], 'int'), 
									array($this->config->item('sts_content_wordpress_username'), 'string'),
									array($this->config->item('sts_content_wordpress_password'), 'string'),
									array(
											array(	'title' => $this->input->post('content_title'),
													'description'	=>	str_replace('{more}', '<!--more-->', $this->input->post('content_body')),
												), 	'struct',
										),
									array('publish', 'string'), 
									); 
							
				
					$this->xmlrpc->request($request);	
			
					if ($this->xmlrpc->send_request())
					{
						log_message('info', 'blog published to remote site successfully');
					}
					else
					{
						//log error
						//echo $this->xmlrpc->display_error();
						log_message('error', $this->xmlrpc->display_error());
					}
				}
				
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('content_article_updated_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'content_articles/update_content_article/'. (int)$this->uri->segment(4) .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function update_wysiwyg()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->uri->segment(4) == 'disable')
		{
			$this->session->set_userdata('admin_disable_wysiwyg', true);	
		}
		else
		{
			$this->session->set_userdata('admin_disable_wysiwyg', false);	
		}
		
		$url = str_replace('-','/', $this->uri->segment(5));
		
		redirect_301(jrox_admin_url(). $url, true, false);
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	// ------------------------------------------------------------------------	
	
	function _check_date_published()
	{
		if ($this->validation->date_published)
		{
			$this->validation->set_message('_check_date_published', $this->lang->line('invalid_date_published_format'). ': ' . $this->validation->date_published);
			
			$a = explode('/', $this->validation->date_published);
			if (count($a) != 3)
			{
				return false;
			}
			elseif (checkdate($a[0], $a[1], $a[2]) == false)
			{
				return false;
			}
		}
		
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_file_path()
	{
		//first check the extension
		$path_parts = pathinfo($this->validation->content_path);
		
		$allowed_ext = array('php', 'phtml', 'html', 'htm');
		
		if (!in_array($path_parts['extension'], $allowed_ext))
		{
			$this->validation->set_message('_check_file_path', $this->lang->line('invalid_file_ext'));
			return false;
		}
		
		if (!file_exists($this->validation->content_path))
		{
			
			$this->validation->set_message('_check_file_path', $this->lang->line('invalid_file_path'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_membership()
	{		
		if (!($this->validation->membership_id))
		{
			
			$this->validation->set_message('_check_membership', $this->lang->line('membership_product_required'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _enable_affiliate_group_permissions()
	{		
		if (empty($_POST['content_permissions']))
		{
			
			$this->validation->set_message('_enable_affiliate_group_permissions', $this->lang->line('affiliate_group_required'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_content_article()
	{
		//set form validation rules
		
		$rules['status'] = 'trim';
		$rules['content_tags'] = 'trim';
		
		if ($this->uri->segment(4) > 1 || $this->uri->segment(3) == 'add_content_article')
		{
			$rules['content_title'] = 'trim|required|min_length[3]|max_length[255]';
		}
		else
		{
			$rules['content_title'] = 'trim|min_length[3]|max_length[255]';
		}
		
		$rules['date_published'] = 'trim|required|callback__check_date_published';
		$rules['ping'] = 'trim|integer';
		$rules['content_description'] = 'trim|max_length[255]';
		$rules['content_type'] = 'trim|required|integer';
		
		if ($this->input->post('content_type') == '3')
		{
			$rules['content_path'] = 'trim|required|callback__check_file_path';
		}
		else
		{
			if ($this->uri->segment(4) > 1 || $this->uri->segment(3) == 'add_content_article')
			{
				$rules['content_body'] = 'trim|required|min_length[10]';
			}
			else
			{
				$rules['content_body'] = 'trim|min_length[10]';
			}
			
		}
		
		if ($this->input->post('require_membership') == 1)
		{
			$rules['membership_id'] = 'trim|required|callback__check_membership';
		}	
		
		if ($this->input->post('enable_affiliate_group_permissions') == 1)
		{
			$rules['enable_affiliate_group_permissions'] = 'trim|required|callback__enable_affiliate_group_permissions';
		}	
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['status'] = $this->lang->line('status');
		$fields['content_tags'] = $this->lang->line('tags');
		$fields['content_title'] = $this->lang->line('title');
		$fields['content_body'] =  $this->lang->line('content_body');
		$fields['date_published'] = $this->lang->line('publish_date');
		$fields['ping'] = $this->lang->line('update_services');
		$fields['content_type'] = $this->lang->line('content_type');
		$fields['content_description'] = $this->lang->line('meta_description');
		$fields['content_path'] = $this->lang->line('content_path');
		$fields['require_membership'] = $this->lang->line('require_membership');
		$fields['membership_id'] = $this->lang->line('membership_id');
		$fields['content_permissions'] = $this->lang->line('restrict_access_to');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
}
?>