<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - countries.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage countries
|
*/

class Countries extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load countries model
		$this->load->model('zones_model');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/countries/view_countries');
	}
	
	// ------------------------------------------------------------------------
	
	function add_country()
	{
		/*
		| -----------------------------------------
		| add a new member
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_country');
		$data['submit_url'] = jrox_admin_url().'countries/add_country';
		$data['update_link'] = 'countries';
		$data['add_link'] = 'add_country';
		
		$this->validation->country_id_redirect = '';
		$this->validation->country_id = '';
		
		//run admin validation check
		if ($this->_check_country() == false)
		{		
			//reload add country form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_country', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the country into db
			$data = $this->zones_model->_add_country();		
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_country_success'));
			
			//ajax message
			echo '<div class="success" onclick="parent.location.href = \'' . jrox_admin_url().'countries/view_countries\';" style="cursor:pointer;">' .$this->lang->line('country') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';			
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_country()
	{
		/*
		| --------------------------------------------
		| delete the country from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->zones_model->_delete_country((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/countries/table/' . $this->config->item('cache_bx'));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/countries/view_countries');
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function update_countries()
	{
		/*
		| ---------------------------
		| mass update countries
		| ---------------------------
		*/
		
		//check if there are any countries checked for update
		if ($this->input->post('country') AND count($this->input->post('country')) > 0)
		{
			$this->zones_model->_change_status($this->input->post('country'), $this->input->post('change-status'));
		}
		
		//set flash data
		//$this->session->set_flashdata('success', $this->lang->line('countries_updated_successfully'));
		echo '<script>self.parent.location.reload(true);</script>';	
	}
	
	// ------------------------------------------------------------------------
	
	function view_countries()
	{
		/*
		| -----------------------------------------
		| view countries
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_countries');
		$data['sub_title'] = $this->lang->line('manage_countries');
		$data['add_link'] = 'add_country';
		$data['update_link'] = 'countries';
		$data['countries_table'] = 'countries-table';
		$data['height'] = '400';
		$data['width'] = '400';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_countries', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get countries via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['sort_name'] = 'country_name';
		$data['header_name'] = 'countries';
		$data['height'] = '400';
		$data['width'] = '400';
		
		//get countries
		$row = $this->zones_model->_get_countries($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		if (empty($row))
		{
			$row[0] = array(
						'country_id' => 0,
						'country_name' => $this->lang->line('no_countries_found'),
						);
		}
		
		//add the data to the array
		$data['countries'] = $row;
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'countries', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_countries_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_country()
	{
		/*
		| -----------------------------------------
		| add a new member
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_country');
		$data['submit_url'] = jrox_admin_url().'countries/update_country';
		$data['add_link'] = 'update_country';
		$data['update_link'] = 'countries';
		$data['countries_table'] = 'countries-table';
		
		$this->validation->country_id_redirect = '<input type="hidden" id="country_id" name="country_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->country_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_country() == false)
		{		
			//reload add country form
			if (empty($_POST))
			{
				$mdata = $this->zones_model->_get_country_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_country', $data);
				}
				else
				{
					//load add member page
					redirect(ADMIN_ROUTE . '/countries/view_countries');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the country into db
			
			$data = $this->zones_model->_update_country((int)$this->uri->segment(4));	
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_country_success'));
			
			//ajax message
			echo '<div class="success" onclick="parent.location.href = \'' . jrox_admin_url().'countries/view_countries\';" style="cursor:pointer;">' . $this->lang->line('update_country_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_tiers()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
	
		foreach ($data as $k => $v)
		{
			if (strstr($k, "country") == true) 
			{
				$rules[$k] = 'trim|required|numeric';
				$fields[$k] = $k ;
			}
		}
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_country()
	{
		//set form validation rules
		
		$rules['country_name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['country_iso_code_2'] = 'trim|required|min_length[2]|max_length[2]';
		$rules['country_iso_code_3'] = 'trim|required|min_length[3]|max_length[3]';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['country_name'] = $this->lang->line('country_name');
		$fields['country_iso_code_2'] = $this->lang->line('iso_2');
		$fields['country_iso_code_3'] = $this->lang->line('iso_3');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
}
?>