<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - currencies.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage currencies
|
*/

class Currencies extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load currencies model
		$this->load->model('currencies_model');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/currencies/view_currencies');
	}
	
	// ------------------------------------------------------------------------
	
	function add_currency()
	{
		/*
		| -----------------------------------------
		| add a new currency
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_currency');
		$data['submit_url'] = jrox_admin_url().'currencies/add_currency';
		
		//run admin validation check
		if ($this->_check_currency() == false)
		{		
			//reload add currency form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_currency', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the currency into db
			$id = $this->currencies_model->_add_currency();		

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('currency') . ' ' . $id . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_currency()
	{
		/*
		| --------------------------------------------
		| delete the currency from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->currencies_model->_delete_currency((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/currencies/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/currencies/view_currencies');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_currencies()
	{
		/*
		| -----------------------------------------
		| view currencies
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_currencies');
		$data['height'] = '350';
		$data['width'] = '600';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_currencies', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get currencies via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '350';
		$data['width'] = '600';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get currencies
		$row = $this->currencies_model->_get_currencies($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		if (empty($row))
		{
			$row[0] = array(
						'currency_id' => 0,
						'currency_name' => $this->lang->line('no_currencies_found'),
						'currency_image' => '',
						'total' => 0,
						);
		}
	 
		//add the data to the array
		$data['currencies'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'currencies', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_currencies_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function set_default()
	{
		//set the default currency
		$data = $this->security_model->_load_config('admin');
		
		$code = $this->uri->segment(4);
		
		$sdata = array('sts_store_default_currency' => $code);
		
		$this->db_validation_model->_update_db_settings($sdata);
		
		redirect(ADMIN_ROUTE . '/currencies/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
	}
	
	// ------------------------------------------------------------------------
	
	function run_update()
	{
		//run currency updater
		
		$data = $this->security_model->_load_config('admin');
		
		$msg = $this->currencies_model->_update_currencies();
		
		echo $msg;
	}
	
	// ------------------------------------------------------------------------
	
	function update_currencies()
	{
		//show the currency updater page first
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		$data['page_title'] = $this->lang->line('update_currencies');
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_update_currencies', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function update_currency()
	{
		/*
		| -----------------------------------------
		| add a new currency
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_currency');
		$data['submit_url'] = jrox_admin_url().'currencies/update_currency/' . (int)$this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_currency() == false)
		{		
			//reload add currency form
			if (empty($_POST))
			{
				$mdata = $this->currencies_model->_get_currency_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_currency', $data);
				}
				else
				{
					//load add currency page
					redirect(ADMIN_ROUTE . '/currencies/view_currencies');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the currency into db
			if ($this->currencies_model->_update_currency((int)$this->uri->segment(4)))
			{
			
				//ajax message
				echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_currency_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
				exit();	
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_currency()
	{
		//set form validation rules
		
		$rules['title'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['code'] = 'trim|required|exact_length[3]';
		$rules['symbol_left'] = 'trim|max_length[15]';
		$rules['symbol_right'] = 'trim|max_length[15]';
		$rules['decimal_point'] = 'trim|max_length[15]';
		$rules['thousands_point'] = 'trim|max_length[15]';
		$rules['decimal_places'] = 'trim|numeric';
		$rules['value'] = 'trim|required|numeric';
		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['title'] = $this->lang->line('currency_name');
		$fields['code'] = $this->lang->line('code');
		$fields['symbol_left'] = $this->lang->line('symbol_left');
		$fields['symbol_right'] = $this->lang->line('symbol_right');
		$fields['decimal_point'] = $this->lang->line('decimal_point');
		$fields['thousands_point'] = $this->lang->line('thousands_point');
		$fields['decimal_places'] = $this->lang->line('decimal_places');
		$fields['value'] = $this->lang->line('amount');
		
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
}
?>