<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - email_send.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to send, queue, schedule single emails to
| members
|
*/

class Email_Send extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load emailing_model
		$this->load->model('emailing_model');
		
		$this->load->model('mailing_lists_model');
		
		//load css body style
		$this->config->set_item('css_body', 'DE');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE);
	}
	
	// ------------------------------------------------------------------------
	
	function member()
	{
		/*
		| --------------------------------------------
		| email_member
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('send_email');
		$data['col_class'] = 'span-17';
		$data['module_name'] = 'email_send-member';
		$data['submit_url'] = jrox_admin_url().'email_send/member/' . $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_email('member') == false)
		{		
			//reload add member form
			if (empty($_POST))
			{
				//get email address
				if ($this->uri->segment(4) > 0)
				{
					$q = $this->db_validation_model->_get_details('members', 'primary_email', 'member_id', $this->uri->segment(4));
					
					$this->validation->recipient_email = $q[0]['primary_email'];
				}
				
				//check if load template is enabled
				
				if ($this->uri->segment(5) == 'template')
				{
					$template = $this->db_validation_model->_get_details('email_templates', '*', 'id', (int)$this->uri->segment(6));
					
					$this->validation->sender_name = $template[0]['email_template_from_name'];
					$this->validation->sender_email = $template[0]['email_template_from_email'];
					$this->validation->subject = $template[0]['email_template_subject'];
					$this->validation->text_body = $template[0]['email_template_body_text'];
					$this->validation->html_body = $template[0]['email_template_body_html'];
					$this->validation->email_type = $template[0]['email_template_html'];
				}
				
				$fdate = explode(':', $this->config->item('sts_admin_date_format'));
				$data['curdate'] = $fdate[0];
				
				//initialize HTML editor
				$options = array(	'instance'	=> 'oEdit1',
									'type' => 'email',
									'content' => $this->validation->html_body,
									'height'	=> '400',
									'width'	=> '100%',
									'editor_type'	=> 'description',
									'textarea'	=>	'html_body',
									'tags'	=> true,
								);
				$check_editor = _initialize_html_editor($options);
			
				$data['editor'] = $check_editor['editor'];
				$data['editor_path'] = $check_editor['editor_path'];
				
				//get custom templates
				$templates = $this->mailing_lists_model->_get_custom_templates();
					
				$data['template_options'] = array(0);
				$key = array(0);
				$value = array($this->lang->line('load_custom_template'));
				
				if (!empty($templates))
				{
					foreach ($templates as $k => $v)
					{
						if ($k > 0)
						{
							$new = jrox_admin_url(). '/email_send/member/' . (int)$this->uri->segment(4) . '/template/' . $k;
							array_push($key, $new);
							array_push($value, $v);
						}	
					}	
					
					$data['template_options'] = combine_array($key, $value);
				}	
				else
				{
					$data['template_options'] = array('0' => $this->lang->line('load_custom_template'));
				}
				//load template
				load_form('admin', 'tpl_adm_email_send', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error">' . $this->validation->error_string . '</div>';
				exit();
			}		
			
		}
		else
		{	
			$sdata = $this->db_validation_model->_clean_data($_POST);
			
			//get the member data
			$member = $this->db_validation_model->_get_details('members', '*', 'member_id', (int)$this->uri->segment(4));
			
			$data = $this->emailing_model->_format_email($sdata, 'member', $member[0]);
			
			if (isset($_POST['queue-email']))
			{
				//queue the email
				//send it now
				if ($this->emailing_model->_queue_email('admin', $data))
				{
					echo '<div class="success">' . $this->lang->line('email_queued_successfully') . '</div>';
					exit();
				}
			}
			else
			{
				//send it now
				if ($this->emailing_model->_send_email('admin', $data))
				{
					echo '<div class="success">' . $this->lang->line('email_sent_successfully') . '</div>';
					exit();
				}
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function send_mass_email()
	{
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//run admin validation check
		if ($this->_check_mass_email() == false)
		{		
			//ajax form
			echo '<div class="error">' . $this->validation->error_string . '</div>';
			exit();
		}
		else
		{
			//clean email data
			$sdata = $this->db_validation_model->_clean_data($_POST);
			
			//get all the users
			$users = $this->emailing_model->_get_list_users($sdata['list_ids']);
			
			if (!empty($users))
			{
				//send it now
				if ($this->emailing_model->_queue_mass_email('admin', $sdata, $users))
				{
					echo '<div class="success">' . $this->lang->line('email_queued_successfully') . '</div>';
					exit();
				}
			}
			else
			{
				//ajax form
				echo '<div class="error">' . $this->lang->line('no_list_users_found') . '</div>';
				exit();
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function mailing_list()
	{
		/*
		| --------------------------------------------
		| email_member
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check if there are any mailing lists selected
		if (empty($_POST['mailing_lists']))
		{
			show_error($this->lang->line('no_lists_selected'));
		}
		else
		{
			$data['list_ids'] = implode(',', $_POST['mailing_lists']);
		}
		
		//set page title
		$data['page_title'] = $this->lang->line('send_email');
		$data['col_class'] = 'span-23';
		$data['module_name'] = 'email_send-mailing_list';
		$data['submit_url'] = jrox_admin_url().'email_send/send_mass_email';
		
		$data['lists'] = $this->emailing_model->_get_mailing_lists($_POST['mailing_lists']);
		
		if (!empty($_POST['email_template']))
		{
			$template = $this->db_validation_model->_get_details('email_templates', '*', 'id', (int)$this->input->post('email_template'));
			
			$this->validation->sender_name = $template[0]['email_template_from_name'];
			$this->validation->sender_email = $template[0]['email_template_from_email'];
			$this->validation->subject = $template[0]['email_template_subject'];
			$this->validation->text_body = $template[0]['email_template_body_text'];
			$this->validation->html_body = $template[0]['email_template_body_html'];
			$this->validation->email_type = $template[0]['email_template_html'];
		}
		else
		{
		
			$this->validation->sender_name = $data['sts_store_name'];
			$this->validation->sender_email = $data['sts_store_email'];
			$this->validation->subject = '';
			$this->validation->text_body = '';
			$this->validation->html_body = '';
			$this->validation->email_type = '';
		}
		
		
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
		
		//initialize HTML editor
		$options = array(	'instance'	=> 'oEdit1',
							'type' => 'email',
							'content' => $this->validation->html_body,
							'height'	=> '400',
							'width'	=> '100%',
							'editor_type'	=> 'description',
							'textarea'	=>	'html_body',
							'tags'	=> true,
						);
		$check_editor = _initialize_html_editor($options);
	
		$data['editor'] = $check_editor['editor'];
		$data['editor_path'] = $check_editor['editor_path'];
						
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_mass_email_send', $data);
				
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_mass_email()
	{
		$rules['list_ids'] = 'trim|required';
		
		if ($this->input->post('email_type') == 'text')
		{
			$rules['text_body'] = 'trim|required|min_length[25]';
			
		}
		else
		{
			$rules['html_body'] = 'trim|required|min_length[25]';
		}
		
		$rules['cc'] = 'trim|valid_emails';
		$rules['bcc'] = 'trim|valid_emails';
		$rules['email_type'] = 'trim|required';
		$rules['sender_name'] = 'trim|required';
		$rules['sender_email'] = 'trim|required|valid_email';
		
		$this->validation->set_rules($rules);
		
		$fields['list_ids'] = $this->lang->line('list_ids');
		$fields['text_body'] = $this->lang->line('text_body');
		$fields['html_body'] = $this->lang->line('html_body');
		
		$fields['email_type'] = $this->lang->line('email_type');
		$fields['recipient_email'] = $this->lang->line('from_email');
		$fields['recipient_name'] = $this->lang->line('from_name');
		
		$fields['cc'] = $this->lang->line('cc');
		$fields['bcc'] = $this->lang->line('bcc');
		$fields['email_type'] = $this->lang->line('email_type');
		$fields['sender_name'] = $this->lang->line('from_name');
		$fields['sender_email'] = $this->lang->line('from_email');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_email($type = '')
	{
		$rules['subject'] = 'trim|required|min_length[5]|max_length[255]';
		$rules['recipient_email'] = 'trim|required|valid_emails';
		$rules['html_body'] = 'trim|required|min_length[20]';
		
	
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['subject'] = $this->lang->line('subject');
		$fields['text_body'] = $this->lang->line('content_text');
		$fields['html_body'] = $this->lang->line('html_body');
		$fields['recipient_email'] = $this->lang->line('email');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
}
?>