<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - email_templates.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage email templates
|
*/

class Email_Templates extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load email_templates model
		$this->load->model('emailing_model');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/email_templates/view_email_templates');
	}
	
	// ------------------------------------------------------------------------
	
	function add_email_template()
	{
		/*
		| -----------------------------------------
		| add a new email_template
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_email_template');
		$data['submit_url'] = jrox_admin_url().'email_templates/add_email_template';
		$data['update_link'] = 'email_templates';
		$data['add_link'] = 'add_email_template';
		
		//run admin validation check
		if ($this->_check_email_template() == false)
		{		
			//reload add email_template form
			if (empty($_POST))
			{
				$this->validation->id = '';
				$this->validation->email_template_type = 'custom';
				
				//initialize HTML editor
				$options = array(	'instance'	=> 'oEdit1',
									'type' => 'email',
									'content' => '',
									'height'	=> '400',
									'width'	=> '100%',
									'editor_type'	=> 'description',
									'textarea'	=>	'email_template_body_html',
									'tags'	=> true,
								);
				$check_editor = _initialize_html_editor($options);
			
				$data['editor'] = $check_editor['editor'];
				$data['editor_path'] = $check_editor['editor_path'];
				
				$this->validation->email_template_from_name = $data['sts_store_name'];
				$this->validation->email_template_from_email = $data['sts_store_email'];
				
				//load template
				load_admin_tpl('admin', 'tpl_adm_manage_email_template', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the email_template into db
			$id = $data = $this->emailing_model->_add_email_template();
			
			if (!empty($id))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('email_template_added_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'email_templates/update_email_template/'. $id .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_email_template()
	{
		/*
		| --------------------------------------------
		| delete the email_template from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->emailing_model->_delete_email_template((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/email_templates/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/email_templates/view_email_templates');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_email_templates()
	{
		/*
		| -----------------------------------------
		| view email_templates
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_email_templates');
		$data['height'] = '500';
		$data['width'] = '700';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_email_templates', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get email_templates via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '700';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get email_templates
		$row = $this->emailing_model->_get_email_templates($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
	 
		//add the data to the array
		$data['email_templates'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'email_templates', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_email_templates_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_email_template()
	{
		/*
		| -----------------------------------------
		| add a new email_template
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_email_template');
		$data['submit_url'] = jrox_admin_url().'email_templates/update_email_template/' . $this->uri->segment(4);
		$data['add_link'] = 'update_email_template';
		$data['update_link'] = 'email_templates';
		
		$this->validation->email_template_id_redirect = '<input type="hidden" id="email_template_id" name="email_template_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->email_template_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_email_template() == false)
		{		
			//reload add email_template form
			if (empty($_POST))
			{
				$mdata = $this->emailing_model->_get_email_template_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
						
					//initialize HTML editor
					$options = array(	'instance'	=> 'oEdit1',
										'type' => 'email',
										'content' => $this->validation->email_template_body_html,
										'height'	=> '400',
										'width'	=> '100%',
										'editor_type'	=> 'description',
										'textarea'	=>	'email_template_body_html',
										'tags'	=> true,
									);
					$check_editor = _initialize_html_editor($options);
				
					$data['editor'] = $check_editor['editor'];
					$data['editor_path'] = $check_editor['editor_path'];
					
					//load template
					load_admin_tpl('admin', 'tpl_adm_manage_email_template', $data);
				}
				else
				{
					//load add email_template page
					redirect(ADMIN_ROUTE . '/email_templates/view_email_templates');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the email_template into db
			if ($this->emailing_model->_update_email_template((int)$this->uri->segment(4)))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('email_template_updated_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'email_templates/update_email_template/'. (int)$this->uri->segment(4) .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_email_template()
	{
		//set form validation rules
		
		$rules['email_template_html'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['email_template_subject'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['email_template_type'] = 'trim';
		
		//check if template is a custom template
		if ($this->input->post('email_template_type') == 'custom')
		{
			$rules['email_template_name'] = 'trim|required|min_length[5]|max_length[50]';
		}
		
		if ($this->input->post('email_template_html') == 'text')
		{
			$rules['email_template_body_text'] = 'trim|required|min_length[25]';
		}
		
		if ($this->input->post('email_template_html') == 'html')
		{
			$rules['email_template_body_html'] = 'trim|required|min_length[25]';
		}
		
		$rules['email_template_from_name'] = 'trim|required|min_length[3]|max_length[50]';
		$rules['email_template_from_email'] = 'trim|required|valid_email';
		$rules['email_template_cc'] = 'trim|valid_emails';
		$rules['email_template_bcc'] = 'trim|valid_emails';
		$rules['email_template_description'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['email_template_html'] = $this->lang->line('email_template_type');
		$fields['email_template_subject'] = $this->lang->line('subject');
		$fields['email_template_type'] = $this->lang->line('email_template_type');
		$fields['email_template_name'] = $this->lang->line('email_template_name');
		$fields['email_template_body_text'] = $this->lang->line('text_template');
		$fields['email_template_body_html'] = $this->lang->line('html_template');
		$fields['email_template_from_name'] = $this->lang->line('from_name');
		$fields['email_template_from_email'] = $this->lang->line('from_email');
		$fields['email_template_cc'] = $this->lang->line('cc');
		$fields['email_template_bcc'] = $this->lang->line('bcc');
		$fields['email_template_description'] =  $this->lang->line('description');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
}
?>