<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - faq_articles.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage faq
|
*/

class Faq_articles extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load faq model
		$this->load->model('faq_model', 'faq');
		
		//load css body style
		$this->config->set_item('css_body', 'ST');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/faq_articles/view_faq_articles');
	}
	
	// ------------------------------------------------------------------------
	
	function add_faq_article()
	{
		/*
		| -----------------------------------------
		| add a new faq_article
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_faq');
		$data['submit_url'] = jrox_admin_url().'faq_articles/add_faq_article';
		$data['content_options'] = 'faq_options';
		$data['manage_content'] = 'manage_faq';
		
		
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
		
		//format url
		$data['url'] = '';
		
		//run admin validation check
		if ($this->_check_faq_article() == false)
		{		
			//reload add faq_article form
			if (empty($_POST))
			{
				$this->validation->id = '';
				$this->validation->category_id = '';
				$this->validation->article_id = '';
				$this->validation->date_published = date($fdate[1], time());
				$this->validation->content_body = html_entity_decode($this->validation->content_body);
				//get faq categories
				$data['categories'] = $this->faq->_get_faq_categories();
				
				//check if html editor is disabled
				$data['disable_wysiwyg'] = _check_wysiwyg_disable('faq_articles-add_faq_article');		
				
				//initialize HTML editor
				$options = array(	'instance'	=> 'oEdit1',
									'type' => 'email',
									'content' => '',
									'height'	=> '400',
									'width'	=> '100%',
									'editor_type'	=> 'Default',
									'textarea'	=>	'content_body',
									'tags'	=> true,
								);
				$check_editor = _initialize_html_editor($options);
			
				$data['editor'] = $check_editor['editor'];
				$data['editor_path'] = $check_editor['editor_path'];
				
				//load template
				load_admin_tpl('admin', 'tpl_adm_manage_faq_article', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the faq_article into db
			$id = $this->faq->_add_faq_article();
			
			if (!empty($id))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('faq_article_added_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'faq_articles/update_faq_article/'. $id .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('faq_articles', 'article_id', (int)$this->uri->segment(4), 'status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/faq_articles/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('faq_article_updated_successfully'));
				
				redirect(ADMIN_ROUTE . '/faq_articles/view_faq_articles');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function delete_faq_article()
	{
		/*
		| --------------------------------------------
		| delete the faq_article from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->faq->_delete_faq_article((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/faq_articles/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/faq_articles/view_faq_articles');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_faq_articles()
	{
		/*
		| -----------------------------------------
		| view faq_articles
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['manage_content'] = 'manage_faq';
		$data['page_title'] = $this->lang->line('manage_faq');
		$data['height'] = '500';
		$data['width'] = '700';
		$data['jrox_controller'] = 'faq_articles';
		$data['jrox_method'] = 'view_faq_articles';
		$data['add_link'] = 'add_faq';
		$data['add_content_article'] = 'add_faq_article';
		$data['jrox_delete_method'] = 'faq';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_content_articles', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get faq_articles via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '700';
		$data['jrox_controller'] = 'faq_articles';
		$data['jrox_method'] = 'update_faq_article';
		$data['jrox_cat_method'] = 'update_faq_category';
		$data['jrox_delete_method'] = 'faq';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get faq_articles
		$row = $this->faq->_get_faq_articles($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		//add the data to the array
		$data['content_articles'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'faq_articles', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_faq_articles_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_faq_article()
	{
		/*
		| -----------------------------------------
		| add a new faq_article
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_faq');
		$data['submit_url'] = jrox_admin_url().'faq_articles/update_faq_article/' . $this->uri->segment(4);
		$data['content_options'] = 'faq_options';
		$data['manage_content'] = 'manage_faq';
		
		//format date
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
			
		//run admin validation check
		if ($this->_check_faq_article() == false)
		{		
			//reload add faq_article form
			if (empty($_POST))
			{
				//get faq categories
				$data['categories'] = $this->faq->_get_faq_categories();
				
				$mdata = $this->faq->_get_faq_article_details((int)$this->uri->segment(4));
				
				//format url
				$data['url'] = base_url() . FAQ_ROUTE . '/view/category_id/' . $mdata[0]['category_id'];
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$this->validation->date_published = date($fdate[1], $mdata[0]['date_published']);
					
					//check if html editor is disabled
					$data['disable_wysiwyg'] = _check_wysiwyg_disable('faq_articles-update_faq_article-' . $this->uri->segment(4));		
						
					//initialize HTML editor
					$options = array(	'instance'	=> 'oEdit1',
										'type' => 'email',
										'content' => $this->validation->content_body,
										'height'	=> '400',
										'width'	=> '100%',
										'editor_type'	=> 'Default',
										'textarea'	=>	'content_body',
										'tags'	=> true,
									);
					$check_editor = _initialize_html_editor($options);
				
					$data['editor'] = $check_editor['editor'];
					$data['editor_path'] = $check_editor['editor_path'];
					
					//load template
					load_admin_tpl('admin', 'tpl_adm_manage_faq_article', $data);
				}
				else
				{
					//load add faq_article page
					redirect(ADMIN_ROUTE . '/faq_articles/view_faq_articles');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the faq_article into db
			if ($this->faq->_update_faq_article((int)$this->uri->segment(4)))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('faq_article_updated_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'faq_articles/update_faq_article/'. (int)$this->uri->segment(4) .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	// ------------------------------------------------------------------------	
	
	function _check_date_published()
	{
		if ($this->validation->date_published)
		{
			$this->validation->set_message('_check_date_published', $this->lang->line('invalid_date_published_format'). ': ' . $this->validation->date_published);
			
			$a = explode('/', $this->validation->date_published);
			if (count($a) != 3)
			{
				return false;
			}
			elseif (checkdate($a[0], $a[1], $a[2]) == false)
			{
				return false;
			}
		}
		
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_faq_article()
	{
		//set form validation rules
		
		$rules['status'] = 'trim';
		$rules['content_tags'] = 'trim';
		$rules['content_title'] = 'trim|required|min_length[3]|max_length[255]';
		$rules['content_body'] = 'trim|required|min_length[10]';
		$rules['date_published'] = 'trim|required|callback__check_date_published';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['status'] = $this->lang->line('status');
		$fields['content_tags'] = $this->lang->line('tags');
		$fields['content_title'] = $this->lang->line('title');
		$fields['content_body'] =  $this->lang->line('content_body');
		$fields['date_published'] = $this->lang->line('publish_date');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
}
?>