<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - faq_categories.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage faq
|
*/

class Faq_Categories extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load faq model
		$this->load->model('faq_cat_model', 'faq');
		
		//load css body style
		$this->config->set_item('css_body', 'ST');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/faq_categories/view_faq_categories');
	}
	
	// ------------------------------------------------------------------------
	
	function add_faq_category()
	{
		/*
		| -----------------------------------------
		| add a new faq_category
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_faq');
		$data['submit_url'] = jrox_admin_url().'faq_categories/add_faq_category';
		
		//format url
		$data['url'] = '';
		
		//run admin validation check
		if ($this->_check_faq_category() == false)
		{		
			//reload add faq_category form
			if (empty($_POST))
			{
				$this->validation->category_id = '';
			
				//load template
				load_form('admin', 'tpl_adm_manage_content_category', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the faq_category into db
			$id = $this->faq->_add_faq_category();
			
			if (!empty($id))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('faq_category_added_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'faq_categories/update_faq_category/'. $id .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_faq_category()
	{
		/*
		| --------------------------------------------
		| delete the faq_category from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->faq->_delete_faq_category((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/faq_categories/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/faq_categories/view_faq_categories');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_faq_categories()
	{
		/*
		| -----------------------------------------
		| view faq_categories
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_faq_categories');
		$data['height'] = '250';
		$data['width'] = '500';
		$data['jrox_method'] = 'faq';
		$data['title'] = 'manage_faq_categories';
		$data['add_link'] = 'add_faq_category';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_content_categories', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get faq_categories via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '250';
		$data['width'] = '500';
		$data['jrox_method'] = 'faq';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get faq_categories
		$row = $this->faq->_get_faq_categories($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		//add the data to the array
		$data['content_categories'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'faq_categories', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_content_categories_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_faq_category()
	{
		/*
		| -----------------------------------------
		| add a new faq_category
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_faq_category');
		$data['submit_url'] = jrox_admin_url().'faq_categories/update_faq_category/' . $this->uri->segment(4);
			
		//run admin validation check
		if ($this->_check_faq_category() == false)
		{		
			//reload add faq_category form
			if (empty($_POST))
			{
				//get faq categories
				$data['categories'] = $this->faq->_get_faq_categories();
				
				$mdata = $this->faq->_get_faq_category_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_content_category', $data);
				}
				else
				{
					//load add faq_category page
					redirect(ADMIN_ROUTE . '/faq_categories/view_faq_categories');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the faq_category into db
			if ($this->faq->_update_faq_category((int)$this->uri->segment(4)))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('faq_category_updated_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'faq_categories/update_faq_category/'. (int)$this->uri->segment(4) .'"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_faq_category()
	{
		//set form validation rules
	
		$rules['category_name'] = 'trim|required|min_length[2]|max_length[255]';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['category_name'] = $this->lang->line('faq_category');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
}
?>