<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - forms.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage forms
|
*/

class Forms extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load forms model
		$this->load->model('forms_model');
		
		//load css body style
		$this->config->set_item('css_body', 'OP');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/forms/view_forms');
	}
	
	// ------------------------------------------------------------------------
	
	function view_forms()
	{	
		/*
		| ---------------------
		| get form fields
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_forms');
		
		//get forms
		$config= $this->forms_model->_get_forms();
		
		//load country info
		$this->load->helper('country');		
		
		$country_options = _load_countries_dropdown($countries = _load_countries_array());
		
		$this->config->set_item('country_options', $country_options);
		
		$data['custom_fields'] = array(); $data['registration_fields'] = array();
		$data['checkout_fields'] = array(); $data['membership_fields'] = array();
		$data['checkout_payment_fields'] = array(); $data['checkout_shipping_fields'] = array();
		$data['registration_payment_fields'] = array(); $data['membership_payment_fields'] = array();
		$data['custom_commission_fields'] = array(); $data['custom_payment_fields'] = array();
		$data['custom_invoice_fields'] = array(); $data['custom_contact_fields'] = array();
				
		foreach ($config as  $v)
		{

			switch ($v['form_type'])
			{
				case 'custom_fields': 
					array_push($data['custom_fields'], $v);
				break;
				
				case 'custom_commission_fields': 
					array_push($data['custom_commission_fields'], $v);
				break;
				
				case 'custom_contact_fields': 
					array_push($data['custom_contact_fields'], $v);
				break;
				
				case 'custom_invoice_fields': 
					array_push($data['custom_invoice_fields'], $v);
				break;
				
				case 'custom_payment_fields': 
					array_push($data['custom_payment_fields'], $v);
				break;
				
				case 'registration_fields':
					array_push($data['registration_fields'], $v);
				break;
				
				case 'registration_payment_fields':
					array_push($data['registration_payment_fields'], $v);
				break;
				
				case 'checkout_fields':
					array_push($data['checkout_fields'], $v);
				break;
				
				case 'checkout_payment_fields':
					array_push($data['checkout_payment_fields'], $v);
				break;
				
				case 'checkout_shipping_fields':
					array_push($data['checkout_shipping_fields'], $v);
				break;
				
				case 'membership_fields':
					array_push($data['membership_fields'], $v);
				break;
				
				case 'membership_payment_fields':
					array_push($data['membership_payment_fields'], $v);
				break;
			}
		}
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_forms', $data);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_forms()
	{
		/*
		| -----------------------------------------
		| update form
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//run admin validation check
		if ($this->_check_forms() == true)
		{		
			//update the form into db
			$data = $this->forms_model->_update_forms();	
			//ajax message
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('update_form_fields_success'));
			
			echo '<script>window.location = "' . jrox_admin_url().'forms/view_forms"</script>';	
			exit();			
		}	
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_forms()
	{
		//set form validation rules
		
		$data = $this->db_validation_model->_clean_data($_POST);
		
		foreach ($data as $k => $v)
		{
			if (preg_match('/form_field_name-*/', $k)) 
			{	
				$array = explode('-', $k);
				
				//check form field name
				if (empty($v))
				{
					echo '<div class="error" id="error-messages">' . $this->lang->line('invalid_form_field_names') . '</div>';
					exit();
				}
			}  
			
			//check sort order
			if (preg_match('/sort_order-*/', $k)) 
			{	
				$array = explode('-', $k);
				
				//check form field name
				if (!is_numeric($v))
				{
					echo '<div class="error" id="error-messages">' . $this->lang->line('all_menu_sort_order_numeric') . '</div>';
					exit();
				}
			}  
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
}
?>