<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - gateways.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage gateways options
|
*/

class Gateways extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load gateways model
		$this->load->model('gateways_model', 'gw');
		
		$this->config->load('gateway_links');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/gateways/view_gateways');
	}
	
	
	// ------------------------------------------------------------------------
	
	function signup_link()
	{
		
		redirect_301($this->config->item('gateway_signup_link_' . $this->uri->segment(4)), true, false);
		exit();
	}
	
	// ------------------------------------------------------------------------
	
	function view_gateways()
	{
		/*
		| -----------------------------------------
		| view gateways modules
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_gateways_modules');
		$data['sub_title'] = $this->lang->line('manage_gateways_modules');
		$data['add_link'] = 'install';
		$data['update_link'] = 'gateways';
		$data['groups_table'] = 'gateways-table';
		$data['height'] = '500';
		$data['width'] = '400';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_gateways', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{
		/*
		| ------------------------------
		| get gateways modules via ajax
		| ------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['sort_name'] = 'gateways_name';
		$data['header_name'] = 'gateways_module';
		$data['height'] = '500';
		$data['width'] = '400';
		
		//get groups
		$row = $this->gw->_get_gateways($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		if (empty($row))
		{
			$row[0] = array(
						'module_id' => 0,
						'module_name' => $this->lang->line('no_gateways_modules_found'),
						'module_status' => 0,
						'module_description' => '',
						'module_file_name' => '',
						'window_height_size' => '',
						'window_width_size' => '',
						'module_sort_order' => '',
						);
		}
		
		//add the data to the array
		$data['module'] = $row;
		
		//count all rows first
		$row_count = $this->db_validation_model->_get_count('modules', 'WHERE module_type = \'payment_gateway\'');
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'modules', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $row_count);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_gateways_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function sort_order()
	{
		/*
		| ---------------------------
		| mass update group tiers
		| ---------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		if ($this->_check_sort_order() == true)
		{	
			$this->gw->_change_sort_order();
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('gateways_updated_successfully'));
			echo '<script>self.parent.location.reload(true);</script>';	
		}
		else
		{
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}
	}
	
	// ------------------------------------------------------------------------
	
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the module
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->db_validation_model->_change_status_field('modules', 'module_id', (int)$this->uri->segment(4), 'module_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/gateways/table/' . $this->config->item('cache_bx'));
			}
			else
			{
				//set flash data
				//$this->session->set_flashdata('success', $this->lang->line('update_modules_success'));
				
				redirect(ADMIN_ROUTE . '/modules/view_modules');
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function mass_remove()
	{
		//mass remove a gateways option to a product
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_sort_order()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
	
		foreach ($data as $k => $v)
		{
			if (strstr($k, "gateways") == true) 
			{
				$rules[$k] = 'trim|required|numeric';
				$fields[$k] = $k ;
			}
		}
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
}
?>