<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - invoice_payments.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage invoice_payments
|
*/

class Invoice_Payments extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load invoice_payments model
		$this->load->model('invoices_model');
		
		//load css body style
		$this->config->set_item('css_body', 'UZ');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/invoice_payments/view_invoice_payments');
	}
	
	// ------------------------------------------------------------------------
	
	function add_invoice_payment()
	{
		/*
		| -----------------------------------------
		| add a payment to an invoice
		| -----------------------------------------
		*/
		
		//load the commissions model to generate the commission
		$this->load->model('commissions_model');
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_payment');
		$data['submit_url'] = jrox_admin_url().'invoice_payments/add_invoice_payment/' . (int)($this->uri->segment(4));
		$data['add_link'] = 'add_invoice_payment';
		
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
		
		//run validation check
		if ($this->_check_invoice_payment() == false)
		{		
			//reload add form
			if (empty($_POST))
			{
				$this->validation->payment_date = date($fdate[1], time());
				
				//get payment gateways
				
				$data['payment_gateways'] = $this->invoices_model->_get_payment_gateways();
			
				//load template
				load_form('admin', 'tpl_adm_manage_payment', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//get current invoice for possible credits
			$check_credit = $this->invoices_model->_get_invoice_details((int)($this->uri->segment(4)));
			
			/*
			| -----------------------------------------
			| Pay the invoice first
			| -----------------------------------------
			*/
			
			//add the payment into db and get the payment array
			$sdata = $this->invoices_model->_add_payment((int)($this->uri->segment(4)), $_POST);
			
			//add any download access or membership option if needed
			if ($this->input->post('payment_type') == 'credit' && $sdata['inv']['payment_status'] == 1)
			{
				$invoice_products = $this->invoices_model->_get_invoice_products((int)($this->uri->segment(4)));
				
				//for calculating different recurring commissions after initial sale
				$initial = 'add';
				
				if (!empty($invoice_products))
				{
					$this->load->model('members_model', 'members');
					$this->load->model('products_model', 'prod');
					
					foreach ($invoice_products as $v)
					{
						if ($v['product_type'] == 'digital')
						{
							//check if the user already has download access, if not add it
							$digital = $this->members->_get_download_details($sdata['inv']['member_id'], $v['product_id']);
							
							if (empty($digital))
							{
								//add the download
								$this->prod->_add_download_access($v['product_id'], $sdata['inv']['member_id'], $v['download_expires_days'], 1);
							}
						}
						elseif ($v['product_type'] == 'membership')
						{
							//check if the user is already subscribed to this membership
							$check_membership[0] = '';
							$check_membership = $this->members->_get_membership_details($sdata['inv']['member_id'], $v['product_id']);
							
							
							//add the membership
							if ($v['enable_product_trial'] == 1)
							{
								$interval_type = $v['product_trial_interval_type'];
								$interval_num = $v['product_trial_interval'];
							}
							else
							{
								$interval_type = $v['recurring_interval_type'];
								$interval_num = $v['recurring_interval'];
							}
						
							switch ($interval_type)
							{
								case 'day':
	
									$expiration = date('m/d/Y', mktime(12, 0, 0, date('m'),   date('d') + $interval_num,   date('Y')));
									$inv = mktime(12, 0, 0, date('m'),   date('d') + $interval_num,   date('Y'));
									$invoice_date = $inv - ($this->config->item('sts_invoice_auto_generate_invoice_day') * 60 * 60 * 24);	
									
								break;
								
								case 'week':
									
									$interval_num = $interval_num * 7;
									
									$expiration = date('m/d/Y', mktime(12, 0, 0, date('m'),   date('d') + $interval_num,   date('Y')));
									$inv = mktime(12, 0, 0, date('m'),   date('d') + $interval_num,   date('Y'));
									$invoice_date = $inv - ($this->config->item('sts_invoice_auto_generate_invoice_day') * 60 * 60 * 24);	
								
								break;
								
								case 'month':
								
									$expiration = date('m/d/Y', mktime(12, 0, 0, date('m') + $interval_num,   date('d'),   date('Y')));
									$inv = mktime(12, 0, 0, date('m') + $interval_num,   date('d'),   date('Y'));
									$invoice_date = $inv - ($this->config->item('sts_invoice_auto_generate_invoice_day') * 60 * 60 * 24);
								
								break;
								
								case 'year':
								
									$expiration = date('m/d/Y', mktime(12, 0, 0, date('m'),   date('d'),   date('Y') + $interval_num));
									$inv = mktime(12, 0, 0, date('m'),   date('d'),   date('Y') + $interval_num);
									$invoice_date = $inv - ($this->config->item('sts_invoice_auto_generate_invoice_day') * 60 * 60 * 24);
								
								break;
							}			

							$intervals_left = '0';
							$intervals = $v['recurring_interval_type'] == 'onetime' ? 0 : $intervals = $v['recurring_interval_ends'];
							
							if ($this->config->item('sts_invoice_enable_auto_generate_invoice') == 0)
							{
								$invoice_date = '0';
							}
						
							//get payment method 
							$payment_method = '';
							$this->db->where('module_type', 'payment_gateway');
							$this->db->where('module_name', $this->input->post('payment_method'));
							$pquery = $this->db->get('modules');
							
							if ($pquery->num_rows() > 0)
							{
								$p_array = $pquery->row_array();
								$payment_method = $p_array['module_file_name'];
							}
							
							if (empty($check_membership[0]))
							{
								$mem_data = array('expires' => $expiration,
													 'product_id' => $v['product_id'],
													 'total_intervals' => $intervals,
													 'intervals_left' => $intervals_left,
													 'invoice_id' => (int)($this->uri->segment(4)),
													 'invoice_date' => date('m/d/Y', $invoice_date),
													 'subscription_id' => $this->input->post('transaction_id'),
													 'membership_payment_type' => $payment_method,
													 );
								
								$this->members->_add_membership($sdata['inv']['member_id'], $mem_data);
								
								//check if we need to add group and mailing list data
								$this->load->model('groups_model');
								
								$mem_details = $this->prod->_get_product_basic($v['product_id']);
								
								// add affiliate group
								if (!empty($mem_details['add_affiliate_group']))
								{
									$this->groups_model->_update_member_group('affiliate', $sdata['inv']['member_id'],$mem_details['add_affiliate_group']);
								}
								
								//add discount group
								if (!empty($mem_details['add_discount_group']))
								{
									$this->groups_model->_update_member_group('discount', $sdata['inv']['member_id'], $mem_details['add_discount_group']);
								}
								
								//add mailing list
								if (!empty($mem_details['add_mailing_list']))
								{
									$this->members->_update_member_list('add', $sdata['inv']['member_id'], $mem_details['add_mailing_list']);
								}
							}
							else
							{
								//update the membership
								$mem_data = array('expires' => $expiration,
													 'total_intervals' => $intervals,
													 'intervals_left' => $intervals_left,
													 'invoice_id' => (int)($this->uri->segment(4)),
													 'subscription_id' => $this->input->post('transaction_id'),
													 'membership_payment_type' => $payment_method,
													 );
								
								$this->members->_update_membership($sdata['inv']['member_id'], $v['product_id'], $mem_data);								
								
								//for calculating different recurring commissions after initial sale
								$initial = 'update';
							}
						}
					}
				}
			}
			
			//remove commissions if any based on setting
			if ($this->input->post('payment_type') == 'refund')
			{
				$this->commissions_model->_update_invoice_commissions((int)($this->uri->segment(4)), $this->config->item('sts_affiliate_refund_commission_type'));
			}
			
			/*
			| --------------------------------------------------
			| Check for any credits that may need to be issued
			| --------------------------------------------------
			*/
			
			//check for any credit payments
			if (!empty($sdata['issue_credit']))
			{
				//calculate invoice credits
				if ($check_credit['inv']['total_amount'] >= $check_credit['total_payments'])
				{
					//add the credit
					$credit = $sdata['total_payments'] - $sdata['inv']['total_amount'];
				}
				else
				{
					$credit = $this->input->post('payment_amount');
				}
				
				//add the credit
				$this->load->model('credits_model');
				
				$credit_note = $this->lang->line('credit_overpayment_note') . "; \n";
				$credit_note .= $this->lang->line('date') . ": " . date($this->config->item('sts_admin_time_format'), now()) . "; \n";
				$credit_note .= $this->lang->line('invoice_id') . ": " . (int)($this->uri->segment(4)) . "; \n";
				
				$credit_array = array('amount' => $credit,
									  'notes' => $credit_note,
									  'invoice_id' => '0',
									  );
									  
				$fdata = $this->credits_model->_add_credit($check_credit['inv']['member_id'], $credit_array);		
			}
			
			/*
			| -------------------------------------------------
			| Now see if we need to generate some commissions
			| -------------------------------------------------
			*/
			
			//check if we need to generate a commission 
			if ($this->input->post('generate_commission_for_invoice') == 1 && $this->input->post('payment_type') == 'credit' && !empty($sdata['inv']['referrer_id']))
			{
				//generate a commission	
				
				//load the downline model to get the upline
				$this->load->model('downline_model');
				
				//load emailing model
				$this->load->model('emailing_model');
				
				//load groups model
				$this->load->model('groups_model');
				
				//load coupons model
				$this->load->model('coupons_model');
				
				//generate the downline array of members
				$members = $this->downline_model->_get_upline($sdata['inv']['referrer_id']);
				
				//set currency
				$num_options = get_default_currency($data['sts_store_default_currency']);
				
				//lets check if there is a coupon code
				if (!empty($sdata['inv']['coupon_code']))
				{
					$coupon_details = $this->coupons_model->_get_coupon_details($sdata['inv']['coupon_code'], 'coupon_code');
				}
				
				//get the discount group
				$disc_group = $this->groups_model->_check_user_group('discount', $sdata['inv']['member_id']);
				
				/*
				| ----------------------------------------------------
				| Give out commissions for all ACTIVE upline members
				| ----------------------------------------------------
				*/
				
				//start the member loop of upline
				foreach ($members as $k => $v) //loop through each member of the upline
				{
					if ($v['status'] == 1) //only add a commission if the member has an active status
					{
						//set commission defaults
						$commission_level = $k; //commission level
						
						
						//set the commission status
						switch ($this->config->item('sts_affiliate_new_commission'))
						{
							case 'no_pending':
							case 'alert_pending':
								
								$comm_status = 'pending';
								
							break;
							
							case 'no_unpaid':
							case 'alert_unpaid':
							
								$comm_status = 'unpaid';
								
							break;
						}
						
						/*
						| -------------------------------------------------------------
						| Check if we're paying commissions per product or total sale
						| -------------------------------------------------------------
						*/
							
						//first check if commission is total sale or per product
						if ($data['sts_affiliate_total_sale_commissions'] == 'total_sale')
						{
							//generate a commission for all products in one invoice
						
							//set the commission notes
							$comm_notes = $this->lang->line('products_purchased_on_commission') . ":\n";
							
							//loop through the products to add to the commission notes
							foreach ($sdata['prod'] as $product)
							{
								$comm_notes .= $this->lang->line('id') . " - " . $product['product_id'] . " " . $product['product_name'] . "\n";
							}
							
							/*
							| -------------------------------------------------------------
							| Finally, let's add a commission for TOTAL SALE ONLY
							| -------------------------------------------------------------
							*/
							
							//calculate the commission amount
							$calc_total = $sdata['inv']['sub_total'] - $sdata['inv']['discount_amount'];
							$comm_amount = $this->commissions_model->_calculate_commission($v['commission_type'], $commission_level, $v['commission_level_' . $k], $calc_total, $initial);
							
							if ($commission_level > 1)
							{
								$sale_amount = '0.00';
							}
							else
							{
								$sale_amount = $sdata['inv']['sub_total'];
							}
							
							if ($comm_amount > 0 )
							{
								//set all the required data
								$insert = array(	'member_id' 		=> 			$v['member_id'],			
													'invoice_id'		=>			$sdata['invoice_id'],
													'comm_status'		=>			$comm_status,
													'approved'			=>			'0',
													'date'				=>			$sdata['payment_date'],
													'commission_amount'	=>			$comm_amount,
													'sale_amount'		=>			$sale_amount,
													'commission_level'	=>			$commission_level,
													'referrer'			=>			'',
													'trans_id'			=>			$sdata['transaction_id'],
													'ip_address'		=>			$this->input->ip_address(),
													'date_paid'			=>			'',
													'commission_notes'	=>			$comm_notes,
													'performance_paid'	=>			'0',
													'email_sent'		=>			'0',
												);	
							
								//add the commission
								$this->commissions_model->_add_commission($insert);
							}
							
						
						/*
						| -------------------------------------------------------------
						| Process commissions per product instead
						| -------------------------------------------------------------
						*/
						
						}
						else //generate a commission per product
						{
							
							
							//generate a commission for each product
							foreach ($sdata['prod'] as $prod => $value)
							{
								//write the commission notes
								$comm_notes = $this->lang->line('products_purchased_on_commission') . ":\n";
								$comm_notes .= $this->lang->line('id') . " - " . $value['product_id'] . " " . $value['product_name'] . "\n";
								
								//check if the product gives out commissions
								if ($value['no_commission'] == 0)
								{
									if ($value['enable_custom_commission'] == 1)
									{
										//get the custom commissions for this product
										$this->db->where('product_id', $value['product_id']);
										$this->db->where('group_id', $v['group_id']);
										$query = $this->db->get('products_to_aff_groups');
										
										if ($query->num_rows() > 0) //if there are custom commissions set it now
										{
											$x = $query->result_array();
											
											$level_amount = $x[0]['commission_level_' . $commission_level];
											
											//echo $value['product_name'] . '= ' . $commission_level . '-' . $level_amount. '<br />';
										}
										else
										{
											$level_amount = $v['commission_level_' . $commission_level];
										}
									}
									else //generate regular group commission
									{
										$level_amount = $v['commission_level_' . $commission_level];
									}
									
									/*
									| -------------------------------------------------------------
									| Finally, let's add a commission for EACH PRODUCT
									| -------------------------------------------------------------
									*/
									
									//check for coupon code
									if (!empty($coupon_details) && $coupon_details['coupon_type'] == 'percent')
									{
										//calculate the new amount
										$disc_amount = $value['unit_price'] * $coupon_details['coupon_amount'];
										$uprice = $value['unit_price'] - $disc_amount;
									}
									else
									{
										$uprice = $value['unit_price'];				
									}
									/*
									//now check for discounts per product
									if (!empty($disc_group['group_id']))
									{
										$this->db->where('product_id', $value['product_id']);
										$this->db->where('group_id', $disc_group['group_id']);
										$cquery = $this->db->get('products_to_disc_groups');
										
										if ($cquery->num_rows() > 0)
										{
											$cdisc = $cquery->row_array();
											if (!empty($cdisc['amount']))
											{
												$disc_group['discount_group_amount'] = $cdisc['amount'];
											}
										}
									}
									
									//now check for discounts per product
									if (!empty($disc_group['discount_group_amount']) && $disc_group['discount_group_amount'] > '0')
									{									
										//calculate the discounts now per product for pecentage only
										if ($disc_group['percentage'] == 1)
										{
											$uprice = $uprice - round($uprice * $disc_group['discount_group_amount'], 2);
										}
										else
										{
											$uprice = $uprice - $disc_group['discount_group_amount'];
										}
										
										
									}
									*/
									//calculate the commission amount
									$comm_amount = $this->commissions_model->_calculate_commission($v['commission_type'], $commission_level, $level_amount, $uprice, $initial);						
				
									//calculate commissions for each quantity ordered
									$v['commission_amount'] = $comm_amount * $value['quantity'];
									
									$email_sent = $this->input->post('send_email') == 1 ? 1 : 0;
									
									if ($commission_level > 1)
									{
										$sale_amount = '0.00';
									}
									else
									{
										$sale_amount = $value['quantity'] *  $uprice;
									}
									
									if ($comm_amount > 0 )
									{
										//set all the required data
										$insert = array(	'member_id' 		=> 			$v['member_id'],			
															'invoice_id'		=>			$sdata['invoice_id'],
															'comm_status'		=>			$comm_status,
															'approved'			=>			'0',
															'date'				=>			$sdata['payment_date'],
															'commission_amount'	=>			$v['commission_amount'],
															'sale_amount'		=>			$sale_amount,
															'commission_level'	=>			$commission_level,
															'referrer'			=>			'',
															'trans_id'			=>			$sdata['transaction_id'],
															'ip_address'		=>			$this->input->ip_address(),
															'date_paid'			=>			'',
															'commission_notes'	=>			$comm_notes,
															'performance_paid'	=>			'0',
															'email_sent'		=>			$email_sent,
														);	
									
										//add the commission
										$this->commissions_model->_add_commission($insert);
									}
								}
							}
						}
						
						/*
						| -------------------------------------------------------------
						| Send out an alert email to the user 
						| -------------------------------------------------------------
						*/
							
						//send out alert email if set
						if ($this->input->post('send_email') == 1)
						{
							if ($v['alert_new_commission'] != '0') //send out the email only if the user wants it
							{
								$v['commission_amount'] = format_amounts($v['commission_amount'], $num_options);
								$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_commission_generated_template');
							}
						}
						
						/*
						| -------------------------------------------------------------
						| Let's see if the user gets any performance bonuses
						| -------------------------------------------------------------
						*/
						
						//check performance bonuses
						if ($this->config->item('sts_affiliate_enable_performance_bonus') == 1)
						{
							//generate bonuses if any
							$unpaid_bonus = $this->commissions_model->_get_commissions_for_bonus($this->config->item('sts_affiliate_performance_bonus_required'), $v['member_id']);
							
							//calculate whether the user has made enough commissions
							if ($unpaid_bonus >= $this->config->item('sts_affiliate_performance_bonus_required_amount'))
							{
								/*
								| -------------------------------------------------------------
								| Should we give them a bonus amount or upgrade the group?
								| -------------------------------------------------------------
								*/
							
								//check if performance is group upgrade or an amount
								if ($this->config->item('sts_affiliate_performance_bonus_type') == 'payment_amount')
								{
									//insert a commission amount
									
									$comm_notes = $this->lang->line('performance_bonus_earned') . "\n";
									$v['bonus_amount'] = format_amounts($this->config->item('sts_affiliate_performance_bonus_amount'), $num_options);
									
									//set all the required data
									$new_bonus = array(	'member_id' 		=> 			$v['member_id'],			
														'invoice_id'		=>			'0',
														'comm_status'		=>			$comm_status,
														'approved'			=>			'0',
														'date'				=>			$sdata['payment_date'],
														'commission_amount'	=>			$this->config->item('sts_affiliate_performance_bonus_amount'),
														'sale_amount'		=>			'0',
														'commission_level'	=>			'1',
														'referrer'			=>			'',
														'trans_id'			=>			$this->lang->line('trans_id_performance_bonus'),
														'ip_address'		=>			$this->input->ip_address(),
														'date_paid'			=>			'',
														'commission_notes'	=>			$comm_notes,
														'performance_paid'	=>			'1',
														'email_sent'		=>			'1',
													);	
								
									//add the commission
									$this->commissions_model->_add_commission($new_bonus);
									
									//send out alerts
									if ($v['alert_new_commission'] != '0') //only send out the email if the user allows it
									{
										$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_bonus_amount_template');
									}
								}
								else //upgrade to group
								{
									$group_upgrade = $this->commissions_model->_upgrade_bonus_group($v['member_id']);
									
									if (!empty($group_upgrade))
									{
										$v['upgraded_affiliate_group'] = $group_upgrade['aff_group_name'];
										
										//send out alerts
										if ($v['alert_new_commission'] != '0')
										{
											$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_group_upgrade_template');
										}
									}
								}
								
								/*
								| -------------------------------------------------------------
								| Let's mark all the commissions paid for bonuses now
								| -------------------------------------------------------------
								*/
								
								//now mark all commissions to performance paid
								$this->commissions_model->_update_commissions_for_bonus($v['member_id']);	
							}
						}
					}
				}
			}
			
			
			if (!empty($sdata))
			{
				
				//ajax message
				echo '<div class="success" onclick="' . _check_close_buttons('click') . '" style="cursor:pointer;">' .$this->lang->line('payment_added_successfully') . '</div>';		
				
			}
		}		
	}
	
	
	// ------------------------------------------------------------------------
	
	function delete_invoice_payment()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$invoice = $this->db_validation_model->_get_details('invoice_payments', 'invoice_id', 'id', $this->uri->segment(4));
		
		if ($this->invoices_model->_delete_payment((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/invoice_payments/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
			
				redirect(ADMIN_ROUTE . '/invoices/update_invoice/' .  $invoice[0]['invoice_id'] . '#fragment-4');
			}
		}
		else
		{
			redirect(ADMIN_ROUTE . '/invoices/view_invoices');
		}
	
	}
	
	
	// ------------------------------------------------------------------------
	
	function view_invoice_payments()
	{
		/*
		| -----------------------------------------
		| view invoice_payments
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_invoice_payments');
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_invoice_payments', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get invoice_payments via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '700';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		if ($data['where_column'] == 'search')
		{
			//load convert library
			$this->load->library('convert');
			
			$data['where_value'] = base64_decode($this->convert->HexToAscii($data['where_value'])); 
		}
		
		//get invoice_payments
		$row = $this->invoices_model->_get_invoice_payments($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_column'], $data['where_value']);

		//add the data to the array
		$data['invoice_payments'] = $row;	
		
		if ($data['where_column'] == 'search')
		{
			
			$sql = 'SELECT ' . $this->db->dbprefix('invoice_payments') . '.*, ' . $this->db->dbprefix('invoices') . '.*
					FROM ' . $this->db->dbprefix('invoice_payments') . '
					LEFT JOIN ' . $this->db->dbprefix('invoices') . ' ON ' .
					$this->db->dbprefix('invoice_payments') . '.invoice_id = ' . $this->db->dbprefix('invoices') . '.invoice_id
					WHERE transaction_id LIKE \'%' . $data['where_value'] .'%\'
					OR payment_amount LIKE \'%' . $data['where_value'] .'%\'';
			
			$query = $this->db->query($sql);
		
			$total_rows = $query->num_rows();

			$data['filter_category'] = $this->lang->line('search');
			$data['filter_name'] = $data['where_value'];
		}
		else
		{
			$total_rows = $this->db->count_all('invoice_payments');
		}
		
		//set pagination
		$data['where_value'] = $this->uri->segment(9,0);
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'invoice_payments', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		//load template
		load_admin_tpl('admin', 'tpl_adm_invoice_payments_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_invoice_payment()
	{
		/*
		| -----------------------------------------
		| add a new invoice_payment
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_invoice_payment');
		$data['submit_url'] = jrox_admin_url().'invoice_payments/update_invoice_payment/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_invoice_payment';
		$data['update_link'] = 'invoice_payments';
		
		//run admin validation check
		if ($this->_check_invoice_payment() == false)
		{		
			//reload add invoice_payment form
			if (empty($_POST))
			{
				$mdata = $this->invoices_model->_get_invoice_payment_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['payment_gateways'] = $this->invoices_model->_get_payment_gateways();
					
					$fdate = explode(':', $this->config->item('sts_admin_date_format'));
					$data['curdate'] = $fdate[0];
					$data['format_date'] = $fdate[1];
					
					$this->validation->payment_date =  date($fdate[1], $this->validation->payment_date);
					
					//load template
					load_form('admin', 'tpl_adm_manage_payment', $data);
				}
				else
				{
					//load add invoice_payment page
					redirect(ADMIN_ROUTE . '/invoice_payments/view_invoice_payments');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the invoice_payment into db
			$data = $this->invoices_model->_update_payment((int)$this->uri->segment(4));	
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('invoice_payments_updated_successfully') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------
	
	function _check_invoice_payment()
	{
		//set form validation rules
		
		$rules['payment_date'] = 'trim|required';
		$rules['payment_amount'] = 'trim|required|numeric';
		$rules['transaction_id'] = 'trim|required|max_length[255]';
		$rules['payment_type'] = 'trim|required';
		$rules['payment_method'] = 'trim|required';
		$rules['payment_notes'] = 'trim';
		$rules['debug_info'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['payment_date'] = $this->lang->line('date');
		$fields['payment_amount'] = $this->lang->line('payment_amount');
		$fields['transaction_id'] = $this->lang->line('transaction_id');
		$fields['payment_type'] = $this->lang->line('payment_type');
		$fields['payment_method'] = $this->lang->line('payment_method');
		$fields['payment_notes'] = $this->lang->line('payment_notes');
		$fields['debug_info'] = $this->lang->line('debug_info');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
}
?>