<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - invoices.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage invoices
|
*/

class Invoices extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load invoices model
		$this->load->model('invoices_model');
		
		//load css body style
		$this->config->set_item('css_body', 'UZ');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		
		//load country helper
		$this->load->helper('country');		

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/invoices/view_invoices');
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status of the invoice
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('invoices', 'invoice_id', (int)$this->uri->segment(4), 'payment_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				
				redirect(ADMIN_ROUTE . '/invoices/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(6,0) . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('invoice_updated_successfully'));
				
				redirect(ADMIN_ROUTE . '/invoices/view_invoices');
			}
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	
	function add_invoice()
	{
		/*
		| -----------------------------------------
		| add a new invoice
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['member_id'] = (int)$this->uri->segment(4);
		
		//check for id
		if (empty($data['member_id']))
		{
			show_error($this->lang->line('no_member_found'));
		}
		
		//run admin validation check
		if ($this->_check_add_invoice() == false)
		{		
			//reload add invoice form
			if (empty($_POST))
			{
				
				//get member name
				$member = $this->db_validation_model->_get_details('members', '*', 'member_id', $data['member_id']);
				
				//check for valid member
				if (empty($member))
				{
					show_error($this->lang->line('no_member_found'));
				}
				
				$shipping = $this->db_validation_model->_get_details('members_addresses', '*', 'member_id', $data['member_id']);		
				
				$sdata['member'] = $member[0];
				$sdata['shipping'] = $shipping[0];
				
				$fdate = explode(':', $this->config->item('sts_admin_date_format'));
				$data['curdate'] = $fdate[0];
				
				//load country helper
				$this->load->helper('country');		
				
				$data['country_options'] = _load_countries_dropdown($countries = _load_countries_array(), true, 'select_country');
				
				//set page title
				$data['page_title'] = $this->lang->line('add_invoice');
				$data['submit_url'] = jrox_admin_url().'invoices/add_invoice/' . $data['member_id'];
				$data['update_link'] = 'invoices';
				$data['add_link'] = 'add_invoice';
						
				foreach ($sdata['member'] as $k => $v)
				{
					$this->validation->$k = $v;
				}
				
				foreach ($sdata['shipping'] as $k => $v)
				{
					$this->validation->$k = $v;
				}
				
				$this->validation->tax_amount = '';
				$this->validation->shipping_amount = '';
				$this->validation->referring_affiliate = '';
				$this->validation->invoice_notes = '';
				$this->validation->date_purchased =  date($fdate[1], time());
				$this->validation->due_date =  date($fdate[1], time() + (3600 * 24 * $this->config->item('sts_invoice_due_date_days')));
				
				//set the sponsor if any
				if (!empty($member[0]['sponsor_id']))
				{
					$sponsor = $this->db_validation_model->_get_details('members', 'username', 'member_id', $member[0]['sponsor_id']);
					$this->validation->referring_affiliate = $sponsor[0]['username'];
				}
				
				//load template
				load_admin_tpl('admin', 'tpl_adm_add_invoice', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the invoice into db
			$data = $this->invoices_model->_add_invoice('admin', $data['member_id'], $_POST);		
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('invoice_added_successfully'));
			
			//ajax message
			echo '<div class="success" onclick="location.href=\'' . jrox_admin_url() .'/invoices/update_invoice/' . $data['invoice_id'] . '\';" style="cursor:pointer;">' . $this->lang->line('invoice_added_successfully') .'</div>';			
			
			//redirect to member details form
			echo '<script>window.location = "' . jrox_admin_url() .'invoices/update_invoice/' . $data['invoice_id'] . '"</script>';

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_invoice()
	{
		/*
		| --------------------------------------------
		| delete the invoice from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->invoices_model->_delete_invoice((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/invoices/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/invoices/view_invoices');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_invoices()
	{
		/*
		| -----------------------------------------
		| view invoices
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		if ($this->uri->segment(4) && $this->uri->segment(4) != 'search')
		{
			//get member name
			$member = $this->db_validation_model->_get_details('members', 'fname, lname', 'member_id', $this->uri->segment(4));
			
			$data['page_title'] = $this->lang->line('view_invoices_for') . ' ' . $member[0]['fname'] . ' ' . $member[0]['lname'];
		}
		else
		{
			$data['page_title'] = $this->lang->line('manage_invoices');
		}
		
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_invoices', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get invoices via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'ASC' ? 'DESC' : 'ASC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '700';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		if ($data['where_column'] == 'search')
		{
			//load convert library
			$this->load->library('convert');
			
			$data['where_value'] = base64_decode($this->convert->HexToAscii($data['where_value'])); 
		}
		
		switch ($data['where_value'])
		{
			case 'order_pending':
				
				$data['invoice_type'] = $this->lang->line('pending');
				
			break;
			
			case 'order_processing':
				
				$data['invoice_type'] = $this->lang->line('processing');
				
			break;
			
			case 'order_completed':
				
				$data['invoice_type'] = $this->lang->line('completed');
				
			break;
			
			default:
				
				$data['invoice_type'] = $this->lang->line('all');
				
			break;
		}
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//get invoices
		$row = $this->invoices_model->_get_invoices($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_column'], $data['where_value']);

	 
		//add the data to the array
		$data['invoices'] = $row;	
		
		//check if search is on
		if ($data['where_column'] == 'search')
		{
			$sql = 'SELECT ' . $this->db->dbprefix('invoices') . '.*
						FROM ' . $this->db->dbprefix('invoices') . '
						WHERE (customers_name LIKE \'%' . $data['where_value'] .'%\'
						OR invoice_id LIKE \'%' . $data['where_value'] .'%\'
						OR customers_company LIKE \'%' . $data['where_value'] .'%\'
						OR shipping_name LIKE \'%' . $data['where_value'] .'%\'
						OR shipping_company LIKE \'%' . $data['where_value'] .'%\'
						OR customers_primary_email LIKE \'%' . $data['where_value'] .'%\')';
			
			$query = $this->db->query($sql);
		
			$total_rows = $query->num_rows();

			$data['filter_category'] = $this->lang->line('search');
			$data['filter_name'] = str_replace('_', ' ', $data['where_value']);
		}
		else
		{
		
			//count the rows
			if (!empty($data['where_value'])) 
			{
				
				if (!empty($data['where_column'])) //search for members invoice with order status
				{
					$sql = 'WHERE order_status = \'' . $data['where_value'] . '\' AND member_id = \'' . $data['where_column'] . '\'';
				}
				else //show order status only
				{	
					$sql = 'WHERE order_status = \'' . $data['where_value'] . '\'';
				}	
				
				$total_rows = $this->db_validation_model->_get_count('invoices', $sql);
			}
			else //seach for member invoices only
			{
				if (!empty($data['where_column']))
				{
					$sql = 'WHERE member_id = \'' . $data['where_column'] . '\'';
				
					$total_rows = $this->db_validation_model->_get_count('invoices', $sql);
				}
				else
				{	
					$total_rows = $total_rows = $this->db->count_all('invoices');
				}	
	
			}
		}
		
		//set pagination
		$data['where_value'] = $this->uri->segment(9,0);
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'invoices', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_invoices_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------	
	
	function update_invoices()
	{
		/*
		| ---------------------------
		| mass update member details
		| ---------------------------
		*/
		
		//check if there are any users checked for update
		if ($this->input->post('invoice') AND count($this->input->post('invoice')) > 0)
		{
			$this->invoices_model->_change_status($this->input->post('invoice'), $this->input->post('change-status'));
		
			//check if we are sending out status alerts
			if ($this->input->post('change-status') == 'order_processing_email' || $this->input->post('change-status') == 'order_completed_email')
			{
				$this->load->model('emailing_model');
				
				//get email details
				foreach ($this->input->post('invoice') as $id)
				{
					$sdata = $this->invoices_model->_get_invoice_basic($id);
					
					if (!empty($sdata['customers_primary_email']))
					{
						$sdata['fname'] = $sdata['customers_name'];
						$sdata['primary_email'] = $sdata['customers_primary_email'];
						$sdata['new_order_status'] = str_replace('_', ' ', $sdata['order_status']);
						$sdata['customers_country'] = _get_country_name($sdata['customers_country'], 'country_name');
						$sdata['shipping_country'] = _get_country_name($sdata['shipping_country'], 'country_name');
						
						if ($this->emailing_model->_send_template_email('member', $sdata, 'member_order_status_change_template'))
						{
							//log success
							log_message('info', 'order status email sent to ' . $sdata['primary_email']);
							
						}
						else 
						{
							show_error($this->lang->line('could_not_send_email') . '. ' . $this->lang->line('check_email_settings'));
							
							log_message('error', 'Could not send order status email to ' . $sdata['primary_email'] . '. Check email settings.');
							
						}
					}
				}
			} 
		}
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('invoices_updated_successfully'));
		echo '<script>self.parent.location.reload(true);</script>';	
	}
	
	// ------------------------------------------------------------------------
	
	function send_invoice()
	{
		/*
		| -----------------------------------------
		| send invoice
		| -----------------------------------------
		*/
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('print_invoice');
		
		//get currency options
		$num_options = get_default_currency($data['sts_store_default_currency']);
		$invoice_id = (int)$this->uri->segment(4);
		
		$mdata = $this->invoices_model->_get_invoice_details($invoice_id);
	
		if (empty($mdata))
		{
			show_error($this->lang->line('no_invoice_found'));
		}
		
		//format the invoice
		$sdata = $this->invoices_model->_send_invoice_format($mdata, $num_options);
		
		//get the email template
		$this->load->model('emailing_model');
		
		if ($this->emailing_model->_send_template_email('admin', $sdata, 'member_payment_invoice_template'))
		{
			//log success
			log_message('info', 'invoice id  ' . $invoice_id . ' sent');
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('invoice_emailed_successfully'));
			
			//redirect
			echo '<script>window.location = "' . jrox_admin_url() .'/invoices/print_invoice/' . $invoice_id . '"</script>';
		}
		else
		{			
			if ($data['sts_email_enable_debugging'] == 0)
			{
				$this->session->set_flashdata('error', $this->lang->line('could_not_send_invoice'));
			
				echo '<script>window.location = "' . jrox_admin_url() .'/invoices/print_invoice/' . $invoice_id . '"</script>';
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function print_invoice()
	{
		/*
		| -----------------------------------------
		| print invoice
		| -----------------------------------------
		*/
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('print_invoice');
		
		//get currency options
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		$mdata = $this->invoices_model->_get_invoice_details((int)$this->uri->segment(4));
	
		if (empty($mdata))
		{
			show_error($this->lang->line('no_invoice_found'));
		}
		
		$data['invoice'] = $mdata;
		
		
		switch ($data['invoice']['inv']['order_status'])
		{
			case 'order_pending':
				
				$data['order_status'] = $this->lang->line('pending');
				
			break;
			
			case 'order_processing':
				
				$data['order_status'] = $this->lang->line('processing');
				
			break;
			
			case 'order_completed':
				
				$data['order_status'] = $this->lang->line('completed');
				
			break;
		}
		
		/*
		$this->load->plugin('dompdf');
			
		$title = url_title($this->lang->line('invoice') . '-' . $data['invoice']['invoice_id']);

		//load template
		$body = load_form('admin', 'tpl_adm_print_invoice', $data, true);
		
		pdf_create($body, $title);
		*/
		
		load_form('admin', 'tpl_adm_print_invoice', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function update_invoice()
	{
		/*
		| -----------------------------------------
		| update a new invoice
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$invoice_id = (int)$this->uri->segment(4);
		
		//check for id
		if (empty($invoice_id))
		{
			show_error($this->lang->line('no_invoice_found'));
		}
		
		//run admin validation check
		if ($this->_check_update_invoice() == false)
		{		
			//reload add invoice form
			if (empty($_POST))
			{						
				$invoice = $this->invoices_model->_get_invoice_details($invoice_id);		
				
				if (!empty($invoice))
				{
					
					$fdate = explode(':', $this->config->item('sts_admin_date_format'));
					$data['curdate'] = $fdate[0];
					$data['format_date'] = $fdate[1];
					
					//get num options
					$this->load->helper('number');
					$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
					
					//load country helper
					$this->load->helper('country');		
					
					$data['country_options'] = _load_countries_dropdown($countries = _load_countries_array(), true, 'select_country');
					
					//set page title
					$data['page_title'] = $this->lang->line('update_invoice') . ' ' . $invoice_id;
					$data['submit_url'] = jrox_admin_url().'invoices/update_invoice/' . $invoice_id;
					$data['add_link'] = 'update_invoice';
					$data['height'] = '400';
					$data['width'] = '700';
					
					foreach ($invoice['inv'] as $k => $v)
					{
						$this->validation->$k = $v;
					}
					
					$this->validation->date_purchased =  date($fdate[1], $this->validation->date_purchased);
					$this->validation->due_date =  date($fdate[1], $this->validation->due_date);
					
					$data['prod'] = $invoice['prod'];
					$data['payments'] = $invoice['payments'];
					$data['total_payments'] = $invoice['total_payments'];
					
					if ($this->config->item('sts_affiliate_enable_affiliate_marketing') == 1)
					{
						$data['commissions'] = $invoice['commissions'];
						$data['total_commissions'] = $invoice['total_commissions'];
					}
					
					$data['total_credits'] = $invoice['total_credits'];
					
					//get next and previous invoices
					$next_prv = $this->db_validation_model->_get_next_prev('invoices', 'invoice_id', $invoice_id);
					
					$data['prev_invoice'] = empty($next_prv['prev']) ? '' : '<a href="' . jrox_admin_url() . '/invoices/update_invoice/' . $next_prv['prev'] . '">' . $this->lang->line('previous_invoice') . '</a>';
					$data['next_invoice'] = empty($next_prv['next']) ? '' : '<a href="' . jrox_admin_url() . '/invoices/update_invoice/' . $next_prv['next'] . '">' . $this->lang->line('next_invoice') . '</a>';
				}
				
				//load template
				load_admin_tpl('admin', 'tpl_adm_manage_invoice', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the invoice into db
			$data = $this->invoices_model->_update_invoice($invoice_id);		
			
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('invoice_updated_successfully'));
			
			//ajax message
			echo '<div class="success" onclick="location.href=\'' . jrox_admin_url() .'/invoices/update_invoice/' . $invoice_id . '\';" style="cursor:pointer;">' . $this->lang->line('invoice_updated_successfully') .'</div>';			
			
			//redirect to member details form
			echo '<script>window.location = "' . jrox_admin_url() .'/invoices/update_invoice/' . $invoice_id . '"</script>';

		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	
	// ------------------------------------------------------------------------	
	
	function _check_add_invoice()
	{
		//check for correct options
		if (!empty($_POST))
		{
			if (!empty($_POST['product_id']))
			{
				//check if product type is membership
				if ($this->input->post('product_type') == 'membership')
				{
					if (empty($_POST['product_id'][0])) 
					{
						echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_id').'</div>';
						echo '<script>showResponse();</script>';
						exit();
					}	
					else
					{
						//check for a valid product id
						if ($this->invoices_model->_check_product_id($_POST['product_id'][0], $this->input->post('product_type')) == false)
						{
							echo '<div class="error" id="error-messages">' . $this->lang->line('invalid_product_id') . ' ' . $_POST['product_id'][0] . '</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}	
				}
				else
				{
					foreach ($this->input->post('product_id') as $k => $v)
					{
						if (empty($v)) {
							echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_id').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}	
						else
						{
							//check for a valid product id
							if ($this->invoices_model->_check_product_id($v, $this->input->post('product_type')) == false)
							{
								echo '<div class="error" id="error-messages">' . $this->lang->line('invalid_product_id') . ' ' . $v . '</div>';
								echo '<script>showResponse();</script>';
								exit();
							}
						}	
					}	
				}
			}
			else
			{
				echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_id').'</div>';
				echo '<script>showResponse();</script>';
				exit();
			}
			
			if (!empty($_POST['unit_price']))
			{
				//check if product type is membership
				if ($this->input->post('product_type') == 'membership')
				{
					if (!empty($_POST['unit_price'][0]))
					{
						if (!is_numeric($_POST['unit_price'][0])) {
							echo '<div class="error" id="error-messages">'.$this->lang->line('price_must_be_numeric').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}		
				}
				else
				{
					foreach ($this->input->post('unit_price') as $k => $v)
					{
						if (!empty($v))
						{
							if (!is_numeric($v)) {
								echo '<div class="error" id="error-messages">'.$this->lang->line('price_must_be_numeric').'</div>';
								echo '<script>showResponse();</script>';
								exit();
							}
						}		
					}
				}	
			}
			
			if (!empty($_POST['quantity']))
			{
				//check if product type is membership
				if ($this->input->post('product_type') == 'membership')
				{
					if (!empty($_POST['quantity'][0]))
					{
						if (!is_numeric($_POST['quantity'][0])) {
							echo '<div class="error" id="error-messages">'.$this->lang->line('quantity_must_be_numeric').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}		
				}
				else
				{
					foreach ($this->input->post('quantity') as $k => $v)
					{
						if (!empty($v))
						{
							if (!is_numeric($v)) {
								echo '<div class="error" id="error-messages">'.$this->lang->line('quantity_must_be_numeric').'</div>';
								echo '<script>showResponse();</script>';
								exit();
							}
						}		
					}	
				}
			}
		}
		//set form validation rules
		
		$rules['date_purchased'] = 'trim|required';
		$rules['due_date'] = 'trim|required';
		$rules['order_status'] = 'trim|required';
		$rules['customers_name'] = 'trim|required|max_length[255]';
		$rules['customers_address_1'] = 'trim|max_length[255]';
		$rules['customers_address_2'] = 'trim|max_length[255]';
		$rules['customers_city'] = 'trim|max_length[255]';
		$rules['customers_state'] = 'trim|max_length[50]';
		$rules['customers_postal_code'] = 'trim|max_length[25]';
		$rules['customers_country'] = 'trim|integer';
		$rules['customers_company'] = 'trim|max_length[50]';
		$rules['customers_telephone'] = 'trim|max_length[50]';
		$rules['customers_primary_email'] = 'trim|valid_email';
		$rules['product_type'] = 'trim|required';
		$rules['shipping_name'] = 'trim|max_length[255]';
		$rules['shipping_address_1'] = 'trim|max_length[255]';
		$rules['shipping_address_2'] = 'trim|max_length[255]';
		$rules['shipping_city'] = 'trim|max_length[255]';
		$rules['shipping_state'] = 'trim|max_length[50]';
		$rules['shipping_postal_code'] = 'trim|max_length[25]';
		$rules['shipping_country'] = 'trim|integer';
		$rules['shipping_company'] = 'trim|max_length[50]';
		$rules['shipping_method'] = 'trim|max_length[255]';
		$rules['shipping_tracking_id'] = 'trim|max_length[255]';
		
		$rules['tax_amount'] = 'trim|numeric';
		$rules['shipping_amount'] = 'trim|numeric';
		$rules['discount_amount'] = 'trim|numeric';
		$rules['coupon_code'] = 'trim|max_length[50]';
		
		$rules['referring_affiliate'] = 'trim|callback__check_username';
		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['date_purchased'] = $this->lang->line('date_purchased');
		$fields['due_date'] = $this->lang->line('due_date');
		$fields['order_status'] = $this->lang->line('order_status');
		$fields['customers_name'] = $this->lang->line('name');
		$fields['customers_address_1'] = $this->lang->line('address_1');
		$fields['customers_address_2'] = $this->lang->line('address_2');
		$fields['customers_city'] = $this->lang->line('city');
		$fields['customers_state'] = $this->lang->line('state');
		$fields['customers_postal_code'] = $this->lang->line('postal_code');
		$fields['customers_country'] = $this->lang->line('country');
		$fields['customers_company'] = $this->lang->line('company');
		$fields['customers_telephone'] = $this->lang->line('home_phone');
		$fields['customers_primary_email'] = $this->lang->line('primary_email');
		$fields['product_type'] = $this->lang->line('product_type');
		$fields['shipping_name'] = $this->lang->line('name');
		$fields['shipping_address_1'] = $this->lang->line('address_1');
		$fields['shipping_address_2'] = $this->lang->line('address_2');
		$fields['shipping_city'] = $this->lang->line('city');
		$fields['shipping_state'] = $this->lang->line('state');
		$fields['shipping_postal_code'] = $this->lang->line('postal_code');
		$fields['shipping_country'] = $this->lang->line('country');
		$fields['shipping_company'] = $this->lang->line('company');
		$fields['shipping_method'] = $this->lang->line('shipping_method');
		$fields['shipping_tracking_id'] = $this->lang->line('shipping_tracking_id');
		
		$fields['tax_amount'] = $this->lang->line('tax_amount');
		$fields['shipping_amount'] = $this->lang->line('shipping_amount');
		$fields['discount_amount'] = $this->lang->line('discount_amount');
		$fields['coupon_code'] = $this->lang->line('coupon_code');
		
		$fields['referring_affiliate'] = $this->lang->line('referring_affiliate');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_update_invoice()
	{
		//check for correct options
		if (!empty($_POST))
		{
			if (!empty($_POST['product_id']))
			{
				//check if product type is membership
				if ($this->input->post('product_type') == 'membership')
				{
					if (empty($_POST['product_id'][0])) 
					{
						echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_id').'</div>';
						echo '<script>showResponse();</script>';
						exit();
					}	
					else
					{
						//check for a valid product id
						if ($this->invoices_model->_check_product_id($_POST['product_id'][0], $this->input->post('product_type')) == false)
						{
							echo '<div class="error" id="error-messages">' . $this->lang->line('invalid_product_id') . ' ' . $_POST['product_id'][0] . '</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}	
				}
				else
				{
					$total = 0;
					
					foreach ($this->input->post('product_id') as $k => $v)
					{
						if (!empty($v))
						{
							//check for a valid product id
							if ($this->invoices_model->_check_product_id($v, $this->input->post('product_type')) == false)
							{
								echo '<div class="error" id="error-messages">' . $this->lang->line('invalid_product_id') . ' ' . $v . '</div>';
								echo '<script>showResponse();</script>';
								exit();
							}
							
							$total++;
						}	
					}	
					
					if ($total == 0)
					{
						echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_id').'</div>';
						echo '<script>showResponse();</script>';
						exit();
					}
				}
			}
			else
			{
				echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_id').'</div>';
				echo '<script>showResponse();</script>';
				exit();
			}
			
			if (!empty($_POST['unit_price']))
			{
				//check if product type is membership
				if ($this->input->post('product_type') == 'membership')
				{
					if (!empty($_POST['unit_price'][0]))
					{
						if (!is_numeric($_POST['unit_price'][0])) {
							echo '<div class="error" id="error-messages">'.$this->lang->line('price_must_be_numeric').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}		
				}
				else
				{
					foreach ($this->input->post('unit_price') as $k => $v)
					{
						if (!empty($v))
						{
							if (!is_numeric($v)) {
								echo '<div class="error" id="error-messages">'.$this->lang->line('price_must_be_numeric').'</div>';
								echo '<script>showResponse();</script>';
								exit();
							}
						}		
					}
				}	
			}
			
			if (!empty($_POST['quantity']))
			{
				//check if product type is membership
				if ($this->input->post('product_type') == 'membership')
				{
					if (!empty($_POST['quantity'][0]))
					{
						if (!is_numeric($_POST['quantity'][0])) {
							echo '<div class="error" id="error-messages">'.$this->lang->line('quantity_must_be_numeric').'</div>';
							echo '<script>showResponse();</script>';
							exit();
						}
					}		
				}
				else
				{
					foreach ($this->input->post('quantity') as $k => $v)
					{
						if (!empty($v))
						{
							if (!is_numeric($v)) {
								echo '<div class="error" id="error-messages">'.$this->lang->line('quantity_must_be_numeric').'</div>';
								echo '<script>showResponse();</script>';
								exit();
							}
						}		
					}	
				}
			}
		}
		//set form validation rules
		
		$rules['date_purchased'] = 'trim|required';
		$rules['due_date'] = 'trim|required';
		$rules['order_status'] = 'trim|required';
		$rules['customers_name'] = 'trim|required|max_length[255]';
		$rules['customers_address_1'] = 'trim|max_length[255]';
		$rules['customers_address_2'] = 'trim|max_length[255]';
		$rules['customers_city'] = 'trim|max_length[255]';
		$rules['customers_state'] = 'trim|max_length[50]';
		$rules['customers_postal_code'] = 'trim|max_length[25]';
		$rules['customers_country'] = 'trim|integer';
		$rules['customers_company'] = 'trim|max_length[50]';
		$rules['customers_telephone'] = 'trim|max_length[50]';
		$rules['customers_primary_email'] = 'trim|valid_email';
		$rules['shipping_name'] = 'trim|max_length[255]';
		$rules['shipping_address_1'] = 'trim|max_length[255]';
		$rules['shipping_address_2'] = 'trim|max_length[255]';
		$rules['shipping_city'] = 'trim|max_length[255]';
		$rules['shipping_state'] = 'trim|max_length[50]';
		$rules['shipping_postal_code'] = 'trim|max_length[25]';
		$rules['shipping_country'] = 'trim|integer';
		$rules['shipping_company'] = 'trim|max_length[50]';
		$rules['shipping_method'] = 'trim|max_length[255]';
		$rules['shipping_tracking_id'] = 'trim|max_length[255]';
		$rules['tracking_id'] = 'trim|numeric|callback__check_tracker_id';
		
		$rules['tax_amount'] = 'trim|numeric';
		$rules['shipping_amount'] = 'trim|numeric';
		$rules['invoice_notes'] = 'trim';
		
		$rules['referring_affiliate'] = 'trim|callback__check_username';
		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['date_purchased'] = $this->lang->line('date_purchased');
		$fields['due_date'] = $this->lang->line('due_date');
		$fields['order_status'] = $this->lang->line('order_status');
		$fields['customers_name'] = $this->lang->line('name');
		$fields['customers_address_1'] = $this->lang->line('address_1');
		$fields['customers_address_2'] = $this->lang->line('address_2');
		$fields['customers_city'] = $this->lang->line('city');
		$fields['customers_state'] = $this->lang->line('state');
		$fields['customers_postal_code'] = $this->lang->line('postal_code');
		$fields['customers_country'] = $this->lang->line('country');
		$fields['customers_company'] = $this->lang->line('company');
		$fields['customers_telephone'] = $this->lang->line('home_phone');
		$fields['customers_primary_email'] = $this->lang->line('primary_email');
		$fields['shipping_name'] = $this->lang->line('name');
		$fields['shipping_address_1'] = $this->lang->line('address_1');
		$fields['shipping_address_2'] = $this->lang->line('address_2');
		$fields['shipping_city'] = $this->lang->line('city');
		$fields['shipping_state'] = $this->lang->line('state');
		$fields['shipping_postal_code'] = $this->lang->line('postal_code');
		$fields['shipping_country'] = $this->lang->line('country');
		$fields['shipping_company'] = $this->lang->line('company');
		$fields['shipping_method'] = $this->lang->line('shipping_method');
		$fields['shipping_tracking_id'] = $this->lang->line('shipping_tracking_id');
		
		$fields['tax_amount'] = $this->lang->line('tax_amount');
		$fields['shipping_amount'] = $this->lang->line('shipping_amount');
		$fields['referring_affiliate'] = $this->lang->line('referring_affiliate');
		$fields['invoice_notes'] = $this->lang->line('invoice_notes');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}

	// ------------------------------------------------------------------------
	
	function _check_username()
	{
		if ($this->db_validation_model->_validate_field('members', 'username', $this->validation->referring_affiliate) == false)
		{
			$this->validation->set_message('_check_username', $this->lang->line('invalid_referring_affiliate'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------
	
	function _check_tracker_id()
	{
		$id = $this->validation->tracking_id;
		
		if (!empty($id))
		{
			if ($this->db_validation_model->_validate_field('tracking', 'id', $this->validation->tracking_id) == false)
			{
				$this->validation->set_message('_check_tracker_id', $this->lang->line('invalid_tracking_id'));
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
}
?>