<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - languages.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage languages
|
*/

class languages extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load languages model
		$this->load->model('settings_model');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/languages/view_languages');
	}
	
	// ------------------------------------------------------------------------
	
	function add_language()
	{
		/*
		| -----------------------------------------
		| add a new language
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//run admin validation check
		if ($this->_check_language() == true)
		{		
			//add the language into db
			$id = $this->settings_model->_add_language();		

			//redirect to languages module
			echo '<script>window.location = "' . jrox_admin_url().'languages/view_languages"</script>';
		}
		else
		{
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function delete_language()
	{
		/*
		| --------------------------------------------
		| delete the language from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->settings_model->_delete_language((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/languages/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/languages/view_languages');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function update_language()
	{
		/*
		| -----------------------------------------
		| view languages
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_language');
		
		$this->load->helper('file');
		
		//run admin validation check
		if ($this->_check_update_language() == false)
		{		
			if (empty($_POST))
			{
			
				//get language file details
				$slang = $this->settings_model->_get_language((int)($this->uri->segment(4)));
		
				if (file_exists(APPPATH . 'language/' . $slang['name'] . '/common_lang.php'))
				{
					$data['writeable'] = is_writable(APPPATH . 'language/' . $slang['name'] . '/common_lang.php') ? true : false;
					
					include_once(APPPATH . 'language/' . $slang['name'] . '/common_lang.php');
					
					$data['lang_file'] = $lang;
					$data['name'] = $slang['name'];
					$data['language_id'] = $slang['language_id'];
					
					//load template
					load_form('admin', 'tpl_adm_manage_language', $data);	
				}
				else
				{
					show_error($this->lang->line('no_language_found'));
				}	
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
	
			if ($this->settings_model->_update_language((int)$this->uri->segment(4)) == true)	
			{
				//ajax message
				echo '<script>alert(\'' . $this->lang->line('update_language_success') . '\')</script>';		
				exit();	
			}
			else
			{
				echo '<script>alert(\'' . $this->lang->line('could_not_update_language_file') . '\')</script>';		
				exit();	
			}
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function view_languages()
	{
		/*
		| -----------------------------------------
		| view languages
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_languages');
		$data['height'] = '350';
		$data['width'] = '600';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_languages', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get languages via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '350';
		$data['width'] = '600';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get languages
		$row = $this->settings_model->_get_languages($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
	 
		//add the data to the array
		$data['languages'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'languages', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_languages_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function set_default()
	{
		//set the default language
		$data = $this->security_model->_load_config('admin');
		
		$code = $this->uri->segment(4);
		
		$sdata = array('sts_store_default_language' => $code);
		
		$this->db_validation_model->_update_db_settings($sdata);
		
		redirect(ADMIN_ROUTE . '/languages/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
	}

	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_update_language()
	{
		if (!empty($_POST))
		{
			$data = $this->db_validation_model->_clean_data($_POST);
		
			foreach ($data as $k => $v)
			{	
				if (empty($v))
				{
					echo '<div class="error" id="error-messages">' . $k . ' ' . $this->lang->line('cannot_be_empty') . '</div>';
					exit();
				}
			}
			
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_language()
	{
		//set form validation rules
		
		$rules['name'] = 'trim|required|min_length[2]|max_length[50]|callback__check_lang_path';
		$rules['code'] = 'trim|required|max_length[5]';
		$rules['image'] = 'trim|required|max_length[255]|callback__check_image_path';
		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['name'] = $this->lang->line('language_name');
		$fields['code'] = $this->lang->line('code');
		$fields['image'] = $this->lang->line('image');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_lang_path()
	{
		$vpath = APPPATH . 'language/' . $this->validation->name . '/common_lang.php';
		
		if (!file_exists($vpath))
		{
			$this->validation->set_message('_check_lang_path', $this->lang->line('invalid_language_path'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_image_path()
	{
		$vpath = $this->config->item('base_physical_path') . '/images/misc/flags/' . $this->validation->image;
		
		if (!file_exists($vpath))
		{
			$this->validation->set_message('_check_image_path', $this->lang->line('invalid_language_image_path'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
}
?>