<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - mailing_lists.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage mailing_lists
|
*/

class Mailing_Lists extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load mailing_lists model
		$this->load->model('mailing_lists_model');
		
		//load css body style
		$this->config->set_item('css_body', 'GJ');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		$this->config->set_item('members_uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/members_table');
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/mailing_lists/view_mailing_lists');
	}
	
	// ------------------------------------------------------------------------
	
	function add_mailing_list()
	{
		/*
		| -----------------------------------------
		| add a new mailing_list
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_mailing_list');
		$data['submit_url'] = jrox_admin_url().'mailing_lists/add_mailing_list';
		$data['update_link'] = 'mailing_lists';
		$data['add_link'] = 'add_mailing_list';
		
		$this->validation->mailing_list_id = '';
		
		//run admin validation check
		if ($this->_check_mailing_list() == false)
		{		
			//reload add mailing_list form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_mailing_list', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the mailing_list into db
			$data = $this->mailing_lists_model->_add_mailing_list();		

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('mailing_list') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_mailing_list()
	{
		/*
		| --------------------------------------------
		| delete the mailing_list from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->mailing_lists_model->_delete_mailing_list((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/mailing_lists/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/mailing_lists/view_mailing_lists');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_list_members()
	{
		/*
		| -----------------------------------------
		| view mailing_lists
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['mailing_list_id'] = (int)($this->uri->segment(4));
		
		//get name of mailing list
		$details = $this->db_validation_model->_get_details('email_mailing_lists', '', 'mailing_list_id', $data['mailing_list_id']);
		
		$name = $details[0]['mailing_list_name'];
		
		//set page title
		$data['page_title'] = $this->lang->line('view_list_members'). ' - ' . $name;
		$data['height'] = '250';
		$data['width'] = '400';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_list_members', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function members_table()
	{	
		/*
		| ---------------------
		| get list members via ajax
		| ---------------------
		*/
	
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['mailing_list_id'] = (int)($this->uri->segment(8));
		
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/members_table'  . '/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '250';
		$data['width'] = '400';
		
		//get follow_ups
		$row = $this->mailing_lists_model->_get_list_members($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['mailing_list_id']);	
	 	
		//add the data to the array
		$data['list_members'] = $row;	
		
		//count the number of follow ups
		$total_follow_ups = $this->db_validation_model->_get_details('email_follow_ups', 'sequence, follow_up_id, follow_up_name', 'mailing_list_id', (int)($this->uri->segment(8)), 'sequence', 'ASC');
		
		
		$data['total_follow_ups'] = array('1' => '1');
		
		if (!empty($total_follow_ups))
		{
			$j = 0;
			for ($i=1; $i<=count($total_follow_ups); $i++)
			{
				$data['total_follow_ups'][$i] = $i . ' - ' . limit_chars($total_follow_ups[$j]['follow_up_name'],25);
				$j++;
			}
		}
		
		//count the rows
		$total_rows = $this->db_validation_model->_get_count('email_mailing_list_members', 'WHERE mailing_list_id=\'' . (int)($this->uri->segment(8)) . '\'');
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['members_uri'], 'email_mailing_lists', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['mailing_list_id']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_list_members_table', $data, false, false);


	
	}
	
	// ------------------------------------------------------------------------
	
	function view_mailing_lists()
	{
		/*
		| -----------------------------------------
		| view mailing_lists
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_mailing_lists');
		$data['height'] = '250';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_mailing_lists', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get mailing_lists via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '250';
		$data['width'] = '400';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get mailing_lists
		$row = $this->mailing_lists_model->_get_mailing_lists($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
	 	
		
		$data['template_options'] = $this->mailing_lists_model->_get_custom_templates();
	 
		//add the data to the array
		$data['mailing_lists'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'email_mailing_lists', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_mailing_lists_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_mailing_list()
	{
		/*
		| -----------------------------------------
		| add a new mailing_list
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_mailing_list');
		$data['submit_url'] = jrox_admin_url().'mailing_lists/update_mailing_list/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_mailing_list';
		$data['update_link'] = 'mailing_lists';
		
		//run admin validation check
		if ($this->_check_mailing_list() == false)
		{		
			//reload add mailing_list form
			if (empty($_POST))
			{
				$mdata = $this->mailing_lists_model->_get_mailing_list_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_mailing_list', $data);
				}
				else
				{
					//load add mailing_list page
					redirect(ADMIN_ROUTE . '/mailing_lists/view_mailing_lists');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the mailing_list into db
			$data = $this->mailing_lists_model->_update_mailing_list((int)$this->uri->segment(4));	
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_mailing_list_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function update_list_members()
	{
		/*
		| ---------------------------
		| mass update list members
		| ---------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['mailing_list_id'] = (int)($this->uri->segment(4));
	
		if ($this->_check_sequence() == true)
		{	
			$this->mailing_lists_model->_change_follow_up_sequence($data['mailing_list_id']);
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('follow_ups_updated_successfully'));
			echo '<script>self.parent.location.reload(true);</script>';	
		}
		else
		{
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_sequence()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
	
		foreach ($data as $k => $v)
		{
			if (strstr($k, "sequence") == true) 
			{
				$rules[$k] = 'trim|required|numeric';
				$fields[$k] = $k ;
			}

		}
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_mailing_list()
	{
		//set form validation rules
		
		$rules['mailing_list_name'] = 'trim|required|min_length[2]|max_length[50]';

		$this->validation->set_rules($rules);

		//repopulate form

		$fields['mailing_list_name'] = $this->lang->line('mailing_list_name');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	
	
	// ------------------------------------------------------------------------
}
?>