<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - manufacturers.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage manufacturers
|
*/

class Manufacturers extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load manufacturers model
		$this->load->model('manufacturers_model');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/manufacturers/view_manufacturers');
	}
	
	// ------------------------------------------------------------------------
	
	function add_manufacturer()
	{
		/*
		| -----------------------------------------
		| add a new manufacturer
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_manufacturer');
		$data['submit_url'] = jrox_admin_url().'manufacturers/add_manufacturer';
		$data['update_link'] = 'manufacturers';
		$data['add_link'] = 'add_manufacturer';
		
		$this->validation->manufacturer_id_redirect = '';
		$this->validation->manufacturer_id = '';
		
		//run admin validation check
		if ($this->_check_manufacturer() == false)
		{		
			//reload add manufacturer form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_manufacturer', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the manufacturer into db
			$data = $this->manufacturers_model->_add_manufacturer();		
			
			//check if a photo has been uploaded
			if (!empty($_FILES))
			{
				$image_data = $this->_upload_image($data);
				
				if (empty($image_data['success']))
				{
					echo '<div class="error" id="error-messages">' . $image_data['msg'] . '</div>';
					exit();
				}
			}

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('manufacturer') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_manufacturer()
	{
		/*
		| --------------------------------------------
		| delete the manufacturer from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->manufacturers_model->_delete_manufacturer((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/manufacturers/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/manufacturers/view_manufacturers');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_manufacturers()
	{
		/*
		| -----------------------------------------
		| view manufacturers
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_manufacturers');
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_manufacturers', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get manufacturers via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '530';
		$data['width'] = '400';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get manufacturers
		$row = $this->manufacturers_model->_get_manufacturers($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);

	 
		//add the data to the array
		$data['manufacturers'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'manufacturers', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manufacturers_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the product
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//run change status function
		if ($this->db_validation_model->_change_status_field('manufacturers', 'manufacturer_id', (int)$this->uri->segment(4), 'manufacturer_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/manufacturers/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('update_manufacturer_success'));
				
				redirect(ADMIN_ROUTE . '/manufacturer/view_manufacturer');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_manufacturer()
	{
		/*
		| -----------------------------------------
		| update a new manufacturer
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_manufacturer');
		$data['submit_url'] = jrox_admin_url().'manufacturers/update_manufacturer';
		$data['add_link'] = 'update_manufacturer';
		$data['update_link'] = 'manufacturers';
		
		$this->validation->manufacturer_id_redirect = '<input type="hidden" id="manufacturer_id" name="manufacturer_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->manufacturer_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_manufacturer() == false)
		{		
			//reload add manufacturer form
			if (empty($_POST))
			{
				$mdata = $this->manufacturers_model->_get_manufacturer_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_manufacturer', $data);
				}
				else
				{
					//load add manufacturer page
					redirect(ADMIN_ROUTE . '/manufacturers/view_manufacturers');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the manufacturer into db
			$data = $this->manufacturers_model->_update_manufacturer((int)$this->uri->segment(4));	
			
			
			//check if a photo has been uploaded
			if (!empty($_FILES) && $_FILES['userfile']['error'] != 4)
			{
				$image_data = $this->_upload_image($data['manufacturer_id']);
				
				if (empty($image_data['success']))
				{
					echo '<div class="error" id="error-messages">' . $image_data['msg'] . '</div>';
					exit();
				}
			}
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_manufacturer_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_manufacturer()
	{
		//set form validation rules
		
		$rules['manufacturer_name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['manufacturer_meta_description'] = 'trim|max_length[255]';
		$rules['manufacturer_meta_image'] = 'trim|max_length[255]';
		$rules['manufacturer_meta_keywords'] = 'trim|max_length[255]';
		$rules['manufacturer_description'] = 'trim|max_length[255]';
		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['manufacturer_name'] = $this->lang->line('manufacturer');
		$fields['manufacturer_meta_description'] = $this->lang->line('description');
		$fields['manufacturer_meta_image'] = $this->lang->line('manufacturer_meta_image');
		$fields['manufacturer_meta_keywords'] = $this->lang->line('keywords');
		$fields['manufacturer_description'] = $this->lang->line('manufacturer_description');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _upload_image($id = '')
	{		
		$this->load->model('uploads_model');
		
		//upload the photo
		$data = $this->uploads_model->_upload_photo('manufacturers', $this->config->item('sts_products_manufacturer_image_auto_resize'));
		
		//add photo to db
		if (!empty($data['success']))
		{
			
			//add the image to the manufacturer
			$sdata['config'] = array(
								'table'	=>	'manufacturers',
								'key'	=>	'manufacturer_id',
								'value' 	=>	$id,
								);
			
			$sdata['fields'] = array (
									'manufacturer_image'	=> 	$data['info']['file_name']
									);			
			
			if (!$this->uploads_model->_update_image_db($sdata))
			{
				return false;
			}
		}
		
		return $data;
		
	}
	
	// ------------------------------------------------------------------------
}
?>