<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - modules.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage modules
|
*/

class Modules extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load modules model
		$this->load->model('modules_model');
		
		//load inflector
		$this->load->helper('inflector');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		
		$this->module_options = array(					
										'account_add' => 'account add',
										'account_update' => 'account update',
										'account_delete' => 'account delete',
										'login' => 'account login',
										'advertising' => 'advertising',
										'affiliate_marketing' => 'affiliate marketing',
										'affiliate_payment' => 'affiliate payment',
										'attribute_callback' => 'attribute callback',
										//'custom_report'	=> 'custom report',
										'data_import'	=> 'data import',
										'data_export'	=>	'date export',
										'member_reporting' => 'member reporting',
										'payment_gateway' => 'payment gateway',
										'post_purchase' => 'post purchase',
										'product_add' => 'product add',
										'product_update' => 'product update',
										'product_delete' => 'product delete',
										'shipping'	=> 'shipping',
										
										//'social_marketing' => 'social_marketing',
										'stats_reporting' => 'stats and reporting',
									);

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/modules/view_modules');
	}
	
	// ------------------------------------------------------------------------
	
	function add_module()
	{
		/*
		| -----------------------------------------
		| add a new module
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		$data['submit_url'] = jrox_admin_url().'modules/add_module';

		//set page title
		$data['page_title'] = $this->lang->line('add_module');
		
		$data['module_options'] = $this->module_options;
		
		//run admin validation check
		if ($this->_check_module() == false)
		{		
			//reload add module form
			if (empty($_POST))
			{
				
				$this->validation->window_height_size = '500';
				$this->validation->window_width_size = '500';
				
				//load template
				load_form('admin', 'tpl_adm_manage_module', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the module into db
			$data = $this->modules_model->_add_module();	
			
			//run the install process if any
			$module_model = '/modules/module_' . $data['module_type'] . '_' . $data['module_file_name'] . '_model';
			
			$this->load->model($module_model, 'modules');
			
			//install the module
			$this->modules->_install_jrox_module($data['module_id']);
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('module') . ' ' . $data['module_id'] . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the box
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('modules', 'module_id', (int)$this->uri->segment(4), 'module_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/modules/table/' . $this->config->item('cache_bx'));
			}
			else
			{
				//set flash data
				//$this->session->set_flashdata('success', $this->lang->line('update_modules_success'));
				
				redirect(ADMIN_ROUTE . '/modules/view_modules');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function delete_module()
	{
		/*
		| --------------------------------------------
		| delete the module from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->modules_model->_delete_module((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/modules/table/' . $this->config->item('cache_bx'));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/modules/view_modules');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_modules()
	{
		/*
		| -----------------------------------------
		| view modules
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_modules');
		$data['height'] = '400';
		$data['width'] = '700';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_modules', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get modules via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '400';
		$data['width'] = '700';
		
		//get modules
		$row = $this->modules_model->_get_modules($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		if (empty($row))
		{
			$row[0] = array(
						'module_id' => 0,
						'module_name' => $this->lang->line('no_modules_found'),
						'total' => 0,
						);
		}
	 
		//add the data to the array
		$data['modules'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'modules', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_modules_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_module()
	{
		/*
		| -----------------------------------------
		| add a new module
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_module');
		$data['submit_url'] = jrox_admin_url().'modules/update_module/' . (int)$this->uri->segment(4);
		
		$data['module_options'] = $this->module_options;
		
		//run admin validation check
		if ($this->_check_module() == false)
		{		
			//reload add module form
			if (empty($_POST))
			{
				$mdata = $this->modules_model->_get_module_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_module', $data);
				}
				else
				{
					//load add module page
					redirect(ADMIN_ROUTE . '/modules/view_modules');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the module into db
			$data = $this->modules_model->_update_module((int)$this->uri->segment(4));	
			
			
			
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_module_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_module()
	{
		//set form validation rules

		$rules['module_type'] = 'trim|required';
		$rules['module_name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['module_description'] = 'trim|max_length[255]';
		$rules['module_file_name'] = 'trim|max_length[255]|callback__check_module_path';
		$rules['window_height_size'] = 'trim|required|numeric';
		$rules['window_width_size'] = 'trim|required|numeric';
		
		
		$this->validation->set_rules($rules);

		//repopulate form
		$fields['module_type'] = $this->lang->line('module_type');
		$fields['module_name'] = $this->lang->line('module_name');
		$fields['module_description'] = $this->lang->line('module_description');
		$fields['module_file_name'] = $this->lang->line('module_file_name');
		$fields['window_height_size'] = $this->lang->line('admin_window_height');
		$fields['window_width_size'] = $this->lang->line('admin_window_width');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_module_path()
	{
		$vpath = APPPATH . 'controllers/modules/module_' . $this->validation->module_type . '_' . $this->validation->module_file_name . '.php';
		
		if (!file_exists($vpath))
		{
			$this->validation->set_message('_check_module_path', $this->lang->line('invalid_module_file_path'));
			return false;
		}
		
		$cpath = APPPATH . 'models/modules/module_' . $this->validation->module_type . '_' . $this->validation->module_file_name . '_model.php';
		
		if (!file_exists($cpath))
		{
			$this->validation->set_message('_check_module_path', $this->lang->line('invalid_model_file_path'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
}
?>