<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - product_categories.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage product_categories
|
*/

class Product_Categories extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load product_categories model
		$this->load->model('product_cat_model', 'pc');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/product_categories/view_categories');
	}
	
	// ------------------------------------------------------------------------
	
	function add_category()
	{
		/*
		| -----------------------------------------
		| add a new category
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_category');
		$data['submit_url'] = jrox_admin_url().'product_categories/add_category';
		$data['update_link'] = 'product_categories';
		$data['add_link'] = 'add_category';
		
		$this->validation->category_id_redirect = '';
		$this->validation->category_id = '';
		
		//run admin validation check
		if ($this->_check_category() == false)
		{		
			//reload add category form
			if (empty($_POST))
			{
				$this->validation->parent_id = '0';
				
				//load template
				load_form('admin', 'tpl_adm_manage_product_category', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the category into db
			$data = $this->pc->_add_category();		
			
			//check if a photo has been uploaded
			if (!empty($_FILES))
			{
				$image_data = $this->_upload_image($data);
				
				if (empty($image_data['success']))
				{
					echo '<div class="error" id="error-messages">' . $image_data['msg'] . '</div>';
					exit();
				}
			}

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('category') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_category()
	{
		/*
		| --------------------------------------------
		| delete the category from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->pc->_delete_category((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/product_categories/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/product_categories/view_categories');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_categories()
	{
		/*
		| -----------------------------------------
		| view product_categories
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_categories');
		$data['height'] = '400';
		$data['width'] = '700';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_product_categories', $data);	
	}
	
	// ------------------------------------------------------------------------

	function table()
	{	
		/*
		| ---------------------
		| get product_categories via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '450';
		$data['width'] = '700';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get product_categories
		$row = $this->pc->_get_product_categories($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		$data['cat_path_array'] = $this->pc->_get_all_product_categories();
		
		
	 
		//add the data to the array
		$data['categories'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'products_categories', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_product_categories_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status of the product
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//run change status function
		if ($this->db_validation_model->_change_status_field('products_categories', 'category_id', (int)$this->uri->segment(4), 'category_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/product_categories/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(6,0) . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('update_category_success'));
				
				redirect(ADMIN_ROUTE . '/products_categories/view_categories');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function update_category()
	{
		/*
		| -----------------------------------------
		| update category
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_category');
		$data['submit_url'] = jrox_admin_url().'product_categories/update_category';
		$data['add_link'] = 'update_category';
		$data['update_link'] = 'product_categories';
		
		$this->validation->category_id_redirect = '<input type="hidden" id="category_id" name="category_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->category_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_category() == false)
		{		
			//reload add category form
			if (empty($_POST))
			{
				$mdata = $this->pc->_get_category_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_product_category', $data);
				}
				else
				{
					//load add category page
					redirect(ADMIN_ROUTE . '/product_categories/view_categories');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the category into db
			$data = $this->pc->_update_category((int)$this->uri->segment(4));	
			
			
			//check if a photo has been uploaded
			if (!empty($_FILES))
			{
				$image_data = $this->_upload_image($data['category_id']);
				
				if (empty($image_data['success']))
				{
					echo '<div class="error" id="error-messages">' . $image_data['msg'] . '</div>';
					exit();
				}
			}
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_category_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_category()
	{
		//set form validation rules
		
		$rules['category_name'] = 'trim|required|min_length[2]|max_length[255]';
		$rules['category_image'] = 'trim|max_length[255]';
		$rules['parent_id'] = 'trim|integer';
		$rules['category_keywords'] = 'trim|max_length[255]';
		$rules['category_description'] = 'trim|max_length[255]';
				
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['category_name'] = $this->lang->line('category');
		$fields['category_image'] = $this->lang->line('category_image');
		$fields['parent_id'] = $this->lang->line('directory_path');
		$fields['category_keywords'] = $this->lang->line('category_keywords');
		$fields['category_description'] = $this->lang->line('category_description');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _upload_image($id = '')
	{		
		$this->load->model('uploads_model');
		
		//upload the photo
		$data = $this->uploads_model->_upload_photo('categories', $this->config->item('sts_products_categories_image_auto_resize'));
		
		//add photo to db
		if (!empty($data['success']))
		{
			
			//add the image to the category
			$sdata['config'] = array(
								'table'	=>	'products_categories',
								'key'	=>	'category_id',
								'value' 	=>	$id,
								);
			
			$sdata['fields'] = array (
									'category_image'	=> 	$data['info']['file_name']
									);			
			
			if (!$this->uploads_model->_update_image_db($sdata))
			{
				return false;
			}
		}
		
		return $data;
		
	}
	
	// ------------------------------------------------------------------------
}
?>