<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - products.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage the different products
|
*/

class Products extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load product_categories model
		$this->load->model('product_cat_model', 'pc');
		
		//load products model
		$this->load->model('products_model', 'prod');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
	}
		
	// ------------------------------------------------------------------------	
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/products/view_products');
	}
	
	// ------------------------------------------------------------------------	
	
	function add_product()
	{
		/*
		| -----------------------------------------
		| add new products
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');		
			
		//run admin validation check
		if ($this->_check_add_product() == false)
		{		
			//ajax form
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}
		else
		{	
			//add the product into db
			$sdata = $this->prod->_add_product($_POST);

			if (!empty($sdata))
			{
				//run add product modules
				$this->_run_product_modules('product_add', $sdata);		
				
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('products_added_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'products/view_products"</script>';
			}
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function manage_videos()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');

		//check videos
		if ($this->_check_videos() == true)
		{
			if ($this->prod->_manage_videos((int)$this->input->post('product_id')))
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('update_video_success'));
			}	
		}
		
		redirect(ADMIN_ROUTE . '/products/update_product/'.$this->input->post('product_id') . '/#fragment-7');
	}
	
	// ------------------------------------------------------------------------
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the product
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//run change status function
		if ($this->db_validation_model->_change_status_field('products', 'product_id', (int)$this->uri->segment(4), 'product_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/products/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('update_product_success'));
				
				redirect(ADMIN_ROUTE . '/products/view_products');
			}
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function delete_product()
	{
		/*
		| --------------------------------------------
		| delete the product from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->prod->_delete_product((int)($this->uri->segment(4))))
		{
			//run add product modules
			$this->_run_product_modules('product_delete', (int)($this->uri->segment(4)));		
			
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/products/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('delete_product_success'));
				
				redirect(ADMIN_ROUTE . '/products/view_products');
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/products/view_products');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{
		/*
		| ---------------------
		| get members via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		if ($data['where_column'] == 'search')
		{
			//load convert library
			$this->load->library('convert');
			
			$data['where_value'] = base64_decode($this->convert->HexToAscii($data['where_value'])); 
		}
		
		//get products
		$row = $this->prod->_get_products($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_column'], $data['where_value']);
		
		
	 
		//add the data to the array
		$data['products'] = $row;	
		
		//count the rows
		if (!empty($data['where_column']) && !empty($data['where_value']))
		{
			//use search query
			if ($data['where_column'] == 'search')
			{
				$this->db->like('product_name', $data['where_value']);
				$this->db->from('products');
				
				$total_rows = $this->db->count_all_results();

				$data['filter_category'] = $this->lang->line('search');
				$data['filter_name'] = str_replace('_', ' ', $data['where_value']);
			}
			else //filter data
			{
		
				switch ($data['where_column'])
				{
					case 'category_id':
						$table = 'products_to_categories';
						$filter = $this->db_validation_model->_get_details('products_categories', 'category_name', $data['where_column'], $data['where_value']);
						$data['filter_category'] = $this->lang->line('category_name');
						$data['filter_name'] = $filter[0]['category_name'];
					break;
					
					case 'attribute_id':
						$table = 'products_to_attributes';
						$filter = $this->db_validation_model->_get_details('products_attributes', 'attribute_name', $data['where_column'], $data['where_value']);
						$data['filter_category'] = $this->lang->line('attribute_name');
						$data['filter_name'] = $filter[0]['attribute_name'];
					break;
					
					case 'vendor_id':
						$table = 'products';
						$filter = $this->db_validation_model->_get_details('vendors', 'vendor_name', $data['where_column'], $data['where_value']);
						$data['filter_category'] = $this->lang->line('vendor_name');
						$data['filter_name'] = $filter[0]['vendor_name'];	
					break;
					
					case 'manufacturer_id':
						$table = 'products';
						$filter = $this->db_validation_model->_get_details('manufacturers', 'manufacturer_name', $data['where_column'], $data['where_value']);
						$data['filter_category'] = $this->lang->line('manufacturer');
						$data['filter_name'] = $filter[0]['manufacturer_name'];	
					break;
					
					default:
						$table = 'products';
						$data['filter_category'] = '';
						$data['filter_name'] = '';
					break;
				}
				
				$total_rows = $this->db_validation_model->_get_count($table, 'WHERE ' . $data['where_column'] . '=\'' . $data['where_value'] . '\'');
			}
		}
		else
		{
			$total_rows = $total_rows = $this->db->count_all('products');
		}
		
		//set pagination
		$data['where_value'] = $this->uri->segment(9,0);
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'products', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_products_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function group_pricing_table()
	{
		/*
		| ---------------------
		| get members via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(6, 0);
		$data['sort_column'] = $this->uri->segment(8, 0);
		$data['sort_order'] = $this->uri->segment(7, 0);
		$data['next_sort_order'] = $this->uri->segment(7) == 'DESC' ? 'ASC' : 'DESC';
		$data['height'] = '440';
		$data['width'] = '400';
		
		$data['uri2'] = ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/group_pricing_table/' . $this->uri->segment(4);
		
		$data['sort_header'] = $data['uri2'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		$row = $this->prod->_get_discount_groups((int)($this->uri->segment(4)), $this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		
	
		//add the data to the array
		$data['groups'] = $row;
		
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri2'], 'discount_groups', $this->session->userdata('per_page'), 6, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_products_group_pricing_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------	
	
	function update_group_pricing()
	{
		/*
		| -----------------------------------------
		| update custom group pricing
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$product_id = (int)$this->uri->segment(4);
		
		//check if there are any users checked for update
		
		if ($this->_check_group_pricing() == true)
		{
			if ($this->prod->_update_group_pricing())
			{
				//echo '<div class="success" id="success">' . $this->lang->line('custom_group_pricing_updated_successfully') . '</div>';
				
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('custom_group_pricing_updated_successfully'));
				
				//redirect to products form
				echo '<script>window.location = "' . jrox_admin_url().'products/update_product/'.$product_id.'"</script>';
			}
		}
		else
		{
			
			echo '<div class="error" id="error-messages">' . $this->lang->line('custom_group_pricing_numeric') . '</div>';
		}

	}
	
	// ------------------------------------------------------------------------	
	
	function set_default_photo()
	{
		/*
		| -----------------------------------------
		| set the default photo to use
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//delete photo
		$this->prod->_set_default_photo((int)$this->uri->segment(4), (int)$this->uri->segment(5, 0));
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('photo_updated_successfully'));
		
		redirect(ADMIN_ROUTE . '/products/update_product/'. (int)$this->uri->segment(5, 0) . '/#fragment-6');
	}
	
	// ------------------------------------------------------------------------	
	
	function view_video()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$id = (int)$this->uri->segment(4);
		
		//delete photo
		if ($data['video'] = $this->prod->_view_video($id))
		{	
			 if ($data['video'][0]['use_external_embed'] == 0)
			 {
			 	$this->load->plugin('flv_player');
				
				$data['video_code'] = Flash_Player(html_entity_decode($data['video'][0]['video_code']), $data['sts_video_player_default_link']);
			 }
			 else
			 {
			 	$data['video_code'] = html_entity_decode($data['video'][0]['video_code']);
			 }
			load_form('admin', 'tpl_adm_view_video', $data);
		}
	}
	
	
	// ------------------------------------------------------------------------
	
	function aff_group_pricing_table()
	{
		/*
		| ---------------------
		| get members via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(6, 0);
		$data['sort_column'] = $this->uri->segment(8, 0);
		$data['sort_order'] = $this->uri->segment(7, 0);
		$data['next_sort_order'] = $this->uri->segment(7) == 'DESC' ? 'ASC' : 'DESC';
		$data['height'] = '350';
		$data['width'] = '400';
		
		$data['uri2'] = ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/aff_group_pricing_table/' . $this->uri->segment(4);
		
		$data['sort_header'] = $data['uri2'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		$data['product_id'] = (int)($this->uri->segment(4));
		
		$row = $this->prod->_get_affiliate_groups((int)($this->uri->segment(4)), $this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		
	
		//add the data to the array
		$data['groups'] = $row;
		
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri2'], 'affiliate_groups', $this->session->userdata('per_page'), 6, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_products_aff_group_pricing_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------	
	
	function update_aff_group_pricing()
	{
		/*
		| -----------------------------------------
		| add a new group
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('custom_affiliate_commissions_per_product');
		$data['submit_url'] = jrox_admin_url().'products/update_aff_group_pricing/' . (int)$this->uri->segment(4) . '/' . (int)$this->uri->segment(5);
		
		//run admin validation check
		if ($this->_check_group() == false)
		{		
			//reload add group form
			if (empty($_POST))
			{
				$mdata = $this->prod->_get_aff_group_pricing((int)$this->uri->segment(4), (int)$this->uri->segment(5));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					
				}
				
				load_form('admin', 'tpl_adm_manage_affiliate_group_pricing', $data);
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the group into db
			
			$data = $this->prod->_update_aff_group_pricing((int)$this->uri->segment(4), (int)$this->uri->segment(5));	
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_group_success'));
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_group_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------	
	
	function delete_photo()
	{
		/*
		| -----------------------------------------
		| update custom group pricing
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$photo_id = (int)$this->uri->segment(4);
		
		//delete photo
		$id = $this->prod->_delete_photo($photo_id);
		
		$this->prod->_check_default_photo($id);
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('photo_deleted_successfully'));
		
		redirect(ADMIN_ROUTE . '/products/update_product/'.$id . '/#fragment-6');
	}	
	
	// ------------------------------------------------------------------------	
	
	function clone_product()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$pid = (int)$this->uri->segment(4);
		
		$new_id = $this->prod->_clone_product($pid);
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('product_cloned_successfully'));
		
		redirect(ADMIN_ROUTE . '/products/update_product/'.$new_id);
	}
	
	// ------------------------------------------------------------------------	
	
	function update_product()
	{
		/*
		| --------------------------------------------
		| update the details of the product in the db
	    | --------------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_product');
		$data['height'] = '550';
		$data['width'] = '400';
		
		//format date
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[0];
		
		//set form
		$data['submit_type'] = 'update_product/' . $this->uri->segment(4);
		
		//load plugins
		$this->load->plugin($this->config->item('sts_content_html_editor'));
		
		if ($this->config->item('sts_content_html_editor') == 'fckeditor')
		{
			if ($this->config->item('sts_admin_enable_wysiwyg_content') == '1')
			{
				$data['editor_path'] =  _generate_javascript($areas = array('product_overview', 'product_description_1', 'product_description_2'), 'description');
			}
		}
		else
		{
			$data['editor_path'] =  '<script language="Javascript" type="text/javascript" src="' . base_url() . 'js/scripts/innovaeditor.js"></script>';
		}
				
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//run admin validation check
		if ($this->_check_update_product() == false)
		{
			//get the details from the db	
			if ((int)$this->uri->segment(4))
			{
				if (empty($_POST))
				{
					//get the details of the product
					if ($product_data = $this->prod->_get_product_details((int)($this->uri->segment(4)))) 
					{
						$data['products_attributes'] = $product_data['products_attributes'];
						$data['products_to_attributes'] = $product_data['products_to_attributes'];
						$data['products_to_categories'] = $product_data['products_to_categories'];
						$data['photos'] = $product_data['photos'];
						$data['categories'] = $product_data['categories'];
						$data['affiliate_groups'] = $product_data['affiliate_groups'];
						$data['discount_groups'] = $product_data['discount_groups'];
						$data['email_mailing_lists'] = $product_data['email_mailing_lists'];
						$data['tax_zones'] = $product_data['tax_zones'];
						$data['post_purchase_modules'] = $product_data['post_purchase_modules'];
						$data['signup_modules'] = $product_data['signup_modules'];
						$data['expires_modules'] = $product_data['expires_modules'];
						$data['manufacturers'] = $product_data['manufacturers'];
						$data['vendors'] = $product_data['vendors'];
						$data['videos'] = $product_data['videos'];
						
						//add the data to the array
						$data['aff_groups_row'] = $this->prod->_get_affiliate_groups((int)($this->uri->segment(4)));
						
						//add the data to the array
						$data['disc_groups_row'] = $this->prod->_get_discount_groups((int)($this->uri->segment(4)));

						
						//setup validation for product
						foreach ($product_data['product'][0] as $key => $value)
						{
							$this->validation->$key = $value;
							
							switch ($key)
							{
								case 'date_available':
								case 'date_expires':
								
									if (!empty($value))
									{
										$this->validation->$key = date($fdate[1], $value);
									}
														
								break;
								
									
								case 'date_added':
								case 'date_modified':
									
									$this->validation->$key = check_string_value($value, 'date');
								
								break;
								
								case 'product_type':
									if ($value == 'membership')
									{
										$this->validation->pricing_header = $this->lang->line('membership_pricing');
									}
									else
									{
										$this->validation->pricing_header = $this->lang->line('product_pricing');
									}
								break;
								
								case 'product_overview';
								
									if ($this->config->item('sts_content_html_editor') == 'innovaeditor')
									{
										$html_type = $data['sts_admin_enable_wysiwyg_content'];
 									}
									else
									{
										$html_type = 0;
									}
									
									$this->validation->$key = HTML_Editor('oEdit1', $html_type, 'description', $value, $key, '300');
									
								break;
								
								case 'product_description_1';
									
									if ($this->config->item('sts_content_html_editor') == 'innovaeditor')
									{
										$html_type = $data['sts_admin_enable_wysiwyg_content'];
 									}
									else
									{
										$html_type = 0;
									}
									
									$this->validation->$key = HTML_Editor('oEdit2', $html_type, 'description', $value, $key, '300');
									
								break;
								
								case 'product_description_2';
									
									if ($this->config->item('sts_content_html_editor') == 'innovaeditor')
									{
										$html_type = $data['sts_admin_enable_wysiwyg_content'];
 									}
									else
									{
										$html_type = 0;
									}
									
									$this->validation->$key = HTML_Editor('oEdit3', $html_type, 'description', $value, $key, '300');
																	
								break;

							}
						}
						
						//setup product categories
						$a = array(); $b = array();
						$cat_path_array = $this->pc->_get_all_product_categories();
						
						foreach ($cat_path_array as $k => $v)
						{
							 $c = $this->pc->_get_path($v['category_id'], $v['category_name'], $v['parent_id'], $cat_path_array);
							array_push($b, $c);
							array_push($a, $v['category_id']);
						}
						
						
						$categories = combine_array($a, $b);		
						asort($categories);
						
						$this->validation->product_categories = form_dropdown('product_categories[]', 
																				$categories, 
																				$product_data['products_to_categories'], 
																				'multiple="multiple" id="product_categories" class="list-menu3 text-upper"');
						
						
						//setup product attributes
						$this->validation->product_attributes = form_dropdown('product_attributes[]', 
																				$product_data['products_attributes'], 
																				$product_data['products_to_attributes'], 
																				'multiple="multiple" id="product_attributes" class="list-menu3 text-upper"');
																				
						//setup product photo
						if (!empty($product_data['photos']))
						{						
							$data['photos'] = $product_data['photos'];	
							//set default photo
							foreach($product_data['photos'][0] as $key => $value)
							{
								$this->validation->$key = $value;
							}
							
							if ($this->config->item('sts_store_image_auto_resize') == 1)
							{
								$photo = $this->validation->raw_name.'_jrox'.$this->validation->file_ext;
								$this->validation->product_photo_url_resize = base_url() . 'images/' .  $data['images_products_dir'] . '/' . $this->validation->photo_file_name;
								$this->validation->product_photo_class = _check_thickbox();
								
							}
							else
							{
								$photo = $this->validation->photo_file_name;
								$this->validation->product_photo_url_resize = 0;
							}
							
							$this->validation->product_photo_url = base_url() . 'images/' .  $data['images_products_dir'] . '/' . $photo;
							$this->validation->product_photo_delete = true;			
						}
						else
						{
							$this->validation->product_photo_url = base_url() . 'themes/admin/' . $data['sts_admin_layout_theme'] .'/images/product1.jpg';
							$this->validation->product_photo_delete = false;
							$this->validation->product_photo_url_resize = 0;
						}							
					}
					else
					{
						redirect(ADMIN_ROUTE . '/products/view_products');
						exit();
					}
					
					//reload update admin form
					$this->validation->product_id = $this->uri->segment(4);
					
					$data['membership_products'] = $this->prod->_get_membership_products(true, 'select_membership_product');
					
					//set the URL
					$data['product_link'] = _jrox_public_url() . PRODUCTS_ROUTE . '/details/' . $this->validation->product_id . '/' . url_title($this->validation->product_name);
					
					load_admin_tpl('admin', 'tpl_adm_manage_product', $data);
				}
				else
				{
					//echo ajax message
					
					echo '<div class="error">' . $this->validation->error_string . '</div>';
				}
					
			}
		}
		else
		{
			//update the admin
			$id = $this->prod->_update_product((int)($this->uri->segment(4)));
			
			//run add product modules
			$this->_run_product_modules('product_update', (int)($this->uri->segment(4)));		
			
			//echo ajax message
			$this->session->set_flashdata('success', $this->lang->line('update_product_success'));
			echo '<script>window.location = "' . jrox_admin_url().'products/update_product/' . $this->uri->segment(4) . '"</script>';
		}		
	
	}
	
	// ------------------------------------------------------------------------	

	function update_products()
	{
		/*
		| ---------------------------
		| mass update product details
		| ---------------------------
		*/
		//echo '<pre>'; print_r($_POST); exit();
		//check if there are any users checked for update
		if ($this->input->post('change-status') == 'update_products')
		{
			$this->prod->_mass_update_products($this->input->post('product_name'),$this->input->post('product_price'), $this->input->post('product_id'), $this->input->post('product_sort'));
		}
		elseif ($this->input->post('change-status') == 'addcategory')
		{
			$this->prod->_mass_add_product_categories($this->input->post('product'), $this->input->post('category_name'));
		}
		else
		{
			if ($this->input->post('product') AND count($this->input->post('product')) > 0)
			{
				$this->prod->_change_status($this->input->post('product'), $this->input->post('change-status'));
			}
		}
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('products_updated_successfully'));
		echo '<script>self.parent.location.reload(true);</script>';	
	}
	
	// ------------------------------------------------------------------------
	
	function upload_photo()
	{		
		/*
		| --------------------------------------------
		| upload product photos
		| --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$product_id = (int)($this->input->post('product_id'));
		
		$this->load->model('uploads_model');
		
		//upload the photo
		$resize = $data['sts_store_image_auto_resize'];
		
		if (!empty($_FILES))
		{
			foreach ($_FILES as $k => $v)
			{
				if (!empty($v['name']))
				{
					$data = $this->uploads_model->_upload_photo('products', $resize , $k);
				
					if ($data['success'])
					{
					
						
						
						//insert new photo into members photo table
						$insert_data = array (
												'product_id'	=> 	$product_id,
												'photo_file_name' => $data['info']['file_name'], 
												'raw_name'	=> $data['info']['raw_name'],
												'file_ext'	=> $data['info']['file_ext'],
												'file_type'	=> $data['info']['file_type'],
												'original_file_name' => $data['info']['orig_name'],
												'image_resized'	=>	$this->config->item('sts_store_image_auto_resize')
											);	
						
						$this->uploads_model->_insert_image_db($insert_data, 'products_photos');
						
					}
					else
					{
						//set flash data
						$this->session->set_flashdata('error', $data['msg']);
						
						//redirect back to the admin photo upload tab	
						redirect(ADMIN_ROUTE . '/products/update_product/' . (int)($this->input->post('product_id')) . '/#fragment-6');		
					}
				}
			}
			
			$this->prod->_check_default_photo($product_id);
			
			if ($data['success'])
			{
				//set success message
				$this->session->set_flashdata('success', $this->lang->line('image_uploaded_successfully'));
			}
		}	
					
		//redirect back to the admin photo upload tab
		redirect(ADMIN_ROUTE . '/products/update_product/' . $product_id . '/#fragment-6');			
		
	}

	// ------------------------------------------------------------------------	
	
	function view_products()
	{	
		/*
		| -----------------------------------------
		| view all products
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_products');
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);

		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_products', $data);	

	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_aff_number($level, $i)
	{
		if (preg_match('/^[\/.0-9]+$/', $level) == 0 ) 
		{
			$this->validation->set_message('_check_aff_number', $this->lang->line('number_forward_slash_only'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_group()
	{
		//set form validation rules
		
		for ($i=1;$i<=10;$i++)
		{
			$level = 'commission_level_' . $i;
			if ($this->config->item('member_enable_bilevel_affiliate_groups') == true)
			{
				$rules[$level] = 'trim|callback__check_aff_number';
			}
			else
			{
				$rules[$level] = 'trim|numeric';
			}
		}	
		
		
		$this->validation->set_rules($rules);

		//repopulate form

		for ($i=1;$i<=10;$i++)
		{
			$level = 'commission_level_' . $i;
			$fields[$level] = $this->lang->line($level);
		}	
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _run_product_modules($type = '', $data = '')
	{
		//load members model
		$this->load->model('modules_model');
		
		//run modules
		$sdata = $this->modules_model->_run_modules($type, 'admin');
		
		if (!empty($sdata))
		{
			//load the api config
			$this->config->load('api');
			
			//load models
			if ($this->config->item('jem_api_' . $type . '_models'))
			{
				$api_models = explode(',', $this->config->item('jem_api_' . $type . '_models'));
				
				foreach ($api_models as $api)
				{
					$this->load->model(trim($api . '_model'), $api . '_api');
				}
			}
			
			//load helpers
			if ($this->config->item('jem_api_' . $type . '_helpers'))
			{
				$helpers = explode(',', $this->config->item('jem_api_' . $type . '_helpers'));
				
				foreach ($helpers as $helper)
				{
					$this->load->helper(trim($helper));
				}
			}
			
			for ($i=0; $i<count($sdata); $i++)
			{
				
				$module_model = 'modules/module_' . $sdata[$i]['module_type'] . '_' . $sdata[$i]['module_file_name'] . '_model';
				
				$this->load->model($module_model, $sdata[$i]['module_file_name']);
				
				$function = '_run_module_admin_' . $sdata[$i]['module_file_name'];
				
				$this->$sdata[$i]['module_file_name']->$function('admin', $data);	
			}
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_group_pricing()
	{
		foreach ($_POST as $k => $v)
		{
			if (preg_match('/group_amount-*/', $k)) 
			{		
				if (!empty($v))
				{
					if (!is_numeric($v))
					{
						return false;
					}
				}
			}
		}
		
		return true;
	}

	// ------------------------------------------------------------------------	
	
	function _check_add_product()
	{
		//check for correct options
		if (!empty($_POST['product_name']))
		{
			foreach ($this->input->post('product_name') as $k => $v)
			{
				if (empty($v)) {
					echo '<div class="error" id="error-messages">'.$this->lang->line('enter_product_name').'</div>';
					echo '<script>showResponse();</script>';
					exit();
				}		
			}	
		}
		
		if (!empty($_POST['product_price']))
		{
			foreach ($this->input->post('product_price') as $k => $v)
			{
				if (!is_numeric($v)) {
					echo '<div class="error" id="error-messages">'.$this->lang->line('price_must_be_numeric').'</div>';
					echo '<script>showResponse();</script>';
					exit();
				}		
			}	
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_videos()
	{
		if (!empty($_POST))
		{
			for ($i=0; $i<=count($_POST['videos']); $i++)
			{
				if (!empty($_POST['videos'][$i]))
				{
					if (empty($_POST['video_name'][$i]))
					{
						$this->session->set_flashdata('error', $this->lang->line('each_video_needs_name'));
						return false;
					}
					
					//check image 
					if (!empty($_POST['video_image'][$i]) && strlen($_POST['video_image'][$i]) > 255)
					{
						$this->session->set_flashdata('error', $this->lang->line('video_image_only_255_chars'));
						return false;
					}
				}
			}
		}
		
		 return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_date_available()
	{
		if ($this->validation->date_available)
		{
			$this->validation->set_message('_check_date_available', $this->lang->line('invalid_date_available_format'). ': ' . $this->validation->date_available);
			
			$a = explode('/', $this->validation->date_available);
			if (count($a) != 3)
			{
				return false;
			}
			elseif (checkdate($a[0], $a[1], $a[2]) == false)
			{
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_date_expires()
	{
		if ($this->validation->date_expires)
		{
			$this->validation->set_message('_check_date_expires', $this->lang->line('invalid_date_expires_format'). ': ' . $this->validation->date_expires);
			
			$a = explode('/', $this->validation->date_expires);
			if (count($a) != 3)
			{
				return false;
			}
			elseif (checkdate($a[0], $a[1], $a[2]) == false)
			{
				return false;
			}
		}
		
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_true_false($value)
	{
		if ($value == 0 || $value == 1)
		{
			return true;
		}
		else
		{
			$this->validation->set_message('_check_true_false', $this->lang->line('changing_fields_only_zero_one'). ': ' . $value);
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_update_product()
	{
		//set form validation rules
		
		$rules['product_id'] = 'trim|required|numeric';
		$rules['product_status'] = 'trim|required|integer';
		$rules['product_name'] = 'trim|required|min_length[3]|max_length[255]';
		$rules['product_views'] = 'trim|numeric';
		$rules['product_new'] = 'trim|required';
		$rules['product_featured'] = 'trim|required';

		$rules['upsell_product'] = 'trim';
		$rules['recommended_product'] = 'trim';
		$rules['product_keywords'] = 'trim';
		$rules['product_title'] = 'trim|max_length[255]';
		$rules['product_meta_description'] = 'trim';
		
		//date available and date expires
		$rules['date_available'] = 'trim|callback__check_date_available';
		$rules['date_expires'] = 'trim|callback__check_date_expires';
		
		//product sku
		$rules['product_sku'] = 'trim|required';
		
		//product price
		$rules['product_price'] = 'trim|required|numeric';
		
		//product overview
		$rules['product_overview'] = 'trim|min_length[5]';
		
		//check for physical type
		if ($this->input->post('product_type') == 'physical')
		{
			$rules['add_cart_for_price'] = 'trim|numeric';
			$rules['login_for_price'] = 'trim|integer';
			$rules['min_quantity_ordered'] = 'trim|numeric';
			$rules['max_quantity_ordered'] = 'trim|numeric';
			$rules['enable_product_inventory'] = 'trim|integer';
			$rules['product_inventory'] = 'trim|integer';
			$rules['product_weight'] = 'trim|numeric';
			$rules['shipping_amount'] = 'trim|numeric';
		}
		elseif ($this->input->post('product_type') == 'digital')  //check for digital type
		{
			$rules['download_location_1'] = 'trim';
			$rules['download_location_2'] = 'trim';
			$rules['download_location_3'] = 'trim';
			$rules['download_location_4'] = 'trim';
			$rules['download_location_5'] = 'trim';
			$rules['download_location_6'] = 'trim';
			$rules['download_location_7'] = 'trim';
			$rules['download_location_8'] = 'trim';
			$rules['download_location_9'] = 'trim';
			$rules['download_location_10'] = 'trim';
			
			$rules['download_expires_days'] = 'trim|numeric';
			$rules['max_downloads_per_user'] = 'trim|numeric';
		}
		elseif ($this->input->post('product_type') == 'membership')  //check for membership type
		{
			if ($this->input->post('recurring_interval_type') != 'onetime')
			{
				$rules['recurring_interval'] = 'trim|required|numeric|callback__check_zero';
			}
			else
			{
				$rules['recurring_interval'] = 'trim|numeric';
			}
			
			$rules['recurring_interval_ends'] = 'trim|numeric';
			$rules['recurring_onetime'] = 'trim|required|integer';
			$rules['enable_product_trial'] = 'trim|integer';
			$rules['product_trial_price'] = 'trim|numeric';
			
			if ($this->input->post('enable_product_trial') == 1)
			{
				$rules['product_trial_interval'] = 'trim|required|callback__check_amount';
			}
			else
			{
				$rules['product_trial_interval'] = 'trim|numeric';
			}
			
			$rules['signup_module_id'] = 'trim|numeric';
			$rules['expires_module_id'] = 'trim|numeric';
			$rules['membership_url_redirect'] = 'trim|prep_url';
		}
		
		$rules['add_to_affiliate_group'] = 'trim|integer';
		$rules['add_to_discount_group'] =  'trim|integer';
		$rules['add_mailing_list'] =  'trim|integer';
		$rules['vendor_id'] = 'trim|integer';
		$rules['manufacturer_id'] = 'trim|integer';
		$rules['post_purchase_module_id'] = 'trim|integer';
		$rules['no_commission'] = 'trim|integer';
		$rules['enable_custom_commission'] = 'trim|integer';
		
		$rules['custom_commission_value_1'] = 'trim|numeric';
		$rules['custom_commission_value_2'] = 'trim|numeric';
		$rules['custom_commission_value_3'] = 'trim|numeric';
		$rules['custom_commission_value_4'] = 'trim|numeric';
		$rules['custom_commission_value_5'] = 'trim|numeric';
		$rules['custom_commission_value_6'] = 'trim|numeric';
		$rules['custom_commission_value_7'] = 'trim|numeric';
		$rules['custom_commission_value_8'] = 'trim|numeric';
		$rules['custom_commission_value_9'] = 'trim|numeric';
		$rules['custom_commission_value_10'] = 'trim|numeric';
		
		
	
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['product_id'] = $this->lang->line('product_id');
		$fields['product_status'] = $this->lang->line('product_status');
		$fields['product_name'] = $this->lang->line('product_name');
		$fields['product_views'] = $this->lang->line('product_views');
		
		$fields['product_keywords'] = $this->lang->line('product_keywords');
		
		$fields['product_new'] = $this->lang->line('product_new');
		$fields['product_featured'] = $this->lang->line('product_featured');
		$fields['upsell_product'] = $this->lang->line('upsell_product');
		$fields['recommended_product'] = $this->lang->line('recommended_product');
		
		
		$fields['commission_type'] = $this->lang->line('commission_type');
		//date available and date expires
		$fields['date_available'] = $this->lang->line('date_available');
		$fields['date_expires'] = $this->lang->line('date_expires');
		
		//product sku
		$fields['product_sku'] = $this->lang->line('product_sku');
		
		//product price
		$fields['product_price'] = $this->lang->line('product_price');
		
		//product overview
		$fields['product_overview'] = $this->lang->line('product_overview');
		
		//check for physical type
		if ($this->input->post('product_type') == 'physical')
		{
			$fields['add_cart_for_price'] = $this->lang->line('add_cart_for_price');
			$fields['login_for_price'] = $this->lang->line('login_for_price');
			$fields['min_quantity_ordered'] = $this->lang->line('min_quantity_ordered');
			$fields['max_quantity_ordered'] = $this->lang->line('max_quantity_ordered');
			$fields['enable_product_inventory'] = $this->lang->line('enable_product_inventory');
			$fields['product_inventory'] = $this->lang->line('product_inventory');
			$fields['product_weight'] = $this->lang->line('product_weight');
			$fields['shippin_amount'] = $this->lang->line('shipping_amount');
		}
		elseif ($this->input->post('product_type') == 'digital')  //check for digital type
		{
			$fields['download_location_1'] = $this->lang->line('download_location_1');
			$fields['download_location_2'] = $this->lang->line('download_location_2');
			$fields['download_location_3'] = $this->lang->line('download_location_3');
			$fields['download_location_4'] = $this->lang->line('download_location_4');
			$fields['download_location_5'] = $this->lang->line('download_location_5');
			$fields['download_location_6'] = $this->lang->line('download_location_6');
			$fields['download_location_7'] = $this->lang->line('download_location_7');
			$fields['download_location_8'] = $this->lang->line('download_location_8');
			$fields['download_location_9'] = $this->lang->line('download_location_9');
			$fields['download_location_10'] = $this->lang->line('download_location_10');
			
			$fields['download_expires_days'] = $this->lang->line('download_expires_days');
			$fields['max_downloads_per_user'] = $this->lang->line('max_downloads_per_user');
		}
		elseif ($this->input->post('product_type') == 'membership')  //check for membership type
		{
			$fields['recurring_interval'] = $this->lang->line('recurring_interval');
			$fields['recurring_onetime'] = $this->lang->line('recurring_onetime');
			$fields['recurring_interval_ends'] = $this->lang->line('recurring_interval_ends');
			$fields['enable_product_trial'] = $this->lang->line('enable_product_trial');
			$fields['product_trial_price'] = $this->lang->line('product_trial_price');
			$fields['product_trial_interval'] = $this->lang->line('product_trial_interval');
			$fields['signup_module_id'] = $this->lang->line('signup_module_id');
			$fields['expires_module_id'] = $this->lang->line('expires_module_id');
			$fields['membership_url_redirect'] = $this->lang->line('membership_url_redirect');
		}
		
		$fields['add_to_affiliate_group'] = $this->lang->line('add_to_affiliate_group');
		$fields['add_to_discount_group'] =  $this->lang->line('add_to_discount_group');
		$fields['add_mailing_list'] =  $this->lang->line('add_mailing_list');
		$fields['vendor_id'] = $this->lang->line('vendor_id');
		$fields['manufacturer_id'] = $this->lang->line('manufacturer_id');
		$fields['post_purchase_module_id'] = $this->lang->line('post_purchase_module_id');
		$fields['no_commission'] = $this->lang->line('no_commission');
		$fields['enable_custom_commission'] = $this->lang->line('enable_custom_commission');
		
		$fields['custom_commission_value_1'] = $this->lang->line('custom_commission_value_1');
		$fields['custom_commission_value_2'] = $this->lang->line('custom_commission_value_2');
		$fields['custom_commission_value_3'] = $this->lang->line('custom_commission_value_3');
		$fields['custom_commission_value_4'] = $this->lang->line('custom_commission_value_4');
		$fields['custom_commission_value_5'] = $this->lang->line('custom_commission_value_5');
		$fields['custom_commission_value_6'] = $this->lang->line('custom_commission_value_6');
		$fields['custom_commission_value_7'] = $this->lang->line('custom_commission_value_7');
		$fields['custom_commission_value_8'] = $this->lang->line('custom_commission_value_8');
		$fields['custom_commission_value_9'] = $this->lang->line('custom_commission_value_9');
		$fields['custom_commission_value_10'] = $this->lang->line('custom_commission_value_10');

		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;

	}
	
	// ------------------------------------------------------------------------	
	
	function _check_zero($value)
	{
		if (!empty($value))
		{
			return true;
		}
		
		$this->validation->set_message('_check_zero', $this->lang->line('required'));
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_amount($value)
	{
		if (!empty($value))
		{
			return true;
		}
		
		$this->validation->set_message('_check_amount', $this->lang->line('required'));
		return false;	
	}
}
?>