<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - regions.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage regions
|
*/

class Regions extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load regions model
		$this->load->model('zones_model');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/regions/view_regions');
	}
	
	// ------------------------------------------------------------------------
	
	function add_region()
	{
		/*
		| -----------------------------------------
		| add a new region
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//load country helper
		$this->load->helper('country');		
		
		$data['country_options'] = _load_countries_dropdown($countries = _load_countries_array());

		//set page title
		$data['page_title'] = $this->lang->line('add_region');
		$data['submit_url'] = jrox_admin_url().'regions/add_region';
		$data['update_link'] = 'add_region';
		$data['add_link'] = 'add_region';
		
		$this->validation->region_id_redirect = '';
		$this->validation->region_id = '';
		
		//run admin validation check
		if ($this->_check_region() == false)
		{		
			//reload add region form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_region', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the region into db
			$data = $this->zones_model->_add_region();		
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_region_success'));
			
			//ajax message
			echo '<div class="success" onclick="parent.location.href = \'' . jrox_admin_url().'regions/view_regions\';" style="cursor:pointer;">' .$this->lang->line('region') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';			
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_region()
	{
		/*
		| --------------------------------------------
		| delete the region from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->zones_model->_delete_region((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/regions/table/' . $this->config->item('cache_bx'));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/regions/view_regions');
		}
	}
	
	// ------------------------------------------------------------------------

	
	function view_regions()
	{
		/*
		| -----------------------------------------
		| view regions
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_regions');
		$data['sub_title'] = $this->lang->line('manage_regions');
		$data['add_link'] = 'add_region';
		$data['update_link'] = 'regions';
		$data['regions_table'] = 'regions-table';
		$data['height'] = '400';
		$data['width'] = '400';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_regions', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get regions via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['sort_name'] = 'aff_region_name';
		$data['header_name'] = 'regions';
		$data['height'] = '400';
		$data['width'] = '400';
		
		//get regions
		$row = $this->zones_model->_get_regions($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		if (empty($row))
		{
			$row[0] = array(
						'region_id' => 0,
						'region_name' => $this->lang->line('no_regions_found'),
						);
		}
		
		//add the data to the array
		$data['regions'] = $row;
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'regions', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_regions_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function update_region()
	{
		/*
		| -----------------------------------------
		| update region
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//load country helper
		$this->load->helper('country');		
		
		$data['country_options'] = _load_countries_dropdown($countries = _load_countries_array());

		//set page title
		$data['page_title'] = $this->lang->line('update_region');
		$data['submit_url'] = jrox_admin_url().'regions/update_region/' . $this->uri->segment(4);
		$data['add_link'] = 'update_region';
		$data['update_link'] = 'regions';
		$data['regions_table'] = 'regions-table';
		
		$this->validation->region_id_redirect = '<input type="hidden" id="region_id" name="region_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->region_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_region() == false)
		{		
			//reload add region form
			if (empty($_POST))
			{
				$mdata = $this->zones_model->_get_region_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_region', $data);
				}
				else
				{
					//load add member page
					redirect(ADMIN_ROUTE . '/regions/view_regions');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the region into db
			
			$data = $this->zones_model->_update_region((int)$this->uri->segment(4));	
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_region_success'));
			
			//ajax message
			echo '<div class="success" onclick="parent.location.href = \'' . jrox_admin_url().'regions/view_regions\';" style="cursor:pointer;">' . $this->lang->line('update_region_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_region()
	{
		//set form validation rules
		
		$rules['region_name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['region_code'] = 'trim|min_length[2]|max_length[50]';
		$rules['region_country_id'] = 'trim|integer|max_length[3]';		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['region_name'] = $this->lang->line('region_name');
		$fields['region_code'] = $this->lang->line('region_code');
		$fields['region_country_id'] = $this->lang->line('country_name');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
}
?>