<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - reports.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage different reports
|
*/

class Reports extends Admin_Controller {
	
	function __construct()
	{
	
		parent::Admin_Controller();	
		
		//load reports model
		$this->load->model('reports_model', 'reports');
		
		//load css body style
		$this->config->set_item('css_body', 'KR');
		
		$this->load->helper('inflector');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		
		//set random graph colors
		$colors = array(	'#003366',
            				'#0066CC',
							'#FF3300'
            			);
		
		$this->config->set_item('random_bg_color', random_element($colors));		
			
	}
	
	// ------------------------------------------------------------------------
	
	function quick_stats_sales()
	{
		/*
		| -----------------------------------------
		| quick stats
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['report_id'] = 'quickstatssales';
		
		require_once(APPPATH . 'libraries/flashcharts/open-flash-chart.php');
		
		$title = new title( $this->lang->line('seven_day_quick_stats_sales') );
		
		$num_options = get_default_currency($data['sts_store_default_currency']);
		
		//generate data
		$row = $this->reports->_generate_quick_stats_sales();
		
		
		$array = array();
		
		$empty = true;
		
		if (!empty($row))
		{
			foreach ($row as $k => $v)
			{
				if ($k == 'id') continue;
				
				if (empty($v)) 
				{
					$v = '0.00';
				}
				else
				{
					$empty = false;
				
					array_push ($array, new pie_value(floatval($v), humanize($k) . ' ' . format_amounts($v, $num_options) . ''));
				}
			}
		}
		
		if ($empty == true)
		{
			echo '<div align="center" style="color: #ff3300; font-size: 20px; font-weight: bold; margin: 1em; padding-top:4em; background: #ff;  height: 290px">' . $this->lang->line('no_sales_made') . '</div>';
			exit();
		}
		
		$pie = new pie();
		$pie->set_start_angle( 35 );
		$pie->set_animate( true );
		$pie->set_tooltip( '#val# of #total#<br>#percent# of 100%' );
		$pie->set_values( $array);
		
		$chart = new open_flash_chart();
		$chart->set_title( $title );
		$chart->set_bg_colour( '#FFFFFF' );
		$pie->set_colours(
		array(
			'#1F8FA1',    
			'#FF6600',    
			'#66CC33',   
			'#DEF799',
			'#0033CC',
			'#FF3300',
			'#FFCC00'   
		) );
		$chart->add_element( $pie );
		
		
		$chart->x_axis = null;
		
		$data['report'] = $chart->toPrettyString();
		
		load_form('admin', 'tpl_adm_reports_quickstats', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function quick_stats_commissions()
	{
		/*
		| -----------------------------------------
		| quick stats
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['report_id'] = 'quickstatscomm';
		
		require_once(APPPATH . 'libraries/flashcharts/open-flash-chart.php');

		$title = new title( $this->lang->line('seven_day_quick_stats_commissions') );
		
		$num_options = get_default_currency($data['sts_store_default_currency']);
		
		//generate data
		$row = $this->reports->_generate_quick_stats_commissions();
		
		if (empty($row))
		{
			echo '<div align="center" style="color: #ff3300; font-size: 20px; font-weight: bold; margin: 1em; padding-top:4em; background: #ff;  height: 290px">' . $this->lang->line('no_commissions_made') . '</div>';
			exit();
		}
		else
		{
			$srow = $row;
		}
		
		$values = array();
		$keys = array();
		
		foreach ($row as $k => $v)
		{
			if ($k == 'id') continue;
			
			if (empty($v)) $v = '0.00';
			
			$tmp = new bar_3d_value(floatval($v));
			$tmp->set_colour( $this->config->item('random_bg_color') );
			$tmp->set_tooltip( humanize($k) . ' - ' . format_amounts($v, $num_options)   );

			array_push ($values, $tmp);
			array_push ($keys, $k);
		}
		
		//sort the values
		rsort($srow);
		
		$bar = new bar_glass();
		$bar->set_values( $values );
		$bar->colour = $this->config->item('random_bg_color');
		
		$x_axis = new x_axis();
		
		$x_axis->colour = '#909090';
		$x_axis->set_labels_from_array($keys);
		
		$y_axis = new y_axis();
		
		$range = floor($srow[0] / 10);
		
		$height = $srow[0];
		
		$y_axis->set_range( 0, $height, $range );
		
		$chart = new open_flash_chart();
		$chart->set_title( $title );
		$chart->add_element( $bar );
		$chart->set_bg_colour( '#FFFFFF' );
		$chart->set_x_axis( $x_axis );
		$chart->set_y_axis( $y_axis );
		
		$data['report'] = $chart->toPrettyString();
		
		load_form('admin', 'tpl_adm_reports_quickstats', $data);
	}
	
	
	// ------------------------------------------------------------------------
	
	function view_reports()
	{
		/*
		| -----------------------------------------
		| view reports
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_reports');
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_reports', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get reports via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '530';
		$data['width'] = '400';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get reports
		$row = $this->reports->_get_reports($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);

	 
		//add the data to the array
		$data['reports'] = $row;	
		
		//count all rows first
		$row_count = $this->db_validation_model->_get_count('modules', 'WHERE module_type = \'stats_reporting\' AND module_status = \'1\'');
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'reports', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $row_count);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_reports_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
}
?>