<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - reports_archive.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage archived reports
|
*/

class Reports_Archive extends Admin_Controller {
	
	function __construct()
	{
	
		parent::Admin_Controller();	
		
		//load reports model
		$this->load->model('reports_model', 'reports');
		
		//load css body style
		$this->config->set_item('css_body', 'KR');
		
		$this->load->helper('inflector');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		
		//set random graph colors
		$colors = array(	'#003366',
            				'#0066CC',
							'#FF3300'
            			);
		
		$this->config->set_item('random_bg_color', random_element($colors));		
			
	}
	
	// ------------------------------------------------------------------------
	
	function view_archive()
	{
		/*
		| -----------------------------------------
		| view reports
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_reports');
		$data['height'] = '530';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_reports_archive', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function view_report()
	{
		/*
		| ---------------------
		| get archived report
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$reports = $this->reports->_get_archive_details($this->uri->segment(4));
		
		
		//set page title
		$data['page_title'] = $reports[0]['report_name'];
		$data['report_id'] = $reports[0]['id'];
		$data['print_page'] = $this->uri->segment('5', '0');
		
		$top = true;
		$bottom = true;
		$data['graph_width'] = '920';
		$data['graph_height'] = '290';
		
		if ($data['print_page'] == 'print')
		{
			$top = false;
			$bottom = false;
			$data['graph_width'] = '700';
			$data['graph_height'] = '150';
		}
		
		$reports_html = $reports[0]['report_html'];
		
		$reports_html = str_replace('{report_id}', $reports[0]['id'], $reports_html);
		$reports_html = str_replace('{graph_height}', $data['graph_height'], $reports_html);
		$reports_html = str_replace('{graph_width}', $data['graph_width'], $reports_html);
		
		$data['reports_html'] = html_entity_decode($reports_html);	
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_view_report_archive', $data, $top, $bottom);
	}
	
	// ------------------------------------------------------------------------
	
	function delete_report()
	{
		/*
		| ---------------------
		| delete archived report
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->reports->_delete_archived_report($this->uri->segment(4)))
		{
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('archived_report_deleted_successfully'));
			
			//redirect to member details form
			echo '<script>window.location = "' . jrox_admin_url() .'reports_archive/view_archive"</script>';
		}
		
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get reports via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '530';
		$data['width'] = '400';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get reports
		$row = $this->reports->_get_reports_archive($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);

	 
		//add the data to the array
		$data['reports'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'report_archive', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_reports_archive_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
}
?>