<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - reviews.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage the different products
|
*/

class Reviews extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load reviews model
		$this->load->model('reviews_model');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
	}
		
	// ------------------------------------------------------------------------	
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/reviews/view_reviews');
	}

	// ------------------------------------------------------------------------
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the review
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('products_reviews', 'id', (int)$this->uri->segment(4), 'status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/reviews/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('reviews_updated_successfully'));
				
				redirect(ADMIN_ROUTE . '/reviews/view_reviews');
			}
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function delete_review()
	{
		/*
		| -----------------------------------------
		| delete review
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->reviews_model->_delete_review((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/reviews/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/reviews/view_reviews/');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function update_reviews()
	{
		/*
		| ---------------------------
		| mass update member details
		| ---------------------------
		*/
		
		//check if there are any users checked for update
		if ($this->input->post('review') AND count($this->input->post('review')) > 0)
		{
			$this->reviews_model->_change_status($this->input->post('review'), $this->input->post('change-status'));
		}
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('reviews_updated_successfully'));
		echo '<script>self.parent.location.reload(true);</script>';	
	}
	
	// ------------------------------------------------------------------------

	function update_review()
	{
		/*
		| -----------------------------------------
		| update review
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_review');
		$data['submit_url'] = jrox_admin_url().'reviews/update_review/' . (int)$this->uri->segment(4);
		$data['update_link'] = 'reviews';
		$data['add_link'] = 'update_review';
		
		//run admin validation check
		if ($this->_check_product_review() == false)
		{		
			//reload add review form
			if (empty($_POST))
			{
				$mdata = $this->reviews_model->_get_product_review_details((int)$this->uri->segment(4));
				
				foreach ($mdata[0] as $key => $value)
				{
					$this->validation->$key = $value;
				}
				
				//load template
				load_form('admin', 'tpl_adm_manage_product_review', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the review into db
			$data = $this->reviews_model->_update_review((int)$this->uri->segment(4));		

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('review_updated_successfully') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------		

	function view_reviews()
	{
		/*
		| -----------------------------------------
		| view reviews
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//set page title
		if (!empty($data['where_column']) && !empty($data['where_value']))
		{
			$data['product_id'] = (int) $this->uri->segment(9, 0);
		
			//get member name
			$product = $total_rows = $this->db_validation_model->_get_details('products', 'product_name', 'product_id', $data['product_id']);
			
			$data['page_title'] = $this->lang->line('view_reviews_for') . ' ' . limit_chars($product[0]['product_name'], 40) ;
		}
		else
		{
			$data['page_title'] = $this->lang->line('view_reviews');
		}
		
		$data['height'] = '500';
		$data['width'] = '500';
		
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_product_reviews', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{
		/*
		| ---------------------
		| get reviews via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '500';
		
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$data['curdate'] = $fdate[1];

		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get manufacturers
		$row = $this->reviews_model->_get_product_reviews($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_column'], $data['where_value']);

	 
		//add the data to the array
		$data['reviews'] = $row;	
		
		$total_rows = $this->db_validation_model->_get_count('products_reviews', 'WHERE ' . $data['where_column'] . '=\'' . $data['where_value'] . '\'');
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'products_reviews', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total_rows, $data['where_column'], $data['where_value']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_product_reviews_table', $data, false, false);
	}
	
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_product_review()
	{
		//set form validation rules
		$rules['comment'] = 'trim|min_length[5]';
		
			$this->validation->set_rules($rules);

		//repopulate form

		$fields['comment'] = $this->lang->line('review');
			
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;	
	}
	
	// ------------------------------------------------------------------------	
	
}
?>