<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - support.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage support
|
*/

class Support extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load support model
		$this->load->model('support_model');
		
		//load css body style
		$this->config->set_item('css_body', 'XY');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		$this->config->set_item('uri2', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/categories_table');
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/support/view_tickets');
	}
	
	// ------------------------------------------------------------------------
	
	function view_categories()
	{
		/*
		| -----------------------------------------
		| view categories
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_categories');
		$data['height'] = '250';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri2'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_support_categories', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function categories_table()
	{
		/*
		| ---------------------
		| get categories via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '250';
		$data['width'] = '400';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get manufacturers
		$row = $this->support_model->_get_categories($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);

	 
		//add the data to the array
		$data['categories'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'support_categories', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_support_categories_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function add_category()
	{
		/*
		| -----------------------------------------
		| add a new category
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_category');
		$data['submit_url'] = jrox_admin_url().'support/add_category';
		$data['add_link'] = 'add_category';
		
		//run admin validation check
		if ($this->_check_category() == false)
		{		
			//reload add category form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_support_category', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the category into db
			$data = $this->support_model->_add_category();		
			
			

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('category') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function update_category()
	{
		/*
		| -----------------------------------------
		| update a category
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_category');
		$data['submit_url'] = jrox_admin_url().'support/update_category/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_category';
		
		//run admin validation check
		if ($this->_check_category() == false)
		{		
			//reload add category form
			if (empty($_POST))
			{
				$mdata = $this->support_model->_get_support_category_details((int)$this->uri->segment(4));
				
				foreach ($mdata[0] as $key => $value)
				{
					$this->validation->$key = $value;
				}			
				
				//load template
				load_form('admin', 'tpl_adm_manage_support_category', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the category into db
			if ($this->support_model->_update_category((int)$this->uri->segment(4)))		
			{
				//ajax message
				echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('category_updated_successfully') . '. ' . $this->lang->line('click_to_close') . '</div>';		
				exit();	
			}
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_category()
	{
		/*
		| --------------------------------------------
		| delete the category
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->support_model->_delete_category((int)($this->uri->segment(4))))
		{
			//log success
			log_message('info', 'category deleted successfully');
			
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/support/categories_table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			show_error($this->lang->line('could_not_delete_ticket'));
				
			log_message('error', 'Could not delete category');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function delete_sub_ticket()
	{
		/*
		| --------------------------------------------
		| delete the child ticket from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->support_model->_delete_ticket((int)($this->uri->segment(4))))
		{
			//log success
			log_message('info', 'ticket deleted successfully');
			
			$this->session->set_flashdata('success', $this->lang->line('support_ticket_updated_successfully'));
			
			redirect(ADMIN_ROUTE . '/support/update_ticket/' . (int)($this->uri->segment(5)));	
		}
		else
		{
			show_error($this->lang->line('could_not_delete_ticket'));
				
			log_message('error', 'could not delete ticket');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function delete_ticket()
	{
		/*
		| --------------------------------------------
		| delete the ticket from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$member = $this->support_model->_delete_ticket((int)($this->uri->segment(4)));
		
		if (!empty($member))
		{
			//send notification email
			$this->load->model('emailing_model');
			
			if ($this->emailing_model->_send_template_email('admin', $member, 'admin_ticket_deletion_template'))
			{
				//log success
				log_message('info', 'ticket deleted successfully');
				
				//redirect if deleting from ajax table	
				if ($this->uri->segment(5) == 2)
				{
					redirect(ADMIN_ROUTE . '/support/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
				}
				else
				{
					echo '<script>self.parent.location.reload(true);</script>';		
				}	
			}
			else
			{
				show_error($this->lang->line('could_not_send_email_alert'));
					
				log_message('error', 'Could not send email to ' . $member['primary_email'] . '. Check email settings.');
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_tickets()
	{
		/*
		| -----------------------------------------
		| view support
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_support_tickets');
		$data['height'] = '530';
		$data['width'] = '400';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_support_tickets', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get support via ajax
		| ---------------------
		*/
	
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '530';
		$data['width'] = '400';
		$data['jrox_controller'] = 'support';
		$data['jrox_method'] = 'update_ticket';
		
		$data['where'] = $this->uri->segment(8, 'open');	
		
		$data['category'] = $this->uri->segment(9, '0');
		
		$data['support_categories'] = $this->support_model->_get_support_categories(true, 'select_category');
		
		//get support
		$row = $this->support_model->_get_support_tickets($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order'], $data['where'], $data['category']);
		
		$total = empty($row['total_rows']) ? 0 : $row['total_rows'];
		
		unset ($row['total_rows']);
		
		//add the data to the array
		$data['support_tickets'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'support_tickets', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column'], $total, $data['where'], $data['category']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_support_tickets_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------	
	
	function change_status()
	{
		/*
		| ---------------------------
		| mass update tickets
		| ---------------------------
		*/
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check if there are any users checked for update
		if ($this->input->post('ticket') AND count($this->input->post('ticket')) > 0)
		{
			$this->support_model->_change_status($this->input->post('ticket'), $this->input->post('change-status'));
		}
		
		//set flash data
		$this->session->set_flashdata('success', $this->lang->line('support_tickets_updated_successfully'));
		
		redirect(ADMIN_ROUTE . '/support/view_tickets');
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->db_validation_model->_change_status_field('support_tickets', 'ticket_id', (int)$this->uri->segment(4), 'ticket_status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				//echo ADMIN_ROUTE . '/support/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0); exit();
				redirect(ADMIN_ROUTE . '/support/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('support_ticket_updated_successfully'));
				
				redirect(ADMIN_ROUTE . '/support/view_tickets');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function assign_ticket()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('assign_ticket');
		$data['submit_url'] = jrox_admin_url().'support/assign_ticket';
		
		if (!empty($_POST))
		{
			$sdata = $this->support_model->_assign_ticket((int)$this->uri->segment(4));
			
			if (!empty($sdata))
			{		
				if ($this->config->item('sts_support_enable_email_on_assigned_ticket') == 1)
				{
					
					$this->load->model('emailing_model');
					
					$sdata['ticket_id'] = (int)$this->uri->segment(4);
					if ($this->emailing_model->_send_template_email('admin', $sdata, 'assign_support_ticket_alert_template'))
					{
						//log success
						log_message('info', 'admin alert sent successfully');
					
						$this->session->set_flashdata('success', $this->lang->line('support_ticket_updated_successfully'));
						
						//redirect to products form
					}
				}
			
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('ticket_assigned_successfully'));
					
				redirect(ADMIN_ROUTE . '/support/assign_ticket');
			}
		}
		
		$admins = $this->db_validation_model->_get_details('admin_users');
		
		$data['admin_options'] = format_array($admins, 'admin_id', 'username');
		
		load_form('admin', 'tpl_adm_support_assign_ticket', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function file_download()
	{
		if ($this->uri->segment(4) != false)
		{
			$id = $this->uri->segment(4);
			
			//set data array
			$data = $this->security_model->_load_config('admin');
			
			//get file name
			$details = $this->support_model->_get_response_details($id);
			
			if (!empty($details['uploaded_file']))
			{
				$this->load->helper('download');
				
				$path = $data['sts_support_upload_folder_path'] . $details['uploaded_file'];
				
				$data = file_get_contents($path); // Read the file's contents
				
				force_download($details['uploaded_file'], $data); 
			}
			else
			{
				show_error($this->lang->line('no_uploaded_file_found'));
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function update_ticket()
	{
		/*
		| -----------------------------------------
		| add a new support
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_ticket');
		$data['submit_url'] = jrox_admin_url().'support/update_ticket/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_support';
		$data['update_link'] = 'support';
		$data['id'] = (int)$this->uri->segment(4);
		
		
		//run admin validation check
		if ($this->_check_support_ticket() == false)
		{		
			
			$data['tickets'] = $this->support_model->_get_support_ticket_details((int)$this->uri->segment(4));
			$this->validation->ticket_priority = $data['tickets'][0]['ticket_priority'];
			$this->validation->ticket_status = $data['tickets'][0]['ticket_status'];
			$this->validation->support_category_id = $data['tickets'][0]['support_category_id'];
			
			if (empty($data['tickets']))
			{	
				//load add support page
				redirect(ADMIN_ROUTE . '/support/view_tickets');
				exit();
			}		
				
	
			//initialize HTML editor
			$options = array(	'instance'	=> 'oEdit1',
								'type' => 'content',
								'content' => html_entity_decode($this->validation->ticket_body),
								'height'	=> '400',
								'width'	=> '100%',
								'editor_type'	=> 'description',
								'textarea'	=>	'ticket_body',
								'tags'	=> true,
							);
			$check_editor = _initialize_html_editor($options);
		
			$data['editor'] = $check_editor['editor'];
			$data['editor_path'] = $check_editor['editor_path'];
			
			//get faq categories
			
			$this->load->model('faq_model');
			
			$data['faq_categories'] = $this->faq_model->_get_faq_categories();
			
			$data['support_categories'] = $this->support_model->_get_support_categories();
			
			//load template
			
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}
			
			load_admin_tpl('admin', 'tpl_adm_manage_support_ticket', $data);		
		}
		else
		{	

			//update the support into db
			$newdata = $this->support_model->_update_support_ticket('admin', (int)$this->uri->segment(4));	
			
			
			//if ($this->config->item('sts_support_enable_file_uploads') == 1)
			//{
				
				//check if a file has been uploaded
				if (!empty($_FILES) && $_FILES['userfile']['error'] != 4)
				{
					$image_data = $this->_upload_support_file($newdata['id']);
					
					if (empty($image_data['success']))
					{
						$this->session->set_flashdata('error', $image_data['msg']);
					}
				}
			//}
			
			//now email it
			//send notification email
			$this->load->model('emailing_model');
			
			if ($this->emailing_model->_send_template_email('member', $newdata['member_data'], 'support_ticket_response_template'))
			{
				//log success
				log_message('info', 'support ticket sent successfully');
			
				$this->session->set_flashdata('success', $this->lang->line('support_ticket_updated_successfully'));
				
				//redirect to products form
			}
			else
			{
				show_error($this->lang->line('could_not_update_support_ticket'));
			}
			
			//load add support page
			redirect(ADMIN_ROUTE . '/support/view_tickets');
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_category()
	{
		//set form validation rules
		
		$rules['category_name'] = 'trim|required|min_length[5]|max_length[25]';
		
		$this->validation->set_rules($rules);

		//repopulate form
		
		$fields['category_name'] = $this->lang->line('category_name');
	
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_support_ticket()
	{
		//set form validation rules
		
		$rules['ticket_body'] = 'trim|required|min_length[20]';
		$rules['ticket_subject'] = 'trim|required|min_length[5]';
		$rules['ticket_priority'] = 'trim|required|integer';
		$rules['ticket_status'] = 'trim|required|integer';
		$rules['support_category_id'] = 'trim|integer';
		
		$this->validation->set_rules($rules);

		//repopulate form
		
		$fields['ticket_body'] = $this->lang->line('ticket_body');
		$fields['ticket_subject'] = $this->lang->line('ticket_subject');
		$fields['ticket_priority'] = $this->lang->line('ticket_priority');
		$fields['ticket_priority'] = $this->lang->line('ticket_status');
		$fields['support_category_id'] = $this->lang->line('category');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _upload_support_file($id)
	{		
		$this->load->model('uploads_model');
		
		//upload the photo
		$data = $this->uploads_model->_upload_file();
		
		//add photo to db
		if (!empty($data['success']))
		{
			//now update the ticket with the file name					
			//format the array
			$sdata = array('uploaded_file' => $data['info']['file_name']);
			
			$this->db->where('ticket_id', $id);
			$this->db->update('support_tickets', $sdata);
			
		}
		
		return $data;
		
	}
	
	// ------------------------------------------------------------------------
}
?>