<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - themes.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage themes
|
*/

class Themes extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load themes model
		$this->load->model('themes_model');
		
		//load css body style
		$this->config->set_item('css_body', 'OP');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/themes/view_themes');
	}
	
	// ------------------------------------------------------------------------
	
	function gen_thumb()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$config['image_library'] = $this->config->item('sts_image_library');
		$config['source_image'] =  $this->config->item('base_physical_path') . '/themes/main/' . $this->uri->segment(4) . '/' . $this->uri->segment(5);
		$config['quality'] = $this->config->item('images_quality');
		$config['maintain_ratio'] = $this->config->item('images_maintain_ratio');
		$config['thumb_marker'] = '_jrox';
		$config['width'] = '200';
		$config['height'] = '200';
		$config['dynamic_output'] = true;
		
		$this->load->library('image_lib', $config);
		$this->image_lib->initialize($config); 
		$this->image_lib->resize();
	
	}
	
	// ------------------------------------------------------------------------
	
	function add_theme()
	{
		/*
		| -----------------------------------------
		| add a new theme
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_theme');
		$data['submit_url'] = jrox_admin_url().'themes/add_theme';
		
		//run admin validation check
		if ($this->_check_layout_theme() == false)
		{		
			//reload add theme form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_layout_theme', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the theme into db
			//get theme data
			include ($this->config->item('base_physical_path') . '/themes/main/' . $this->validation->theme_name . '/theme_info.php');
			
			$sdata['theme_name'] = $this->input->post('theme_name', true);
			$sdata['theme_default'] = '0';
			$sdata['theme_description'] = (!empty($jrox_theme_description)) ? $jrox_theme_description : '';
			$sdata['theme_image_preview'] = (!empty($jrox_theme_image_preview)) ? $jrox_theme_image_preview : '';
			
			$id = $this->themes_model->_add_theme($sdata);		

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('theme') . ' ' . $id . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_theme()
	{
		/*
		| --------------------------------------------
		| delete the theme from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ((int)($this->uri->segment(4)) == 1)
		{
			redirect(ADMIN_ROUTE . '/themes/table/' . $this->config->item('cache_bx'));
		}
		else
		{
			if ($this->themes_model->_delete_theme((int)($this->uri->segment(4))))
			{
				//redirect if deleting from ajax table	
				if ($this->uri->segment(5) == 2)
				{
					redirect(ADMIN_ROUTE . '/themes/table/' . $this->config->item('cache_bx'));
				}
				else
				{
					echo '<script>self.parent.location.reload(true);</script>';		
				}	
			}
			else
			{
				redirect(ADMIN_ROUTE . '/themes/view_themes');
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function download_theme()
	{
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->uri->segment(4))
		{
			$name = $this->uri->segment(4);
			
			$this->load->library('zip');
			
			$path = $this->config->item('base_physical_path') . '/themes/main/' . $name . '/';
			
			if ($this->zip->read_dir($path))
			{
				$this->zip->download($name . '.zip');
			}
			else
			{
				show_error($this->lang->line('no_theme_found'));
			}
			 	
		}
		else
		{
			show_error($this->lang->line('no_theme_found'));
		}
	}
	
	// ------------------------------------------------------------------------
	
	function set_default()
	{
		$data = $this->security_model->_load_config('admin');
		
		if ($this->themes_model->_set_default((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/themes/table/' . $this->config->item('cache_bx'));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/themes/view_themes');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_themes()
	{
		/*
		| -----------------------------------------
		| view themes
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_themes');
		$data['height'] = '200';
		$data['width'] = '400';
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_themes', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get themes via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '530';
		$data['width'] = '400';
		
		$themes_per_page =  empty($this->session->userdata['themes_per_page']) ? 8 : $this->session->userdata['themes_per_page'];
		
		//get themes
		$row = $this->themes_model->_get_themes($themes_per_page, $data['offset'], $data['sort_column'], $data['sort_order']);
	 
		//add the data to the array
		$data['themes'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'layout_themes', $themes_per_page, 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_themes_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_layout_theme()
	{
		//set form validation rules
		$rules['theme_name'] = 'trim|required|min_length[5]|max_length[50]|callback__check_theme_file_path';
		
		$this->validation->set_rules($rules);

		$fields['theme_name'] = $this->lang->line('theme_name');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_theme_file_path()
	{
		
		$cpath = $this->config->item('base_physical_path') . '/themes/main/' . $this->validation->theme_name . '/theme_info.php';
	
		if (!file_exists($cpath))
		{
			$this->validation->set_message('_check_theme_file_path', $this->lang->line('invalid_theme_file_path'));
			return false;
		}
		elseif ($this->db_validation_model->_validate_field('layout_themes', 'theme_name', $this->validation->theme_name))
		{
			$this->validation->set_message('_check_theme_file_path', $this->lang->line('theme_file_name_in_use'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
}
?>