<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - tracking.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage tracking
|
*/

class Tracking extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load tracking model
		$this->load->model('tracking_model');
		
		//load css body style
		$this->config->set_item('css_body', 'GJ');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');
		$this->config->set_item('members_uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/members_table');
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/tracking/view_tracking');
	}
	
	// ------------------------------------------------------------------------
	
	function add_tracking()
	{
		/*
		| -----------------------------------------
		| add a new tracking
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = 'add tracking';
		$data['submit_url'] = jrox_admin_url().'tracking/add_tracking';
		$data['update_link'] = 'tracking';
		$data['add_link'] = 'add_tracking';
		
		$this->validation->id = '';
		
		//run admin validation check
		if ($this->_check_tracking() == false)
		{		
			//reload add tracking form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_tracking', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the tracking into db
			$data = $this->tracking_model->_add_tracking();		

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('tracking') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_tracking_referral()
	{
		/*
		| --------------------------------------------
		| delete the tracking referral from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->tracking_model->_delete_tracking_referral((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/tracking/referrals_table/' . $this->uri->segment(6) . '/' . $this->config->item('cache_bx') . '/'  . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/tracking/view_tracking');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function delete_tracking()
	{
		/*
		| --------------------------------------------
		| delete the tracking from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->tracking_model->_delete_tracking((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/tracking/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/tracking/view_tracking');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function reset_tracking()
	{
		/*
		| --------------------------------------------
		| reset the tracking from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->tracking_model->_reset_tracking((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/tracking/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/tracking/view_tracking');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_referrals()
	{	
		/*
		| -----------------------------------------
		| view tracking
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		
		$tracking = $this->tracking_model->_get_tracking_details($this->uri->segment(4));
		$data['page_title'] = $this->lang->line('view_tracking') . ' - ' . $tracking['name'];
		$data['height'] = '350';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(5,0);
		$data['where_value'] =  $this->uri->segment(6,0);
		$data['tid'] = $this->uri->segment(4,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_tracking_referrals', $data);	
	}
	
	
	// ------------------------------------------------------------------------
	
	function referrals_table()
	{
		/*
		| -----------------------------------------
		| view tracking
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(6, 0);
		$data['sort_column'] = $this->uri->segment(8, 0);
		$data['sort_order'] = $this->uri->segment(7, 0);
		$data['next_sort_order'] = $this->uri->segment(7) == 'ASC' ? 'DESC' : 'ASC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '350';
		$data['width'] = '400';
		
		//check if there are any sql wheres
		//$data['where_column'] = $this->uri->segment(5,0);
		//$data['where_value'] =  $this->uri->segment(6,0);
		
		//get tracking
		$row = $this->tracking_model->_get_tracking_referrals($this->uri->segment(4), $this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
	 
		//add the data to the array
		$data['tracking'] = $row['tracking'];	
		$data['tid'] = $this->uri->segment(4);
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination(ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/referrals_table/' . $this->uri->segment(4), 'tracking_referrals', $this->session->userdata('per_page'), 6, $data['sort_order'], $data['sort_column'], $row['totals']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_tracking_referrals_table', $data, false, false);
	}
	
	
	// ------------------------------------------------------------------------
	
	function view_tracking()
	{
		/*
		| -----------------------------------------
		| view tracking
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_tracking');
		$data['height'] = '350';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_tracking_ids', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get tracking via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '350';
		$data['width'] = '400';
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get tracking
		$row = $this->tracking_model->_get_tracking($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
	 
		//add the data to the array
		$data['tracking'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'tracking', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_tracking_ids_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_tracking()
	{
		/*
		| -----------------------------------------
		| add a new tracking
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_tracking');
		$data['submit_url'] = jrox_admin_url().'tracking/update_tracking/' . (int)$this->uri->segment(4);
		$data['add_link'] = 'update_tracking';
		$data['update_link'] = 'tracking';
		
		//run admin validation check
		if ($this->_check_tracking() == false)
		{		
			//reload add tracking form
			if (empty($_POST))
			{
				$mdata = $this->tracking_model->_get_tracking_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_tracking', $data);
				}
				else
				{
					//load add tracking page
					redirect(ADMIN_ROUTE . '/tracking/view_tracking');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the tracking into db
			$data = $this->tracking_model->_update_tracking((int)$this->uri->segment(4));	
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_tracking_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_tracking()
	{
		//set form validation rules
		
		$rules['name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['url'] = 'trim|required|prep_url';

		$this->validation->set_rules($rules);

		//repopulate form

		$fields['name'] = $this->lang->line('tracking_name');
		$fields['url'] = $this->lang->line('tracking_url');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	
	
	// ------------------------------------------------------------------------
}
?>