<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - vendors.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage vendors
|
*/

class Vendors extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load vendors model
		$this->load->model('vendors_model');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/vendors/view_vendors');
	}
	
	// ------------------------------------------------------------------------
	
	function add_vendor()
	{
		/*
		| -----------------------------------------
		| add a new vendor
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_vendor');
		$data['submit_url'] = jrox_admin_url().'vendors/add_vendor';
		$data['update_link'] = 'vendors';
		$data['add_link'] = 'add_vendor';
		
		$this->validation->vendor_id_redirect = '';
		$this->validation->vendor_id = '';
		
		//load country helper
		$this->load->helper('country');		
		
		$data['country_options'] = _load_countries_dropdown($countries = _load_countries_array());
		
		//run admin validation check
		if ($this->_check_vendor() == false)
		{		
			//reload add vendor form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_vendor', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the vendor into db
			$data = $this->vendors_model->_add_vendor();		

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' .$this->lang->line('vendor') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';		
			exit();	

		}		
	}
	
	// ------------------------------------------------------------------------
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the vendor
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		//get shipping config
		if ($this->vendors_model->_change_status((int)$this->uri->segment(4)))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/vendors/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				$this->session->set_flashdata('success', $this->lang->line('update_vendor_success'));
				
				redirect(ADMIN_ROUTE . '/vendors/view_vendors');
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function delete_vendor()
	{
		/*
		| --------------------------------------------
		| delete the vendor from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->vendors_model->_delete_vendor((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/vendors/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/vendors/view_vendors');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function view_vendors()
	{
		/*
		| -----------------------------------------
		| view vendors
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_vendors');
		$data['height'] = '400';
		$data['width'] = '650';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_vendors', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get vendors via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['height'] = '500';
		$data['width'] = '650';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		//get vendors
		$row = $this->vendors_model->_get_vendors($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		
		//add the data to the array
		$data['vendors'] = $row;	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'vendors', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_vendors_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	
	function update_vendor()
	{
		/*
		| -----------------------------------------
		| add a new vendor
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('update_vendor');
		$data['submit_url'] = jrox_admin_url().'vendors/update_vendor';
		$data['add_link'] = 'update_vendor';
		$data['update_link'] = 'vendors';
		
		$this->validation->vendor_id_redirect = '<input type="hidden" id="vendor_id" name="vendor_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->vendor_id = $this->uri->segment(4);
		
		//load country helper
		$this->load->helper('country');		
		
		$data['country_options'] = _load_countries_dropdown($countries = _load_countries_array());
		
		//run admin validation check
		if ($this->_check_vendor() == false)
		{		
			//reload add vendor form
			if (empty($_POST))
			{
				$mdata = $this->vendors_model->_get_vendor_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//load template
					load_form('admin', 'tpl_adm_manage_vendor', $data);
				}
				else
				{
					//load add vendor page
					redirect(ADMIN_ROUTE . '/vendors/view_vendors');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the vendor into db
			$data = $this->vendors_model->_update_vendor((int)$this->uri->segment(4));	

			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_vendor_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_vendor()
	{
		//set form validation rules
		
		$rules['vendor_name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['vendor_contact_name'] = 'trim|max_length[255]';
		$rules['vendor_contact_email'] = 'trim|valid_email|max_length[255]';
		$rules['vendor_address'] = 'trim|max_length[255]';
		$rules['vendor_city'] = 'trim|max_length[255]';
		$rules['vendor_state'] = 'trim|max_length[255]';
		$rules['vendor_country'] = 'trim|integer';
		$rules['vendor_zip'] = 'trim|max_length[255]';
		$rules['vendor_phone'] = 'trim|max_length[255]';
		$rules['vendor_send_alert'] = 'trim|integer';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['vendor_name'] = $this->lang->line('vendor_name');
		$fields['vendor_contact_name'] = $this->lang->line('vendor_contact_name');
		$fields['vendor_contact_email'] = $this->lang->line('vendor_contact_email');
		$fields['vendor_address'] = $this->lang->line('vendor_address');
		$fields['vendor_city'] = $this->lang->line('vendor_city');
		$fields['vendor_state'] = $this->lang->line('vendor_state');
		$fields['vendor_country'] = $this->lang->line('vendor_country');
		$fields['vendor_zip'] = $this->lang->line('vendor_zip');
		$fields['vendor_phone'] = $this->lang->line('vendor_phone');
		$fields['vendor_send_alert'] = $this->lang->line('vendor_send_alert');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------

}
?>