<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - zones.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage zones
|
*/

class Zones extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load zones model
		$this->load->model('zones_model');
		
		//load css body style
		$this->config->set_item('css_body', 'CF');
		
		//create pagination links		
		$this->config->set_item('uri', ADMIN_ROUTE. '/' . $this->uri->segment(2) . '/table');

	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/zones/view_zones');
	}
	
	// ------------------------------------------------------------------------
	
	function add_zone()
	{
		/*
		| -----------------------------------------
		| add a new zone
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');	
		
		$data['country_options'] = $this->zones_model->_select_zones();
		
		$this->validation->regions = '';
		
		//set page title
		$data['page_title'] = $this->lang->line('add_tax_zone');
		$data['submit_url'] = jrox_admin_url().'zones/add_zone';
		$data['update_link'] = 'add_zone';
		$data['add_link'] = 'add_affiliate_zone';
		
		$this->validation->zone_id_redirect = '';
		$this->validation->zone_id = '';
		
		//run admin validation check
		if ($this->_check_zone() == false)
		{		
			//reload add zone form
			if (empty($_POST))
			{
				//load template
				load_form('admin', 'tpl_adm_manage_zone', $data);
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the zone into db
			$data = $this->zones_model->_add_zone();		
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_zone_success'));
			
			//ajax message
			echo '<div class="success" onclick="parent.location.href = \'' . jrox_admin_url().'regions/view_regions\';" style="cursor:pointer;">' .$this->lang->line('tax_zone') . ' ' . $data . ' ' . $this->lang->line('added_successfully') . '. ' . $this->lang->line('click_to_close_or_add') . '</div>';			
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function delete_zone()
	{
		/*
		| --------------------------------------------
		| delete the zone from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->zones_model->_delete_zone((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect(ADMIN_ROUTE . '/zones/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE . '/zones/view_zones');
		}
	}
	
	// ------------------------------------------------------------------------

	
	function view_zones()
	{
		/*
		| -----------------------------------------
		| view zones
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('manage_tax_zones');
		$data['sub_title'] = $this->lang->line('manage_tax_zones');
		$data['add_link'] = 'add_zone';
		$data['update_link'] = 'zones';
		$data['zones_table'] = 'zones-table';
		$data['height'] = '500';
		$data['width'] = '400';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_manage_zones', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{	
		/*
		| ---------------------
		| get zones via ajax
		| ---------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		$data['sort_name'] = 'aff_zone_name';
		$data['header_name'] = 'zones';
		$data['update_link'] = 'zones';
		$data['height'] = '500';
		$data['width'] = '400';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//get zones
		$row = $this->zones_model->_get_zones($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		if (empty($row))
		{
			$row[0] = array(
						'tax_zone_id' => 0,
						'tax_amount' => 0,
						'tax_zone_name' => $this->lang->line('no_zones_found'),
						);
		}
		
		//add the data to the array
		$data['zones'] = $row;
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'tax_zones', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('admin', 'tpl_adm_zones_table', $data, false, false);

	
	}
	
	// ------------------------------------------------------------------------
	
	function update_zone()
	{
		/*
		| -----------------------------------------
		| add a new zone
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$data['country_options'] = $this->zones_model->_select_zones();
		
		//set page title
		$data['page_title'] = $this->lang->line('update_zone');
		$data['submit_url'] = jrox_admin_url().'zones/update_zone/' . $this->uri->segment(4);
		$data['add_link'] = 'update_affiliate_zone';
		$data['update_link'] = 'zones';
		$data['zones_table'] = 'zones-table';
		
		$this->validation->zone_id_redirect = '<input type="hidden" id="tax_zone_id" name="tax_zone_id" value="' . (int)$this->uri->segment(4) . '" />';
		$this->validation->zone_id = $this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_zone() == false)
		{		
			//reload add zone form
			if (empty($_POST))
			{
				$mdata = $this->zones_model->_get_zone_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					//get the zones for this tax zone
					$this->validation->regions = $this->zones_model->_get_tax_zones((int)$this->uri->segment(4));
					
					//load template
					load_form('admin', 'tpl_adm_manage_zone', $data);
				}
				else
				{
					//load add member page
					redirect(ADMIN_ROUTE . '/zones/view_zones');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//add the zone into db
			
			$data = $this->zones_model->_update_zone((int)$this->uri->segment(4));	
			
			//set flash data
			//$this->session->set_flashdata('success', $this->lang->line('add_zone_success'));
			
			//ajax message
			echo '<div class="success" onclick="parent.location.href = \'' . jrox_admin_url().'regions/view_regions\';" style="cursor:pointer;">' . $this->lang->line('update_zone_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			//redirect to admin details form
			/*echo '<script>self.parent.location.reload(true);</script>';*/
		}		
	}
	
	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_zone()
	{
		//set form validation rules
		
		$rules['tax_zone_name'] = 'trim|required|min_length[2]|max_length[50]';
		$rules['tax_amount'] = 'trim|required|numeric';		
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['tax_zone_name'] = $this->lang->line('tax_zone_name');
		$fields['tax_amount'] = $this->lang->line('tax_amount');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
		
	}
	
	// ------------------------------------------------------------------------
}
?>