<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - account.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage a user's account details
|
*/

class Account extends Member_Controller {
	
	function __construct()
	{
		parent::Member_Controller();	
		
		$this->config->set_item('css_body', 'jroxMembersAccount');
		
		//get countries
		$this->load->helper('country');
		$this->country_options = _load_countries_dropdown($countries = _load_countries_array(true));
	}
	
	// ------------------------------------------------------------------------
	
	function load_regions()
	{
	
		//set data array
		$data = $this->security_model->_load_config('members');

		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		$cid = $this->uri->segment(4, $this->config->item('sts_store_default_country'));
		
		$regions = _load_regions_array($cid);
		
		if (!empty($regions))
		{
			echo '<select name="' . $this->uri->segment(5) . '" id="' . $this->uri->segment(5) . '" class="jroxCheckoutInputFields">';

			foreach ($regions as $v)
			{
				echo '<option value="' . $v['region_id'] . '">' . $v['region_name'] . '</option>';
			}
			
			echo '</select>';
		}
		else
		{
			$fdata = array(
							 'name'        => $this->uri->segment(5),
							 'id'          => $this->uri->segment(5),
							 'value'       => '',
							 'size'        => '50',
							 'class'       => 'generalInput jroxCheckoutInputFields required',
							);

			echo form_input($fdata);
		}
		
	}
	
	// ------------------------------------------------------------------------
	
	function activate_affiliate()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//set page title
		$data['page_title'] = $this->lang->line('affiliate_activation');
		$data['meta_keywords'] = '';
		$data['lang_heading'] = $this->lang->line('affiliate_account_activation');
		
		$this->load->model('emailing_model');
		
		//check if admin approval is required
		if ($this->config->item('sts_affiliate_admin_approval_required') == 1)
		{
			$data['show_message'] = $this->lang->line('affiliate_admin_approval_required');
			
			//send alert to admin
			$this->load->model('admins_model');
			$admin_users = $this->admins_model->_get_all_admins();
			
			$userdata = $this->members->_get_member_basic($this->session->userdata('userid'));
			
			//send out new order alerts to admins
			foreach ($admin_users as $admin_user)
			{
				if ($admin_user['alert_affiliate_signup'] == 1) //send out the admin alert
				{
					foreach ($userdata as $key => $value)
					{				
						if ($key == 'sponsor_data') { continue; }
						$admin_user['member_' . $key] = $value;
					}
					
					$admin_user['member_name'] = $userdata['fname'] . ' ' . $userdata['lname'];
					$admin_user['member_username'] = $userdata['username'];
					$admin_user['signup_ip'] = $this->input->ip_address();
					
					$this->emailing_model->_send_template_email('admin', $admin_user, 'admin_affiliate_marketing_activation_template');
				}
			}  	
		}
		else
		{
			
			$mdata = $this->members->_update_aff_marketing($this->session->userdata('userid'), true);
			
			//update session
			$this->session->set_userdata('m_aff_marketing', '1');
			
			if ($mdata)
			{
				if ($mdata != 'inactive')
				{			
					$this->emailing_model->_send_template_email('member', $mdata, 'member_affiliate_marketing_approval_template');
				}
			}	
			
			$data['show_message'] = $this->lang->line('affiliate_account_activated');
			
		}
		
		$data['sub_message'] = '<a href="' . _jrox_members_url() . '">' . $this->lang->line('click_here_to_go_back') . '</a>';
		
		$this->parser->_JROX_load_view('tpl_general_message', 'members', $data);
	}
	
	// ------------------------------------------------------------------------	
	
	function index()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$text_array = array('account_details', 'email_address', 'password', 'affiliate_information', 'member_photo',
							'account_information', 'required','yes', 'no', 'please_wait', 'update_subscriptions',
							'continue', 'shipping_information', 'dashboard_mailing_lists', 'update_photo', 'create_support_ticket', 
							'dashboard_open_tickets', 'dashboard_closed_tickets', 'dashboard_support_tickets',
							'dashboard_paid_invoices', 'dashboard_paid_commissions', 'dashboard_quickstats', 
							'dashboard_unpaid_invoices', 'dashboard_unpaid_commissions',);
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('account_details');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		$data['billing_form_fields'] = array();
		$data['payment_form_fields'] = array();
		$data['shipping_form_fields'] = array();
		$data['custom_fields'] = array();
		
		if ($this->session->flashdata('show_message')) 
		{
			$data['show_message'] = $this->session->flashdata('show_message');
		}
		else
		{
			$data['show_message'] = '';
		}
		
		//get commissions
		$num_options = get_default_currency($this->config->item('sts_store_default_currency'));
		
		$totals = $this->members->_get_dashboard_totals($this->session->userdata('userid'));
		
				
		$data['dashboard_unpaid_commissions'] = format_amounts($totals['unpaid_commissions'], $num_options);
		$data['dashboard_paid_commissions'] = format_amounts($totals['paid_commissions'], $num_options);
		
		$data['dashboard_unpaid_invoices'] = $totals['unpaid_invoices'];
		$data['dashboard_paid_invoices'] = $totals['paid_invoices'];
		
		$data['dashboard_open_tickets'] = $totals['open_tickets'];
		$data['dashboard_closed_tickets'] = $totals['closed_tickets'];
		
		
		//get all the form fields
		$this->load->model('checkout_model', 'checkout');
		$this->account_fields = $this->checkout->_get_checkout_fields();
		
		//run admin validation check
		if ($this->_check_billing_data() == false)
		{	
			if (empty($_POST['jroxSubmitPForm']))
			{	
				//get the member data
				$mem_info = $this->members->_get_member_basic($this->session->userdata('userid'));
					
				if (!empty($mem_info))
				{
					//set referral info
					foreach ($mem_info as $key => $val)
					{
						$data[$key] = $val;
					}
					
					//get ship info
					$ship_info = $this->members->_get_member_shipping($this->session->userdata('userid'));
					
					foreach ($ship_info[0] as $key => $val)
					{
						$data[$key] = $val;
					}
					
					$data['show_delete_photo'] = '';
					
					//check if we are allowing photo uploads
					if ($this->config->item('sts_affiliate_allow_upload_photos') == 1)
					{
						$data['show_upload'] = 1;
						$mem_photos = $this->members->_get_member_photos($this->session->userdata('userid'));
						
						if (!empty($mem_photos))
						{
							if ($this->config->item('sts_affiliate_image_auto_resize') == 1)
							{
								$data['member_photo'] = 'images/members/' . $mem_photos[0]['raw_name'].'_jrox'.$mem_photos[0]['file_ext'];
							}
							else
							{
								$data['member_photo'] = 'images/members/' . $mem_photos[0]['photo_file_name'];
							}
							
							$data['show_delete_photo'] = '<button name="member_button" id="member_button" type="button" onclick="location.href=\'' . $data['members_url'] . '/account/delete_photo/' . $mem_photos[0]['raw_name'] . '/' . $this->session->userdata('userid') . '\';">' . $this->lang->line('delete_photo') . '</button>';
						}
						else
						{
							$data['member_photo'] = 'images/misc/sponsor.png';
						}
					}
					else
					{
						$data['show_upload'] = 0;
					}
				}	
				else
				{
					$this->session->sess_destroy();
					redirect();
				}
				
				//set the default countries
				foreach ($this->account_fields as $row)
				{
					switch ($row['form_field_name'])
					{
						case 'billing_country':
							
							$s_billing_country = empty($data['billing_country']) ? $row['form_field_values'] : $data['billing_country'];
							
						break;
						
						case 'payment_country':
						
							$s_payment_country = empty($data['payment_country']) ? $row['form_field_values'] : $data['payment_country'];
						
						break;
						
					}
				}
	
				//format the form fields
				$i = 0;
				foreach ($this->account_fields as $row)
				{
						
					$required = $row['form_field_required'] == 1 ? 'required' : '';
					
					$row['check_required'] = $row['form_field_required'] == 1 ? '*' : '';
					
					//set the default values: post or database
					if ($this->input->post($row['form_field_name']) == false)
					{  
						if (!empty($data[$row['form_field_name']]))
						{
							$selected = $data[$row['form_field_name']];
						}
						else
						{
							$selected = $row['form_field_values'];
						}
					}
					else
					{
						$selected = $this->input->post($row['form_field_name']);
					}
					
					switch ($row['form_field_name'])
					{
						case 'billing_country':
	
							$attributes = 'id="' . $row['form_field_name'] . '" class="jroxCheckoutInputFields" onchange="onSelectChange(\'billing_country\', this)"';
							$row['form_field'] = form_dropdown($row['form_field_name'], $this->country_options, $selected, $attributes);
							
							$row['form_field'] .= '<span class="loading"><img src="themes/main/' . $this->config->item('layout_design_site_theme') . '/images/ajax-loader2.gif" align="absmiddle"  alt=""/></span>';
							
						break;
						
						case 'payment_country':
						
							$attributes = 'id="' . $row['form_field_name'] . '" class="jroxCheckoutInputFields" onchange="onSelectChange(\'payment_country\', this)"';
							$row['form_field'] = form_dropdown($row['form_field_name'], $this->country_options, $selected, $attributes);
							
							$row['form_field'] .= '<span class="loading"><img src="themes/main/' . $this->config->item('layout_design_site_theme') . '/images/ajax-loader2.gif" align="absmiddle"  alt=""/></span>';
							
						break;
						
						case 'billing_state':
						
							$regions = _load_regions_array($s_billing_country);
							
							if (!empty($regions))
							{
								$regions_a = array(); $regions_b = array();
								
								foreach ($regions as $v)
								{
									array_push($regions_a, $v['region_id']);
									array_push($regions_b, $v['region_name']);
								}
							
								
								$region_options = combine_array($regions_a, $regions_b);		
								
								$select_region = '';
								if ($this->input->post('billing_state') == false)
								{
									if ($this->security_model->_check_user_session() == true) //set the correct region ID
									{
										$select_region = _get_region_name($data['billing_state'], 'region_id', 'region_name');
										
									}
								}
								else
								{
									$select_region = $this->input->post('billing_state');
								}
								
								
								$attributes = 'id="' . $row['form_field_name'] . '" class="jroxCheckoutInputFields"';
								$row['form_field'] = form_dropdown($row['form_field_name'], $region_options, $select_region, $attributes);
							}
							else
							{
								$fdata = array(
										  'name'        => $row['form_field_name'],
										  'id'          => $row['form_field_name'],
										  'value'       => $selected,
										  'size'        => '50',
										  'class'       => 'generalInput jroxCheckoutInputFields ' . $required,
										);
						
								$row['form_field'] = form_input($fdata);
							}
							
							
								
						break;
						
						case 'payment_state':
						
							$regions = _load_regions_array($s_payment_country);
							
							if (!empty($regions))
							{
								$regions_a = array(); $regions_b = array();
								
								foreach ($regions as $v)
								{
									array_push($regions_a, $v['region_id']);
									array_push($regions_b, $v['region_name']);
								}
								
								//array_push($regions_a, '0');
								//array_push($regions_b, $this->lang->line('not_listed'));
								
								$region_options = combine_array($regions_a, $regions_b);		
								
								$select_region = '';
								if ($this->input->post('payment_state') == false)
								{
									if ($this->security_model->_check_user_session() == true) //set the correct region ID
									{
										$select_region = _get_region_name($data['payment_state'], 'region_id', 'region_name');
										
									}
								}
								else
								{
									$select_region = $this->input->post('payment_state');
								}
								
								$attributes = 'id="' . $row['form_field_name'] . '" class="jroxCheckoutInputFields"';
								$row['form_field'] = form_dropdown($row['form_field_name'], $region_options, $select_region, $attributes);
							}
							else
							{
								$fdata = array(
										  'name'        => $row['form_field_name'],
										  'id'          => $row['form_field_name'],
										  'value'       => $selected,
										  'size'        => '50',
										  'class'       => 'generalInput jroxCheckoutInputFields ' . $required,
										);
						
								$row['form_field'] = form_input($fdata);
							}
							
							
								
						break;
						
						case 'username':
						
							$row['form_field'] = '<div style="margin: 5px 0">' . $selected . '</div>';
						
						break;
						
						case 'password':
						
							$fdata = array(
										  'name'        => $row['form_field_name'],
										  'id'          => $row['form_field_name'],
										  'value'       => '',
										  'size'        => '50',
										  'class'       => ' generalInput jroxCheckoutInputFields',
										);
					
							$row['form_field'] = form_password($fdata);
							$row['check_required'] = '';
						
						break;
						
						case 'primary_email':
						case 'paypal_id':
							
							$required .= ' email';
									
						default:
							
							if ($row['form_type'] == 'custom_fields')
							{
								$row['form_field'] = load_field_type($row['form_field_type'], $row, $selected, ' generalInput jroxCheckoutInputFields ' . $required);
							}
							else
							{
							
								$fdata = array(
											  'name'        => $row['form_field_name'],
											  'id'          => $row['form_field_name'],
											  'value'       => $selected,
											  'size'        => '50',
											  'class'       => ' generalInput jroxCheckoutInputFields ' . $required,
											);
							
								$row['form_field'] = form_input($fdata);
							}
						break;
					}
			
					//sort the data
					
					switch ($row['form_type'])
					{
						case 'checkout_fields':
							
							array_push($data['billing_form_fields'], $row);	
							
						break;
						
						case 'checkout_payment_fields':
						
							array_push($data['payment_form_fields'], $row);	
						
						break;
						
						case 'checkout_shipping_fields':
						
							array_push($data['shipping_form_fields'], $row);	
						
						break;
						
						case 'custom_fields':
							
							array_push($data['custom_fields'], $row);
							
						break;
					}
					
					$i++;
				}
				
				/*
				if (!empty($confirm_password))
				{
					//add a confirm password option
					$fdata = array(
											  'name'        => 'passconf',
											  'id'          => 'passconf',
											  'value'       => '',
											  'size'        => '50',
											  'class'       => ' generalInput jroxCheckoutInputFields required',
											);
							
					$row['form_field'] = form_password($fdata);
					$row['form_field_description'] = $this->lang->line('confirm_password');
					
					array_push($data['billing_form_fields'], $row);					
				}
				*/
				
				$data['show_custom_fields'] = 0;
				
				if ($data['sts_form_enable_custom_fields_registration'] == 1)
				{
					$data['show_custom_fields'] = 1;
				}
				
				//check for payment fields
				$data['show_affiliate'] = !empty($data['payment_form_fields']) ? 1 : 0;
				$data['show_shipping'] = !empty($data['shipping_form_fields']) ? 1 : 0;
				
				//now check if we need captcha
				$this->load->helper('captcha');
					
				$captcha = _generate_captcha('sts_sec_enable_captcha_order_form', $data['checkout_url']);
					
				$data = array_merge($data, $captcha);
				
				//get all mailing lists
				$mailing_lists = $this->lists->_get_all_mailing_lists();
				
				$userlists = array();
				
				//get users subscribed lists
				$userlists = $this->members->_get_member_mailing_lists($this->session->userdata('userid'), true);
				
				$data['member_hide_list_box'] = $this->config->item('member_hide_mailing_list_box') == true ? 1 : 0;
				
				if ($this->config->item('member_hide_mailing_list_box') == false)
				{
					//format the mailing list
					$data['mailing_lists'] = array();
					
					foreach ($mailing_lists as $row)
					{
						$row['mailing_list_name'] = character_limiter($row['mailing_list_name'], 25);
						$checkbox = false;
						if (!empty($userlists))
						{
							$checkbox = in_array($row['mailing_list_id'], $userlists) ? true : false;
						}
			
						$checkbox_data = array(
										'name'        => 'lists[]',
										'id'          => $row['mailing_list_name'],
										'value'       => $row['mailing_list_id'],
										'checked'     => $checkbox,
										'class'       => 'checkBox',
										);
									
						$row['mailing_list_check_box']	= form_checkbox($checkbox_data);
						
						array_push($data['mailing_lists'], $row);
					}
				}
				
				//check for profile description
				$data['show_profile_description'] = '';
				if ($this->config->item('sts_affiliate_enable_profile_description') == '1')
				{
					$textarea_data = array(
									'name'        => 'profile_description',
									'id'          => 'profile_description',
									'value'       => $data['profile_description'],
									'rows'        => '10',
									'cols'		  => '31',
									'class'       => 'jroxCheckoutInputFields',
									);
								
				
					$data['show_profile_description'] = '<div id="jroxCheckoutAffiliate_profile_description" class="jroxMemberAccountDetailsFields">
                
                	<div class="jroxCheckoutPaymentFieldName"><label>' . $this->lang->line('profile_description') . '</label></div>
               	
                	<div class="jroxCheckoutPaymentFieldInput" id="jroxCheckoutPaymentFieldInput_profile_description">' . form_textarea($textarea_data) . '</div>
                
                </div>';
				}
	
				//load the template
				$this->parser->_JROX_load_view('tpl_members_account', 'members', $data);
			}
			else
			{
				echo '<div class="errorMessage" id="error-messages">' . $this->validation->error_string . '</div>';
				exit();
			}
		}
		else
		{
			//update the member
			$userdata = $this->members->_update_member($this->session->userdata('userid'));	
			
			echo '<div class="successMessage" id="successMessage">' . $this->lang->line('account_updated_successfully') . '</div>';
			exit();
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function delete_photo()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//check if user is deleting his photo only
		if ($this->session->userdata('userid') != $this->uri->segment(5)) { show_error('invalid_data'); }
		
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		$this->load->model('uploads_model');
		
		//delete the photo
		
		$pdata['config'] = array(
								'type'	=>	'delete',
								'table'	=>	'members_photos',
								'key'	=>	'raw_name',
								'value' 	=>	$this->uri->segment(4),
								'id'	=>	$this->uri->segment(5)
								);
			
		$pdata['fields'] = array (
								'member_id'	=> 	$this->uri->segment(5)
								);		
		
		if ($this->uploads_model->_delete_photo('members', $pdata))
		{	
			$this->session->set_flashdata('show_message', '<div class="successMessage" id="successMessage">' . $this->lang->line('image_deleted_successfully') . '</div>');
		}
		else
		{
			//set flash data
			$this->session->set_flashdata('show_message', '<div class="errorMessage">' . $this->lang->line('could_not_delete_image') . '</div>');
		}
		
		//redirect back to account area
		redirect(MEMBERS_ROUTE . '/account');	
	}
	
	// ------------------------------------------------------------------------	
	
	function update_photo()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		$this->load->model('uploads_model');
		
		//upload the photo
		$data = $this->uploads_model->_upload_photo('members', $this->config->item('sts_affiliate_image_auto_resize'));
		
		if ($data['success'])
		{
			$member_id = $this->session->userdata('userid');
		
			//get the admin data first
			$member_data = $this->db_validation_model->_get_details('members_photos', '', 'member_id', $member_id);
		
			if (empty($member_data))
			{
				//insert new photo into members photo table
				$insert_data = array (
										'member_id'	=> 	$member_id,
										'photo_file_name' => $data['info']['file_name'], 
										'raw_name'	=> $data['info']['raw_name'],
										'file_ext'	=> $data['info']['file_ext'],
										'file_type'	=> $data['info']['file_type'],
										'original_file_name' => $data['info']['orig_name'],
										'image_resized'	=>	$this->config->item('sts_affiliate_image_auto_resize')
									);	
				
				$this->uploads_model->_insert_image_db($insert_data, 'members_photos');
			}
			else
			{
				//update the members photo table with new photo
				
				$data['config'] = array(
											'table'	=>	'members_photos',
											'key'	=>	'member_id',
											'value' 	=>	$member_id
										);
				
				$data['fields'] = array (
											'photo_file_name' => $data['info']['file_name'], 
											'raw_name'	=> $data['info']['raw_name'],
											'file_ext'	=> $data['info']['file_ext'],
											'file_type'	=> $data['info']['file_type'],
											'original_file_name' => $data['info']['orig_name'],
											'image_resized'	=>	$this->config->item('sts_affiliate_image_auto_resize')
										);			
				
				$this->uploads_model->_update_image_db($data);
				
				//delete any old photo
				if ($member_data[0]['photo_file_name'])
				{
					@unlink('./images/' . $this->config->item('images_members_dir') . '/' . $member_data[0]['photo_file_name']);
					
					//delete thumbs
					if ($this->config->item('sts_affiliate_image_auto_resize') == 1)
					{
						@unlink('./images/' . $this->config->item('images_members_dir') . '/' . $member_data[0]['raw_name'] . '_jrox' . $member_data[0]['file_ext']);
					}
				}
			}
			
			$this->session->set_flashdata('show_message', '<div class="successMessage" id="successMessage">' . $this->lang->line('image_uploaded_successfully') . '</div>');

			//redirect back to account area
			redirect(MEMBERS_ROUTE . '/account');	
		}
		else
		{
			//set flash data
			$this->session->set_flashdata('show_message', '<div class="errorMessage">' . $data['msg'] . '</div>');
			
			redirect(MEMBERS_ROUTE . '/account');	
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_billing_data()
	{
		
		//first format the different fields
		$account_fields = array();
		$account_payment_fields = array();
		$account_shipping_fields = array();
		$custom_fields = array();
		
		foreach ($this->account_fields as $row)
		{
			switch ($row['form_type'])
			{
				case 'checkout_fields':
				
					array_push($account_fields, $row);
				
				break;
				
				case 'checkout_payment_fields':
				
					array_push($account_payment_fields, $row);
					
				break;
				
				case 'checkout_shipping_fields':
				
					array_push($account_shipping_fields, $row);
					
				break;
				
				case 'custom_fields':
				
					array_push($custom_fields, $row);
					
				break;
			}
		}
			
		//run the checkout fields
		
		//set the member id if any
		if ($this->security_model->_check_user_session() == true)
		{
			$this->validation->member_id = $this->session->userdata('userid');
		}
		
		foreach ($account_fields as $field)
		{
			switch ($field['form_field_name'])
			{
				case 'fname':
				
					$rules[$field['form_field_name']] = 'trim|required|min_length[2]';
					
				break;
				
				case 'username':
				
					continue;
				
				break;
				
				case 'billing_state':
				
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|required';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim';
					}
					
					//check if billing_state is an integer and if so convert
					
					if (!empty($_POST['billing_state']))
					{
						if (is_numeric($_POST['billing_state']))
						{
							$_POST['billing_state'] = _get_region_name($_POST['billing_state'], 'region_name', 'region_id');
							
						}
					}	
					
				break;
				
				case 'primary_email':
					
					$rules[$field['form_field_name']] = 'trim|required|strtolower|valid_email|callback__check_email_update';
					
				break;
				
				case 'password':
				
					if ($this->input->post('password'))
					{
						$rules[$field['form_field_name']] = 'trim|min_length[6]|max_length[25]|alpha_dash';
					}
					
				break;
				
				case 'website':
				
					$rules[$field['form_field_name']] = 'trim|prep_url';
				
				break;
				
				default:
				
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|required|max_length[255]';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|max_length[255]';
					}
				
				break;
			}
			
			$fields[$field['form_field_name']] = $field['form_field_description'];
		}
		
		//check shipping 
		if ($this->input->post('jroxEnableShipping') == 1)
		{
			foreach ($account_shipping_fields as $field)
			{
				switch ($field['form_field_name'])
				{					
					case 'shipping_state':
				
						if ($field['form_field_required'] == 1)
						{
							$rules[$field['form_field_name']] = 'trim|required';
						}
						else
						{
							$rules[$field['form_field_name']] = 'trim';
						}
						
						//check if billing_state is an integer and if so convert
						if (!empty($_POST['shipping_state']))
						{
							if (is_numeric($_POST['shipping_state']))
							{
								$_POST['shipping_state'] = _get_region_name($_POST['shipping_state'], 'region_name', $id = 'region_id');
							}
						}
					break;
					
					default:
					
						if ($field['form_field_required'] == 1)
						{
							$rules[$field['form_field_name']] = 'trim|required|max_length[255]';
						}
						else
						{
							$rules[$field['form_field_name']] = 'trim|max_length[255]';
						}
					
					break;
				}
				
				$fields[$field['form_field_name']] = $field['form_field_description'];
			}
		}
		
		//check payment

		foreach ($account_payment_fields as $field)
		{
			switch ($field['form_field_name'])
			{					
				case 'payment_state':
			
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|required';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim';
					}
					
					//check if billing_state is an integer and if so convert
					if (!empty($_POST['payment_state']))
					{
						if (is_numeric($_POST['payment_state']))
						{
							$_POST['payment_state'] = _get_region_name($_POST['payment_state'], 'region_name', $id = 'region_id');
						}
					}
				break;
				
				case 'payment_preference_amount':
				
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|required|numeric';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|numeric';
					}
				
				break;
				
				case 'paypal_id':
					
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|required|valid_email|callback__check_paypal_id_update';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|valid_email|callback__check_paypal_id_update';
					}
					
				break;
				
				case 'safepay_id':
					
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|required|max_length[255]|callback__check_safepay_id_update';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|max_length[255]|callback__check_safepay_id_update';
					}
					
				break;
				
				case 'alertpay_id':
					
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|required|max_length[255]|callback__check_alertpay_id_update';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|max_length[255]|callback__check_alertpay_id_update';
					}
				
				break;
				
				case 'moneybookers_id':
					
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|required|max_length[255]|callback__check_moneybookers_id_update';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|max_length[255]|callback__check_moneybookers_id_update';
					}

				break;
				
				case 'custom_id':
					
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|required|max_length[255]|callback__check_custom_id_update';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|strtolower|max_length[255]|callback__check_custom_id_update';
					}
					
				break;
				
				default:
				
					if ($field['form_field_required'] == 1)
					{
						$rules[$field['form_field_name']] = 'trim|required|max_length[255]';
					}
					else
					{
						$rules[$field['form_field_name']] = 'trim|max_length[255]';
					}
				
				break;
			}
			
			$fields[$field['form_field_name']] = $field['form_field_description'];
		}
		
		//check captcha
		if ($this->config->item('sts_sec_enable_captcha_order_form') == 1)
		{
			$rules['jroxVerifyField'] = 'trim|required|callback__check_captcha';
		}
		
		$this->validation->set_rules($rules);
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_captcha()
	{
		if ($this->session->userdata('user_captcha_set') != $this->validation->jroxVerifyField)
		{
			$this->validation->set_message('_check_captcha', $this->lang->line('invalid_verification_code'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------		
	
	function _check_email_update()
	{
		if ($this->db_validation_model->_validate_field('members', 'primary_email', $this->validation->primary_email, 'member_id', $this->validation->member_id))
		{
			$this->validation->set_message('_check_email_update', $this->lang->line('member_email_taken'));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_custom_ids($type = '', $id = '', $add = '', $callback = '', $lang = '')
	{
		if ($this->db_validation_model->_validate_field('members', $type, $id, 'member_id', $this->validation->member_id))
		{
			$this->validation->set_message($callback, $this->lang->line($lang));
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_paypal_id_update()
	{
		return  $this->_check_custom_ids('paypal_id', $this->validation->paypal_id, 'update', '_check_paypal_id_update', 'paypal_id_taken');
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_safepay_id_update()
	{
		return $this->_check_custom_ids('safepay_id', $this->validation->safepay_id, 'update', '_check_safepay_id_update', 'safepay_id_taken');
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_moneybookers_id_update()
	{
		return $this->_check_custom_ids('moneybookers_id', $this->validation->moneybookers_id, 'update', '_check_moneybookers_id_update', 'moneybookers_id_taken');
	}		
	
	// ------------------------------------------------------------------------	
	
	function _check_alertpay_id_update()
	{
		return $this->_check_custom_ids('alertpay_id', $this->validation->alertpay_id, 'update', '_check_alertpay_id_update', 'alertpay_id_taken');
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_custom_id_update()
	{
		return $this->_check_custom_ids('custom_id', $this->validation->custom_id, 'update', '_check_custom_id_update', 'custom_id_taken');
	}
}

?>