<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - content.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to generate member only content pages
|
*/

class Content extends Member_Controller {

	function __construct()
	{
		parent::Member_Controller();
		
		$this->config->set_item('css_body', 'jroxMembersContent');
		
		//load required models
		$this->load->model('content_model', 'content');
		
		//create pagination links		
		$this->config->set_item('uri', $this->config->slash_item('base_folder_path') . $this->config->slash_item('site_index_page') . $this->uri->segment(1));
		$this->config->set_item('uri_string', str_replace('/', ':', trim_slashes($this->uri->uri_string())));	
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		redirect(MEMBERS_ROUTE . '/content/view');
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$text_array = array('members_content', 'no_content_found', 'read_more');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('content');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		$uri = $data['uri'] . '/content/view/';

		$data['offset'] = $this->uri->segment(4, 0);
		$data['sort_column'] = $this->uri->segment(6, 0);
		$data['sort_order'] = $this->uri->segment(5, 0);
		$data['next_sort_order'] = $this->uri->segment(5) == 'DESC' ? 'ASC' : 'DESC';
		
		$sdata = $this->content->_get_members_content('5',  MEMBERS_CONTENT_PER_PAGE, $data['offset'], $data['sort_column'], $data['sort_order']);

		$data['show_content'] = 0;
		
		if (!empty($sdata['articles']))
		{
			$data['show_content'] = 1;
			$data['articles'] = $sdata['articles'];
		}

		$pagination = $this->db_validation_model->_set_pagination($uri, 'content_articles', MEMBERS_CONTENT_PER_PAGE, 4, $data['sort_order'], $data['sort_column'],  $sdata['total_rows'], '', '', 'public');
		
		$data['pagination_rows'] = $pagination['rows'];
		
		$data['num_pages'] = $pagination['num_pages'];
			
		$data['no_pages'] = $data['num_pages'] > 1 ? 1 : 0;

		//load the template
		$this->parser->_JROX_load_view('tpl_members_content', 'members', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function article()
	{
		//view article content by ID
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$text_array = array('members_content');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		//get the article
		$row = $this->content->_get_article_details((int)$this->uri->segment(4));
		
		$this->content->_check_perms('members', $row['category_id']);
		
		//set the meta tags
		$data['page_title'] = $row['content_title'];
		$data['meta_keywords'] = $data['sts_store_default_keywords'] . ', ' . $row['content_tags'];
		$data['meta_description'] = $data['sts_store_description'] . ' - ' . $row['content_title'];
		
		foreach ($row as $k => $v)
		{	
			if ($k == 'content_body')
			{
				$v = $this->init->_parse_member_data(html_entity_decode($v));
			}
			
			$data[$k] = $v;
		}
		
		//load the template
		$this->parser->_JROX_load_view('tpl_members_content_article', 'members', $data);
			
	}
	
	
}

?>