<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - dashboard.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to generate the dashboard for the user
|
*/
class Dashboard extends Member_Controller {
	
	function __construct()
	{
		parent::Member_Controller();	
		
		//load css body style
		$this->config->set_item('css_body', 'jroxMembersDashboard');
		
		//load required models
		$this->load->model('content_model', 'content');
		
		//create pagination links		
		$this->config->set_item('uri', $this->config->slash_item('base_folder_path') . $this->config->slash_item('site_index_page') . $this->uri->segment(1));
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$text_array = array('dashboard', 'members_dashboard', 'dashboard_general_affiliate_link', 'dashboard_affiliate_signup_link',
							'dashboard_downloads', 'read_more', 'dashboard_quickstats', 'dashboard_support_tickets', 'dashboard_mailing_lists',
							'dashboard_unpaid_invoices', 'dashboard_unpaid_commissions', 'dashboard_open_tickets', 'dashboard_closed_tickets',
							'dashboard_paid_invoices', 'dashboard_paid_commissions', 'update_subscriptions', 'create_support_ticket', 'welcome',
							'join_our_aff_program', 'click_here_activate', 'affiliate_program',
							);
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('members_area');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		$data['show_articles'] = 0;
		
		$data['affiliate_activation_link'] = _jrox_members_url() . '/account/activate_affiliate';
		
		//get members main menu content
		$articles = $this->content->_get_dashboard_content(6);
		
		if (!empty($articles))
		{
			$data['show_articles'] = 1;
			$data['articles'] = $articles;
		}
		
		//get commissions
		$num_options = get_default_currency($this->config->item('sts_store_default_currency'));
		
		$totals = $this->members->_get_dashboard_totals($this->session->userdata('userid'));
		
		$data['dashboard_unpaid_commissions'] = format_amounts($totals['unpaid_commissions'], $num_options);
		$data['dashboard_paid_commissions'] = format_amounts($totals['paid_commissions'], $num_options);
		
		$data['dashboard_unpaid_invoices'] = $totals['unpaid_invoices'];
		$data['dashboard_paid_invoices'] = $totals['paid_invoices'];
		
		$data['dashboard_open_tickets'] = $totals['open_tickets'];
		$data['dashboard_closed_tickets'] = $totals['closed_tickets'];
		
		$data['dashboard_name'] = $this->session->userdata('m_fname');
		
		//get support tickets
		
		//get all mailing lists
		$mailing_lists = $this->lists->_get_all_mailing_lists();
		
		$userlists = array();
		
		//get users subscribed lists
		$userlists = $this->members->_get_member_mailing_lists($this->session->userdata('userid'), true);
		
		$data['member_hide_list_box'] = $this->config->item('member_hide_mailing_list_box') == true ? 1 : 0;
		
		if ($this->config->item('member_hide_mailing_list_box') == false)
		{
				
			//format the mailing list
			$data['mailing_lists'] = array();
			
			foreach ($mailing_lists as $row)
			{
				$row['mailing_list_name'] = character_limiter($row['mailing_list_name'], 25);
				$checkbox = false;
				if (!empty($userlists))
				{
					$checkbox = in_array($row['mailing_list_id'], $userlists) ? true : false;
				}
	
				$checkbox_data = array(
								'name'        => 'lists[]',
								'id'          => $row['mailing_list_name'],
								'value'       => $row['mailing_list_id'],
								'checked'     => $checkbox,
								'class'       => 'checkBox',
								);
							
				$row['mailing_list_check_box']	= form_checkbox($checkbox_data);
				
				array_push($data['mailing_lists'], $row);
			}
		
		}
		
		//set dashboard links
		$data['enable_links'] = $this->config->item('sts_content_members_dashboard_enable');
		
		//construct the dashboard icons
		
		$data['dashboard_links'] = '';
		
		if ($this->config->item('sts_content_members_dashboard_enable_account_details') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/account\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardAccountDetails"></div>
                
											' . $this->lang->line('dashboard_account_details') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_invoices') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/invoices/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardInvoices"></div>
                
											' . $this->lang->line('dashboard_invoices') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_tools') == 1 && $this->session->userdata('m_aff_marketing') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/marketing/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardTools"></div>
                
											' . $this->lang->line('dashboard_marketing') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_reports') == 1 && $this->session->userdata('m_aff_marketing') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/reports/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardReports"></div>
                
											' . $this->lang->line('dashboard_reports') . '
										
										 </div>';
		}
		

		
		if ($this->config->item('sts_content_members_dashboard_enable_support') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/support/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardSupport"></div>
                
											' . $this->lang->line('dashboard_support') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_commissions') == 1 && $this->session->userdata('m_aff_marketing') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/commissions/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardCommissions"></div>
                
											' . $this->lang->line('dashboard_commissions') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_content') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/content/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardContentArticles"></div>
                
											' . $this->lang->line('dashboard_content') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_downloads') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/downloads/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardDownloads"></div>
                
											' . $this->lang->line('dashboard_downloads') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_downline') == 1 && $this->session->userdata('m_aff_marketing') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="javascript:void(window.open(\''. $data['members_url'] . '/downline/view\', \'popup\', \'width=700,height=500, location=no, menubar=no, status=no,toolbar=no, scrollbars=yes, resizable=yes\'))">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardDownline"></div>
                
											' . $this->lang->line('dashboard_downline') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_memberships') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/memberships/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardMemberships"></div>
                
											' . $this->lang->line('dashboard_memberships') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_coupons') == 1 && $this->session->userdata('m_aff_marketing') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/coupons/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardCoupons"></div>
                
											' . $this->lang->line('dashboard_coupons') . '
										
										 </div>';
		}
		
		if ($this->config->item('sts_content_members_dashboard_enable_traffic') == 1 && $this->session->userdata('m_aff_marketing') == 1)
		{
			$data['dashboard_links'] .= '<div class="jroxMembersDashboardIcons" onclick="location.href=\'' . $data['members_url'] . '/traffic/view\';">
            
                							<div class="jroxMembersDashboardIconsImage" id="jroxMembersDashboardTraffic"></div>
                
											' . $this->lang->line('dashboard_traffic') . '
										
										 </div>';
		}
		
		
		$data['last_login_date'] = $this->lang->line('last_login_date') . ': ' . $this->session->userdata('m_ll_date');
		$data['last_login_ip'] = $this->lang->line('from') . ': ' . $this->session->userdata('m_ll_ip');
		$data['enable_affiliate_marketing'] = $this->session->userdata('m_aff_marketing');
		
		$data['admin_approval_request'] = 0;
		
		if ($this->config->item('sts_affiliate_enable_affiliate_marketing') == '1')
		{
			if ($data['enable_affiliate_marketing'] == '0' && !$this->config->item('disable_affiliate_account_activation_box'))
			{
				$data['admin_approval_request'] = 1;
			}
		}
		
		$this->parser->_JROX_load_view('tpl_members_dashboard', 'members', $data);
		
	}
}
?>