<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - downloads.php
| -------------------------------------------------------------------------     
| 
| This controller file shows any downloads made by the user
|
*/

class Downloads extends Member_Controller {
	
	function __construct()
	{
		parent::Member_Controller();	
		
		$this->config->set_item('css_body', 'jroxMembersDownloads');
		
		//create pagination links		
		$this->config->set_item('uri', $this->config->slash_item('base_folder_path') . $this->config->slash_item('site_index_page') . $this->uri->segment(1));
		$this->config->set_item('uri_string', str_replace('/', ':', trim_slashes($this->uri->uri_string())));
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		redirect(MEMBERS_ROUTE . '/downloads/view');
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$text_array = array('downloads', 'no_downloads_found', 'expires', 'downloads_allowed', 'product_name');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('downloads');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];

		
		$downloads = $this->members->_get_member_downloads($this->session->userdata('userid'));

		$data['show_downloads'] = 0;
		
		if (!empty($downloads))
		{
			$data['show_downloads'] = 1;
			$data['downloads'] = array();
			
			foreach ($downloads as $row)
			{
				$row['s_expires'] = _show_date($row['expires']);
				$row['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				
				if (empty($row['max_downloads_per_user']))
				{
					$row['s_max_downloads_per_user'] = $this->lang->line('unlimited');
				}
				else
				{
					$row['s_max_downloads_per_user'] = $row['max_downloads_per_user'];
				}
				
				//check if download is membership based
				if (!empty($row['membership_based']))
				{
					$row['s_download_link_1'] = !empty($row['download_location_1']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/1', $this->lang->line('download_file_1')) : '';
					$row['s_download_link_2'] = !empty($row['download_location_2']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/2', $this->lang->line('download_file_2')) : '';
					$row['s_download_link_3'] = !empty($row['download_location_3']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/3', $this->lang->line('download_file_3')) : '';
					$row['s_download_link_4'] = !empty($row['download_location_4']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/4', $this->lang->line('download_file_4')) : '';
					$row['s_download_link_5'] = !empty($row['download_location_5']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/5', $this->lang->line('download_file_5')) : '';
					$row['s_download_link_6'] = !empty($row['download_location_6']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/6', $this->lang->line('download_file_6')) : '';
					$row['s_download_link_7'] = !empty($row['download_location_7']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/7', $this->lang->line('download_file_7')) : '';
					$row['s_download_link_8'] = !empty($row['download_location_8']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/8', $this->lang->line('download_file_8')) : '';
					$row['s_download_link_9'] = !empty($row['download_location_9']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/9', $this->lang->line('download_file_9')) : '';
					$row['s_download_link_10'] = !empty($row['download_location_10']) ? anchor(MEMBERS_ROUTE.'/downloads/mget/' . $row['product_id'] . '/10', $this->lang->line('download_file_10')) : '';
				}
				else
				{
					//create the download links
						
					$row['s_download_link_1'] = !empty($row['download_location_1']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/1', $this->lang->line('download_file_1')) : '';
					$row['s_download_link_2'] = !empty($row['download_location_2']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/2', $this->lang->line('download_file_2')) : '';
					$row['s_download_link_3'] = !empty($row['download_location_3']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/3', $this->lang->line('download_file_3')) : '';
					$row['s_download_link_4'] = !empty($row['download_location_4']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/4', $this->lang->line('download_file_4')) : '';
					$row['s_download_link_5'] = !empty($row['download_location_5']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/5', $this->lang->line('download_file_5')) : '';
					$row['s_download_link_6'] = !empty($row['download_location_6']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/6', $this->lang->line('download_file_6')) : '';
					$row['s_download_link_7'] = !empty($row['download_location_7']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/7', $this->lang->line('download_file_7')) : '';
					$row['s_download_link_8'] = !empty($row['download_location_8']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/8', $this->lang->line('download_file_8')) : '';
					$row['s_download_link_9'] = !empty($row['download_location_9']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/9', $this->lang->line('download_file_9')) : '';
					$row['s_download_link_10'] = !empty($row['download_location_10']) ? anchor(MEMBERS_ROUTE.'/downloads/get/' . $row['id'] . '/10', $this->lang->line('download_file_10')) : '';
				}
				
				array_push($data['downloads'], $row);
			}
		}

		//load the template
		$this->parser->_JROX_load_view('tpl_members_downloads', 'members', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function mget()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		
		//download the file
		$id = $this->uri->segment(4);
		$num = $this->uri->segment(5, 1);
		
		//get downloads based on membership
		$this->load->model('products_model');
		
		$download = $this->products_model->_get_product_basic($id);
		
		$show_download = false;
		if ($id)
		{
			//first check if the membership has expired
			$mem = $download['add_to_membership'];
		
			$mems = $this->members->_get_member_membership($this->session->userdata('userid'), $download['add_to_membership']);

			if (!empty($mems))
			{
				if ($mems['expires'] > now())
				{
					$show_download = true;
				}
			}
		}
		
		if ($show_download == true)
		{
			$location = 'download_location_' . $num;
			
			//check if this is a URL redirect first
			if(preg_match("/ftp:\/\//",$download[$location]) || preg_match("/http:\/\//",$download[$location]) || preg_match("/https:\/\//",$download[$location]))
			{
				redirect_301($download[$location], true, false);
			}
			else
			{
				$this->load->helper('download');
				$this->load->helper('file');
				$data = read_file($download[$location]);
			
				$name = basename($download[$location]);
			
				force_download($name, $data); 
			}
		}
		else
		{
			show_error($this->lang->line('download_expired'));
		}
	}
	
	// ------------------------------------------------------------------------
	
	function get()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		
		//download the file
		$id = $this->uri->segment(4);
		$num = $this->uri->segment(5, 1);
		
		//get the download details first
		$download = $this->members->_get_download($id);
		
		//check for expiration and max downloads
		if ($download['expires'] < now())
		{
			show_error($this->lang->line('download_expired'));
		}
		elseif (!empty($download['max_downloads_per_user']))
		{
			if ($download['downloads'] >= $download['max_downloads_per_user'])
			{
				show_error($this->lang->line('maximum_download_reached'));
			}
		}
		
		$location = 'download_location_' . $num;
		
		//update the download amount  for user
		$total = $download['downloads'] + 1;
		$this->members->_update_download_total($id, $total);
		
		//check if this is a URL redirect first
		if(preg_match("/ftp:\/\//",$download[$location]) || preg_match("/http:\/\//",$download[$location]) || preg_match("/https:\/\//",$download[$location]))
		{
			redirect_301($download[$location], true, false);
		}
		else
		{
			$this->load->helper('download');
			$this->load->helper('file');
			$data = read_file($download[$location]);
		
			$name = basename($download[$location]);
		
			force_download($name, $data); 
		}
	}
}

?>