<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - invoices.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to show all orders made by the user
|
*/

class Invoices extends Member_Controller {
	
	function __construct()
	{
		parent::Member_Controller();	
		
		$this->config->set_item('css_body', 'jroxMembersInvoice');
		
		//load invoices model	
	
		$this->load->model('invoices_model', 'invoices');
		$this->load->helper('country');
		
		//create pagination links		
		$this->config->set_item('uri', $this->config->slash_item('base_folder_path') . $this->config->slash_item('site_index_page') . $this->uri->segment(1));
		$this->config->set_item('uri_string', str_replace('/', ':', trim_slashes($this->uri->uri_string())));
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		redirect(MEMBERS_ROUTE . '/invoices/view');
	}
	
	// ------------------------------------------------------------------------
	
	function send_invoice()
	{
		/*
		| -----------------------------------------
		| send invoice
		| -----------------------------------------
		*/
	
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		$data['page_title'] = $this->lang->line('print_invoice');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		//get currency options
		$num_options = get_default_currency($data['sts_store_default_currency']);
		$invoice_id = (int)$this->uri->segment(4);
		
		$mdata = $this->invoices->_get_invoice_details($invoice_id);
	
		if (empty($mdata)) { show_error($this->lang->line('no_invoice_found')); }
		
		//check if this user owns the invoice
		$this->security_model->_check_data_ownership($mdata['inv']['member_id']);	
		
		//format the invoice
		$sdata = $this->invoices->_send_invoice_format($mdata, $num_options);

		//get the email template
		$this->load->model('emailing_model');
	
		if ($this->emailing_model->_send_template_email('admin', $sdata, 'member_payment_invoice_template'))
		{
			//log success
			log_message('info', 'invoice id  ' . $invoice_id . ' sent');
			
			//set flash data
			$this->session->set_flashdata('show_message', '<div class="successMessage" id="successMessage">' . $this->lang->line('invoice_emailed_successfully') . '</div>');
		}
		else
		{			
			if ($data['sts_email_enable_debugging'] == 0)
			{			
				$this->session->set_flashdata('show_message', '<div class="errorMessage" id="errorMessage">' . $this->lang->line('could_not_send_invoice') . '</div>');
			}
		}
		
		redirect(MEMBERS_ROUTE . '/invoices/view');
	}
	
	// ------------------------------------------------------------------------
	
	function print_invoice()
	{
		/*
		| -----------------------------------------
		| print invoice
		| -----------------------------------------
		*/
		//show invoices made by the user
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$text_array = array('invoice', 'date_purchased', 'due_date', 'order_status', 'account_information', 'total',
							'shipping_information', 'invoice_notes', 'tax_amount', 'shipping_amount', 'discount_amount',
							'total_amount', 'print_invoice_payment_date', 'print_invoice_payment_method', 'print_invoice_total_payments',
							'print_invoice_transaction_id', 'print_invoice_payments', 'print_invoice_sku', 'sub_total_amount',
							'print_invoice_product_name', 'print_invoice_unit_price', 'print_invoice_quantity');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('print_invoice');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		//get currency options
		$num_options = get_default_currency($data['sts_store_default_currency']);
		
		$mdata = $this->invoices->_get_invoice_details((int)$this->uri->segment(4));
		
		if (empty($mdata)) { show_error($this->lang->line('no_invoice_found')); }
		
		$this->security_model->_check_data_ownership($mdata['inv']['member_id']);	
		
		$data['invoice'] = $mdata;
		
		
		switch ($data['invoice']['inv']['order_status'])
		{
			case 'order_pending':
				
				$data['order_status'] = $this->lang->line('pending');
				
			break;
			
			case 'order_processing':
				
				$data['order_status'] = $this->lang->line('processing');
				
			break;
			
			case 'order_completed':
				
				$data['order_status'] = $this->lang->line('completed');
				
			break;
		}
		
		$data['show_logo'] = $this->config->item('sts_invoice_enable_logo');
		
		if (!empty($data['layout_design_site_logo']))
		{
			$data['logo_image'] = '<img src="' . base_url() . 'images/products/' . $data['layout_design_site_logo'] . '" height="' . $data['layout_design_site_logo_height'] . '" width="' . $data['layout_design_site_logo_width'] . '" border="0"/>';  
		}
		else
		{
			$data['logo_image'] =   '<h2 style="margin-bottom: 5px;">' . $data['layout_design_header_name'] . '<label></label></h2><h3 style="margin:5px;">' . $data['layout_design_header_tag_line'] . '</h3>';
		}
		
		$data['sts_store_country'] = _get_country_name($data['sts_store_shipping_country'], 'country_name');
		$data['invoice_id'] = $data['invoice']['inv']['invoice_id'];
		$data['date_purchased'] = _show_date($data['invoice']['inv']['date_purchased']);
		$data['due_date'] = _show_date($data['invoice']['inv']['due_date']);
		
		$data['customers_name'] = $data['invoice']['inv']['customers_name'];
		$data['customers_company'] = $data['invoice']['inv']['customers_company'];
		$data['customers_address_1'] = $data['invoice']['inv']['customers_address_1'];
		$data['customers_address_2'] = $data['invoice']['inv']['customers_address_2'];
		$data['customers_city'] = $data['invoice']['inv']['customers_city'];
		
		$data['customers_state'] = $data['invoice']['inv']['customers_state'];
		$data['customers_postal_code'] = $data['invoice']['inv']['customers_postal_code'];
		$data['customers_country'] = _get_country_name($data['invoice']['inv']['customers_country'], 'country_name');
		$data['customers_telephone'] = $data['invoice']['inv']['customers_telephone'];
		$data['customers_primary_email'] = $data['invoice']['inv']['customers_primary_email'];
		
		$data['shipping_name'] = $data['invoice']['inv']['shipping_name'];
		$data['shipping_company'] = $data['invoice']['inv']['shipping_company'];
		$data['shipping_address_1'] = $data['invoice']['inv']['shipping_address_1'];
		$data['shipping_address_2'] = $data['invoice']['inv']['shipping_address_2'];
		$data['shipping_city'] = $data['invoice']['inv']['shipping_city'];
		$data['shipping_state'] = $data['invoice']['inv']['shipping_state'];
		$data['shipping_postal_code'] = $data['invoice']['inv']['shipping_postal_code'];
		$data['shipping_country'] = _get_country_name($data['invoice']['inv']['shipping_country'], 'country_name');
		$data['shipping_method'] = $data['invoice']['inv']['shipping_method'];
		$data['shipping_tracking_id'] = $data['invoice']['inv']['shipping_tracking_id'];
		$data['invoice_notes'] = $data['invoice']['inv']['invoice_notes'];
		$data['sub_total'] = format_amounts($data['invoice']['inv']['sub_total'], $num_options);
		
		$data['tax_amount'] = format_amounts($data['invoice']['inv']['tax_amount'], $num_options);
		$data['shipping_amount'] = format_amounts($data['invoice']['inv']['shipping_amount'], $num_options);
		$data['discount_amount'] = format_amounts($data['invoice']['inv']['discount_amount'], $num_options);
		$data['total_amount'] = format_amounts($data['invoice']['inv']['total_amount'], $num_options);
		
		foreach ($data['invoice']['prod'] as $v)
		{
			$data['invoice']['prod']['s_product_notes'] = nl2br($v['product_notes']);
			$data['invoice']['prod']['s_unit_price'] = format_amounts($v['unit_price'], $num_options);
			$data['invoice']['prod']['total_quantity'] = format_amounts($v['unit_price'] * $v['quantity'], $num_options);
		}
		
		$data['products'] = $data['invoice']['prod'];
		
		$data['payments'] = array();
		if (!empty($data['invoice']['payments']))
		{
			$data['show_payments'] = 1;
			foreach ($data['invoice']['payments'] as $v)
			{
				$v['s_payment_date'] = _show_date($v['payment_date']);
				$v['s_payment_method'] = $v['payment_method'] . ' - ' .  $this->lang->line($v['payment_type']);
				$v['s_payment_amount'] = format_amounts($v['payment_amount'], $num_options);
				
				array_push($data['payments'], $v);
			}
		}
		else
		{
			$data['show_payments'] = 0;
		}
		
		if (!empty($data['invoice']['total_payments']))
		{
			$data['total_payments'] =  format_amounts($data['invoice']['total_payments'], $num_options);
			$data['invoice_balance'] = _format_invoice_balance($data['invoice']['inv']['total_amount'] - $data['invoice']['total_payments'], $num_options);
		}
		else
		{
			$data['total_payments'] =  '';
			$data['invoice_balance'] = '';
		}
		
		//load the template
		echo $this->parser->_JROX_parse('tpl_members_print_invoice', APPPATH . 'views/members', $data, true);
	}
	
	// ------------------------------------------------------------------------
	
	function details()
	{
		
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//check for currency 
		$site_currency = get_site_currency();
		
		if ($this->config->item('sts_store_default_currency') != $site_currency['settings_value'])
		{
			$this->config->set_item('sts_store_default_currency', $site_currency['settings_value']);
		}
		$this->num_options = get_default_currency($this->config->item('sts_store_default_currency'));
		
		$text_array = array('billing_information', 'account_information', 'shipping_information',  'trial', 'then',
							'select_shipping_option', 'select_payment_option', 'grand_total', 'balance_due',
							'confirmation_payment', 'subtotal', 'payment', 'payment_information', 'invoice_details',
							'discounts', 'order_information', 'order_instructions', 'edit',  'invoices',
							'click_to_pay_invoice', 'pay_invoice', 'payments', 'membership_information', 'invoice');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		//set the page title
		$data['page_title'] = $this->lang->line('pay_invoice');
		
		//get invoice
		$data['jrox_invoice_id'] = (int)$this->uri->segment(4);
		
		$mdata = $this->invoices->_get_invoice_details((int)$this->uri->segment(4));
		
		if (empty($mdata)) { show_error($this->lang->line('no_invoice_found')); }
		
		$this->security_model->_check_data_ownership($mdata['inv']['member_id']);	
		
		//set message
		if ($this->session->flashdata('show_message'))
		{
			$data['show_message'] = '<div class="errorMessage" id="errorMessage">' . $this->session->flashdata('show_message') . '</div>';
		}
		else
		{
			$data['show_message'] = '';
		}

		//now get the member data
		
		//first get the billing info
		//now get the member data
		$mem_info = $this->members->_get_member_basic($this->session->userdata('userid'));
					
		if (!empty($mem_info))
		{
			//set referral info
			foreach ($mem_info as $key => $val)
			{
				$data[$key] = $val;
			}
			
			$data['billing_country_name'] = _get_country_name($data['billing_country'], 'country_name', 'country_id');
			
			//check if sponsor is already set
			if (!empty($data['sponsor_id']))
			{
				$sponsor_set = true;
			}
			
			$ship_info = $this->members->_get_member_shipping($this->session->userdata('userid'));
				
			//set referral info
			foreach ($ship_info[0] as $key => $val)
			{
				$data[$key] = $val;
			}
		
			$data['shipping_country_name'] = _get_country_name($data['shipping_country'], 'country_name', 'country_id');
		}	

		$data['show_shipping'] = $mdata['inv']['product_type'] == 'physical' ? 1 : 0;			
	
		//check if sponsor is already set
		if (!empty($mdata['inv']['referrer_id']))
		{
			$sponsor_set = true;
		}
			
		$data['total_cart_weight'] = '';
		$data['total_cart_quantity'] = '';
		$data['subtotal_cart_price'] = $mdata['inv']['sub_total'];
		
		$data['discount_totals_text'] = '-' . format_amounts($mdata['inv']['discount_amount'], $this->num_options);
		$data['subtotal_cart_price_text'] = format_amounts($mdata['inv']['sub_total'], $this->num_options);
		
		$data['discounts'] = '';
		$data['shipping_handling'] = '';
		$data['taxes'] = '';
		
		if (!empty($mdata['inv']['discount_amount']))
		{
			$data['discounts'] = '<li class="jroxCheckoutCartSubtotal">
									 <div class="jroxCheckoutPaymentItemsPrice"><span class="jroxBold">' . $data['discount_totals_text'] . '</span></div>
									 <div class="jroxCheckoutPaymentItemsName"><span class="jroxBold">' . $this->lang->line('total_discounts') . '</span></div>
									 
									 <div class="clear"></div>
									 </li>';
		}	
		
		if ($data['show_shipping'] == 1)
		{
			$data['shipping_handling'] = '<li class="jroxCheckoutCartSubtotal">
									 <div class="jroxCheckoutPaymentItemsPrice"><span class="jroxBold">' . format_amounts($mdata['inv']['shipping_amount'], $this->num_options) . '</span></div>
									 <div class="jroxCheckoutPaymentItemsName"><span class="jroxBold">' . $this->lang->line('s_and_h') . ' ' . $mdata['inv']['shipping_method'] . '</span></div>
									 
									 <div class="clear"></div>
									 </li>';
		}
		
		if ($mdata['inv']['product_type'] != 'membership')
		{
			$data['taxes'] = '<li class="jroxCheckoutCartSubtotal">
									 <div class="jroxCheckoutPaymentItemsPrice"><span class="jroxBold">' . format_amounts($mdata['inv']['tax_amount'], $this->num_options) . '</span></div>
									 <div class="jroxCheckoutPaymentItemsName"><span class="jroxBold">' . $this->lang->line('taxes') . '</span></div>
									 
									 <div class="clear"></div>
									 </li>';
		}
															
		//calculate the grand totals
		$data['grandtotal_cart_price'] = $mdata['inv']['sub_total'] + $mdata['inv']['tax_amount'] + $mdata['inv']['shipping_amount'] - $mdata['inv']['discount_amount'];
		
		//get all payments
		$data['balance_due'] = $data['grandtotal_cart_price'] - $mdata['total_payments'];
		$data['total_payments_text'] = format_amounts($mdata['total_payments'], $this->num_options);
		
		$data['grandtotal_cart_price_text'] = format_amounts($data['balance_due'], $this->num_options);
		
		//check if the invoice is a membership or regular product and create the array accordingly
		

		$data['payments'] = array();
		if (!empty($mdata['payments']))
		{
			$data['show_payments'] = 1;
			foreach ($mdata['payments'] as $v)
			{
				$v['s_payment_date'] = _show_date($v['payment_date']);
				$v['s_payment_method'] = $v['payment_method'] . ' - ' .  $this->lang->line($v['payment_type']);
				$v['s_payment_amount'] = format_amounts($v['payment_amount'], $this->num_options);
				
				array_push($data['payments'], $v);
			}
		}
		else
		{
			$data['show_payments'] = 0;
		}
		
		if (!empty($mdata['total_payments']))
		{
			$data['total_payments'] =  format_amounts($mdata['total_payments'], $this->num_options);
			$data['invoice_balance'] = _format_invoice_balance($mdata['inv']['total_amount'] - $mdata['total_payments'], $this->num_options);
		}
		else
		{
			$data['total_payments'] =  '';
			$data['invoice_balance'] = '';
		}
		
		//format the products
		$data['payment_invoice_id'] = $mdata['inv']['invoice_id'];
		
		$data['show_payment_button'] = 0;
		if ($mdata['inv']['payment_status'] == 0)
		{
			$data['show_payment_button'] = 1;
		}
		
		/*
		|----------------------------
		|  format membership pricing
		|----------------------------
		*/
		
		if ($mdata['inv']['product_type'] == 'membership')
		{
			$data['jrox_product_type'] = 'membership';
			$data['jroxSubmitPForm'] = 'invoice_membership';
			$data['membership_id'] = $mdata['prod'][0]['product_id'];
			$data['pid'] = $mdata['prod'][0]['product_id'];

			
			//format the cart items			
			foreach($mdata['prod'][0] as $row => $val)
			{
				$data[$row] = $val;

			}	
			$data['attribute_list'] = nl2br($mdata['prod'][0]['product_notes']);

			$data['jrox_amount'] = $data['product_price'] - $mdata['inv']['discount_amount'];
			$data['subtotal_price'] = format_amounts($data['jrox_amount'], $this->num_options);
			
			
			//format recurring_interval_type
	
			switch ($data['recurring_interval_type'])
			{
	
				case 'day':
				
					$data['recurring_interval_type_text'] = $this->lang->line('every') . ' ' . $data['recurring_interval'] . ' ' . $this->lang->line('day_s');
					
				break;
				
				case 'week':
				
					$data['recurring_interval_type_text'] = $this->lang->line('every') . ' ' . $data['recurring_interval'] . ' ' . $this->lang->line('week_s');
					
				break;
				
				case 'month':
				
					$data['recurring_interval_type_text'] = $this->lang->line('every') . ' ' . $data['recurring_interval'] . ' ' . $this->lang->line('month_s');
					
				break;
				
				case 'year':
				
					$data['recurring_interval_type_text'] = $this->lang->line('every') . ' ' . $data['recurring_interval'] . ' ' . $this->lang->line('year_s');
					
				break;
			}
			
			$data['show_trial'] = 0;
			
			if ($data['enable_product_trial'] == 1)
			{
				$data['show_trial'] = 1;
				$data['product_trial_price_text'] = $data['product_trial_price'] > 0 ? format_amounts($data['product_trial_price'], $this->num_options) : $this->lang->line('free');
				
				switch ($data['product_trial_interval_type'])
				{				
					case 'day':
					
						$data['product_trial_interval_type_text'] = $this->lang->line('for') . ' ' . $data['product_trial_interval'] . ' ' . $this->lang->line('day_s');
						
					break;
					
					case 'week':
					
						$data['product_trial_interval_type_text'] = $this->lang->line('for') . ' ' . $data['product_trial_interval'] . ' ' . $this->lang->line('week_s');
						
					break;
					
					case 'month':
					
						$data['product_trial_interval_type_text'] = $this->lang->line('for') . ' ' . $data['product_trial_interval'] . ' ' . $this->lang->line('month_s');
						
					break;
					
					case 'year':
					
						$data['product_trial_interval_type_text'] = $this->lang->line('for') . ' ' . $data['product_trial_interval'] . ' ' . $this->lang->line('year_s');
						
					break;
				}
			}
			
			//load the checkout template
			$this->parser->_JROX_load_view('tpl_members_membership_invoice', 'members', $data);
		}
		else
		{
			$data['checkout_items'] = array();
			
			if (!empty($mdata['prod']))
			{
				//format the cart items			
				foreach($mdata['prod'] as $row)
				{
					$row['s_product_name'] = $row['product_name'];
					$row['subtotal_price'] = $row['product_price'];
					$row['attribute_list'] = nl2br($row['product_notes']);
					
					array_push($data['checkout_items'], $row);
				}	
			}
			
			//load the checkout template
			$this->parser->_JROX_load_view('tpl_members_product_invoice', 'members', $data);
		
		}
	
		
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		//show invoices made by the user
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		if ($this->session->flashdata('show_message')) 
		{
			$data['show_message'] = $this->session->flashdata('show_message');
		}
		else
		{
			$data['show_message'] = '';
		}
		
		$text_array = array('invoices', 'unpaid_invoices', 'paid_invoices',  'no_invoices_found', 'invoice_id', 'order_status', 
							'invoice_total', 'amount_paid', 'actions', 'view_unpaid_invoices', 'view_paid_invoices',
							'date', 'due_date', 'pay', 'print', 'view', 'paid', 'email');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('invoices');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		if ($this->uri->segment(4) == 'unpaid')
		{
			$data['lang_invoices'] = $this->lang->line('unpaid_invoices');
		}
		elseif ($this->uri->segment(4) == 'paid')
		{
			$data['lang_invoices'] = $this->lang->line('paid_invoices');
		}
		
		$data['where_value'] = $this->uri->segment(4, 'all');
		
		$uri = $data['uri'] . '/invoices/view/' . $data['where_value'];

		$data['offset'] = $this->uri->segment(5, '0');
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		
		
		//get currency options
		$num_options = get_default_currency($this->config->item('sts_store_default_currency'));
		
		$sdata = $this->invoices->_get_user_invoices($this->session->userdata('userid'),  MEMBERS_INVOICES_PER_PAGE, $data['offset'], $data['sort_column'], $data['sort_order'], $num_options, $data['where_value']);

		$data['show_invoices'] = 0;
		
		if (!empty($sdata['invoices']))
		{
			$data['show_invoices'] = 1;
			$data['invoices'] = $sdata['invoices'];
		}

		$pagination = $this->db_validation_model->_set_pagination($uri, 'invoices', MEMBERS_INVOICES_PER_PAGE, 5, $data['sort_order'], $data['sort_column'],  $sdata['total_rows'], '', '', 'public');
		
		$data['pagination_rows'] = $pagination['rows'];
			
		$data['num_pages'] = $pagination['num_pages'];
			
		$data['no_pages'] = $data['num_pages'] > 1 ? 1 : 0;

		//load the template
		$this->parser->_JROX_load_view('tpl_members_invoices', 'members', $data);
	}
}
?>