<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - support.php
| -------------------------------------------------------------------------     
| 
| This controller file manages the helpdesk tickets for the user
|
*/

class Support extends Member_Controller {
	
	function __construct()
	{
		parent::Member_Controller();	
		
		$this->config->set_item('css_body', 'jroxMembersSupport');
		
		//create pagination links		
		$this->config->set_item('uri', $this->config->slash_item('base_folder_path') . $this->config->slash_item('site_index_page') . $this->uri->segment(1));
		$this->config->set_item('uri_string', str_replace('/', ':', trim_slashes($this->uri->uri_string())));
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		redirect(MEMBERS_ROUTE . '/support/view');
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		if ($this->session->flashdata('show_message')) 
		{
			$data['show_message'] = $this->session->flashdata('show_message');
		}
		else
		{
			$data['show_message'] = '';
		}
		
		$text_array = array('support', 'support_tickets', 'no_tickets_found', 'date', 'subject', 'priority', 'ticket_id', 'actions',
							'view_open_tickets', 'view_closed_tickets', 'view', 'add_new_ticket');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('support_tickets');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		if ($this->uri->segment(4) == 'open')
		{
			$data['lang_support_tickets'] = $this->lang->line('open_tickets');
		}
		elseif ($this->uri->segment(4) == 'closed')
		{
			$data['lang_support_tickets'] = $this->lang->line('closed_tickets');
		}
		
		$data['where_value'] = $this->uri->segment(4, 'all');
		
		$uri = $data['uri'] . '/support/view/' . $data['where_value'];

		$data['offset'] = $this->uri->segment(5, '0');
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		
		$sdata = $this->support->_get_user_tickets($this->session->userdata('userid'),  MEMBERS_SUPPORT_PER_PAGE, $data['offset'], $data['sort_column'], $data['sort_order'], $data['where_value']);

		$data['show_support'] = 0;
		
		if (!empty($sdata['tickets']))
		{
			$data['show_support'] = 1;
			$data['tickets'] = $sdata['tickets'];
		}

		$pagination = $this->db_validation_model->_set_pagination($uri, 'support_tickets', MEMBERS_SUPPORT_PER_PAGE, 5, $data['sort_order'], $data['sort_column'],  $sdata['total_rows'], '', '', 'public');
		
		$data['pagination_rows'] = $pagination['rows'];
			
		$data['num_pages'] = $pagination['num_pages'];
			
		$data['no_pages'] = $data['num_pages'] > 1 ? 1 : 0;

		//load the template
		$this->parser->_JROX_load_view('tpl_members_support', 'members', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function add()
	{
		//add a new support ticket
		
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		if ($this->session->flashdata('show_message')) 
		{
			$data['show_message'] = $this->session->flashdata('show_message');
		}
		else
		{
			$data['show_message'] = '';
		}
		
		$text_array = array('support', 'support_tickets', 'no_tickets_found', 'date', 'subject', 'priority',
							'view', 'add_new_ticket', 'category', 'attach_file');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('add_new_ticket');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		$data['submit_url'] = $data['members_url'] . '/support/add';
		$data['lang_add_response'] = $this->lang->line('add_support_ticket');
		if ($this->_check_ticket() == false)
		{
			$data['ticket_subject'] = $this->validation->ticket_subject;
			$data['ticket_body'] = $this->validation->ticket_body;
			$data['category_id'] = $this->validation->category_id;
			$data['ticket_priority'] = $this->validation->ticket_priority;
			
			if (!empty($_POST['jroxSubmitPForm']))
			{
				$data['show_message'] = '<div class="errorMessage" id="error-messages">' . $this->validation->error_string . '</div>';
			}
			
			//check for file uploading option
			
			$data['show_upload'] = '';
			$data['s_ticket_status'] = '0';
			$data['close_ticket'] = '';
			
			if ($this->config->item('sts_support_enable_file_uploads') == 1)
			{
				$data['show_upload'] = '<input type="file" name="userfile" size="40" class="jroxMembersSupportFileUpload"/>';
			}
			
			$support_categories = $this->support->_get_support_categories(true, 'select_category');
			
			$data['support_categories'] = form_dropdown('support_category_id', $support_categories, $data['category_id'], 'class="jroxMembersSupportCategories"');
			$array = array('0' => $this->lang->line('low'),
							'1' => $this->lang->line('normal'),
							'2' => $this->lang->line('high')
							);
							
			$data['support_priority'] = form_dropdown('ticket_priority', $array, $data['ticket_priority'], 'class="jroxMembersSupportPriority"');
			
			$data['show_response'] = 0;
			
			$fdata = array(
						  'name'        => 'ticket_body',
						  'id'          => 'jroxMembersSupportResponse',
						  'value'       => $this->validation->ticket_body,
						  'rows'   		=> '20',
						  'cols'        => '100',
						  'class'       => 'jroxMembersSupportResponse required',
						);

			$data['editor'] = form_textarea($fdata);
		
			//load the template
			$this->parser->_JROX_load_view('tpl_members_manage_ticket', 'members', $data);
		}
		else
		{
			//add ticket in db				
			$newdata = $this->support->_add_ticket($this->session->userdata('userid'));	
			
			
			if ($this->config->item('sts_support_enable_file_uploads') == 1)
			{
				//check if a file has been uploaded
				if (!empty($_FILES) && $_FILES['userfile']['error'] != 4)
				{
					$image_data = $this->_upload_support_file($newdata['id']);
					
					if (empty($image_data['success']))
					{
						$this->session->set_flashdata('show_message', $image_data['msg']);
					}
				}
			}
			
			$this->session->set_flashdata('show_message', '<div class="successMessage" id="successMessage">' . $this->lang->line('support_ticket_added_successfully') . '</div>');
			
			//now email it
			//send notification email
			$this->load->model('emailing_model');
			
			//get all admins for sending out admin alerts
			$this->load->model('admins_model');
			$admin_users = $this->admins_model->_get_all_admins();
			
			//send out new order alerts to admins
			foreach ($admin_users as $admin_user)
			{
				if ($admin_user['alert_ticket_response'] == 1) //send out the admin alert
				{
					$admin_user['ticket_subject'] = $newdata['ticket_data']['ticket_subject'];
					$admin_user['ticket_message'] = $newdata['ticket_data']['ticket_body'];
					$admin_user['ticket_message_html'] = nl2br($newdata['ticket_data']['ticket_body']);
					$admin_user['member_name'] = $newdata['member_data']['fname']. ' ' . $newdata['member_data']['lname'];
					$admin_user['member_username'] = $newdata['member_data']['username'];
					$admin_user['member_email'] = $newdata['member_data']['primary_email'];
					$admin_user['ticket_id'] = $newdata['id'];
					
					//set the ticket priority
					switch ($newdata['ticket_data']['ticket_priority'])
					{
						case '0';
							$admin_user['ticket_priority'] = $this->lang->line('low');
						break;
						
						case '1';
							$admin_user['ticket_priority'] = $this->lang->line('normal');
						break;
						
						case '2';
							$admin_user['ticket_priority'] = $this->lang->line('high');
						break;
					}
										
					$this->emailing_model->_send_template_email('admin', $admin_user, 'admin_alert_support_ticket_response');
				}
			}  	
			
			
			//load add support page
			redirect(MEMBERS_ROUTE . '/support/view/');
		}
	}
	
	// ------------------------------------------------------------------------
	
	function update_status()
	{
		/*
		| -----------------------------------------
		| change the status
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
	
		//get shipping config
		$this->db_validation_model->_change_status_field('support_tickets', 'ticket_id', (int)$this->uri->segment(4), 'ticket_status');
		
		$this->session->set_flashdata('show_message', '<div class="successMessage" id="successMessage">' . $this->lang->line('support ticket closed successfully') . '</div>');
		
		redirect(MEMBERS_ROUTE . '/support/view/');
	}
	
	// ------------------------------------------------------------------------
	
	function update()
	{
		//add a new support ticket
		
		//set data array
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		if ($this->session->flashdata('show_message')) 
		{
			$data['show_message'] = $this->session->flashdata('show_message');
		}
		else
		{
			$data['show_message'] = '';
		}
		
		$text_array = array('support', 'support_tickets', 'no_tickets_found', 'date', 'subject', 'priority',
							'view', 'category', 'attach_file');
		
		foreach ($text_array as $txt)
		{
			$data['lang_' . $txt] = $this->lang->line($txt);
		}
		
		$data['page_title'] = $this->lang->line('update_ticket');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		$data['submit_url'] = $data['members_url'] . '/support/update/' . (int)$this->uri->segment(4) . '#msg';
		$data['lang_add_response'] = $this->lang->line('update_ticket');
		$data['lang_please_open_new_ticket'] = $this->lang->line('please_open_new_ticket');
		$data['lang_ticket_has_been_closed'] = $this->lang->line('ticket_has_been_closed');
		$data['lang_add_new_ticket'] = $this->lang->line('update_ticket_id') . ' ' . (int)$this->uri->segment(4);
		
		if ($this->_check_ticket() == false)
		{
			$tickets = $this->support->_get_support_ticket_details((int)$this->uri->segment(4));
			
			$data['support_category_id'] = form_hidden('support_category_id', $tickets[0]['support_category_id']);
			
			$data['tickets'] = array();
			
			if (!empty($tickets))
			{	
				$data['show_response'] = 1;
				$data['s_ticket_status'] = $tickets[0]['ticket_status'];
				$data['close_ticket'] = '<button id="jroxMembersSupportAddTicketButton" class="jroxButton jroxFloatRight" type="button" onclick="window.location=\'' . $this->config->item('members_url') . '/support/update_status/' . (int)$this->uri->segment(4) . '\'" style="margin-right: 1em"><span>' . $this->lang->line('close_ticket') . '</span></button> ';
				
				foreach ($tickets as $v)
				{
					
					if ($v['admin_response'] == 1)
					{
						$v['response_data'] = '<div class="jroxMembersSupportAdminBox">';
						$v['response_data'] .= '<div class="jroxMembersSupportUserResponse">' . $this->lang->line('admin_response_by') . ' ' . $v['admin_user'];  
					
					}
					else
					{
						$v['response_data'] = '<div class="jroxMembersSupportUserBox">';
						$v['response_data'] .= '<div class="jroxMembersSupportUserResponse">' . $this->lang->line('member_response_by') . ' ' . $v['member']; 
					}
					
					$v['response_data'] .=  $this->lang->line('on') . ' ' . _show_timestamp($v['date_added'], false) . '</div>';
					
					 
					if ($v['admin_response'] == 1)
					{
						$v['response_data'] .= '<div class="jroxMembersSupportTicketBody"><span class="jroxBold">' . $v['ticket_subject'] . '</span><br />' .$v['ticket_body'] . '</div>';
					}
					else
					{
						$v['response_data'] .= '<div class="jroxMembersSupportTicketBody"><span class="jroxBold">' . $v['ticket_subject'] . '</span><br />' . nl2br($v['ticket_body']) . '</div>';
					}

					if ($v['uploaded_file'])
					{
						$v['response_data'] .= '<div class="jroxMembersSupportFileAttachments">' . $this->lang->line('file_attachments') . ': <a href="' . $data['members_url'] . '/support/file_download/' . $v['ticket_id'] . '">' . $v['uploaded_file'] . '</a></div>';
					}
					
					$v['response_data'] .= '<div class="clear"></div></div>';
					
					array_push($data['tickets'], $v);
				}
			}
			else
			{
				show_error($this->lang->line('invalid_data'));
			}
			
			$this->security_model->_check_data_ownership($tickets[0]['member_id']);	
			
			if (!empty($_POST['jroxSubmitPForm']))
			{
				$data['show_message'] = '<div class="errorMessage" id="error-messages">' . $this->validation->error_string . '</div>';
				$data['ticket_subject'] = $this->validation->ticket_subject;
				$data['ticket_body'] = $this->validation->ticket_body;
				$data['category_id'] = $this->validation->category_id;
				$data['ticket_priority'] = form_hidden('ticket_priority', $data['tickets'][0]['ticket_priority']);
			}
			else
			{
				$data['ticket_subject'] = '';
				$data['ticket_status'] = '';
				$data['category_id'] = $tickets[0]['support_category_id'];
				$data['ticket_priority'] = form_hidden('ticket_priority', $data['tickets'][0]['ticket_priority']);
			}
			
			//check for file uploading option
			
			$data['show_upload'] = '';
			
			if ($this->config->item('sts_support_enable_file_uploads') == 1)
			{
				$data['show_upload'] = '<label>' . $this->lang->line('attach_file') . ': </label><input type="file" name="userfile" size="40" class="jroxMembersSupportFileUpload"/>';
			}
			
			$category = $this->db_validation_model->_get_details('support_categories', '*', 'support_category_id', $data['category_id']);
			$data['support_categories'] = $category[0]['category_name'];
			
			if (isset($data['tickets'][0]['ticket_priority']))
			{
				$ticket_priority = $data['tickets'][0]['ticket_priority'];
			}
			else
			{
				$ticket_priority = $this->validation->ticket_priority;
			}
				switch ($ticket_priority)
				{
					case '0':
						$data['support_priority'] = $this->lang->line('low');
					break;
					
					case '1':
						$data['support_priority'] = $this->lang->line('normal');
					break;
					
					case '2':
						$data['support_priority'] = $this->lang->line('high');
					break;
				}
			
			
			$fdata = array(
						  'name'        => 'ticket_body',
						  'id'          => 'jroxMembersSupportResponse',
						  'value'       => $this->validation->ticket_body,
						  'rows'   		=> '20',
						  'cols'        => '100',
						  'class'       => 'jroxMembersSupportResponse required',
						);

			$data['editor'] = form_textarea($fdata);
		
			//load the template
			$this->parser->_JROX_load_view('tpl_members_manage_ticket', 'members', $data);
		}
		else
		{
			//add ticket in db				
			$newdata = $this->support->_update_support_ticket('member', (int)$this->uri->segment(4));	
			
			
			if ($this->config->item('sts_support_enable_file_uploads') == 1)
			{
				//check if a file has been uploaded
				if (!empty($_FILES) && $_FILES['userfile']['error'] != 4)
				{
					$image_data = $this->_upload_support_file($newdata['id']);
					
					if (empty($image_data['success']))
					{
						$this->session->set_flashdata('show_message', $image_data['msg']);
					}
				}
			}
			
			$this->session->set_flashdata('show_message', '<div class="successMessage" id="successMessage">' . $this->lang->line('support_ticket_updated_successfully') . '</div>');
			
			//now email it
			//send notification email
			$this->load->model('emailing_model');
			
			//get all admins for sending out admin alerts
			$this->load->model('admins_model');
			$admin_users = $this->admins_model->_get_all_admins();
			
			//send out new order alerts to admins
			foreach ($admin_users as $admin_user)
			{
				if ($admin_user['alert_ticket_response'] == 1) //send out the admin alert
				{
					$admin_user['ticket_subject'] = $newdata['ticket_data']['ticket_subject'];
					$admin_user['ticket_message'] = $newdata['ticket_data']['ticket_body'];
					$admin_user['ticket_message_html'] = nl2br($newdata['ticket_data']['ticket_body']);
					$admin_user['member_name'] = $newdata['member_data']['fname']. ' ' . $newdata['member_data']['lname'];
					$admin_user['member_username'] = $newdata['member_data']['username'];
					$admin_user['member_email'] = $newdata['member_data']['primary_email'];
					$admin_user['ticket_id'] = (int)$this->uri->segment(4);
					
					//set the ticket priority
					switch ($newdata['ticket_data']['ticket_priority'])
					{
						case '0';
							$admin_user['ticket_priority'] = $this->lang->line('low');
						break;
						
						case '1';
							$admin_user['ticket_priority'] = $this->lang->line('normal');
						break;
						
						case '2';
							$admin_user['ticket_priority'] = $this->lang->line('high');
						break;
					}
										
					$this->emailing_model->_send_template_email('admin', $admin_user, 'admin_alert_support_ticket_response');
				}
			}  	
			
			
			//load add support page
			redirect(MEMBERS_ROUTE . '/support/update/' . (int)$this->uri->segment(4));
		}
	}
	
	// ------------------------------------------------------------------------
	
	function file_download()
	{
		if ($this->uri->segment(4) != false)
		{
			$id = (int)$this->uri->segment(4);
			
			//set data array
			$data = $this->security_model->_load_config('members');
			 
			//get file name
			$details = $this->support->_get_response_details($id);
			
			if (!empty($details['uploaded_file']))
			{ 
			 
				$this->load->helper('download');
				$this->load->helper('file');
		
				$path = $data['sts_support_upload_folder_path'] . $details['uploaded_file'];
				
				$data = read_file($path); // Read the file's contents
				
				force_download($details['uploaded_file'], $data); 
			}
			else
			{
				show_error($this->lang->line('no_uploaded_file_found'));
			}
		}
	}
	
	// ------------------------------------------------------------------------
	
	function close()
	{
		//close the ticket
	}
	
		// ------------------------------------------------------------------------	
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
	
	function _check_ticket()
	{
		if ($this->uri->segment(3) == 'add')
		{
			$rules['ticket_subject'] = 'trim|required|max_length[255]';
			$rules['ticket_priority'] = 'trim|required';
			$rules['support_category_id'] = 'trim|required|callback__check_category';
		}
		else
		{
			$rules['ticket_subject'] = 'trim|max_length[255]';
		}
		
		$rules['ticket_body'] = 'trim|required';
		$rules['category_id'] = 'trim';
		
		
		$fields['ticket_subject'] = $this->lang->line('ticket_subject');
		$fields['ticket_body'] = $this->lang->line('ticket_body');
		$fields['category_id'] = $this->lang->line('category_id');
		$fields['ticket_priority'] = $this->lang->line('ticket_priority');
		
		$this->validation->set_rules($rules);
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_category()
	{
		if ($this->validation->support_category_id == '0')
		{
			$this->validation->set_message('_check_category', $this->lang->line('select_category'));
			return false;
		}
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _upload_support_file($id)
	{		
		$this->load->model('uploads_model');
		
		//upload the photo
		$data = $this->uploads_model->_upload_file();
		
		//add photo to db
		if (!empty($data['success']))
		{
			//now update the ticket with the file name					
			//format the array
			$sdata = array('uploaded_file' => $data['info']['file_name']);
			
			$this->db->where('ticket_id', $id);
			$this->db->update('support_tickets', $sdata);
			
		}
		
		return $data;
		
	}
}
?>