<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_affiliate_marketing_banners.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage banner options
|
*/

class Module_Affiliate_Marketing_Banners extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load banners model
		$this->load->model('affiliate_marketing_model', 'aff');
		
		//load required model
		$this->load->model('modules/module_affiliate_marketing_banners_model', 'banners_model');
		
		//load uploads model
		$this->load->model('uploads_model');
		
		//load css body style
		$this->config->set_item('css_body', 'GJ');
		
		//create pagination links		
		$this->config->set_item('uri', 'modules/' . $this->uri->segment(2) . '/table');
		
		$this->config->set_item('module_name', 'module_affiliate_marketing_banners');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/affiliate_marketing/view_affiliate_tools');
	}
	
	
	// ------------------------------------------------------------------------
	
	function add()
	{
		/*
		| -----------------------------------------
		| add a new banner
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_banner');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_banners/add';
		$data['update_link'] = 'banners';
		$data['add_link'] = 'add';
		$data['error_string'] = '';
		
		
		//run admin validation check
		if ($this->_check_banner() == false)
		{		
			//reload add banner form
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}	
		}
		else
		{	
			
			if ($this->input->post('use_external_image') == 0)
			{
				//check if a photo has been uploaded
				if (!empty($_FILES) && $_FILES['userfile']['error'] != 4)
				{
					$image_data = $this->_upload_image($data);
					
					if (empty($image_data['success']))
					{
						$data['error_string'] =  $image_data['msg'];
					}
				}
				else
				{
					$data['error_string'] = $this->lang->line('banner_file_required');
				}
			}
			
			
			//if there is no error add it to the db
			if (empty($data['error_string']))
			{
				//add the banner into db
				$id = $this->banners_model->_add_banner();		
				
				if ($this->input->post('use_external_image') == 0)
				{
					//update the file name
					$this->_update_banner_image('add', $id, $image_data['info']['file_name']);
				}
				
				$this->session->set_flashdata('success', $this->lang->line('add_banner_success'));
					
				redirect('modules/module_affiliate_marketing_banners/edit/' . $id);
			}
		}		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_banner', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function delete()
	{
		/*
		| --------------------------------------------
		| delete the banner from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->banners_model->_delete_banner((int)($this->uri->segment(4))))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect('/modules/module_affiliate_marketing_banners/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE);
		}
	}
	
	// ------------------------------------------------------------------------
	
	function edit()
	{
		/*
		| -----------------------------------------
		| update a new banner
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_banner');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_banners/edit/' . (int)$this->uri->segment(4);
		$data['update_link'] = 'banners';
		
		$data['add_link'] = 'edit';
		$data['error_string'] = '';
		
		
		//run admin validation check
		if ($this->_check_banner() == false)
		{		
			//reload add banner form
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}	
			else
			{
				$mdata = $this->banners_model->_get_banner_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['banner'] = $mdata[0];
				}
				else
				{
					redirect(ADMIN_ROUTE);
				}
				
			}
		}
		else
		{	
			//first check if there is an uploaded banner file and ovewrite
			
			if (!empty($_FILES) && $_FILES['userfile']['error'] != 4)
			{
				$image_data = $this->_upload_image($data);
				
				if (empty($image_data['success']))
				{
					$data['error_string'] =  $image_data['msg'];
				}
			}
			else
			{
				//check if file is being replaced
				
				if ($this->input->post('use_external_image') == 0 && !$this->input->post('banner_file_name'))
				{
					$data['error_string'] = $this->lang->line('banner_file_required');	
				}
			}
			
			//if there is no error update it in the db
			if (empty($data['error_string']))
			{
				//add the banner into db
				$id = $this->banners_model->_edit_banner((int)$this->uri->segment(4));		
				
				if (!empty($image_data))
				{
					//update the file name
					$this->_update_banner_image('update', $id, $image_data['info']['file_name']);
				}
				
				if ($this->input->post('use_external_image') == 1)
				{
					$this->_update_banner_image('update', $id, $this->input->post('banner_file_name'));
				}
				
				$this->session->set_flashdata('success', $this->lang->line('update_banner_success'));
					
				redirect('/modules/module_affiliate_marketing_banners/edit/' . $id);
			}
		}		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_banner', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function update()
	{
		/*
		| -----------------------------------------
		| add a new banner
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('banner_options');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_banners/update';
		$data['add_link'] = 'update_banner';
		$data['update_link'] = 'banners';
		
		//run admin validation check
		if ($this->_check_banner_options() == false)
		{		
			//reload add banner form
			if (empty($_POST))
			{
				$mdata = $this->aff->_get_affiliate_marketing_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['sts_config'] = array();
					
					foreach ($mdata[0]['sts_config'] as  $v)
					{
						$this->validation->$v['settings_key'] = $v['settings_value'];
		
						array_push($data['sts_config'], $v);
					
					}
					
					//load template
					load_form('modules', 'tpl_adm_manage_affiliate_marketing_options', $data, false, false);
				}
				else
				{
					//load add banner page
					redirect();
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the banner into db
			$data = $this->aff->_update_options((int)$this->uri->segment(4));	

			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_options_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		/*
		| -----------------------------------------
		| view banners modules
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_banners');
		$data['sub_title'] = $this->lang->line('manage_banners');
		
		$data['add_link'] = 'add_banner';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_tools', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{
		/*
		| ------------------------------
		| get banners modules via ajax
		| ------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		$data['add_link'] = 'add_banner';
		$data['table_name'] = 'affiliate_banners';
		$data['no_tools_found'] = 'no_banners_found';
		$data['header_name'] = 'banner_name';
		$data['height'] = '500';
		$data['width'] = '400';
		
		//get sql wheres
		$data['where_column'] = $this->uri->segment(8,0);
		$data['where_value'] =  $this->uri->segment(9,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//get groups
		$row = $this->banners_model->_get_banners($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		//add the data to the array
		$data['tools'] = $row;
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'affiliate_banners', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_affiliate_marketing_banners_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function sort_order()
	{
		/*
		| ---------------------------
		| mass update group tiers
		| ---------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
	
		if ($this->_check_sort_order() == true)
		{	
			$this->aff->_change_sort_order('affiliate_banners');
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('banner_updated_successfully'));
			
			echo '<script>self.parent.location.reload(true);</script>';	
		}
		else
		{
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}
	}
	
	// ------------------------------------------------------------------------
	
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the module
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->db_validation_model->_change_status_field('affiliate_banners', 'id', (int)$this->uri->segment(4), 'status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect('/modules/module_affiliate_marketing_banners/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				//$this->session->set_flashdata('success', $this->lang->line('update_modules_success'));
				
				redirect(ADMIN_ROUTE . '/modules/view_modules');
			}
		}
	}
	

	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_banner_options()
	{
		$rules['module_affiliate_marketing_banners_file_types'] = 'trim|required';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['module_affiliate_marketing_banners_file_types'] = $this->lang->line('module_affiliate_marketing_banners_file_types');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_banner_height()
	{
		if ($this->validation->banner_height < 1)
		{
			$this->validation->set_message('_check_banner_height', $this->lang->line('invalid_banner_height'));
			return false;
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_banner_width()
	{
		if ($this->validation->banner_width < 1)
		{
			$this->validation->set_message('_check_banner_width', $this->lang->line('invalid_banner_width'));
			return false;
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_banner()
	{
		$rules['status'] = 'trim|required|integer';
		$rules['name'] = 'trim|required|min_length[5]|max_length[50]';
		$rules['rotator_group'] = 'trim|integer';
		$rules['enable_redirect'] = 'trim|integer';
		
		if ($this->input->post('enable_redirect') == 1)
		{
			$rules['redirect_custom_url'] = 'trim|required|prep_url';
		}
		
		$rules['banner_height'] = 'trim|required|numeric|callback__check_banner_height';
		$rules['banner_width'] = 'trim|required|numeric|callback__check_banner_width';
		$rules['use_external_image'] = 'trim|integer';
		
		if ($this->input->post('use_external_image') == 1)
		{
			$rules['banner_file_name'] = 'trim|required|prep_url';
		}
		
		$rules['notes'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['status'] = $this->lang->line('status');
		$fields['name'] = $this->lang->line('banner_name');
		$fields['rotator_group'] = $this->lang->line('rotator_group');
		$fields['enable_redirect'] = $this->lang->line('enable_redirect');
		$fields['redirect_custom_url'] = $this->lang->line('redirect_custom_url');
		$fields['banner_height'] = $this->lang->line('banner_height');
		$fields['banner_width'] = $this->lang->line('banner_width');
		$fields['use_external_image'] = $this->lang->line('use_external_image');
		$fields['banner_file_name'] = $this->lang->line('banner_file_name');
		$fields['notes'] = $this->lang->line('notes');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _update_banner_image($type = '', $id = '', $file_name = '')
	{
		
		if ($type == 'update')
		{
			//get the data first
			$this->db->where('id', $id);
			$query = $this->db->get('affiliate_banners');
			
			$row = $query->result_array();
			
			if ($row[0]['banner_file_name'] != $file_name)
			{
				//delet the old banner
				
				@unlink('./images/' . $this->config->item('images_banners_dir') . '/' . $row[0]['banner_file_name']);
		
			}	
		}
		
		//add the image to the banner
		$sdata['config'] = array(
							'table'	=>	'affiliate_banners',
							'key'	=>	'id',
							'value' 	=>	$id,
							);
		
		$sdata['fields'] = array (
								'banner_file_name'	=> 	$file_name
								);			
		
		if ($this->uploads_model->_update_image_db($sdata))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _upload_image()
	{		
		
		//upload the photo
		$data = $this->uploads_model->_upload_photo('banners', '0', 'userfile', $this->config->item('module_affiliate_marketing_banners_file_types'));
		
		return $data;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_sort_order()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
	
		foreach ($data as $k => $v)
		{
			if (strstr($k, "tool") == true) 
			{
				$rules[$k] = 'trim|required|numeric';
				
				$opt = explode('-', $k);
				
				$fields[$k] = $this->lang->line('banner_id'). ' ' .end($opt) ;
			}
		}
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
}
?>