<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_affiliate_marketing_text_ads.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage text_ad options
|
*/

class Module_Affiliate_Marketing_Text_Ads extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load text_ads model
		$this->load->model('affiliate_marketing_model', 'aff');
		
		//load required model
		$this->load->model('modules/module_affiliate_marketing_text_ads_model', 'text_ads_model');
		
		//load css body style
		$this->config->set_item('css_body', 'GJ');
		
		//create pagination links		
		$this->config->set_item('uri', 'modules/' . $this->uri->segment(2) . '/table');
		
		//module name
		$this->config->set_item('module_name', 'module_affiliate_marketing_text_ads');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/affiliate_marketing/view_affiliate_tools');
	}
	
	
	// ------------------------------------------------------------------------
	
	function add()
	{
		/*
		| -----------------------------------------
		| add a new text_ad
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_text_ad');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_text_ads/add';
		$data['update_link'] = 'text_ads';
		$data['manage_tool'] = 'manage_text_ad';
		$data['tool_details'] = 'text_ad_details';
		$data['tool_options'] = 'text_ad_options';
		$data['view_link'] = 'view_text_ads';
		$data['view_links'] = 'view_text_ads';
		$data['add_link'] = 'add';
		$data['error_string'] = '';
		
		//run admin validation check
		if ($this->_check_text_ad() == false)
		{		
			//reload add text_ad form
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}	
			else
			{
				//set the default text ad width
				$this->validation->text_ad_width = $data['module_affiliate_marketing_text_ads_default_text_ad_width'];
				$this->validation->border_color = $data['module_affiliate_marketing_text_ads_default_border_color'];
				$this->validation->bg_title_color = $data['module_affiliate_marketing_text_ads_default_bg_title_color'];
				$this->validation->font_title_color = $data['module_affiliate_marketing_text_ads_default_font_title_color'];
				$this->validation->bg_body_color = $data['module_affiliate_marketing_text_ads_default_bg_body_color'];
				$this->validation->font_body_color = $data['module_affiliate_marketing_text_ads_default_font_body_color'];
			}
			//initialize HTML editor
			$options = array(	'instance'	=> 'oEdit1',
								'type' => 'content',
								'content' => html_entity_decode($this->validation->text_ad_body),
								'height'	=> '400',
								'width'	=> '100%',
								'editor_type'	=> 'Basic',
								'textarea'	=>	'text_ad_body',
								'tags'	=> true,
							);
			$check_editor = _initialize_html_editor($options);
		
			$data['editor'] = $check_editor['editor'];
			$data['editor_path'] = $check_editor['editor_path'];
		
		}
		else
		{	
			
			//if there is no error add it to the db
			if (empty($data['error_string']))
			{
				//add the text_ad into db
				$id = $this->text_ads_model->_add_text_ad();		
				
				$this->session->set_flashdata('success', $this->lang->line('add_text_ad_success'));
					
				redirect('modules/module_affiliate_marketing_text_ads/edit/' . $id);
			}
		}		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_text_ad', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function delete()
	{
		/*
		| --------------------------------------------
		| delete the text_ad from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		if ($this->aff->_delete_tool('text_ad', (int)($this->uri->segment(4)), 'affiliate_text_ads'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect('/modules/module_affiliate_marketing_text_ads/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE);
		}
	}
	
	// ------------------------------------------------------------------------
	
	function edit()
	{
		/*
		| -----------------------------------------
		| update a new text_ad
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_text_ad');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_text_ads/edit/' . (int)$this->uri->segment(4);
		$data['update_link'] = 'text_ads';
		$data['manage_tool'] = 'manage_text_ad';
		$data['tool_details'] = 'text_ad_details';
		$data['tool_options'] = 'text_ad_options';
		$data['view_link'] = 'view_text_ad';
		$data['view_links'] = 'view_text_ads';
		$data['add_link'] = 'edit';
		$data['error_string'] = '';
		
		
		//run admin validation check
		if ($this->_check_text_ad() == false)
		{		
			//reload add text_ad form
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}	
			else
			{
				$mdata = $this->text_ads_model->_get_text_ad_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['text_ad'] = $mdata[0];
				}
				else
				{
					redirect(ADMIN_ROUTE);
				}
			}
			
			//initialize HTML editor
			$options = array(	'instance'	=> 'oEdit1',
								'type' => 'content',
								'content' => html_entity_decode($this->validation->text_ad_body),
								'height'	=> '400',
								'width'	=> '100%',
								'editor_type'	=> 'Basic',
								'textarea'	=>	'text_ad_body',
								'tags'	=> true,
							);
			$check_editor = _initialize_html_editor($options);
		
			$data['editor'] = $check_editor['editor'];
			$data['editor_path'] = $check_editor['editor_path'];
		}
		else
		{	
			
			
			//if there is no error update it in the db
			if (empty($data['error_string']))
			{
				//add the text_ad into db
				$id = $this->text_ads_model->_edit_text_ad((int)$this->uri->segment(4));		
				
				$this->session->set_flashdata('success', $this->lang->line('update_text_ad_success'));
					
				redirect('/modules/module_affiliate_marketing_text_ads/edit/' . $id);
			}
		}		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_text_ad', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function update()
	{
		/*
		| -----------------------------------------
		| add a new text_ad
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('text_ad_options');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_text_ads/update';
		$data['add_link'] = 'update_text_ad';
		$data['update_link'] = 'text_ads';
		
		//run admin validation check
		if ($this->_check_text_ad_options() == false)
		{		
			//reload add text_ad form
			if (empty($_POST))
			{
				$mdata = $this->aff->_get_affiliate_marketing_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['sts_config'] = array();
					
					foreach ($mdata[0]['sts_config'] as  $v)
					{
						$this->validation->$v['settings_key'] = $v['settings_value'];
		
						array_push($data['sts_config'], $v);
					
					}
					
					//load template
					load_form('modules', 'tpl_adm_manage_affiliate_marketing_text_ad_options', $data, false, false);
				}
				else
				{
					//load add text_ad page
					redirect();
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the text_ad into db
			$data = $this->aff->_update_options((int)$this->uri->segment(4));	

			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_options_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		/*
		| -----------------------------------------
		| view text_ads modules
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_text_ads');
		$data['sub_title'] = $this->lang->line('manage_text_ads');
		
		$data['add_link'] = 'add_text_ad';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_tools', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{
		/*
		| ------------------------------
		| get text_ads modules via ajax
		| ------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		$data['add_link'] = 'add_text_ad';
		$data['table_name'] = 'affiliate_text_ads';
		$data['no_tools_found'] = 'no_text_ads_found';
		$data['header_name'] = 'text_ad_name';
		$data['height'] = '500';
		$data['width'] = '400';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//get groups
		$row = $this->text_ads_model->_get_text_ads($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		//add the data to the array
		$data['tools'] = $row;
	
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'affiliate_text_ads', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_affiliate_marketing_text_ads_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function sort_order()
	{
		/*
		| ---------------------------
		| mass update group tiers
		| ---------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
	
		if ($this->_check_sort_order() == true)
		{	
			$this->aff->_change_sort_order('affiliate_text_ads');
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('text_ad_updated_successfully'));
			
			echo '<script>self.parent.location.reload(true);</script>';	
		}
		else
		{
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}
	}
	
	// ------------------------------------------------------------------------
	
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the module
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->db_validation_model->_change_status_field('affiliate_text_ads', 'id', (int)$this->uri->segment(4), 'status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect('/modules/module_affiliate_marketing_text_ads/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				//$this->session->set_flashdata('success', $this->lang->line('update_modules_success'));
				
				redirect(ADMIN_ROUTE . '/modules/view_modules');
			}
		}
	}
	

	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_text_ad_options()
	{
		$rules['module_affiliate_marketing_text_ads_default_text_ad_width'] = 'trim|required|numeric';
		$rules['module_affiliate_marketing_text_ads_default_border_color'] = 'trim|required';
		$rules['module_affiliate_marketing_text_ads_default_bg_title_color'] = 'trim|required';
		$rules['module_affiliate_marketing_text_ads_default_font_title_color'] = 'trim|required';
		$rules['module_affiliate_marketing_text_ads_default_bg_body_color'] = 'trim|required';
		$rules['module_affiliate_marketing_text_ads_default_font_body_color'] = 'trim|required';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['module_affiliate_marketing_text_ads_default_text_ad_width'] = $this->lang->line('text_ad_width');
		$fields['module_affiliate_marketing_text_ads_default_border_color'] = $this->lang->line('border_color');
		$fields['module_affiliate_marketing_text_ads_default_bg_title_color'] = $this->lang->line('bg_title_color');
		$fields['module_affiliate_marketing_text_ads_default_font_title_color'] = $this->lang->line('font_title_color');
		$fields['module_affiliate_marketing_text_ads_default_bg_body_color'] = $this->lang->line('bg_body_color');
		$fields['module_affiliate_marketing_text_ads_default_font_body_color'] = $this->lang->line('font_body_color');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_text_ad_height()
	{
		if ($this->validation->text_ad_height < 1)
		{
			$this->validation->set_message('_check_text_ad_height', $this->lang->line('invalid_text_ad_height'));
			return false;
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_text_ad_width()
	{
		if ($this->validation->text_ad_width < 1)
		{
			$this->validation->set_message('_check_text_ad_width', $this->lang->line('invalid_text_ad_width'));
			return false;
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_text_ad()
	{
		$rules['status'] = 'trim|required|integer';
		$rules['name'] = 'trim|required|min_length[5]|max_length[50]';
		$rules['text_ad_title'] = 'trim|required|min_length[5]|max_length[255]';
		$rules['text_ad_body'] = 'trim|required|min_length[20]';
		$rules['enable_redirect'] = 'trim|integer';
		$rules['border_color'] = 'trim';
		$rules['bg_title_color'] = 'trim';
		$rules['font_title_color'] = 'trim';
		$rules['bg_body_color'] = 'trim';
		$rules['font_body_color'] = 'trim';
		$rules['text_ad_width'] = 'trim|required|numeric';
		
		if ($this->input->post('enable_redirect') == 1)
		{
			$rules['redirect_custom_url'] = 'trim|required|prep_url';
		}
		
		$rules['notes'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['status'] = $this->lang->line('status');
		$fields['name'] = $this->lang->line('text_ad_name');
		$fields['text_ad_title'] = $this->lang->line('text_ad_title');
		$fields['text_ad_body'] = $this->lang->line('text_ad_body');
		$fields['enable_redirect'] = $this->lang->line('enable_redirect');
		$fields['redirect_custom_url'] = $this->lang->line('redirect_custom_url');

		$fields['border_color'] = $this->lang->line('border_color');
		$fields['bg_title_color'] = $this->lang->line('bg_title_color');
		$fields['font_title_color'] = $this->lang->line('font_title_color');
		$fields['bg_body_color'] = $this->lang->line('bg_body_color');
		$fields['font_body_color'] = $this->lang->line('font_body_color');
		$fields['text_ad_width'] = $this->lang->line('text_ad_width');
		
		$fields['notes'] = $this->lang->line('notes');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	
	
	// ------------------------------------------------------------------------	
	
	function _check_sort_order()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
	
		foreach ($data as $k => $v)
		{
			if (strstr($k, "tool") == true) 
			{
				$rules[$k] = 'trim|required|numeric';
				
				$opt = explode('-', $k);
				
				$fields[$k] = $this->lang->line('text_ad_id'). ' ' .end($opt) ;
			}
		}
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
}
?>