<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_data_export_members_csv.php
| -------------------------------------------------------------------------     
| 
| This controller file is for exporting members
|
*/


class Module_Data_Export_Members extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load general export model
		$this->load->model('export_model', 'export');
		
		//load export members model
		$this->load->model('modules/module_data_export_members_model', 'data_export');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//module name
		$this->config->set_item('module_name', 'module_data_export_members');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect('modules/module_data_export_members/run_module');
	}
	
	// ------------------------------------------------------------------------
	
	function run_module()
	{
		
		/*
		| -----------------------------------------
		| run module
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$this->load->dbutil();

		$members = $this->data_export->_get_members();
		
		$delimiter = $this->config->item('module_data_export_members_delimiter');
		$newline = "\r\n";
		
		$sdata = $this->dbutil->csv_from_result($members, $delimiter, $newline); 
		
		$this->load->helper('download');
		
		$name = $this->lang->line('filename_export_members').'-'.date('m-d-Y').'.csv';

		force_download($name, $sdata); 
	
	}
	
	// ------------------------------------------------------------------------	
	
	function update()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('export_members');
		
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_data_export_members/update/'.(int)$this->uri->segment(4);
	
		//run check
		
		if ($this->_check_update() == false)
		{		
			
			//reload add group form
			if (empty($_POST))
			{
				$mdata = $this->export->_get_export_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{	
						$this->validation->$key = $value;	
					}
					
					
					$data['sts_config'] = array();
					
					foreach ($mdata[0]['sts_config'] as  $v)
					{
						$this->validation->$v['settings_key'] = $v['settings_value'];
		
						array_push($data['sts_config'], $v);
					
					}
					
					//load template
					load_admin_tpl('modules', 'tpl_adm_manage_data_export_members', $data, false, false);
	
				}
				else
				{
					//load add page
					redirect(ADMIN_ROUTE . '/export/view_export_modules');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update shipping config
			$data = $this->export->_update_export((int)$this->uri->segment(4));	
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_module_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
		}		
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_update()
	{
	
		$rules['module_data_export_members_delimiter'] = 'trim|required';
		$rules['module_data_export_members_total_rows'] = 'trim|integer';
		$rules['module_data_export_members_starting_rows'] = 'trim|integer';
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$fields['module_data_export_members_delimiter'] = $this->lang->line('module_data_export_members_delimiter');
		$fields['module_data_export_members_total_rows'] = $this->lang->line('module_data_export_members_total_rows');
		$fields['module_data_export_members_starting_rows'] = $this->lang->line('module_data_export_members_starting_rows');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}

	
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	
}
?>