<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_data_import_members.php
| -------------------------------------------------------------------------     
| 
| This controller file is for importing members
|
*/


class Module_Data_Import_Members extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load general import model
		$this->load->model('import_model', 'import');
		$this->load->model('uploads_model', 'uploads');
		$this->load->model('members_model', 'members');
		
		//load import payments model
		$this->load->model('modules/module_data_import_members_model', 'data_import');
		
		//load css body style
		$this->config->set_item('css_body', 'MN');
		
		//module name
		$this->config->set_item('module_name', 'module_data_import_members');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect('modules/module_data_import_members/run_module');
	}
	
	// ------------------------------------------------------------------------
	
	function run_module()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('import_members');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_data_import_members/run_module/'.(int)$this->uri->segment(4);	
		$data['show_message'] = '';
		
		if ($this->_check_module() == false)
		{		
			if (!empty($_POST))
			{
				$data['show_message'] = '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}
		}
		else
		{	
			//run import			
			if(!empty($_FILES)) 
			{
				$sdata = $this->data_import->_import_data();	
				
				if ($sdata == 'error')
				{
					$data['show_message'] = '<div class="error" id="error-messages">' . $this->lang->line('csv_txt_file_only') . '</div>';
				}
				else
				{
					$data['show_message'] = '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $sdata['total'] . ' ' . $this->lang->line('rows_imported_successfully') . '. ' . $this->lang->line('click_to_continue') . '</div>';
					
					if (!empty($sdata['not_added']))
					{
						$data['show_message'] = '<div class="error" id="error-messages">' . $this->lang->line('duplicate_emails') . ':<br /> ' .$sdata['not_added'] . '</div>';
					}
				}
			} 
			else 
			{
				$data['show_message'] = '<div class="error" id="error-messages">' . $this->lang->line('csv_txt_file_only') . '</div>';
			}
		}	
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_data_import_members', $data, false, false);	
	}
	
	// ------------------------------------------------------------------------	
	
	function update()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('import_members');
		
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_data_import_members/update/'.(int)$this->uri->segment(4);
	
		//run check
		
		if ($this->_check_update() == false)
		{		
			
			//reload add group form
			if (empty($_POST))
			{
				$mdata = $this->import->_get_import_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{	
						$this->validation->$key = $value;	
					}
					
					
					$data['sts_config'] = array();
					
					foreach ($mdata[0]['sts_config'] as  $v)
					{
						$this->validation->$v['settings_key'] = $v['settings_value'];
		
						array_push($data['sts_config'], $v);
					
					}
					
					//load template
					load_admin_tpl('modules', 'tpl_adm_manage_data_import_settings', $data, false, false);
	
				}
				else
				{
					//load add page
					redirect(ADMIN_ROUTE . '/import/view_import_modules');
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update shipping config
			$data = $this->import->_update_import((int)$this->uri->segment(4));	
			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_module_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
		}		
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_module()
	{
		$rules['enable_file_path'] = 'trim|required';
		
		if ($this->input->post('enable_file_path') == 'yes')
		{
			$rules['file_path'] = 'trim|required|callback__check_file_path';
		}
		else
		{
			$rules['file_path'] = 'trim';
		}
		
		//check for file path
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$fields['file_path'] = $this->lang->line('file_path');
		$fields['enable_file_path'] = $this->lang->line('enable_file_path');

		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}

	
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function isAllowedExtension($fileName) 
	{
		$allowedExtensions = array("txt", "csv");
		
		if (in_array(end(explode(".", $fileName)), $allowedExtensions))
		{
			return true;
		}
		
		return false;
	}


	// ------------------------------------------------------------------------	
	
	function _check_file_path()
	{
		if (!file_exists($this->config->item('base_physical_path') . '/import/members/' . $this->validation->file_path))
		{
			echo $this->config->item('base_physical_path') . '/import/members/' . $this->validation->file_path; exit();
			$this->validation->set_message('_check_file_path', $this->lang->line('invalid_file_path'));
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_update()
	{
	
		$rules['module_data_import_members_delimiter'] = 'trim|required';
		$rules['module_data_import_members_total_rows'] = 'trim|integer';
		$rules['module_data_import_members_starting_rows'] = 'trim|integer';
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$fields['module_data_import_members_delimiter'] = $this->lang->line('module_data_import_members_delimiter');
		$fields['module_data_import_members_total_rows'] = $this->lang->line('module_data_import_members_total_rows');
		$fields['module_data_import_members_starting_rows'] = $this->lang->line('module_data_import_members_starting_rows');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}

	
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	
}
?>