<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - Module_Member_Reporting_Month_Commmission_Stats.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage reports
|
*/

class Module_Member_Reporting_Month_Commission_Stats extends Member_Controller {
	
	function __construct()
	{
		parent::Member_Controller();	
		
		//load modules model
		$this->load->model('modules/module_member_reporting_month_commission_stats_model', 'modules');
		
		$this->load->model('reports_model', 'reports');
		
		//load css body style
		$this->config->set_item('css_body', 'jroxMembersReports');
		
		$this->load->helper('inflector');
		
		//set random graph colors
		$colors = array(	'#003366',
            				'#0066CC',
							'#FF3300'
            			);
		
		$this->config->set_item('random_bg_color', random_element($colors));		
		
		//module name
		$this->config->set_item('module_name', 'module_member_reporting_month_commission_stats');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(MEMBERS_ROUTE . 'reports/view');
	}
	
	// ------------------------------------------------------------------------
	
	function generate()
	{
		
		/*
		| -----------------------------------------
		| generate report
		| -----------------------------------------
		*/

		//set data array
		$this->config->set_item('num_options', get_default_currency($this->config->item('sts_store_default_currency')));
		$data = $this->security_model->_load_config('members');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
				
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		$data['page_title'] = $this->lang->line('monthly_commission_stats_by_day');
		$data['report_title'] = $this->lang->line('monthly_commission_stats_by_day');
		$data['meta_keywords'] = $data['sts_store_default_keywords'];
		$data['meta_description'] = $data['sts_store_description'];
		
		$data['row_name'] = $this->lang->line('day_of_month');
		$data['row_amount'] = $this->lang->line('amount');
		
		//reset total amount
		$data['total_amount'] = '0';
		
		//check for current month and date
		$m = $this->uri->segment('4');
		$y = $this->uri->segment('5');
		
		$data['cmonth'] = !(empty($m)) ? $m : date("m");
		$data['cyear'] = !(empty($y)) ? $y : date("Y");
		
		//setup dropdown for selecting months
		$data['select_months'] = _generate_month_dropdown($data['cmonth'] . '/' . $data['cyear'], 'jroxSortDropdown' , 'document.location=\'' . $data['members_url'] . '/' . $data['module_name'] . '/report/' . '\' + this.value');
	
		//generate the data
		
		include_once ($data['base_physical_path'] . '/themes/main/' . $data['layout_design_site_theme'] . '/theme_info.php');
		
		$stats = $this->modules->_generate_report($this->session->userdata('userid'), $data['cmonth'], $data['cyear']);
		
		if (!empty($stats))
		{
			$srow = $stats[0];
			
			$data['stats'] = array();
			$data['total_amount'] = 0;
			//setup the data for flash
			foreach ($srow as $k => $v)
			{	
				if ($k == 'id') continue;
				
				$arr['date'] = $k;
				$arr['amount'] = $v;
				$arr['s_amount'] = format_amounts($v, $data['num_options']);
				$arr['s_date'] = humanize($k) . ' ' . $data['cyear'];
				
				$arr['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				
				 
				array_push($data['stats'], $arr);
				
				$data['total_amount'] += $v;	
			}
			
			$data['total_amount'] = format_amounts($data['total_amount'], $data['num_options']);
			
			$data['show_stats'] = 1;		
			
			$data['graph_data'] = $this->reports->_generate_flash_data($srow, false, JROX_CHARTS_BG_COLOR, JROX_CHARTS_GRID_COLOR);
			
			$data['show_graph'] = _generate_report_graph($data['graph_data']);
		}
		else
		{
			$data['show_stats'] = 0;		
			$data['show_graph'] = '';
			$data['lang_no_data_found'] = $this->lang->line('no_data_found');
		}
		
		$data['lang_totals'] = $this->lang->line('totals');
		$data['lang_reports_and_stats'] = $this->lang->line('reports_and_stats');
		
		//load the template
		$this->parser->_JROX_load_view('tpl_members_bar_graph_report', 'members', $data);
						
	}
	
	// ------------------------------------------------------------------------
	
}
?>