<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - Module_Stats_Reporting_Year_sales_Stats.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage reports
|
*/

class Module_Stats_Reporting_Year_Commissions_Stats extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load modules model
		$this->load->model('modules/module_stats_reporting_year_commissions_stats_model', 'modules');
		
		$this->load->model('reports_model', 'reports');
		
		//load css body style
		$this->config->set_item('css_body', 'KR');
		
		$this->load->helper('inflector');
		
		//set random graph colors
		$colors = array(	'#003366',
            				'#0066CC',
							'#FF3300'
            			);
		
		$this->config->set_item('random_bg_color', random_element($colors));		
		
		//module name
		$this->config->set_item('module_name', 'module_stats_reporting_year_commissions_stats');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect('reports/view_reports');
	}
	
	// ------------------------------------------------------------------------
	
	function generate()
	{
		
		/*
		| -----------------------------------------
		| generate report
		| -----------------------------------------
		*/

		//set data array
		$this->config->set_item('num_options', get_default_currency($this->config->item('sts_store_default_currency')));
		$data = $this->security_model->_load_config('admin');
		
		$data['page_title'] = $this->lang->line('yearly_commissions_stats_by_month');
		$data['row_name'] = 'day_of_month';
		$data['row_amount'] = 'amount';
		
		//reset total amount
		$data['total_amount'] = '0';
		
		//check for current month and date
		$m = $this->uri->segment('4');
		$y = $this->uri->segment('5');
		
		$data['cmonth'] = '1';
		$data['cyear'] = !(empty($y)) ? $y : date("Y");
		
		//setup dropdown for selecting months
		$data['select_months'] = _generate_year_dropdown($data['cmonth'] . '/' . $data['cyear']);
	
		//generate the data
		$stats = $this->modules->_generate_report($data['cyear']);
		
		if (!empty($stats))
		{
			$srow = $stats[0];
			
			$data['stats'] = array();
			
			//setup the data for flash
			foreach ($srow as $k => $v)
			{	
				if ($k == 'id') continue;
				
				$arr = array('date' => $k,
							 'amount' => $v);
							 
				array_push($data['stats'], $arr);
			}
			
			$data['graph_data'] = $this->reports->_generate_flash_data($srow);
		}
		$data['print_page'] = $this->uri->segment('6', '0');
		
		$top = true;
		$bottom = true;
		$data['graph_width'] = '920';
		$data['graph_height'] = '290';
		
		if ($data['print_page'] == 'print')
		{
			$top = false;
			$bottom = false;
			$data['graph_width'] = '700';
			$data['graph_height'] = '150';
		}	

		//archive the report
		if ($data['print_page'] == 'archive')
		{
			
			$name = $data['cyear'] . ' ' . $data['page_title'] . ': ' . date($data['sts_admin_time_format'], now());
			
			$data['page_title'] = $name;	
			
			$html_data = load_form('modules', 'tpl_adm_bar_graph_report', $data, true);
			
			$sdata = $this->reports->_generate_archive($name, htmlentities($html_data));
		
			if ($sdata)
			{
				redirect(ADMIN_ROUTE. '/reports_archive/view_archive/');
				exit();
			}

		}
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_bar_graph_report', $data, $top, $bottom);
						
	}
	
	// ------------------------------------------------------------------------
	
}
?>