<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - thankyou.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage the thank you page
|
*/

class Thankyou extends Checkout_Controller {
	
	function __construct()
	{
		parent::Checkout_Controller();	
		
		//load css body style
		$this->config->set_item('css_body', 'jroxCheckout');
		
		//create pagination links		
		$this->config->set_item('uri', $this->config->slash_item('base_folder_path') . $this->config->slash_item('site_index_page') . $this->uri->segment(1));
		$this->config->set_item('uri_string', str_replace('/', ':', trim_slashes($this->uri->uri_string())));	
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		$this->security_model->_load_session('public');
		
		//set data array
		$data = $this->security_model->_load_config('public');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}		
		
		//update login status
		if ($this->session->userdata('m_login_status') == 1)
		{
			if ($this->members->_check_member_purchase($this->session->userdata('userid')) == true)
			{
				$this->session->set_userdata('m_login_status', '0');
			}
		}
		
		//reset cart
		$this->checkout->_reset_cart();
							
		//set page title
		$data['page_title'] = $this->lang->line('thank_you');
		$data['meta_keywords'] = '';
		$data['lang_thank_you'] = $this->lang->line('thank_you');
				
		$data['lang_thank_you_order'] = $this->lang->line('checkout_thank_you_order');
		$data['lang_checkout_check_your_account'] = $this->lang->line('checkout_check_your_account');
				
		$data['lang_login_to_account'] = anchor(base_url() . MEMBERS_ROUTE, $this->lang->line('click_to_login_to_account'));
		
		$data['analytics'] = '';
		if ($this->uri->segment(3))
		{
			$invoice = $this->invoices->_get_invoice_details((int)$this->uri->segment(3));
		}
		//add google analytics ecommerce tracking
		if ($this->config->item('sts_store_google_analytics_code'))
		{
			//get invoice data 
			if (!empty($invoice))
			{
				$data['analytics'] = '<script type="text/javascript">
var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
document.write(unescape("%3Cscript src=\'" + gaJsHost + "google-analytics.com/ga.js\' type=\'text/javascript\'%3E%3C/script%3E"));
</script>
<script type="text/javascript">
var pageTracker = _gat._getTracker("' . $this->config->item('sts_store_google_analytics_code') . '");
pageTracker._trackPageview();
pageTracker._addTrans(
  "' . $invoice['inv']['invoice_id'] . '", // order ID - required
  "' . $this->config->item('sts_store_name') . '", // affiliation or store name
  "' . $invoice['inv']['sub_total'] . '", // total - required
  "' . $invoice['inv']['tax_amount'] . '", // tax
  "' . $invoice['inv']['shipping_amount'] . '", // shipping
  "' . $invoice['inv']['customers_city'] . '", // city
  "' . $invoice['inv']['customers_state'] . '", // state or province
  "' . _get_country_name($invoice['inv']['customers_country'], 'country_iso_code_3') . '" // country
);
';

foreach ($invoice['prod'] as $prod)
{
   $data['analytics'] .= 'pageTracker._addItem(
	  "' . $invoice['inv']['invoice_id'] . '", // order ID - necessary to associate item with transaction
	  "' . $prod['product_sku'] . '", // SKU/code - required
	  "' . $prod['product_name'] . '", // product name
	  "", // category or variation
	  "' . $prod['product_price'] . '", // unit price - required
	  "' . $prod['quantity'] . '" // quantity - required
   );';
}

$data['analytics'] .= 'pageTracker._trackTrans(); //submits transaction to the Analytics servers

</script>
';
			}
		}
		
		//thank you page code
		if ($this->config->item('sts_store_thank_you_page_code'))
		{
			$data['thank_you_page_code'] = base64_decode($this->config->item('sts_store_thank_you_page_code'));

			if (!empty($invoice))
			{
				$data['thank_you_page_code'] = str_replace('{invoice_id}', $invoice['inv']['invoice_id'], $data['thank_you_page_code']);
				$data['thank_you_page_code'] = str_replace('{sub_total}', $invoice['inv']['sub_total'], $data['thank_you_page_code']);
				$data['thank_you_page_code'] = str_replace('{order_total}', $invoice['total_payments'], $data['thank_you_page_code']);
				
				//replace code for affiliates
				if (!empty($invoice['inv']['referrer_id']))
				{
					$member_data = $this->members->_get_member_basic($invoice['inv']['referrer_id']);
					
					foreach ($member_data as $k => $v)
					{
						if ($k != 'password')
						{
							$data['thank_you_page_code'] = str_replace('{referrer_' . $k . '}', $v, $data['thank_you_page_code']);	
						}
					}
					
				}
			}
		}
		
		$this->parser->_JROX_load_view('tpl_payment_thankyou', 'checkout', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function offline()
	{
		$this->security_model->_load_session('public');
		
		//set data array
		$data = $this->security_model->_load_config('public');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//reset cart
		$this->checkout->_reset_cart();
		
		//set page title
		$data['page_title'] = $this->lang->line('thank_you');
		$data['meta_keywords'] = '';
		$data['lang_thank_you'] = $this->lang->line('thank_you');
		
		$data['page_title'] = $this->lang->line('thank_you');
		$data['meta_keywords'] = '';
		$data['lang_thank_you'] = $this->lang->line('thank_you');
				
		$data['lang_thank_you_order'] = $this->lang->line('checkout_thank_you_order');
		$data['lang_checkout_check_your_account'] = nl2br($this->config->item('module_payment_gateway_offline_payment_message'));
		
		if ($this->config->item('module_payment_gateway_offline_payment_download_link'))
		{		
			$data['lang_offline_form_link'] = anchor($this->config->item('module_payment_gateway_offline_payment_download_link'), $this->lang->line('offline_order_form_link'));
		}
		else
		{
			$data['lang_offline_form_link'] = anchor(base_url() . MEMBERS_ROUTE, $this->lang->line('click_to_login_to_account'));
		}
		
		//thank you page code
		if ($this->config->item('sts_store_thank_you_page_code'))
		{
			$data['thank_you_page_code'] = base64_decode($this->config->item('sts_store_thank_you_page_code'));
		}
		
		$this->parser->_JROX_load_view('tpl_offline_payment_thankyou', 'checkout', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function membership()
	{
		$this->security_model->_load_session('public');
			
		//set data array
		$data = $this->security_model->_load_config('public');
		
		//initialize site with required db config
		$sdata = $this->init->_initialize(__CLASS__,  __FUNCTION__);
		
		//set up the languages array
		$data['languages'] = $sdata['languages'];
		
		//set all text
		foreach ($sdata['text'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		//set referral info
		foreach ($sdata['aff_cfg'] as $key => $val)
		{
			$data[$key] = $val;
		}
		
		if ($this->session->userdata('jroxMMOrderContents'))
		{
			$this->order_info = unserialize(base64_decode($this->session->userdata('jroxMMOrderContents')));
			
			//check if this is a free trial and generate the membership
			if ($this->order_info['jrox_enable_product_trial'] == 1 && $this->order_info['jrox_trial_amount'] == '0')
			{
				
				$check_membership[0] = '';
				$check_membership = $this->members->_get_membership_details($this->order_info['member_id'], $this->order_info['pid']);	
				$add_type = empty($check_membership) ? 'add' : 'update';
				$process_results['subscription_id'] = $this->members->_generate_membership($add_type, $this->order_info, $check_membership[0], $invoice_id, $payment);
	
				// add affiliate group
				if (!empty($this->order_info['add_affiliate_group']))
				{
					$this->groups_model->_update_member_group('affiliate', $this->order_info['member_id'],$this->order_info['add_affiliate_group']);
				}
				
				//add discount group
				if (!empty($this->order_info['add_discount_group']))
				{
					$this->groups_model->_update_member_group('discount', $this->order_info['member_id'], $this->order_info['add_discount_group']);
				}
				
				//add mailing list
				if (!empty($this->order_info['add_mailing_list']))
				{
					$this->members->_update_member_list('add', $this->order_info['member_id'], $this->order_info['add_mailing_list']);
				}
			}
		}
		
		//reset cart
		$this->checkout->_reset_cart('membership');
		
		//set page title
		$data['page_title'] = $this->lang->line('thank_you');
		$data['meta_keywords'] = '';
		$data['lang_thank_you'] = $this->lang->line('thank_you');
		
		$data['page_title'] = $this->lang->line('thank_you');
		$data['meta_keywords'] = '';
		$data['lang_thank_you'] = $this->lang->line('thank_you');
				
		$data['lang_thank_you_order'] = $this->lang->line('checkout_thank_you_order');
		$data['lang_checkout_check_your_account'] = '';
		
		//get the URL to redirect
		$url = base_url() . 'login/general/membership/' . $this->uri->segment(3);
		
		$data['lang_login_to_account'] = anchor($url, $this->lang->line('click_to_proceed_to_membership'));
		
		$data['analytics'] = '';
		//add google analytics ecommerce tracking
		if ($this->config->item('sts_store_google_analytics_code'))
		{
			//get invoice data 
			if ($this->uri->segment(4))
			{
				$invoice = $this->invoices->_get_invoice_details((int)$this->uri->segment(4));
				
				if ($invoice)
				{
					$data['analytics'] = '<script type="text/javascript">
var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
document.write(unescape("%3Cscript src=\'" + gaJsHost + "google-analytics.com/ga.js\' type=\'text/javascript\'%3E%3C/script%3E"));
</script>
<script type="text/javascript">
  var pageTracker = _gat._getTracker("' . $this->config->item('sts_store_google_analytics_code') . '");
  pageTracker._trackPageview();
  pageTracker._addTrans(
      "' . $invoice['inv']['invoice_id'] . '", // order ID - required
      "' . $this->config->item('sts_store_name') . '", // affiliation or store name
      "' . $invoice['inv']['sub_total'] . '", // total - required
      "' . $invoice['inv']['tax_amount'] . '", // tax
      "' . $invoice['inv']['shipping_amount'] . '", // shipping
      "' . $invoice['inv']['customers_city'] . '", // city
      "' . $invoice['inv']['customers_state'] . '", // state or province
      "' . _get_country_name($invoice['inv']['customers_country'], 'country_iso_code_3') . '" // country
    );
	';
   
   foreach ($invoice['prod'] as $prod)
   {
	   $data['analytics'] .= 'pageTracker._addItem(
		  "' . $invoice['inv']['invoice_id'] . '", // order ID - necessary to associate item with transaction
		  "' . $prod['product_sku'] . '", // SKU/code - required
		  "' . $prod['product_name'] . '", // product name
		  "", // category or variation
		  "' . $prod['product_price'] . '", // unit price - required
		  "' . $prod['quantity'] . '" // quantity - required
	   );';
	}
	
   $data['analytics'] .= 'pageTracker._trackTrans(); //submits transaction to the Analytics servers

</script>
';
				}
			}
		}
		
		//thank you page code
		if ($this->config->item('sts_store_thank_you_page_code'))
		{
			$data['thank_you_page_code'] = base64_decode($this->config->item('sts_store_thank_you_page_code'));
		}
		
		$this->parser->_JROX_load_view('tpl_payment_thankyou', 'checkout', $data);
	}

}

?>