<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - admins_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing the administrators
|
*/

class Admins_Model extends Model {
	
	function _add_admin() //insert the new admin into db
	{		
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//setup permissions array
		if (!empty($data['permissions']))
		{
			$data['permissions'] = implode(',', $data['permissions']);
		}
		else
		{
			$data['permissions'] = '';
		}
			
		//insert into db
		if (!$this->db->insert('admin_users', $data))
		{
			show_error($this->lang->line('could_not_add_admin'));
			
			//log error
			log_message('error', 'Could not insert admin into admin_users table');
			
			return false;
		}
		
		//log success
		log_message('info', 'Admin user added');
		return $this->db->insert_id();
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_admin_photo($id = '')
	{
		//delete product photos
		$this->db->where('admin_id', $id);
		$query = $this->db->get('admin_users');
		
		//delete photo files
		if ($query->num_rows() > 0)
		{
			$photo_data = $query->row_array();
			
			if ($photo_data['admin_photo'])
			{
				@unlink('./images/' . $this->config->item('images_admins_dir') . '/' . $photo_data['admin_photo']);
			}
		}
		
		//delete from products_photos
		$this->db->where('admin_id', $id);			
		$update = array('admin_photo' => '');
		
		if ($this->db->update('admin_users', $update))
		{
			//log success
			log_message('info', 'photo for admin ID #' . $id . ' updated in admin_users table');
			
			return true;
		}	
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_status($data = '', $type = 'inactive')
	{

		foreach ($data as $id)
		{
			if ($id == 1)
			{
				continue;
			}
			
			$this->db->where('admin_id', $id);
			
			if ($type == 'delete')
			{
				if (!$this->db->delete('admin_users'))
				{
					show_error($this->lang->line('could_not_delete_admin'));
					
					//log error
					log_message('error', 'Could not delete admin ID #' . $id . ' in admin_users table');
					return false;
				}
				
				//log success
				log_message('info', 'Admin ID #' . $id . ' deleted');
			}
			else
			{
				//update admin in db
				
				$data = array(
								'status' => $type,
							);
				
				if (!$this->db->update('admin_users', $data))
				{
					show_error($this->lang->line('could_not_update_admin'));
					
					//log error
					log_message('error', 'Could not update admin ID #' . $id . ' in admin_users table');
					return false;
				}
				
				//log success
				log_message('info', 'Status Changed for admin ID# ' . $id);
			}
			
		}
		
		return true;		
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_admin($id = '') //delete an admin
	{
		if ($id > 1) //cannot delete the superadmin
		{
			$this->db->where('admin_id', $id);		
			
			if (!$this->db->delete('admin_users'))
			{
				show_error($this->lang->line('could_not_delete_admin'));
				
				//log error
				log_message('error', 'Could not delete admin ID #' . $id . ' in admin_users table');
				return false;
			}
			
			//log success
			log_message('info', 'Admin ID #' . $id . ' deleted');
		}

		return true;	
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_admins($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_au_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_au_column');
		
		//$this->db->join('admin_permissions', 'admin_users.admin_id = admin_permissions.admin_id');
		$this->db->order_by($sort_column, $sort_order); 	
		$query = $this->db->get('admin_users', $limit, $offset);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_all_admins()
	{	
		$query = $this->db->get('admin_users');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_admin_details($id = '')
	{
		//get all the admins from db for list view
		//$this->db->join('admin_permissions', 'admin_users.admin_id = admin_permissions.admin_id', 'left');
		
		$this->db->where('admin_users.admin_id', $id);
		$query = $this->db->get('admin_users');
		
		return $query->result_array();
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_admin($id = '')
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//setup permissions array
		if ($id == 1) //super admin has all permissions
		{
			$data['permissions'] = '';
			$data['status'] = 'active';
			$data['show_assigned_tickets_only'] = '0';
		}
		else
		{
			if (!empty($data['permissions']))
			{
				$data['permissions'] = implode(',', $data['permissions']);
			}
			else
			{
				$data['permissions'] = '';
			}
		}
			
		//check first if photo needs to be deleted
		if (empty($data['admin_photo']))
		{
			$admin_data = $this->_get_admin_details($id);
			
			if (!empty($admin_data[0]['admin_photo']))
			{
				@unlink('./images/' . $this->config->item('images_admins_dir') . '/' . $admin_data[0]['admin_photo']);
			}
		}
		
		//update admin in db
		$this->db->where('admin_id', $id);
		
		if (!$this->db->update('admin_users', $data))
		{
			show_error($this->lang->line('could_not_update_admin'));
			
			//log error
			log_message('error', 'Could not update admin ID #' . $id . ' in admin_users table');
			return false;
		}
		
		//log success
		log_message('info', 'Admin ID #' . $id . ' updated');
		return $id;
	}
	
	// ------------------------------------------------------------------------	
}
?>