<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - affiliate_marketing_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for affiliate_marketing
|
*/

class Affiliate_Marketing_Model extends Model {

	function _check_config($id = '')
	{
		$this->db->where('module_id', $id);
		$this->db->where('module_type', 'affiliate_marketing');
		$query = $this->db->get('affiliate_marketing');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_user_traffic($id = '', $limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		if (!$sort_order) $sort_order = $this->config->item('mem_dbs_tff_order');
		if (!$sort_column) $sort_column = $this->config->item('mem_dbs_tff_column');
		
		$this->db->where('member_id', $id);
		$this->db->order_by($sort_column, $sort_order);
		$this->db->limit($limit, $offset);			
		
		$query = $this->db->get('traffic');
		
		if ($query->num_rows() > 0)
		{
		
			$a['traffic'] = array();
			
			foreach ($query->result_array() as $row)
			{
				$row['s_referrer'] = empty($row['referrer']) ? $this->lang->line('unknown_site') : $row['referrer'];
				$row['s_referrer_url'] = empty($row['referrer']) ? '#' : limit_chars($row['referrer'], 75); 
				$row['s_date'] = _show_date($row['date']);
				$row['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				
				array_push($a['traffic'], $row);
			}
			
			//get total rows
			$this->db->where('member_id', $id);
			$this->db->from('traffic');
			
			$a['total_rows'] = $this->db->count_all_results();
			
			return $a;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _insert_affiliate_traffic($data = '')
	{
		if ($this->db->insert('traffic', $data))
		{
			return $this->db->insert_id();
		}
		
		return false;		
	}
	
	// ------------------------------------------------------------------------	
	
	function _validate_user($user = '', $id = false)
	{

		$this->db->select('members.*, members.member_id as mid, members_photos.*');
		$this->db->from('members');
		$this->db->where('enable_affiliate_marketing !=' , '0');
		
		if ($id == true)
		{		
			$this->db->where('members.member_id', $user);
		}
		else
		{
			$this->db->where('members.username', $user);
		}
		
		$this->db->where('status', '1');
		$this->db->join('members_photos', 'members.member_id = members_photos.member_id', 'left');
		$this->db->group_by('members.member_id');
		
		$query = $this->db->get();

		if ($query->num_rows() > 0)
		{
			$a = $query->row_array();
			
			unset ($a['password']);
			
			return $a;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_tool($type = '', $id = '', $table = '')
	{
		//update text_links first
		
		$data = array('tool_id' => '0',
					  'tool_type' => '');
		
		//update traffic
		$this->db->where('tool_id', $id);
		$this->db->where('tool_type', $type);
		$this->db->update('traffic', $data);
		
		//update commissions
		$this->db->where('tool_id', $id);
		$this->db->where('tool_type', $type);
		$this->db->update('affiliate_commissions', $data);
		
		//update invoice
		$this->db->where('referrer_id', $id);
		$this->db->where('tool_type', $type);
		$data = array('referrer_id' => '0',
					  'tool_type' => '');
					  
		$this->db->update('invoices', $data);
		
		//delete text_link
		$this->db->where('id', $id);
		if ($this->db->delete($table))
		{
			
			//log success
			log_message('info', $type . ' ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_' . $type));
			
			//log error
			log_message('error', $type . ' ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_module_key($key = '')
	{
		$m = 'f01c1197ea83a07ca972939b68985824';
	
		if ($key == $m)
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_tool_details($type = '', $id = '')
	{
		$this->db->where('id', $id);
		$this->db->where('status', '1');
		//$this->db->where('enable_redirect', '1');
		$query = $this->db->get('affiliate_' . $type);
	
		if ($query->num_rows() > 0)
		{
			return $query->row_array();
			
		}
		
		return false;
	}

	// ------------------------------------------------------------------------	
	
	function _get_affiliate_marketing_details($id = '')
	{
		//$this->db->join('settings', 'affiliate_marketing.affiliate_marketing_id = settings.settings_group');
		$this->db->where('module_id', $id);
		$this->db->where('module_type', 'affiliate_marketing');
		$query = $this->db->get('modules');
		
		if ($query->num_rows() > 0)
		{
			$row = $query->result_array();	
			
			$row[0]['sts_config'] = array();
			
			//get any configs
			$this->db->where('settings_module', 'affiliate_marketing');
			$this->db->where('settings_group', $id);
			$this->db->order_by('settings_sort_order', 'ASC');
			$query = $this->db->get('settings');
		
			//add the options to the config array
			foreach ($query->result_array() as $options)
			{
				array_push($row[0]['sts_config'], $options);
			}
			
			return $row;
		}
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_affiliate_marketing($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_afm_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_afm_column');
		
		//$this->db->join('admin_permissions', 'admin_users.admin_id = admin_permissions.admin_id');
		$this->db->order_by($sort_column, $sort_order); 	
		$this->db->where('module_type', 'affiliate_marketing');
		$query = $this->db->get('modules', $limit, $offset);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_user_tools()
	{		
		//$this->db->join('admin_permissions', 'admin_users.admin_id = admin_permissions.admin_id');
		$this->db->order_by($this->config->item('mem_dbs_afm_column'), $this->config->item('mem_dbs_afm_order')); 	
		$this->db->where('module_type', 'affiliate_marketing');
		$this->db->where('module_status', '1');
		$query = $this->db->get('modules');

		if ($query->num_rows() > 0)
		{
			$a = array();
			foreach ($query->result_array() as $v)
			{
				if (file_exists($this->config->item('base_physical_path') . '/themes/main/' . $this->config->item('layout_design_site_theme') . '/images/module_' . $v['module_type'] . '_' . $v['module_file_name'] . '.' . $this->config->item('member_marketing_tool_ext')))
				{				
					$v['tool_image'] = base_url() . 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/module_' . $v['module_type'] . '_' . $v['module_file_name'] . '.' .  $this->config->item('member_marketing_tool_ext');
				}
				elseif (file_exists($this->config->item('base_physical_path') . '/images/modules/module_' . $v['module_type'] . '_' . $v['module_file_name'] . '.' . $this->config->item('member_marketing_tool_ext')))
				{				
					$v['tool_image'] = base_url() . 'images/modules/module_' . $v['module_type'] . '_' . $v['module_file_name'] . '.' .  $this->config->item('member_marketing_tool_ext');
				}
				else
				{
					$v['tool_image'] = base_url() . 'images/modules/web_advertising.png';
				}
			
				array_push($a, $v);
			}
			
			return $a;
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_sort_order($table = '')
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		foreach ($data as $k => $v)
		{
			if (strstr($k, "tool") == true) 
			{
				$id = explode("-", $k);
			
				$this->db->where('id', $id[1]);
				
				$sdata = array('sort_order' => $v);
				
				if (!$this->db->update($table, $sdata))
				{
					show_error($this->lang->line('could_not_update_affiliate_marketing'));
					
					//log error
					log_message('error', 'Could not update affiliate_marketing #' . $k . ' in affiliate_marketing table');
					return false;
				}
			}
		}
		
		//make sure tiers are numbered sequentially
		$this->db_validation_model->_db_sort_order($table, 'id', 'sort_order'); 
		
		return true;		
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_options()
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		if ($this->db_validation_model->_update_db_settings($data))
		{
			//log success
			log_message('info', 'settings table updated successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_update_settings'));
			
			//log error
			log_message('error', 'Could not update settings table');
			
			return false;		
		}
		
		return true;
	}	
	
	// ------------------------------------------------------------------------	
	
}
?>