<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - attributes_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing product attributes
|
*/

class Attributes_Model extends Model {	
	
	function _add_attribute()
	{
		$data = $this->db_validation_model->_clean_data($_POST);

		//get all options
		$option_name = $data['option_name'];
		$add_price = $data['add_price'];
		$price_amount = $data['price_amount'];
		$add_weight = $data['add_weight'];
		$weight_amount = $data['weight_amount'];
		$sort = $data['sort'];
		
		unset ($data['option_name']);
		unset ($data['add_price']);
		unset ($data['price_amount']);
		unset ($data['add_weight']);
		unset ($data['weight_amount']);
		unset ($data['sort']);
		
		if ($data['attribute_type'] == 'checkbox')
		{
			//check for options and reconstruct
			$data['attribute_options'] = '';
		}
		
		
		if ($data['attribute_type'] == 'dropdown')
		{	
			$data['attribute_options'] = '';
			
			$sort_order = 1;
			foreach ($option_name as $k => $v)
			{
				if (!empty($v))
				{
					if (empty($sort[$k])) $sort[$k] = $sort_order;
					
					$opt = trim($v).':'.trim($add_price[$k]).':'.trim($price_amount[$k]).':'.trim($add_weight[$k]).':'.trim($weight_amount[$k]) . ':' . trim($sort[$k]);
					$data['attribute_options'] .= $opt.'|';
				}
				$sort_order++;
			}	
		}	
		
		//insert into db
		if (!$this->db->insert('products_attributes', $data))
		{
			show_error($this->lang->line('could_not_add_attribute'));
			
			//log error
			log_message('error', 'Could not insert category into products_attributes table');
			
			return false;
		}
		else
		{
			$attribute_id = $this->db->insert_id();
			
			//log success
			log_message('info', 'attribute '. $attribute_id . ' inserted into products_attributes table');
		}
		
		return $attribute_id;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_product_attributes($id = '')
	{
		//get product attributes
		$this->db->where('product_id', $id);
		$this->db->where('attribute_status', '1');
		$this->db->join('products_attributes', 'products_attributes.attribute_id=products_to_attributes.attribute_id');
		$query = $this->db->get('products_to_attributes');
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}		
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _format_attribute($row = '')
	{
		$this->load->helper('inflector');
	
		$form['attribute_name'] = humanize($row['attribute_name']);
		$form['attribute_id'] = $row['attribute_id'];
		$form['attribute_required'] = $row['attribute_required'];
		$form['check_required'] = '';
		
		$required = '';
		if ($form['attribute_required'] == '1')
		{
			$required = 'required';
			$form['check_required'] = '*';
		}
		
		switch ($row['attribute_type'])
		{
			case 'dropdown':
				
				$select = array();
				$values = array();
				if ($form['attribute_required'] == '0')
				{
					$select = array('0');
					$values = array($this->lang->line('please_select_option'));
				}
				
				if (!empty($row['attribute_options']))
				{
					$format = explode('|', $row['attribute_options']);
					$attrib_options = array();
					
					//sort the array first
					$f_keys = array();
					$f_values = array();
					foreach ($format as $k => $v)
					{	
						$rows = explode(':', $v);
						
						array_push($f_keys, $rows[5]);
						array_push($f_values, $v);
					}
					
					//combine the array
					$new_format = combine_array($f_keys, $f_values);
					ksort($new_format);
					
					foreach ($new_format as $k => $v)
					{								
						$rows = explode(':', $v);
						
						if (!empty($v))
						{	
							$name = $rows[0];
							$value = $rows[0];
							
							if ($rows[1] == 'add')
							{
								$name .= '(+ ' . $rows[2] .')'; 
							}
							elseif ($rows[1] == 'sub')
							{
								$name .= '(- ' . $rows[2] .')'; 
							}
							
							array_push($select, $value);
							array_push($values, $name);
						}							
					}
				}
				
				//sort attributes alphabetically		
				$row_options = combine_array($select, $values);
				
				$form['attribute_data'] = form_dropdown('attributes[' . $row['attribute_id'] . ']', $row_options, '', 'id="jroxProductDetailsAttributeDropdown_' . $row['attribute_id'] . ' " class="jroxProductDetailsAttributeDropdown ' . $required . '"');
							
			break;
			
			case 'checkbox':
			
				$data = array(
							'name'        => 'attributes[' . $row['attribute_id'] . ']',
							'id'          => 'jroxProductDetailsAttributeCheckBox_' . $row['attribute_id'],
							'value'       => 'yes',
							'checked'     => false,
							'class'       => 'jroxProductDetailsAttributeCheckBox ' . $required,
							);
						
				$form['attribute_data'] = form_checkbox($data);

			break;
			
			case 'text':
				
				$data = array(
							  'name'        => 'attributes[' . $row['attribute_id'] . ']',
							  'id'          => 'jroxProductDetailsAttributeText_' . $row['attribute_id'],
							  'value'       => '',
							  'maxlength'   => '255',
							  'size'        => '50',
							  'class'       => 'jroxProductDetailsAttributeText ' . $required,
							);

				$form['attribute_data'] = form_input($data);

			break;
			
			case 'textarea':
				
				$data = array(
							  'name'        => 'attributes[' . $row['attribute_id'] . ']',
							  'id'          => 'jroxProductDetailsAttributeTextArea_' . $row['attribute_id'],
							  'value'       => '',
							  'rows'  		=> '5',
							  'cols'        => '25',
							  'class'       => 'jroxProductDetailsAttributeTextArea ' . $required,
							);

				$form['attribute_data'] = form_textarea($data);
				
			break;
		}
		
		return $form;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_attribute_callbacks()
	{
		//get attribute modules
		$this->db->where('module_type', 'attribute_callback');
		$this->db->where('module_status', '1');
		$query = $this->db->get('modules');
		if ($query->num_rows() > 0)
		{
			$attribute_callbacks = $query->result_array();
			$attribute_callbacks = format_array($attribute_callbacks, 'module_id', 'module_name', true);
		
			return $attribute_callbacks;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _delete_attribute($id = '')
	{
		//update product_categories first
		$this->db->where('attribute_id', $id);
		
		
		//delete attribute
		$this->db->where('attribute_id', $id);
		if ($this->db->delete('products_to_attributes'))
		{
			
			//log success
			log_message('info', 'attribute ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_attribute'));
			
			//log error
			log_message('error', 'attribute ID #' . $id . ' could not be deleted');
		}
		
		//delete attribute
		$this->db->where('attribute_id', $id);
		if ($this->db->delete('products_attributes'))
		{
			
			//log success
			log_message('info', 'attribute ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_attribute'));
			
			//log error
			log_message('error', 'attribute ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}	
	
	// ------------------------------------------------------------------------
	
	function _get_attribute_details($id = '')
	{
		//get the data from attributes table
		$this->db->where('attribute_id', $id);
		$query = $this->db->get('products_attributes');
		
		if ($query->num_rows() > 0)
		{
			return $query->row_array();
		}
		else
		{
			return false;
		}
	}
	
	// ------------------------------------------------------------------------
	
	function _get_attributes($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the categories from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_att_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_att_column');

		$sql = 'SELECT ' . $this->db->dbprefix('products_attributes') . '.*,
				(SELECT COUNT(*) from ' . $this->db->dbprefix('products_to_attributes') . ' 
				WHERE ' . $this->db->dbprefix('products_attributes') . '.attribute_id = ' . $this->db->dbprefix('products_to_attributes') . '.attribute_id) as total
				FROM ' . $this->db->dbprefix('products_attributes') . '
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$prod_cats = $query->result_array();
			
			return $prod_cats;
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_status($id = '')
	{	
		$this->db->where('attribute_id', $id);
		$query = $this->db->get('products_attributes');
		
		$row = $query->result_array();
		
		$status = ($row[0]['attribute_status'] == '1') ? '0' : '1';
		
		$data = array('attribute_status' => $status);
		
	
		$this->db->where('attribute_id', $id);
		
		if ($this->db->update('products_attributes', $data))
		{
			
			//log success
			log_message('info', 'Status Changed for attribute ID# ' . $id);
			
		return true;
		}
		
		show_error($this->lang->line('could_not_update_attribute'));
			
		//log error
		log_message('error', 'Could not update attribute ID #' . $id . ' in attribute table');
		return false;
	}

	// ------------------------------------------------------------------------
	
	function _get_all_attributes()
	{
		$query = $this->db->get('products_attributes');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _mass_update_attributes()
	{
		$atts = $this->_get_all_attributes();
		
		if (!empty($atts))
		{
			$i = 0;
			
			foreach ($atts as $v)
			{
				$j = 1;
				if ($v['attribute_type'] == 'dropdown')
				{
					$att_options = '';
					
					$format = explode('|', $v['attribute_options']);
					
					foreach ($format as $a)
					{								
						if (!empty($a))
						{
							$rows = explode(':', $a);
							if (!empty($v))
							{
								if (empty($rows[5]))
								{
									$opt = trim($rows[0]).':'.trim($rows[1]).':'.trim($rows[2]).':'.trim($rows[3]).':'.trim($rows[4]) . ':' . $j;
									$att_options .= $opt.'|';
									$j++;
								}
							}
						}
					}
					
					//update attributes
					$array = array('attribute_options' => $att_options);

					$this->db->where('attribute_id', $v['attribute_id']);
					$this->db->update('products_attributes', $array);
					$i++;
				}
			}
		}
		
		return $i . ' attributes updated';
	}	
	
	// ------------------------------------------------------------------------
	
	function _update_attribute($id = '', $post_array = '')
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($post_array);

		//get all options
		$option_name = $data['option_name'];
		$add_price = $data['add_price'];
		$price_amount = $data['price_amount'];
		$add_weight = $data['add_weight'];
		$weight_amount = $data['weight_amount'];
		$sort = $data['sort'];
		
		unset ($data['option_name']);
		unset ($data['add_price']);
		unset ($data['price_amount']);
		unset ($data['add_weight']);
		unset ($data['weight_amount']);
		unset ($data['sort']);
		
		$data['attribute_required'] = empty($data['attribute_required']) ? '0' : '1';
		
		if ($data['attribute_type'] == 'checkbox')
		{
			//check for options and reconstruct
			$data['attribute_options'] = '';
		}
		
		if ($data['attribute_type'] == 'dropdown')
		{	
			$data['attribute_options'] = '';
			
			$i = 0;
			foreach ($option_name as $k => $v)
			{
				if (!empty($v))
				{
					if (empty($sort[$k])) $sort[$k] = $i;
					$opt = trim($v).':'.trim($add_price[$k]).':'.trim($price_amount[$k]).':'.trim($add_weight[$k]).':'.trim($weight_amount[$k]) . ':' . trim($sort[$k]);
					$data['attribute_options'] .= $opt.'|';
				}
				
				$i++;
			}	
		}	
		
		//update attribute data
		$this->db->where('attribute_id', $id);
		
		if (!$this->db->update('products_attributes', $data))
		{
			show_error($this->lang->line('could_not_update_attribute'));
			
			//log error
			log_message('error', 'Could not update attribute ID ' . $id . 'in products_attributes table');
			
			return false;
		}
		else
		{
			
			//log success
			log_message('info', 'attribute ID '. $id . ' updated in products_attributes table');
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------	
}
?>