<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - cart_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing the shopping cart
|
*/

class Cart_Model extends Model {	
	
	var $gc_probability	= 20;
	
	function __construct()
	{
		parent::Model();	
		
		$this->cart_table = 'shopping_cart';
		
		//set the time
		$this->sess_length = $this->config->item('sess_expiration_cart');
	}
	
	// ------------------------------------------------------------------------
	
	function _get_vendor_items()
	{
	$sql = 'SELECT ' . $this->db->dbprefix('shopping_cart') . '.*, ' . $this->db->dbprefix('shopping_cart') . '.product_id as pid, 
				' . $this->db->dbprefix('products') . '.*, ' . $this->db->dbprefix('vendors') . '.*
				FROM  ' . $this->db->dbprefix('shopping_cart') . '
				LEFT JOIN ' . $this->db->dbprefix('products') . '  
				ON ' . $this->db->dbprefix('shopping_cart') . '.product_id = ' . $this->db->dbprefix('products') . '.product_id 
				LEFT JOIN ' . $this->db->dbprefix('vendors') . '  
				ON ' . $this->db->dbprefix('products') . '.vendor_id = ' . $this->db->dbprefix('vendors') . '.vendor_id 
				WHERE cart_id = \'' . $this->session->userdata('session_id') .'\'
				GROUP BY ' . $this->db->dbprefix('shopping_cart') . '.cid
				ORDER BY ' . $this->db->dbprefix('shopping_cart') . '.cid DESC';

		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{			
			$items = array();
			foreach ($query->result_array() as $row)
			{
				$row['s_product_price'] = $row['product_price'];

				$row['ztax1'] = 0;
				if (!empty($row['tax_zone']))
				{
					$this->db->where('tax_zone_id', $row['tax_zone']);
					$zquery = $this->db->get('tax_zones');
					if ($zquery->num_rows() > 0)
					{
						$zrow = $zquery->row_array();
						$row['ztax1'] = $row['s_product_price'] * $zrow['tax_amount'];
					}
				}
				
				if ($this->config->item('product_add_tax_zone_to_price') == true)
				{
					$row['s_product_price'] = $row['s_product_price'] + $row['ztax1'];
				}
				
				if (!empty($row['attributes']))
				{
					$attrib = unserialize($row['attributes']);
					
					foreach ($attrib as $k => $v)
					{
						//get the attribute values
						$attrib_data = $this->attrib->_get_attribute_details($k);
						
						//check if the attribute is a dropdown
						if ($attrib_data['attribute_type'] == 'dropdown')
						{
							//check for attribute amount
							$format = explode('|', $attrib_data['attribute_options']);
							
							foreach ($format as $option)
							{								
								
								$value = explode(':', $option);
								
								if (!empty($value))
								{
									if ($v == $value[0])
									{	
										
										//format amounts
										if ($value[1] == 'add')
										{
											$row['s_product_price'] = $row['s_product_price'] + $value[2];
										}
										elseif ($value[1] == 'sub')
										{
											$row['s_product_price'] = $row['s_product_price'] - $value[2];
										}
										
										//format weight
										if ($value[3] == 'add')
										{
											$row['product_weight'] = $row['product_weight'] + $value[4];
										}
										elseif ($value[3] == 'sub')
										{
											$row['product_weight'] = $row['product_weight'] - $value[4];
										}
										
									}
									
								}							
							}
						}
						
					}
				}
	
				array_push($items, $row);
			}
			
			return $items;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_cart_items($num_options = '')
	{
		$sql = 'SELECT ' . $this->db->dbprefix('shopping_cart') . '.*, ' . $this->db->dbprefix('shopping_cart') . '.product_id as pid, 
				' . $this->db->dbprefix('products') . '.*, ' . $this->db->dbprefix('products_photos') . '.*
				FROM  ' . $this->db->dbprefix('shopping_cart') . '
				LEFT JOIN ' . $this->db->dbprefix('products') . '  
				ON ' . $this->db->dbprefix('shopping_cart') . '.product_id = ' . $this->db->dbprefix('products') . '.product_id 
				LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
				AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
				WHERE cart_id = \'' . $this->session->userdata('session_id') .'\'
				GROUP BY ' . $this->db->dbprefix('shopping_cart') . '.cid
				ORDER BY ' . $this->db->dbprefix('shopping_cart') . '.cid DESC';

		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$rows['items'] = array();
			$rows['subtotal_cart_price'] = 0;
			$rows['total_cart_weight'] = 0;
			$rows['total_cart_quantity'] = 0;
			
				
			foreach ($query->result_array() as $row)
			{
				$row['ztax1'] = 0;
				
				if ($row['product_sale_price'] > '0') { $row['product_price'] = $row['product_sale_price']; }
				
				if (!empty($row['tax_zone']))
				{
					$this->db->where('tax_zone_id', $row['tax_zone']);
					$zquery = $this->db->get('tax_zones');
					if ($zquery->num_rows() > 0)
					{
						$zrow = $zquery->row_array();
						$row['ztax1'] = $row['product_price'] * $zrow['tax_amount'];
					}
				}
				
				if ($this->config->item('product_add_tax_zone_to_price') == true)
				{
					$row['product_price'] = $row['product_price'] + $row['ztax1'];
				}
				
				
				$row['s_product_price'] = $row['product_price'];
				$row['total_product_weight'] = $row['product_weight'];
				$row['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				//check the attributes
				$row['attribute_list'] = '';
				$row['attribute_list_text'] = '';
				
				if (!empty($row['attributes']))
				{
					$attrib = unserialize($row['attributes']);
					
					foreach ($attrib as $k => $v)
					{
						//get the attribute values
						$attrib_data = $this->attrib->_get_attribute_details($k);
						
						//check if the attribute is a dropdown
						if ($attrib_data['attribute_type'] == 'dropdown')
						{
							//check for attribute amount
							$format = explode('|', $attrib_data['attribute_options']);
							
							foreach ($format as $option)
							{								
								
								$value = explode(':', $option);
								
								if (!empty($value))
								{
									if ($v == $value[0])
									{	
										
										//format amounts
										if ($value[1] == 'add')
										{
											$row['s_product_price'] = $row['s_product_price'] + $value[2];
										}
										elseif ($value[1] == 'sub')
										{
											$row['s_product_price'] = $row['s_product_price'] - $value[2];
										}
										
										//format weight
										if ($value[3] == 'add')
										{
											$row['product_weight'] = $row['product_weight'] + $value[4];
											$row['total_product_weight'] = $row['total_product_weight'] + $value[4];
										}
										elseif ($value[3] == 'sub')
										{
											$row['product_weight'] = $row['product_weight'] - $value[4];
											$row['total_product_weight'] = $row['total_product_weight'] - $value[4];
										}
										
										$row['attribute_list'] .= '<span class="jroxCartOptions"><span class="jroxBold">' . $attrib_data['attribute_name'] . '</span> - <span class="jroxOptionValue">' . $value[0] . '</span></span><br />';
										$row['attribute_list_text'] .= $attrib_data['attribute_name'] . ' - ' . $value[0] . "\n";
									}
									
								}							
							}
						}
						else
						{
							$row['attribute_list'] .= '<span class="jroxCartOptions"><span class="jroxBold">' . $attrib_data['attribute_name'] . '</span> - <span class="jroxOptionValue">' . $v . '</span></span><br />';
							$row['attribute_list_text'] .= $attrib_data['attribute_name'] . ' - ' . $v . "\n";
						}
					}
				}
				
				//check the image
				if (empty($row['photo_file_name']))
				{
					$row['image_file'] = '<img src="' . base_url(). 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/no_photo.png" class="jroxCartNoImage"/>';
				}
				else
				{
					$row['image_file'] = _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], '', '', false, false, 'jroxCartImages');
					
				}
				
				//format links
				$row['product_link'] = base_url() . $this->config->slash_item('site_index_page') . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . url_title($row['product_name']);
				
				//format the amounts
				$row['total_product_price'] = format_amounts($row['s_product_price'], $num_options);
				$row['subtotal_price'] = format_amounts($row['s_product_price'] * $row['quantity'], $num_options);
				
				//update totals
				$rows['subtotal_cart_price'] = $rows['subtotal_cart_price'] + ($row['s_product_price'] * $row['quantity']);
				$rows['total_cart_weight'] = $rows['total_cart_weight'] + ($row['total_product_weight'] * $row['quantity']);
				$rows['total_cart_quantity'] = $rows['total_cart_quantity'] + $row['quantity'];
				
				array_push($rows['items'], $row);
				
			}
			
			
			//echo '<pre>'; print_r($rows); exit();
			return $rows;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _add_item($pid = '', $qnty = 1)
	{
		
		//first check if there is the same product there already and just update the quantity
		
		if (is_array($this->input->post('attributes')))
		{
			$attrib = array_filter($this->input->post('attributes'));
			$attributes = $this->input->post('attributes') != false ? serialize($attrib) : '';
		}
		else
		{
			$attributes = '';
		}	
		
		$item = $this->_get_item($pid, $attributes);
		
		$qty = $this->input->post('quantity');
		$quantity = !empty($qty) ? $qty : $qnty;
		
		if (!empty($item))
		{
			$new_qty = $item->quantity + (int)$quantity;
			$this->_update_quantity($pid, $new_qty, $attributes);
			
			return true;
		}
		else
		{			
			$sdata = array('cart_id' => $this->session->userdata('session_id'),
						   'product_id' => (int)$pid,
						   'attributes' => $attributes,
						   'quantity'	=> (int)$quantity,
						   'date'	=> _generate_timestamp(),
						   );
						   
			if ($this->db->insert($this->cart_table, $sdata) == true)
			{
				//update cart total
				$this->_update_total_items();
				
				//run cleanup routine
				$this->_run_cleanup();
				return true;
			}
		
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _update_total_items()
	{
		$total = $this->_count_items();
		
		if (empty($total))
		{
			$text = $this->lang->line('no_items_in_cart');
		}
		elseif ($total == 1)
		{
			$text = $total . ' ' . $this->lang->line('item_in_cart');
		}
		else
		{
			$text = $total . ' ' . $this->lang->line('items_in_cart');
		}
		
		$this->session->set_userdata('user_cart_items_set', $total);
		$this->session->set_userdata('user_cart_items_set_text', $text);
	}
	
	// ------------------------------------------------------------------------
	
	function _count_items()
	{
		$this->db->where('cart_id', $this->session->userdata('session_id'));
		$total = $this->db->count_all_results($this->cart_table);
	
		return $total;
	}
	
	// ------------------------------------------------------------------------
	
	function _update_quantity($pid = '', $qty = '', $attributes = '')
	{
		$data = array('quantity' => $qty,
					  'date' => _generate_timestamp());
		
		$this->db->where('cart_id', $this->session->userdata('session_id'));
		$this->db->where('product_id', $pid);
		
		if (!empty($attributes))
		{
			$this->db->where('attributes', $attributes);
		}
		
		if ($this->db->update($this->cart_table, $data))
		{
			return true;
		}
		
		return false;
	}

	// ------------------------------------------------------------------------	
	
	function _update_cart($array = '')
	{
		$data = $this->db_validation_model->_clean_data($array);
		$show_error = '';
		
		foreach ($data as $k => $v)
		{
			$prod = explode('_', $k);
			
			$cid = $prod[0];
			$pid = $prod[1];
			$min = $prod[2];
			$max = $prod[3];

			//first delete the product if zero
			if (empty($v))
			{
				$this->_delete_item($cid);
			}
			else
			{
				//check minimum
				if (!empty($min))
				{
					if ($v < $min)
					{
						$name = $this->db_validation_model->_get_details('products', 'product_name', 'product_id', $pid);
						
						$show_error .= $name[0]['product_name'] . ' ' . $this->lang->line('requires_min_quantity_of') . ' ' . $min . "\n";
						$v = $min;
					}
				}
				
				if (!empty($max))
				{
					if ($v > $max)
					{
						$name = $this->db_validation_model->_get_details('products', 'product_name', 'product_id', $pid);
						
						$show_error .= $name[0]['product_name'] . ' ' . $this->lang->line('has_maximum_quantity_of') . ' ' . $max . "\n";
						$v = $max;
						
					}
				}
				
				$v = $v < 1 ? '1' : $v;
					
				$this->_update_cart_qty($cid, $v);

			}
		}
		
		return $show_error;
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_cart_qty($cid = '', $qty = '')
	{
		$sdata = array('quantity' => $qty);
		
		$this->db->where('cid', $cid);
		
		if ($this->db->update($this->cart_table, $sdata))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_item($pid = '', $attributes = '')
	{
		$this->db->where('cart_id', $this->session->userdata('session_id'));
		$this->db->where('product_id', $pid);
		
		if (!empty($attributes))
		{
			$this->db->where('attributes', $attributes);
		}
		
		$query = $this->db->get($this->cart_table);
		
		if ($query->num_rows() > 0)
		{
			return $query->row();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_item($cid = '')
	{
		$this->db->where('cid', $cid);
		if ($this->db->delete($this->cart_table))
		{
			//update cart total
			$this->_update_total_items();
			
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _run_cleanup()
	{
		srand(time());
		if ((rand() % 100) < $this->gc_probability) 
		{  
			$expire = _generate_timestamp() - $this->sess_length;
			
			$this->db->where('date <', $expire);
			$this->db->delete($this->cart_table);
			
			log_message('debug', 'cart_maintenance performed');
		}    
	}
	
	// ------------------------------------------------------------------------	

}
?>