<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - commissions_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for generating commissions
|
*/

class Commissions_Model extends Model {
	
	function _add_commission($data = '')
	{
		$data = $this->db_validation_model->_clean_data($data);
		
		//insert into db
		if (!$this->db->insert('affiliate_commissions', $data))
		{
			show_error($this->lang->line('could_not_add_commission'));
			
			//log error
			log_message('error', 'Could not insert commission into commissions table');
			
			return false;
		}
		else
		{
			$data['comm_id']= $this->db->insert_id();
			
			//log success
			log_message('info', 'commission '. $data['comm_id'] . ' inserted into commissions table');
		}
		
		return $data;
	}

	
	// ------------------------------------------------------------------------
	
	function _update_invoice_commissions($id = '', $type = '') //update commissions associated with invoice on refund
	{
		if ($type != 'none')
		{
			//set the arrays
			$paid_comms = array();
			$unpaid_comms = array();
		
			//get all commissions associated with invoice
			$this->db->where('invoice_id', $id);
			$query = $this->db->get('affiliate_commissions');
			
			if ($query->num_rows() > 0)
			{
				//sort commissions
				foreach ($query->result_array() as $row)
				{
					if ($row['comm_status'] == 'paid')
					{
						array_push($paid_comms, $row);
					}
					else
					{
						array_push($unpaid_comms, $row);
					}
				}
				//echo '<pre>'; print_r($unpaid_comms); exit();
				//let's process the unpaid commissions first
				
				if (count($unpaid_comms) > 0)
				{
					$comm_ids = array();
					foreach ($unpaid_comms as $v)
					{
						array_push($comm_ids, $v['comm_id']);
					}
					
					$this->_change_status($comm_ids, $type);
				}
				
				//now lets do the paid commissions
				
				//we need to create a reverse entry for this since the commission is already paid
				
				if (count($paid_comms) > 0)
				{
					foreach ($paid_comms as $v)
					{
						$reverse = array(	'member_id' 			=> 			$v['member_id'],			
											'invoice_id'			=>			$id,
											'comm_status'			=>			'unpaid',
											'approved'				=>			'1',
											'date'					=>			_generate_timestamp(),
											'commission_amount'		=>			'-' . $v['commission_amount'],
											'sale_amount'			=>			'0',
											'commission_level'		=>			$v['commission_level'],
											'referrer'				=>			'',
											'trans_id'				=>			$this->lang->line('commission_reversal') . ' - ' . $v['comm_id'],
											'ip_address'			=>			$v['ip_address'],
											'date_paid'				=>			'',
											'commission_notes'		=>			$this->lang->line('commission_reversal'),
											'performance_paid'		=>			'1',
											'email_sent'			=>			'1',
								);	
			
						//add the commission
						$this->_add_commission($reverse);
					}
				}
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _auto_approve_commissions($day = '')
	{
		//get all commissions
		
		$time = _generate_timestamp() - ($day * 60 * 60 * 24);
		 
		$this->db->where('approved', '0');
		$this->db->where('date <=', $time);
		$query = $this->db->get('affiliate_commissions');
		
		if ($query->num_rows() > 0)
		{
			$i = 0;
			
			foreach ($query->result_array() as $row)
			{
				//now approve it
				$array = array('approved' => '1', 'comm_status' => 'unpaid');
				$this->db->where('comm_id', $row['comm_id']);
				$this->db->update('affiliate_commissions', $array);
			
				$i++;
			}
			
			return $i .' affiliate commissions auto-approved';
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_status($data = '', $type = '0')
	{

		foreach ($data as $id)
		{
			
			$this->db->where('comm_id', $id);
			
			if ($type == 'delete')
			{
				$this->_delete_commission((int)($id));
			}
			else
			{
				//update member in db
				if ($type == 'pending')
				{
					$data = array('comm_status' => $type);
				}
				elseif ($type == 'unpaid')
				{
					$data = array('comm_status' => $type);
				}
				else
				{
					$data = array('approved' => $type,
								  'comm_status'	=> 'unpaid',
								 );
				}
				
				
				
				if (!$this->db->update('affiliate_commissions', $data))
				{
					show_error($this->lang->line('could_not_update_commission'));
					
					//log error
					log_message('error', 'Could not update commission ID #' . $id . ' in commissions table');
					return false;
				}
				
				//log success
				log_message('info', 'Status Changed for commission ID# ' . $id);
			}
			
		}
		
		return true;		
	}
	
	// ------------------------------------------------------------------------
	
	function _get_default_comm_amounts()
	{
		//get the default commission amounts for non-group members
		$default_comms = $this->db_validation_model->_get_details('affiliate_groups' , '*', 'group_id', '1');
				
		$comms = $default_comms[0];
	
		return $comms;
	}
	
	// ------------------------------------------------------------------------
	
	function _calculate_commission($type = '', $level = '', $level_amount = '', $subtotal = '', $initial = '')
	{
		//check if you need to use the default commissions
		if (empty($level_amount))
		{
			$defaults = $this->_get_default_comm_amounts();
			$level_amount = $defaults['commission_level_' . $level];
			$type = $defaults['commission_type'];
		}
		
		if ($this->config->item('member_enable_bilevel_affiliate_groups') == true)
		{
			//explode the levels
			$a = explode('/', $level_amount);
			$level_amount = $a[0];
			if ($initial == 'update' && !empty($a[1]))
			{
				$level_amount = $a[1];	
			}
		}
		
		if ($type == 'percent')
		{
			$amount = $level_amount * $subtotal;
		}
		else
		{
			$amount = $level_amount;
		}
		
		return $amount;
	}
	 
	// ------------------------------------------------------------------------
	
	function _get_commissions_for_bonus($type = '', $mid = '')
	{
		//get only commissions that have not been calculated for performance
		$this->db->where('performance_paid', '0'); 
		$this->db->where('member_id', $mid);
		
		switch ($type)
		{
			case 'commission_amount':
			
				$this->db->select_sum('commission_amount');
			
			break;
			
			case 'sales_amount':
			
			break;
		
		}
		
		$query = $this->db->get('affiliate_commissions');
		
		$a = $query->result_array();
	
		return $a[0]['commission_amount'];
	}
	
	// ------------------------------------------------------------------------
	
	function _upgrade_bonus_group($mid = '')
	{
		$this->db->where('member_id', $mid);
		$this->db->where('group_type', 'affiliate');
		$this->db->join('affiliate_groups', 'affiliate_groups.group_id = members_groups.group_id', 'left');
		$query = $this->db->get('members_groups');
		
		$group = $query->result_array();
		
		//current tier is
		$tier = $group[0]['tier'];
		
		//next tier
		$next = $tier + 1;
		
		//see if the tier is still available
		$this->db->where('tier', $next);
		$query = $this->db->get('affiliate_groups');
		
		if ($query->num_rows() > 0)
		{
			$new = $query->result_array();
			
			//update the user's group
			$sdata = array('group_id' => $new[0]['group_id']);
			
			$this->db->where('member_id', $mid);
			$this->db->where('group_type', 'affiliate');
			$this->db->update('members_groups', $sdata);
		
			return $new[0];
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _update_commissions_for_bonus($mid = '')
	{
		$this->db->where('performance_paid', '0'); 
		$this->db->where('member_id', $mid);
		
		$sdata = array('performance_paid' => '1');
		
		if ($this->db->update('affiliate_commissions', $sdata))
		{
			return true;
		}
	
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _delete_commission($id = '')
	{
		//delete commission
		$this->db->where('comm_id', $id);
		if ($this->db->delete('affiliate_commissions'))
		{
			
			//log success
			log_message('info', 'commission ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_commission'));
			
			//log error
			log_message('error', 'commission ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}	
	
	// ------------------------------------------------------------------------

	function _get_commission_details($id = '')
	{
		//get the data from commissions table
		$sql = 'SELECT ' . $this->db->dbprefix('affiliate_commissions') . '.*,
						(SELECT username from ' . $this->db->dbprefix('members') . ' 
						WHERE ' . $this->db->dbprefix('affiliate_commissions') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id) as username
						FROM ' . $this->db->dbprefix('affiliate_commissions') . '
						WHERE comm_id = \'' . $id . '\'';
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		else
		{
			return false;
		}
	}
	
	
	// ------------------------------------------------------------------------
	
	function _get_commissions($limit = 25, $offset = 0, $sort_column = '', $sort_order = '',  $where_column = '', $where_value = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_afc_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_afc_column');

		if ($where_column == 'search')
		{
			$sql = 'SELECT ' . $this->db->dbprefix('affiliate_commissions') . '.*, ' . $this->db->dbprefix('members') . '.*
						FROM ' . $this->db->dbprefix('affiliate_commissions') . '
						JOIN ' . $this->db->dbprefix('members') . ' ON ' .
						$this->db->dbprefix('affiliate_commissions') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id
						WHERE ' . $this->db->dbprefix('affiliate_commissions') . '.trans_id LIKE \'%' . $where_value .'%\'
						OR ' . $this->db->dbprefix('affiliate_commissions') . '.commission_amount LIKE \'%' . $where_value .'%\'
						OR ' . $this->db->dbprefix('affiliate_commissions') . '.sale_amount LIKE \'%' . $where_value .'%\'
						OR ' . $this->db->dbprefix('members') . '.fname LIKE \'%' . $where_value .'%\'
						OR ' . $this->db->dbprefix('members') . '.lname LIKE \'%' . $where_value .'%\'
						OR ' . $this->db->dbprefix('members') . '.username LIKE \'%' . $where_value .'%\'
						ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;

		}
		else
		{
			if (!empty($where_value))
			{
				$sql = 'SELECT ' . $this->db->dbprefix('affiliate_commissions') . '.*,
						(SELECT username from ' . $this->db->dbprefix('members') . ' 
						WHERE ' . $this->db->dbprefix('affiliate_commissions') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id) as username
						FROM ' . $this->db->dbprefix('affiliate_commissions') . '
						WHERE comm_status = \'' . $where_value . '\'';
						
				if (!empty($where_column))
				{
					$sql .= ' AND member_id = \'' . $where_column . '\'';
				}
				
				$sql .= ' ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
			}
			else
			{
				$sql = 'SELECT ' . $this->db->dbprefix('affiliate_commissions') . '.*,
						(SELECT username from ' . $this->db->dbprefix('members') . ' 
						WHERE ' . $this->db->dbprefix('affiliate_commissions') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id) as username
						FROM ' . $this->db->dbprefix('affiliate_commissions');
						
				if (!empty($where_column))
				{
					$sql .= ' WHERE member_id = \'' . $where_column . '\'';
				}
				
				$sql .= ' ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
			}
		}
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}

	// ------------------------------------------------------------------------
	
	function _update_commission($id = '')
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		$use_group_defaults = $data['use_group_defaults'];
		$referring_affiliate = $data['referring_affiliate'];
		
		unset($data['use_group_defaults']);
		unset($data['referring_affiliate']);
		
		//set up dates
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		switch ($fdate[0])
		{
			case 'mm/dd/yyyy':
					
				if (!empty($data['date']))
				{
					//format date
					$pub = explode('/', $data['date']);
					$data['date'] = mktime(date('H'),date('i'),date('s'), $pub[0], $pub[1], $pub[2]);
				}
				
				if (!empty($data['date_paid']))
				{
					//format date
					$pub = explode('/', $data['date_paid']);
					$data['date_paid'] = mktime(date('H'),date('i'),date('s'), $pub[0], $pub[1], $pub[2]);
				}
				
			break;
		}
				
		
		//get referring affiliate details
		$member = $this->db_validation_model->_get_details('members', '*', 'username', $referring_affiliate);
		$data['member_id'] = $member[0]['member_id'];
		
		//calculate the amounts from the affiliate group
		if ($use_group_defaults == 1)
		{
			//get referring affiliate's group data
			$this->db->join('affiliate_groups', 'affiliate_groups.group_id = members_groups.group_id', 'left');
			$this->db->where('group_type', 'affiliate');
			$this->db->where('member_id', $data['member_id']);
			
			$query = $this->db->get('members_groups');
		
			$group = $query->result_array();
			
			if ($group[0]['commission_type'] == 'percent')
			{
				$level = $data['commission_level'];
				$data['commission_amount'] = $data['sale_amount'] * $group[0]['commission_level_' . $level];
			}
			else
			{
				$data['commission_amount'] = $group[0]['commission_level_' . $level];
			}
		}

		//update commission data
		$this->db->where('comm_id', $id);
		
		if (!$this->db->update('affiliate_commissions', $data))
		{
			show_error($this->lang->line('could_not_update_commission'));
			
			//log error
			log_message('error', 'Could not update commission ID ' . $id . 'in commissions table');
			
			return false;
		}
		else
		{
			
			//log success
			log_message('info', 'commission ID '. $id . ' updated in commissions table');
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_user_commissions($id = '', $limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $num_options = '', $where_value = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_afc_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_afc_column');
		
		$sql = 'SELECT ' . $this->db->dbprefix('affiliate_commissions') . '.*
						FROM ' . $this->db->dbprefix('affiliate_commissions') . '
						WHERE member_id = \'' . $id . '\'';
			
		if ($where_value == 'unpaid')
		{	
			if ($this->config->item('sts_affiliate_show_pending_comms_members') == 1)
			{
				$sql .= ' AND comm_status != \'paid\' ';	
			}
			else
			{
				$sql .= ' AND comm_status = \'unpaid\' ';
			}
		}
		elseif ($where_value == 'paid')
		{
			$sql .= ' AND comm_status = \'paid\' ';	
		}
		else
		{
			if ($this->config->item('sts_affiliate_show_pending_comms_members') == 0)
			{
				$sql .= ' AND comm_status != \'pending\' ';	
			}
		}		
		$sql .= ' ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
		
			$a['commissions'] = array();
			
			foreach ($query->result_array() as $row)
			{
				$row['s_commission_amount'] = format_amounts($row['commission_amount'], $num_options);
				$row['s_sale_amount'] = format_amounts($row['sale_amount'], $num_options);
				$row['s_date'] = _show_date($row['date']);
				$row['s_date_paid'] = _show_date($row['date_paid']);
				$row['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				$row['s_referrer'] = limit_chars($row['referrer'], 50);
				$row['s_commission_notes'] = nl2br($row['commission_notes']);
				$row['s_approved'] = $row['approved'] == '1' ? 'tick' : 'warning1';
				
				
				
				array_push($a['commissions'], $row);
			}
			
			//get total rows
			$this->db->where('member_id', $id);
			
			if ($where_value == 'unpaid')
			{				
				if ($this->config->item('sts_affiliate_show_pending_comms_members') == 1)
				{
					$this->db->where('comm_status !=', 'paid');
				}
				else
				{
					$this->db->where('comm_status', 'unpaid');
				}
			}
			elseif ($where_value == 'paid')
			{
				$this->db->where('comm_status', 'paid');
			}
			else
			{
				if ($this->config->item('sts_affiliate_show_pending_comms_members') == 0)
				{
					$this->db->where('comm_status !=', 'pending');
				}
			}
		
			$this->db->from('affiliate_commissions');
			
			$a['total_rows'] = $this->db->count_all_results();
			
			return $a;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_commissions($sdata = '', $mid = '', $admin_users = '', $num_options = '', $members = '', $initial = '')
	{
		if (!empty($members))
		{
			/*
			| ----------------------------------------------------
			| Give out commissions for all ACTIVE upline members
			| ----------------------------------------------------
			*/
			
			//lets check if there is a coupon code
			if (!empty($sdata['inv']['coupon_code']))
			{
				$coupon_details = $this->coupons->_get_coupon_details($sdata['inv']['coupon_code'], 'coupon_code');
			}
			
			//get the discount group $sdata['inv']
			$disc_group = $this->groups_model->_check_user_group('discount', $sdata['inv']['member_id']);
						
			//start the member loop of upline
			foreach ($members as $k => $v) //loop through each member of the upline
			{
				if ($this->config->item('sts_affiliate_restrict_self_commission') == 1)
				{
					if ($mid == $v['member_id']) continue;
				}
				
				if ($v['status'] == 1 && $v['enable_affiliate_marketing'] != '0') //only add a commission if the member has an active status
				{
					//set commission defaults
					$commission_level = $k; //commission level
					
					
					//set the commission status
					switch ($this->config->item('sts_affiliate_new_commission'))
					{
						case 'no_pending':
						case 'alert_pending':
							
							$comm_status = 'pending';
							
						break;
						
						case 'no_unpaid':
						case 'alert_unpaid':
						
							$comm_status = 'unpaid';
							
						break;
					}
					
					/*
					| -------------------------------------------------------------
					| Check if we're paying commissions per product or total sale
					| -------------------------------------------------------------
					*/
						
					//first check if commission is total sale or per product
					if ($this->config->item('sts_affiliate_total_sale_commissions') == 'total_sale')
					{
						//generate a commission for all products in one invoice
					
						//set the commission notes
						$comm_notes = $this->lang->line('products_purchased_on_commission') . ":\n";
						
						//loop through the products to add to the commission notes
						foreach ($sdata['prod'] as $product)
						{
							$comm_notes .= $this->lang->line('id') . " - " . $product['product_id'] . " " . $product['product_name'] . "\n";
						}
						
						/*
						| -------------------------------------------------------------
						| Finally, let's add a commission for TOTAL SALE ONLY
						| -------------------------------------------------------------
						*/
						
						//calculate the commission amount
						if ($commission_level > 1)
						{
							$sale_amount = '0.00';
						}
						else
						{
							$sale_amount = $sdata['inv']['sub_total'] - $sdata['inv']['discount_amount'];
						}
						
						$calc_total = $sdata['inv']['sub_total'] - $sdata['inv']['discount_amount'];
						
						$comm_amount = $this->_calculate_commission($v['commission_type'], $commission_level, $v['commission_level_' . $k], $calc_total, $initial); 
						
						
					
						if ($comm_amount > 0 )
						{
							//set all the required data
							$insert = array(	'member_id' 		=> 			$v['member_id'],			
												'invoice_id'		=>			$sdata['invoice_id'],
												'comm_status'		=>			$comm_status,
												'approved'			=>			'0',
												'date'				=>			$sdata['payment_date'],
												'commission_amount'	=>			$comm_amount,
												'sale_amount'		=>			$sale_amount,
												'commission_level'	=>			$commission_level,
												'referrer'			=>			'',
												'trans_id'			=>			$sdata['transaction_id'],
												'ip_address'		=>			$this->input->ip_address(),
												'date_paid'			=>			'',
												'commission_notes'	=>			$comm_notes,
												'performance_paid'	=>			'0',
												'email_sent'		=>			'0',
											);	
						
							//add the commission
							$this->_add_commission($insert);
						
						
							/*
							| -------------------------------------------------------------
							| Send out an alert email to the user 
							| -------------------------------------------------------------
							*/
			
							//send out alert email if set
							if ($this->config->item('sts_affiliate_new_commission') == 'alert_pending' || $this->config->item('sts_affiliate_new_commission') == 'alert_unpaid')
							{
								if ($v['alert_new_commission'] != '0') //send out the email only if the user wants it
								{
									$v['commission_amount'] = format_amounts($comm_amount, $num_options);
									$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_commission_generated_template', true);
								}
							}
							
							//send out admin alerts for new commission
							foreach ($admin_users as $admin_user)
							{
								if ($admin_user['alert_affiliate_commission'] == 1) //send out the admin alert
								{
									$admin_user['member_username'] = $v['username'];
									$admin_user['commission_amount'] = format_amounts($comm_amount, $num_options);
									$this->emailing_model->_send_template_email('admin', $admin_user, 'admin_affiliate_commission_generated_template', true);
								}
							}
						}
					
					/*
					| -------------------------------------------------------------
					| Process commissions per product instead
					| -------------------------------------------------------------
					*/
					
					}
					else //generate a commission per product
					{
						//generate a commission for each product
						foreach ($sdata['prod'] as $prod => $value)
						{
							//write the commission notes
							$comm_notes = $this->lang->line('products_purchased_on_commission') . ":\n";
							$comm_notes .= $this->lang->line('id') . " - " . $value['product_id'] . " " . $value['product_name'] . "\n";
							
							//check if the product gives out commissions
							if ($value['no_commission'] == '0')
							{
								if ($value['enable_custom_commission'] == '1')
								{
									//get the custom commissions for this product
									$this->db->where('product_id', $value['product_id']);
									$this->db->where('group_id', $v['group_id']);
									$query = $this->db->get('products_to_aff_groups');
									
									if ($query->num_rows() > 0) //if there are custom commissions set it now
									{
										$x = $query->result_array();
										
										$level_amount = $x[0]['commission_level_' . $commission_level];
										
										//echo $value['product_name'] . '= ' . $commission_level . '-' . $level_amount. '<br />';
									}
									else
									{
										$level_amount = $v['commission_level_' . $commission_level];
									}
								}
								else //generate regular group commission
								{
									$level_amount = $v['commission_level_' . $commission_level];
								}
								
								/*
								| -------------------------------------------------------------
								| Finally, let's add a commission for EACH PRODUCT
								| -------------------------------------------------------------
								*/
								
								//check for coupon code
								if (!empty($coupon_details) && $coupon_details['coupon_type'] == 'percent')
								{
									//calculate the new amount
									$disc_amount = $value['unit_price'] * $coupon_details['coupon_amount'];
									$uprice = $value['unit_price'] - $disc_amount;
								}
								else
								{
									$uprice = $value['unit_price'];				
								}
								
								//now check for discounts per product
								if (!empty($disc_group['group_id']))
								{
									$this->db->where('product_id', $value['product_id']);
									$this->db->where('group_id', $disc_group['group_id']);
									$cquery = $this->db->get('products_to_disc_groups');
									
									if ($cquery->num_rows() > 0)
									{
										$cdisc = $cquery->row_array();
										if (!empty($cdisc['amount']))
										{
											$disc_group['discount_group_amount'] = $cdisc['amount'];
										}
									}
								}
									
								//now check for discounts per product
								if (!empty($disc_group['discount_group_amount']) && $disc_group['discount_group_amount'] > '0')
								{
									//calculate the discounts now per product for pecentage only
									if ($disc_group['percentage'] == 1)
									{
										$uprice = $uprice - round($uprice * $disc_group['discount_group_amount'], 2);
									}
									else
									{
										$uprice = $uprice - $disc_group['discount_group_amount'];
									}
									
								}
								
								//calculate the commission amount
								$comm_amount = $this->_calculate_commission($v['commission_type'], $commission_level, $level_amount, $uprice, $initial);				
								
								//calculate commissions for each quantity ordered
								$v['commission_amount'] = $comm_amount * $value['quantity'];
								
								$email_sent = 1;
								
								if ($commission_level > 1)
								{
									$sale_amount = '0.00';
								}
								else
								{
									$sale_amount = $value['quantity'] *  $uprice;
								}
								
								if ($v['commission_amount'] > 0)
								{
									//set all the required data
									$insert = array(	'member_id' 		=> 			$v['member_id'],			
														'invoice_id'		=>			$sdata['invoice_id'],
														'comm_status'		=>			$comm_status,
														'approved'			=>			'0',
														'date'				=>			$sdata['payment_date'],
														'commission_amount'	=>			$v['commission_amount'],
														'sale_amount'		=>			$sale_amount,
														'commission_level'	=>			$commission_level,
														'referrer'			=>			'',
														'trans_id'			=>			$sdata['transaction_id'],
														'ip_address'		=>			$this->input->ip_address(),
														'date_paid'			=>			'',
														'commission_notes'	=>			$comm_notes,
														'performance_paid'	=>			'0',
														'email_sent'		=>			$email_sent,
													);	
								
									//add the commission
									$this->_add_commission($insert);
									
									/*
									| -------------------------------------------------------------
									| Send out an alert email to the user 
									| -------------------------------------------------------------
									*/
									
									$comm_amount = $v['commission_amount'];
										
									//send out alert email if set
									if ($this->config->item('sts_affiliate_new_commission') == 'alert_pending' || $this->config->item('sts_affiliate_new_commission') == 'alert_unpaid')
									{
										if ($v['alert_new_commission'] != '0') //send out the email only if the user wants it
										{
											$v['commission_amount'] = format_amounts($comm_amount, $num_options);
											$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_commission_generated_template', true);
										}
									}
									
									//send out admin alerts for new commission
									foreach ($admin_users as $admin_user)
									{
										if ($admin_user['alert_affiliate_commission'] == 1) //send out the admin alert
										{
											$admin_user['member_username'] = $v['username'];
											$admin_user['commission_amount'] = format_amounts($comm_amount, $num_options);
											$this->emailing_model->_send_template_email('admin', $admin_user, 'admin_affiliate_commission_generated_template', true);
										}
									}
								}
							}
						}
					}
					
					
					
					
					/*
					| -------------------------------------------------------------
					| Let's see if the user gets any performance bonuses
					| -------------------------------------------------------------
					*/
					
					//check performance bonuses
					if ($this->config->item('sts_affiliate_enable_performance_bonus') == 1)
					{
						//generate bonuses if any
						$unpaid_bonus = $this->_get_commissions_for_bonus($this->config->item('sts_affiliate_performance_bonus_required'), $v['member_id']);
						
						//calculate whether the user has made enough commissions
						if ($unpaid_bonus >= $this->config->item('sts_affiliate_performance_bonus_required_amount'))
						{
							/*
							| -------------------------------------------------------------
							| Should we give them a bonus amount or upgrade the group?
							| -------------------------------------------------------------
							*/
						
							//check if performance is group upgrade or an amount
							if ($this->config->item('sts_affiliate_performance_bonus_type') == 'payment_amount')
							{
								//insert a commission amount
								
								$comm_notes = $this->lang->line('performance_bonus_earned') . "\n";
								$v['bonus_amount'] = format_amounts($this->config->item('sts_affiliate_performance_bonus_amount'), $num_options);
								
								//set all the required data
								$new_bonus = array(	'member_id' 		=> 			$v['member_id'],			
													'invoice_id'		=>			'0',
													'comm_status'		=>			$comm_status,
													'approved'			=>			'0',
													'date'				=>			$sdata['payment_date'],
													'commission_amount'	=>			$this->config->item('sts_affiliate_performance_bonus_amount'),
													'sale_amount'		=>			'0',
													'commission_level'	=>			'1',
													'referrer'			=>			'',
													'trans_id'			=>			$this->lang->line('trans_id_performance_bonus'),
													'ip_address'		=>			$this->input->ip_address(),
													'date_paid'			=>			'',
													'commission_notes'	=>			$comm_notes,
													'performance_paid'	=>			'1',
													'email_sent'		=>			'1',
												);	
							
								//add the commission
								$this->_add_commission($new_bonus);
								
								if ($this->config->item('sts_affiliate_new_commission') == 'alert_pending' || $this->config->item('sts_affiliate_new_commission') == 'alert_unpaid')
								{
									//send out alerts
									if ($v['alert_new_commission'] != '0') //only send out the email if the user allows it
									{
										$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_bonus_amount_template', true);
									}
								}
								
								//send out admin alerts for new commission
								foreach ($admin_users as $admin_user)
								{
									if ($admin_user['alert_affiliate_commission'] == 1) //send out the admin alert
									{
										$admin_user['member_username'] = $v['username'];
										$admin_user['commission_amount'] = $v['bonus_amount'];
										$this->emailing_model->_send_template_email('admin', $admin_user, 'admin_affiliate_commission_generated_template', true);
									}
								}
							}
							else //upgrade to group
							{
								$group_upgrade = $this->_upgrade_bonus_group($v['member_id']);
								
								if (!empty($group_upgrade))
								{
									$v['upgraded_affiliate_group'] = $group_upgrade['aff_group_name'];
									
									if ($this->config->item('sts_affiliate_new_commission') == 'alert_pending' || $this->config->item('sts_affiliate_new_commission') == 'alert_unpaid')
									{	
										//send out alerts
										if ($v['alert_new_commission'] != '0')
										{
											$this->emailing_model->_send_template_email('member', $v, 'member_affiliate_performance_group_upgrade_template', true);
										}
									}
								}
							}
							
							/*
							| -------------------------------------------------------------
							| Let's mark all the commissions paid for bonuses now
							| -------------------------------------------------------------
							*/
							
							//now mark all commissions to performance paid
							$this->_update_commissions_for_bonus($v['member_id']);	
						}
					}
				}
			}	
		}
	}
}
?>