<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - content_comments_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing the product content_comments
|
*/

class Content_Comments_Model extends Model {	
	
	function _add_content_comment($id = '')
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		$data['article_id'] = $id;
		$data['date'] = _generate_timestamp();
		
		//insert into db
		if (!$this->db->insert('content_comments', $data))
		{
			show_error($this->lang->line('could_not_add_content_comment'));
			
			//log error
			log_message('error', 'Could not insert comment into content_comments table');
			
			return false;
		}
		else
		{
			$content_comment_id = $this->db->insert_id();
			
			//log success
			log_message('info', 'comment '. $content_comment_id . ' inserted into content_comments table');
		}
		
		return $content_comment_id;
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_status($data = '', $type = '0')
	{

		foreach ($data as $id)
		{
			
			$this->db->where('id', $id);
			
			if ($type == 'delete')
			{
				$this->_delete_content_comment((int)($id));
			}
			else
			{
				//update member in db
				
				$data = array(
								'status' => $type,
							);
				
				if (!$this->db->update('content_comments', $data))
				{
					show_error($this->lang->line('could_not_update_content_comment'));
					
					//log error
					log_message('error', 'Could not update content_comment ID #' . $id . ' in products_content_comments table');
					return false;
				}
				
				//log success
				log_message('info', 'Status Changed for content_comment ID# ' . $id);
			}
			
		}
		
		return true;		
	}
	
	
	// ------------------------------------------------------------------------	
	
	function _update_comment($id = '')
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		$this->db->where('id', $id);
		if (!$this->db->update('content_comments', $data))
		{
			show_error($this->lang->line('could_not_update_content_comment'));
			
			//log error
			log_message('error', 'Could not update content_comment into content_comments table');
			
			return false;
		}
		else
		{
			$content_comment_id = $this->db->insert_id();
			
			//log success
			log_message('info', 'content_comment '. $content_comment_id . ' updated in content_comments table');
		}
		
		return $content_comment_id;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_content_comment_details($id = '')
	{
		$sql = 'SELECT ' . $this->db->dbprefix('content_comments') . '.*,
				(SELECT username from ' . $this->db->dbprefix('members') . ' 
				WHERE ' . $this->db->dbprefix('content_comments') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id) as member,
				(SELECT content_title from ' . $this->db->dbprefix('content_articles') . ' 
				WHERE ' . $this->db->dbprefix('content_comments') . '.article_id = ' . $this->db->dbprefix('content_articles') . '.article_id) as title
				FROM ' . $this->db->dbprefix('content_comments') . '
				WHERE ' . $this->db->dbprefix('content_comments') . '.id = ' . $id;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_content_comment($id = '')
	{
		$this->db->where('id', $id);
		
		
		if ($query = $this->db->delete('content_comments'))
		{
			return true;
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_content_comments($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $where_column = '', $where_value = '')
	{
		//get all the products from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_com_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_com_column');
		
		if (!empty($where_column) && !empty($where_value))
		{
		
		$sql = 'SELECT ' . $this->db->dbprefix('content_comments') . '.*,
				(SELECT username from ' . $this->db->dbprefix('members') . ' 
				WHERE ' . $this->db->dbprefix('content_comments') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id) as member,
				(SELECT content_title from ' . $this->db->dbprefix('content_articles') . ' 
				WHERE ' . $this->db->dbprefix('content_comments') . '.article_id = ' . $this->db->dbprefix('content_articles') . '.article_id) as title
				FROM ' . $this->db->dbprefix('content_comments') . '
				WHERE ' . $this->db->dbprefix('content_comments') . '.article_id = ' . $where_value . ' 
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}
		else
		{
			$sql = 'SELECT ' . $this->db->dbprefix('content_comments') . '.*,
				(SELECT username from ' . $this->db->dbprefix('members') . ' 
				WHERE ' . $this->db->dbprefix('content_comments') . '.member_id = ' . $this->db->dbprefix('members') . '.member_id) as member,
				(SELECT content_title from ' . $this->db->dbprefix('content_articles') . ' 
				WHERE ' . $this->db->dbprefix('content_comments') . '.article_id = ' . $this->db->dbprefix('content_articles') . '.article_id) as title
				FROM ' . $this->db->dbprefix('content_comments') . '
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}	
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------
	
	
}
?>