<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - gateways_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for gateways
|
*/

class Gateways_Model extends Model {

	function _check_config($id = '')
	{
		$this->db->where('module_id', $id);
		$this->db->where('module_type', 'payment_gateway');
		$query = $this->db->get('modules');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_signup_link($m = '')
	{
		
		if ($this->config->item('gateway_signup_link_' . $m))
		{
        	echo'<label class="tooltip">
            <a href="' . jrox_admin_url() . 'gateways/signup_link/' . $m . '" target="_blank">
            <img src="' . base_url() . 'themes/admin/' . $this->config->item('sts_admin_layout_theme') . '/images/favorites.png" alt="" width="16" height="16" style="vertical-align:middle" />            </a>
            <span>' . $this->lang->line('signup_for_an_account') . '</span></label>';
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_module_key($key = '')
	{
		$m = 'f01c1197ea83a07ca972939b68985824';
	
		if ($key == $m)
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_all_gateways($type = '')
	{
	
		$this->db->where('module_type', 'payment_gateway');
		$this->db->where('module_status', '1');
		$this->db->order_by('module_sort_order', 'ASC');
		$query = $this->db->get('modules');
		
		if ($query->num_rows() > 0)
		{
			if ($type == 'checkout' && $this->config->item('checkout_custom_payment_options'))
			{
				$rows = array();
				$types = explode(',', $this->config->item('checkout_custom_payment_options'));
				
				foreach ($query->result_array() as $row)
				{
					if (in_array($row['module_file_name'], $types))
					{
						array_push($rows, $row);	
					}
				}
				
				return $rows;
			}
			
			if ($type == 'memberships' && $this->config->item('membership_custom_payment_options'))
			{
				$rows = array();
				$types = explode(',', $this->config->item('membership_custom_payment_options'));
				
				foreach ($query->result_array() as $row)
				{
					if (in_array($row['module_file_name'], $types))
					{
						array_push($rows, $row);	
					}
				}
				
				return $rows;
			}
			
			return $query->result_array();
		}
		 
		return  false;
	}
	

	// ------------------------------------------------------------------------	
	
	function _get_gateways_details($id = '')
	{
		//$this->db->join('settings', 'gateways.gateways_id = settings.settings_group');
		$this->db->where('module_id', $id);
		$this->db->where('module_type', 'payment_gateway');
		$query = $this->db->get('modules');
		
		if ($query->num_rows() > 0)
		{
			$row = $query->result_array();	
			
			$row[0]['sts_config'] = array();
			
			//get any configs
			$this->db->where('settings_module', 'payment_gateway');
			$this->db->where('settings_group', $id);
			$this->db->order_by('settings_sort_order', 'ASC');
			$query = $this->db->get('settings');
		
			//add the options to the config array
			foreach ($query->result_array() as $options)
			{
				array_push($row[0]['sts_config'], $options);
			}
			
			return $row;
		}
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_gateways($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_pgw_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_pgw_column');
		
		//$this->db->join('admin_permissions', 'admin_users.admin_id = admin_permissions.admin_id');
		$this->db->order_by($sort_column, $sort_order); 	
		$this->db->where('module_type', 'payment_gateway');
		$query = $this->db->get('modules', $limit, $offset);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_sort_order()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		foreach ($data as $k => $v)
		{
			if (strstr($k, "gateways") == true) 
			{
				$id = explode("-", $k);
			
				$this->db->where('module_id', $id[1]);
			
				//update member in db
					
				$data = array('module_sort_order' => $v);
				$this->db->where('module_type', 'payment_gateway');
				
				if (!$this->db->update('modules', $data))
				{
					show_error($this->lang->line('could_not_update_gateways'));
					
					//log error
					log_message('error', 'Could not update gateways #' . $k . ' in gateways table');
					return false;
				}
			}
		}
		
		//make sure tiers are numbered sequentially
		$this->db_validation_model->_db_sort_order('modules', 'module_id', 'module_sort_order', 'module_type = \'payment_gateway\''); 
		
		return true;		
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_gateway()
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		$module_name = $data['module_name'];
		unset($data['module_name']);
		
		if ($this->db_validation_model->_update_db_settings($data))
		{
			//log success
			log_message('info', 'settings table updated successfully');
			
			//update module name
			$sdata = array('module_name' => $module_name);
			
			$this->db->where('module_id', (int)$this->uri->segment(4));
			$this->db->update('modules', $sdata);
		}
		else
		{
			show_error($this->lang->line('could_not_update_settings'));
			
			//log error
			log_message('error', 'Could not update settings table');
			
			return false;		
		}
		
		return true;
	}	
	
	// ------------------------------------------------------------------------	
	
}
?>