<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - global_discounts_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing global_discounts
|
*/

class Global_Discounts_Model extends Model {	

	function _get_global_discounts()
	{
		//get the data from global_discounts table
		$this->db->order_by('max_amount', 'ASC');
		$query = $this->db->get('global_discounts');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		else
		{
			return false;
		}
	}
	
	// ------------------------------------------------------------------------
	
	function _delete_global_discount($id = '')
	{
		$this->db->where('id', $id);
		
		if ($this->db->delete('global_discounts'))
		{
			
			//log success
			log_message('info', 'global_discounts #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_global_discount'));
			
			//log error
			log_message('error', 'global_discounts #' . $id . ' could not be deleted');
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _update_global_discounts($post_array)
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($post_array);
		
		foreach ($data as $k => $v)
		{
			if (preg_match('/min_amount-*/', $k)) 
			{	
				$array = explode('-', $k);
				
				$id = $array[1];
				
				if ($id == '0')
				{
					if (!empty($data['min_amount-0']) && !empty($data['max_amount-0']) && !empty($data['discount_amount-0']))
					{
						$data['status-0'] = (empty($data['status-0'])) ? '0' : $data['status-0'];
						
						$insert = array(
											'status' => $data['status-0'],
											'min_amount'	=>	$this->input->xss_clean($data['min_amount-0']),
											'max_amount'	=> $this->input->xss_clean($data['max_amount-0']),
											'discount_amount' => $this->input->xss_clean($data['discount_amount-0']),
											'discount_type' => $this->input->xss_clean($data['discount_type-0']),
											'status' => $this->input->xss_clean($data['status-0']),
										);
										
						$this->db->insert('global_discounts', $insert);
					}
				}
				else
				{
					if (!empty($data['min_amount-'. $id]) && !empty($data['max_amount-' . $id]) && !empty($data['discount_amount-'  . $id]))
					{
						$data['status-' . $id] = (empty($data['status-' . $id])) ? '0' : $data['status-' . $id];
						
						$update = array(
											'status' => $data['status-' . $id],
											'min_amount'	=>	$this->input->xss_clean($data['min_amount-' . $id]),
											'max_amount'	=> $this->input->xss_clean($data['max_amount-' . $id]),
											'discount_amount' => $this->input->xss_clean($data['discount_amount-' . $id]),
											'discount_type' => $this->input->xss_clean($data['discount_type-' . $id]),
											'status' => $this->input->xss_clean($data['status-' . $id]),
										);
						
						$this->db->where('id', $id);
						$this->db->update('global_discounts', $update);
					}
				}
			}	
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
}
?>