<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - manufacturers_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing manufacturers
|
*/

class Manufacturers_Model extends Model {	
	
	function _add_manufacturer()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		if (isset($data['userfile']))
		{	
			unset($data['userfile']);
		}
		
		//insert into db
		if (!$this->db->insert('manufacturers', $data))
		{
			show_error($this->lang->line('could_not_add_manufacturer'));
			
			//log error
			log_message('error', 'Could not insert manufacturer into manufacturers table');
			
			return false;
		}
		else
		{
			$manufacturer_id = $this->db->insert_id();
			
			//log success
			log_message('info', 'manufacturer '. $manufacturer_id . ' inserted into manufacturers table');
		}
		
		return $manufacturer_id;
	}
	
	// ------------------------------------------------------------------------
	
	function _delete_manufacturer($id = '')
	{
		if ($id == 1)
		{
			return false;
		}	
		
		//update manufacturers first
		$this->db->where('manufacturer_id', $id);
		$data = array('manufacturer_id' => 1);

		if ($this->db->update('products', $data))
		{
			//log success
			log_message('info', 'manufacturer ID #' . $id . ' updated successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_manufacturer'));
			
			//log error
			log_message('error', 'manufacturer ID #' . $id . ' could not be updated');
		}
	
		//delete photo if any
		
		//get manufacturer data
		$manufacturer_data = $this->_get_manufacturer_details($id);
		
		//check first if photo needs to be deleted
		if (!empty($manufacturer_data[0]['manufacturer_image']))
		{
			@unlink('./images/' . $this->config->item('images_manufacturers_dir') . '/' . $manufacturer_data[0]['manufacturer_image']);
		}
		
		//delete manufacturer
		$this->db->where('manufacturer_id', $id);
		if ($this->db->delete('manufacturers'))
		{
			
			//log success
			log_message('info', 'manufacturer ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_manufacturer'));
			
			//log error
			log_message('error', 'manufacturer ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}	
	
	// ------------------------------------------------------------------------
	
	function _get_all_manufacturers($sort_column = 'manufacturer_name', $sort_order = 'ASC', $active = false)
	{
		
		$sql = 'SELECT ' . $this->db->dbprefix('manufacturers') . '.*,
				(SELECT COUNT(*) FROM ' . $this->db->dbprefix('products') . ' 
				WHERE ' . $this->db->dbprefix('products') . '.manufacturer_id = ' . $this->db->dbprefix('manufacturers') . '.manufacturer_id
				AND product_status = \'1\'
				AND date_expires >= ' . now() . '
				AND date_available < ' . now() . ') as total
				FROM ' . $this->db->dbprefix('manufacturers');
		
		if ($active == true)
		{
			$sql .=  ' WHERE manufacturer_status = \'1\'';	
		}
		
			
		$sql .= ' ORDER BY ' . $this->db->dbprefix('manufacturers') . '.' . $sort_column . ' ' . $sort_order;
		
		$query = $this->db->query($sql);
	
		return $query->result_array();
	}
	
	// ------------------------------------------------------------------------

	function _get_manufacturer_details($id = '')
	{
		//get the data from manufacturers table
		$this->db->where('manufacturer_id', $id);
		$query = $this->db->get('manufacturers');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		else
		{
			return false;
		}
	}
	
	// ------------------------------------------------------------------------
	
	function _get_manufacturers($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_man_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_man_column');

		$sql = 'SELECT ' . $this->db->dbprefix('manufacturers') . '.*,
				(SELECT COUNT(*) from ' . $this->db->dbprefix('products') . ' 
				WHERE ' . $this->db->dbprefix('manufacturers') . '.manufacturer_id = ' . $this->db->dbprefix('products') . '.manufacturer_id) as total
				FROM ' . $this->db->dbprefix('manufacturers') . '
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}

	// ------------------------------------------------------------------------
	
	function _update_manufacturer()
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		if (isset($data['userfile']))
		{	
			unset($data['userfile']);
		}
		
		//get manufacturer data
		$manufacturer_data = $this->_get_manufacturer_details($data['manufacturer_id']);
		
		//check first if photo needs to be deleted
		if (empty($data['manufacturer_image']))
		{
			
			if (!empty($manufacturer_data[0]['manufacturer_image']))
			{
				@unlink('./images/' . $this->config->item('images_manufacturers_dir') . '/' . $manufacturer_data[0]['manufacturer_image']);
			}
		}
		
		//update manufacturer data
		$this->db->where('manufacturer_id', $data['manufacturer_id']);
		
		if (!$this->db->update('manufacturers', $data))
		{
			show_error($this->lang->line('could_not_update_manufacturer'));
			
			//log error
			log_message('error', 'Could not update manufacturer ID ' . $data['manufacturer_id'] . 'in manufacturers table');
			
			return false;
		}
		else
		{
			
			//log success
			log_message('info', 'manufacturer ID '. $data['manufacturer_id'] . ' updated in manufacturers table');
		}
		
		return $manufacturer_data[0];
	}
	
	// ------------------------------------------------------------------------	
}
?>