<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - marketing_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for affiliate and marketing tools
|
*/

class Marketing_Model extends Model {
	
	
	function _add_aff_ad_category() //add the affiliate ad category into db
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//insert into db
		if (!$this->db->insert('affiliate_ad_categories', $data))
		{
			//log error
			log_message('error', 'Could not insert category into affiliate ad categories table');
			return false;
		}
		
		//log success
		log_message('info', 'Affiliate Ad Category Added');
		return $this->db->insert_id();
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_aff_ad_category($acat_id = '') //delete an affiliat ad category
	{

		$this->db->where('acat_id', $acat_id);

		if (!$this->db->delete('affiliate_ad_categories'))
		{
			show_error($this->lang->line('lang_adm_could_not_delete_aff_ad_category'));

			//log error
			log_message('error', 'Could not delete affiliate ad category ID #' . $acat_id . ' in affiliate ad categories table');
			
			return false;
		}

		//log success
		log_message('info', 'Affiliate Ad Category ID #' . $acat_id . ' deleted');

		return true;	
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_aff_ad_categories($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the affiliate ad categories from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_aac_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_aac_column');
		
		$this->db->order_by($sort_column, $sort_order); 	
		$query = $this->db->get('affiliate_ad_categories', $limit, $offset);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}

		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_aff_ad_category($acat_id = '')
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//update admin in db
		$this->db->where('acat_id', $acat_id);
		
		if (!$this->db->update('affiliate_ad_categories', $data))
		{
			show_error($this->lang->line('lang_adm_could_not_update_affiliate_ad_categories'));
			
			//log error
			log_message('error', 'Could not update affiliate ad category ID #' . $acat_id . ' in affiliate_ad_categories table');
			return false;
		}
		
		//log success
		log_message('info', 'Affiliate Ad Category ID #' . $acat_id . ' updated');
		return $acat_id;
	}
	
	// ------------------------------------------------------------------------	
}
?>