<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_affiliate_marketing_html_ads_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for percent shipping
|
*/

class Module_Affiliate_Marketing_Html_Ads_Model extends Model {	
	
	function _install_jrox_module($id = '')
	{	
		//check admin session
		$this->security_model->_check_admin_session();
		
		$delete = 'DROP TABLE IF EXISTS ' . $this->db->dbprefix('affiliate_html_ads') . ';';
		
		$query = $this->db->query($delete);
		
		$sql = 'CREATE TABLE IF NOT EXISTS ' . $this->db->dbprefix('affiliate_html_ads') . ' (		  
				  id int(10) NOT NULL auto_increment,
				  status enum(\'0\',\'1\') NOT NULL default \'0\',
				  name varchar(255) NOT NULL,
				  html_ad_type text NOT NULL,
				  html_ad_body text NOT NULL,
				  enable_redirect enum(\'0\',\'1\') NOT NULL,
				  redirect_custom_url varchar(255) NOT NULL,
				  sort_order int(10) NOT NULL default \'0\',
				  notes text NOT NULL,
				  border_color varchar(25) NOT NULL,
				  bg_title_color varchar(25) NOT NULL,
				  font_title_color varchar(25) NOT NULL,
				  bg_body_color varchar(25) NOT NULL,
				  font_body_color varchar(25) NOT NULL,
				  html_ad_width int(10) NOT NULL,
				  PRIMARY KEY  (id),
				  KEY html_ad_name (name)
				) AUTO_INCREMENT=1;';
				
		$query = $this->db->query($sql);
		
		$sql = 'INSERT INTO ' . $this->db->dbprefix('settings') . ' 
				(settings_key, settings_value, settings_module, settings_type, settings_group, settings_sort_order, settings_function) 
				VALUES 
				(\'module_affiliate_marketing_html_ads_default_html_ad_width\', \'150\', \'affiliate_marketing\', \'text\', \'' . $id . '\', \'1\', \'none\'), 
				(\'module_affiliate_marketing_html_ads_default_border_color\', \'333333\', \'affiliate_marketing\', \'text\', \'' . $id . '\', \'1\', \'none\'), 
				(\'module_affiliate_marketing_html_ads_default_bg_title_color\', \'ffffff\', \'affiliate_marketing\', \'text\', \'' . $id . '\', \'2\', \'none\'), 
				(\'module_affiliate_marketing_html_ads_default_font_title_color\', \'333333\', \'affiliate_marketing\', \'text\', \'' . $id . '\', \'3\', \'none\'), 
				(\'module_affiliate_marketing_html_ads_default_bg_body_color\', \'ffffff\', \'affiliate_marketing\', \'text\', \'' . $id . '\', \'4\', \'none\'), 
				(\'module_affiliate_marketing_html_ads_default_font_body_color\', \'333333\', \'affiliate_marketing\', \'text\', \'' . $id . '\', \'5\', \'none\');';
		
		$query = $this->db->query($sql);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _add_html_ad()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		$data['sort_order'] = '1';
		
		$data['html_ad_body'] = _content_filter($data['html_ad_body']);
		
		//insert into db
		if (!$this->db->insert('affiliate_html_ads', $data))
		{
			show_error($this->lang->line('could_not_add_html_ad'));
			
			//log error
			log_message('error', 'Could not insert html_ad into html_ads table');
			
			return false;
		}
		else
		{
			$id = $this->db->insert_id();
			
			//log success
			log_message('info', 'html_ad '. $id . ' inserted into html_ads table');
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------	
	
	function _edit_html_ad($id = '')
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		$data['html_ad_body'] = _content_filter($data['html_ad_body']);
		
		//insert into db
		$this->db->where('id', $id);
		if (!$this->db->update('affiliate_html_ads', $data))
		{
			show_error($this->lang->line('could_not_update_html_ad'));
			
			//log error
			log_message('error', 'Could not update text link in affiliate_html_ads table');
			
			return false;
		}
		else
		{	
			//log success
			log_message('info', 'text link '. $id . ' updated into affiliate_html_ads table');
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------

	function _get_html_ad_details($id = '')
	{
		//get the data from html_ads table
		$this->db->where('id', $id);
		$query = $this->db->get('affiliate_html_ads');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		else
		{
			return false;
		}
	}
	
	function _generate_html_ad_code($code = '', $public = false)
	{
		$html = '';
		
		if ($code['html_ad_type'] == 'floating_div')
		{
		
			if ($public == true)
			{
				$html .= '<script language="JavaScript" type="text/javascript" src="' . base_url() . 'js/jquery.js"></script>
<script language="JavaScript" type="text/javascript" src="' . base_url() . 'js/common.js"></script>
<script language="JavaScript" type="text/javascript" src="' . base_url() . 'js/ui/ui.core.js"></script>
<script language="JavaScript" type="text/javascript" src="' . base_url() . 'js/ui/ui.draggable.js"></script>
<link rel="stylesheet" media="screen" type="text/css" href="' . base_url() . 'js/ui/ui.css" />
';
			}		
		
			$html .= '<script type="text/javascript">
							$(document).ready(function(){
							
								$(\'#text-ad-' . $code['id'] . '\').draggable();
								
								$(\'#show-ad\').click(function(){
									$(\'#text-ad-' . $code['id'] . '\').show(\'slow\');				
								});
								
								
								$(\'a#close-jrox-window\').click(function(){
									$(\'#text-ad-' . $code['id'] . '\').hide(\'slow\');
								})
							
							});
					</script>
					';
			
			$html .= '<div id="text-ad-' . $code['id'] . '" style="width:' . $code['html_ad_width'] . 'px;" class="jrox-bg-shadow">
			<div style="border: 1px solid #' . $code['border_color'] . '; background:#' . $code['bg_body_color'] . '; color:#' . $code['font_body_color'] . ';" class="jrox-ad-box">
			
			<div id="text-ad-' . $code['id'] . '-handle" style="background:#' . $code['bg_title_color'] . '; color:#' . $code['font_title_color'] . ';" class="jrox-close-ad">
			<div style="float:right"><a href="#" id="close-jrox-window" class="jrox-x-close">x</a></div>' . $code['name'] . '
			<div style="clear:both; height: 1px"></div>
			</div>
		   
		   ' . $code['html_ad_body'] . '
		   
		   <div style="clear:both; height: 1px"></div>
		   </div>
		   </div>';
		}
		else
		{
		
			$html .= ' <div id="text-ad-' . $code['id'] . '" style="width:' . $code['html_ad_width'] . 'px; border: 1px solid #' . $code['border_color'] . '; background:#' . $code['bg_body_color'] . '; color:#' . $code['font_body_color'] . ';" class="ad-box">
		   
		   ' . $code['html_ad_body'] . '
		   
		   <div style="clear:both; height: 1px"></div>
		   </div>';
		}
		
		return $html;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_html_ads($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $members = false, $mid = '')
	{
		//get all the html_ads from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_bnr_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_bnr_column');
		
		if ($members == true && !empty($mid))
		{
			$sql = 'SELECT ' . $this->db->dbprefix('affiliate_html_ads') . '.*,
					(SELECT COUNT(*) from ' . $this->db->dbprefix('traffic') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('traffic') . '.tool_id 
					AND ' . $this->db->dbprefix('traffic') . '.tool_type = \'html_ads\'
					AND member_id = \'' . $mid . '\') as clicks,';
					
			if ($this->config->item('sts_affiliate_show_pending_comms_members') == 1)
			{
				$sql .= ' (SELECT SUM(commission_amount) from ' . $this->db->dbprefix('affiliate_commissions') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('affiliate_commissions') . '.tool_id 
					AND ' . $this->db->dbprefix('affiliate_commissions') . '.tool_type = \'html_ads\'
					AND member_id = \'' . $mid . '\') as commissions,
					
					(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount) from ' . $this->db->dbprefix('invoices') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('invoices') . '.tool_id 
					AND ' . $this->db->dbprefix('invoices') . '.tool_type = \'html_ads\'
					AND referrer_id = \'' . $mid . '\') as sales';
			}
			else
			{
				$sql .= ' (SELECT SUM(commission_amount) from ' . $this->db->dbprefix('affiliate_commissions') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('affiliate_commissions') . '.tool_id 
					AND ' . $this->db->dbprefix('affiliate_commissions') . '.tool_type = \'html_ads\'
					AND member_id = \'' . $mid . '\'
					AND comm_status != \'pending\') as commissions,
					
					(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount) from ' . $this->db->dbprefix('invoices') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('invoices') . '.tool_id 
					AND ' . $this->db->dbprefix('invoices') . '.tool_type = \'html_ads\'
					AND referrer_id = \'' . $mid . '\') as sales';
			}		
			
					
			$sql .= ' FROM ' . $this->db->dbprefix('affiliate_html_ads') . '
					WHERE status = \'1\'
					ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}
		else
		{
		
			$sql = 'SELECT ' . $this->db->dbprefix('affiliate_html_ads') . '.*,
					(SELECT COUNT(*) from ' . $this->db->dbprefix('traffic') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('traffic') . '.tool_id 
					AND ' . $this->db->dbprefix('traffic') . '.tool_type = \'html_ads\') as clicks,
					
					(SELECT SUM(commission_amount) from ' . $this->db->dbprefix('affiliate_commissions') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('affiliate_commissions') . '.tool_id 
					AND ' . $this->db->dbprefix('affiliate_commissions') . '.tool_type = \'html_ads\') as commissions,
					
					(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount) from ' . $this->db->dbprefix('invoices') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_html_ads') . '.id = ' . $this->db->dbprefix('invoices') . '.tool_id 
					AND ' . $this->db->dbprefix('invoices') . '.tool_type = \'html_ads\') as sales
					
					FROM ' . $this->db->dbprefix('affiliate_html_ads') . '
					ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _preview_code($id = '')
	{
		$data = $this->aff->_get_tool_details('html_ads', $id);
		
		$data['s_title'] = $data['name'];
				
		//format the affiliate link
		$link = _jrox_public_url() . _jrox_slash_item(AFF_TOOLS_ROUTE) . $this->session->userdata('m_username') . '/tool/html_ads/' . $data['id'];
				
		$data['html_ad_body'] = str_replace('{affiliate_link}', $link, $data['html_ad_body']);
				
		$data['tool_code'] = $this->init->_parse_member_data($this->_generate_html_ad_code($data, true));
		$data['tool_code'] = auto_link($data['tool_code']);
		
		//set the title and message body
		$data['subject_title'] = $this->lang->line('subject');
		$data['body_title'] = $this->lang->line('html_ad');
		$data['template'] = 'tpl_members_marketing_preview_code2';
		
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_tools($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $mid = '', $num_options = '')
	{
		//get the affiliate tools and put in the array
		$rows = $this-> _get_html_ads($limit, $offset, 'sort_order', 'ASC', true, $mid);
		
		$a['tool_rows'] = array();
		
		if (!empty($rows))
		{
			$a['tool_rows'] = array();
		
			foreach ($rows as $v)
			{
				$v['s_commissions'] = format_amounts($v['commissions'], $num_options);
				$v['s_sales'] = format_amounts($v['sales'], $num_options);
				$v['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				
				$v['s_title'] = $v['name'];
				
				//format the affiliate link
				$link = _jrox_public_url() . _jrox_slash_item(AFF_TOOLS_ROUTE) . $this->session->userdata('m_username') . '/tool/html_ads/' . $v['id'];
				
				$v['html_ad_body'] = str_replace('{affiliate_link}', $link, $v['html_ad_body']);
				
				$v['tool_code'] = htmlspecialchars($this->init->_parse_member_data($this->_generate_html_ad_code($v, true)));
				
				array_push($a['tool_rows'], $v);
			}		
		}
		
		//set the title and message body
		$a['subject_title'] = $this->lang->line('subject');
		$a['body_title'] = $this->lang->line('html_ad');
		
		$a['row_count'] = $this->db_validation_model->_get_count('affiliate_html_ads', 'WHERE status = \'1\'');
		$a['use_pagination'] = true;
		$a['template'] = 'tpl_members_general_marketing_tools';
		
		return $a;
	}
	
	// ------------------------------------------------------------------------	
}
?>