<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_affiliate_marketing_text_links_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for percent shipping
|
*/

class Module_Affiliate_Marketing_Text_Links_Model extends Model {	
	
	function _install_jrox_module($id = '')
	{	
		//check admin session
		$this->security_model->_check_admin_session();
		
		$delete = 'DROP TABLE IF EXISTS ' . $this->db->dbprefix('affiliate_text_links') . ';';
		
		$query = $this->db->query($delete);
		
		$sql = 'CREATE TABLE IF NOT EXISTS ' . $this->db->dbprefix('affiliate_text_links') . ' (		  
				  id int(10) NOT NULL auto_increment,
				  status enum(\'0\',\'1\') NOT NULL default \'0\',
				  name varchar(255) NOT NULL,
				  text_link_title text NOT NULL,
				  enable_redirect enum(\'0\',\'1\') NOT NULL,
				  redirect_custom_url varchar(255) NOT NULL,
				  sort_order int(10) NOT NULL default \'0\',
				  notes text NOT NULL,
				  PRIMARY KEY  (id),
				  KEY text_link_name (name)
				) AUTO_INCREMENT=1;';
				
		$query = $this->db->query($sql);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _add_text_link()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		$data['sort_order'] = '1';
		
		//insert into db
		if (!$this->db->insert('affiliate_text_links', $data))
		{
			show_error($this->lang->line('could_not_add_text_link'));
			
			//log error
			log_message('error', 'Could not insert text_link into text_links table');
			
			return false;
		}
		else
		{
			$id = $this->db->insert_id();
			
			//log success
			log_message('info', 'text_link '. $id . ' inserted into text_links table');
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------	
	
	function _edit_text_link($id = '')
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//insert into db
		$this->db->where('id', $id);
		if (!$this->db->update('affiliate_text_links', $data))
		{
			show_error($this->lang->line('could_not_update_text_link'));
			
			//log error
			log_message('error', 'Could not update text link in affiliate_text_links table');
			
			return false;
		}
		else
		{	
			//log success
			log_message('info', 'text link '. $id . ' updated into affiliate_text_links table');
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------

	function _get_text_link_details($id = '')
	{
		//get the data from text_links table
		$this->db->where('id', $id);
		$query = $this->db->get('affiliate_text_links');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		else
		{
			return false;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_text_links($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $members = false, $mid = '')
	{
		//get all the text_links from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_bnr_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_bnr_column');
		
		if ($members == true && !empty($mid))
		{
			$sql = 'SELECT ' . $this->db->dbprefix('affiliate_text_links') . '.*,
					(SELECT COUNT(*) from ' . $this->db->dbprefix('traffic') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('traffic') . '.tool_id 
					AND ' . $this->db->dbprefix('traffic') . '.tool_type = \'text_links\'
					AND member_id = \'' . $mid . '\') as clicks,';
					
			if ($this->config->item('sts_affiliate_show_pending_comms_members') == 1)
			{
				$sql .= ' (SELECT SUM(commission_amount) from ' . $this->db->dbprefix('affiliate_commissions') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('affiliate_commissions') . '.tool_id 
					AND ' . $this->db->dbprefix('affiliate_commissions') . '.tool_type = \'text_links\'
					AND member_id = \'' . $mid . '\') as commissions,
					
					(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount) from ' . $this->db->dbprefix('invoices') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('invoices') . '.tool_id 
					AND ' . $this->db->dbprefix('invoices') . '.tool_type = \'text_links\'
					AND referrer_id = \'' . $mid . '\') as sales';
			}
			else
			{
				$sql .= ' (SELECT SUM(commission_amount) from ' . $this->db->dbprefix('affiliate_commissions') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('affiliate_commissions') . '.tool_id 
					AND ' . $this->db->dbprefix('affiliate_commissions') . '.tool_type = \'text_links\'
					AND member_id = \'' . $mid . '\'
					AND comm_status != \'pending\') as commissions,
					
					(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount) from ' . $this->db->dbprefix('invoices') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('invoices') . '.tool_id 
					AND ' . $this->db->dbprefix('invoices') . '.tool_type = \'text_links\'
					AND referrer_id = \'' . $mid . '\') as sales';
			}		
			
					
			$sql .= ' FROM ' . $this->db->dbprefix('affiliate_text_links') . '
					WHERE status = \'1\'
					ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}
		else
		{
		
			$sql = 'SELECT ' . $this->db->dbprefix('affiliate_text_links') . '.*,
					(SELECT COUNT(*) from ' . $this->db->dbprefix('traffic') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('traffic') . '.tool_id 
					AND ' . $this->db->dbprefix('traffic') . '.tool_type = \'text_links\') as clicks,
					
					(SELECT SUM(commission_amount) from ' . $this->db->dbprefix('affiliate_commissions') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('affiliate_commissions') . '.tool_id 
					AND ' . $this->db->dbprefix('affiliate_commissions') . '.tool_type = \'text_links\') as commissions,
					
					(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount) from ' . $this->db->dbprefix('invoices') . ' 
					WHERE ' . $this->db->dbprefix('affiliate_text_links') . '.id = ' . $this->db->dbprefix('invoices') . '.tool_id 
					AND ' . $this->db->dbprefix('invoices') . '.tool_type = \'text_links\') as sales
					
					FROM ' . $this->db->dbprefix('affiliate_text_links') . '
					ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _preview_code($id = '')
	{
		$data = $this->aff->_get_tool_details('text_links', $id);
		
		$data['s_title'] = '';
				
		//format the affiliate link
		$link = _jrox_public_url() . _jrox_slash_item(AFF_TOOLS_ROUTE) . $this->session->userdata('m_username') . '/tool/text_links/' . $data['id'];
				
		$data['tool_code'] = '<a href="' . $link . '">' . $data['text_link_title'] . '</a>';
		
		//set the title and message body
		$data['subject_title'] = $this->lang->line('subject');
		$data['body_title'] = $this->lang->line('text_link');
		$data['template'] = 'tpl_members_marketing_preview_code2';
		
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_tools($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $mid = '', $num_options = '')
	{
		//get the affiliate tools and put in the array
		$rows = $this-> _get_text_links($limit, $offset, 'sort_order', 'ASC', true, $mid);
		
		$a['tool_rows'] = array();
		
		if (!empty($rows))
		{
			$a['tool_rows'] = array();
		
			foreach ($rows as $v)
			{
				$v['s_commissions'] = format_amounts($v['commissions'], $num_options);
				$v['s_sales'] = format_amounts($v['sales'], $num_options);
				$v['row_style'] = alternator('jroxRowStyle1', 'jroxRowStyle2');
				
				//format the affiliate link
				$link = _jrox_public_url() . _jrox_slash_item(AFF_TOOLS_ROUTE) . $this->session->userdata('m_username') . '/tool/text_links/' . $v['id'];

				$v['tool_code'] = htmlspecialchars('<a href="' . $link . '">' . $v['text_link_title'] . '</a>');
				
				array_push($a['tool_rows'], $v);
			}		
		}
		
		//set the title and message body
		$a['subject_title'] = $this->lang->line('subject');
		$a['body_title'] = $this->lang->line('text_link');
		
		$a['row_count'] = $this->db_validation_model->_get_count('affiliate_text_links', 'WHERE status = \'1\'');
		$a['use_pagination'] = true;
		$a['template'] = 'tpl_members_general_marketing_tools';
		
		return $a;
	}
	
	// ------------------------------------------------------------------------	
}
?>