<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_data_import_mass_edit_products_model.php
| -------------------------------------------------------------------------     
| 
| This controller file is for functions for importing products
|
*/


class Module_Data_Import_Mass_Edit_Products_Model extends Model {

	function _install_jrox_module($id = '')
	{	
		//insert required config rows in settings table		
		$config = array(
							'settings_key'	=>	'module_data_import_mass_edit_products_delimiter',
							'settings_value'	=>	'tab',
							'settings_module'	=>	'data_import',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'delimiter',
							);
		
		//insert into settings table
		if ($this->db->insert('settings', $config))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _import_data()
	{
		$this->load->helper('file');
		
		if ($this->input->post('enable_file_path') == 'no' && !empty($_FILES))
		{
			if ($_FILES['userfile']['error'] == '4')
			{
				return 'error';
				exit();
			}
			
			$config['upload_path'] = './import/products/';
			$config['allowed_types'] = 'txt|csv';
			$config['max_size']	= '0';
			$config['encrypt_name'] = true;
			$config['remove_spaces'] = true;
			
			//upload the photo
			$data = $this->uploads->_upload_file('userfile', $config);
			
			//add photo to db
			if (!empty($data['success']))
			{	
				$file = $data['info'];
		
				$data = read_file('./import/products/' . $file['file_name']);
			}
			else
			{
				echo '<div class="error" id="error-messages">' .  $data['msg'] . '</div>';
				exit();
			}
		}
		else
		{
			$data = read_file('./import/products/' . $this->input->post('file_path'));
		}
		
		$array = explode("\n", $data);
		//echo '<pre>'; print_r($array); exit();
		//SET COLUMN NUMBER
		$i = 1;
		
		
		switch ($this->config->item('module_data_import_mass_edit_products_delimiter'))
		{
			case 'tab':
				$separator = "\t";
			break;
			
			case 'semicolon':
				$separator = ";";
			break;
			
			default:
				$separator = ",";
			break;
		}
				
		//INSERT INTO MEMBERS TABLE
		$total = 0;
		foreach ($array as $value)
		{
			if (empty($value)) { continue; }
			
			$f = explode($separator,$value);
						
			$fields = array();
			
			foreach ($f as $field)
			{
				$a = $this->_string_check($field);
				
				array_push($fields, trim($a));
			}
			//echo '<pre>'; print_r($fields); exit();
			if ($fields[0] == 'product_id' || $fields[0] == 'product_type')
			{
				$columns = array();
			
				foreach ($fields as $key => $row) //put all the column headers in one array first
				{
					array_push($columns, trim($row)); 
				}
				
				continue;
			}
			else
			{
				
				$srow = combine_array($columns, $fields);
				
				$update = false;
	
				//check for an sku
				if(!empty($srow['product_sku']))
				{
					$this->db->where('product_sku', $srow['product_sku']);
					$query = $this->db->get('products');
					
					if ($query->num_rows > 0) 
					{ 						
						$pdata = array(
								'product_type'								=>			$this->_check_product_type($srow['product_type']), //physical digital membership
								'product_status'							=>			$srow['product_status'] == '1' ? '1' : '', 
								'product_name'								=>			empty($srow['product_name']) ? '' : $srow['product_name'],
								'product_featured'							=> 			$srow['product_featured'] == '1' ? '1' : '', 
								'recommended_product'						=>			$srow['recommended_product'] == '1' ? '1' : '', 
								'product_keywords'							=>			empty($srow['product_keywords']) ? '' : $srow['product_keywords'],
								'product_new'								=> 			$srow['product_new'] == '1' ? '1' : '', 
								'product_trial_price'						=>			$this->_check_numeric($srow['product_trial_price']),
								'product_price'								=>			$this->_check_numeric($srow['product_price']),
								'date_added'								=>			empty($srow['date_added']) ? _generate_timestamp() : $this->_format_date($srow['date_added']),
								'date_modified'								=>			empty($srow['date_modified']) ? _generate_timestamp() : $this->_format_date($srow['date_modified']),
								'date_available'							=>			empty($srow['date_available']) ? _generate_timestamp() : $this->_format_date($srow['date_available']),
								'date_expires'								=>			empty($srow['date_expires']) ? _generate_timestamp() + (3600 * 24 * 365 * 20) : $this->_format_date($srow['date_expires']),
								'enable_product_trial'						=>			$srow['enable_product_trial'] == '1' ? '1' : '', 
								'product_trial_interval'					=>			$this->_check_numeric($srow['product_trial_interval']),
								'product_trial_interval_type'				=>			$this->_check_product_trial_type($srow['product_trial_interval_type']), //day week month year
								'recurring_onetime'							=>			$srow['recurring_onetime'] == '1' ? '1' : '', 
								'recurring_interval'						=>			$this->_check_numeric($srow['recurring_interval']),
								'recurring_interval_type'					=>			$this->_check_product_trial_type($srow['recurring_interval_type']), //day week month year
								'recurring_interval_ends'					=>			$this->_check_numeric($srow['recurring_interval_ends']),
								'use_video_default'							=>			$srow['use_video_default'] == '1' ? '1' : '', 
								'download_location_1'						=>			empty($srow['download_location_1']) ? '' : $srow['download_location_1'],
								'download_location_2'						=>			empty($srow['download_location_2']) ? '' : $srow['download_location_2'],
								'download_location_3'						=>			empty($srow['download_location_3']) ? '' : $srow['download_location_3'],
								'download_location_4'						=>			empty($srow['download_location_4']) ? '' : $srow['download_location_4'],
								'download_location_5'						=>			empty($srow['download_location_5']) ? '' : $srow['download_location_5'],
								'download_location_6'						=>			empty($srow['download_location_6']) ? '' : $srow['download_location_6'],
								'download_location_7'						=>			empty($srow['download_location_7']) ? '' : $srow['download_location_7'],
								'download_location_8'						=>			empty($srow['download_location_8']) ? '' : $srow['download_location_8'],
								'download_location_9'						=>			empty($srow['download_location_9']) ? '' : $srow['download_location_9'],
								'download_location_10'						=>			empty($srow['download_location_10']) ? '' : $srow['download_location_10'],
								'download_expires_days'						=>			$this->_check_numeric($srow['download_expires_days']),
								'max_downloads_per_user'					=>			$this->_check_numeric($srow['max_downloads_per_user']),		
								'membership_url_redirect'					=>			empty($srow['membership_url_redirect']) ? $srow['membership_url_redirect'] : '',	
								'product_weight'							=>			$this->_check_numeric($srow['product_weight']),		
								'manufacturer_id'							=>			$this->_check_numeric($srow['manufacturer_id']),
								'vendor_id'									=>			$this->_check_numeric($srow['vendor_id']),
								'post_purchase_module_id'					=>			$this->_check_numeric($srow['post_purchase_module_id']),
								'signup_module_id'							=>			$this->_check_numeric($srow['signup_module_id']),
								'expires_module_id'							=>			$this->_check_numeric($srow['expires_module_id']),
								'add_affiliate_group'						=>			$this->_check_numeric($srow['add_affiliate_group']),
								'add_discount_group'						=>			$this->_check_numeric($srow['add_discount_group']),
								'add_mailing_list'							=>			$this->_check_numeric($srow['add_mailing_list']),
								'product_views'								=>			$this->_check_numeric($srow['product_views']),
								'enable_product_inventory'					=>			$this->_check_global($srow['enable_product_inventory']), //0 1 2
								'product_inventory'							=>			empty($srow['product_inventory']) ? '' : $srow['product_inventory'],
								'add_cart_for_price'						=>			empty($srow['add_cart_for_price']) ? '' : '1', 
								'login_for_price'							=>			empty($srow['login_for_price']) ? '' : '1', 
								'min_quantity_ordered'						=>			$this->_check_numeric($srow['min_quantity_ordered']),
								'max_quantity_ordered'						=>			$this->_check_numeric($srow['max_quantity_ordered']),
								'product_overview'							=>			empty($srow['product_overview']) ? '' : $srow['product_overview'], 
								'product_description_1'						=>			empty($srow['product_description_1']) ? '' : $srow['product_description_1'], 
								'product_description_2'						=>			empty($srow['product_description_2']) ? '' : $srow['product_description_2'], 
								'no_commission'								=>			empty($srow['no_commission']) ? '' : '1', 
								'enable_custom_commission'					=>			empty($srow['enable_custom_commission']) ? '' : $srow['enable_custom_commission'], 
								'product_sort'								=>			empty($srow['product_sort'])? '' : $this->_check_numeric($srow['product_sort']),		
								'product_title'								=>			empty($srow['product_title']) ? '' : $srow['product_title'], 
								'product_meta_description'					=>			empty($srow['product_meta_description']) ? '' : $srow['product_meta_description'], 
								'add_to_membership'							=>			empty($srow['add_to_membership'])? '' : $this->_check_add_membership($srow['add_to_membership']),
						);
						
						//lets now remove any blank fields for updating
						
						foreach ($pdata as $a => $b)
						{
							if (strlen($b) > '0')
							{
								$sdata[$a] = $b;	
							}
						}
						
						$this->db->where('product_sku', $srow['product_sku']);
						$this->db->update('products', $sdata);
						
						//now lets get the product 	ID
						$this->db->select('product_id');
						$this->db->where('product_sku', $srow['product_sku']);
						$query = $this->db->get('products');
						
						if ($query->num_rows() > 0)
						{
							$prod_array = $query->row_array();
							//print_r($prod_array);
							$id = $prod_array['product_id'];
						}
						
						//update the product categories
						if (!empty($srow['product_categories']))
						{
							$cat = explode('|', $srow['product_categories']);
							
							if (count($cat) > 0)
							{
								$this->db->where('product_id', $id); //we need to delete all the old categories first
						
								$this->db->delete('products_to_categories'); //delete it
								
								foreach ($cat as $c) //now insert each new category
								{
									if ($this->_check_prod_cat($c) == true)
									{
										$pcat = array(
														'product_id' 			=> 			$id,
														'category_id'			=>			$c,			
														);
														
										$this->db->insert('products_to_categories', $pcat);
									}
								}
							}							
						}	
						
						//add custom commmissions
						if (!empty($srow['enable_custom_commission']))
						{
							//check the affiliate group ID in $fields[59] 
							if ($this->_check_aff_group($srow['affiliate_group']) == true)
							{
								//reset the affiliate group first
								$this->db->where('product_id', $id);
								$this->db->delete('products_to_aff_groups');
								
								//add commission levels
								$comm_array = array(
													'product_id' => $id,
													'group_id' => $srow['affiliate_group'],
													'commission_level_1' => empty($srow['commission_level_1']) ? '0' : $this->_check_numeric($srow['commission_level_1']),
													'commission_level_2' => empty($srow['commission_level_2']) ? '0' : $this->_check_numeric($srow['commission_level_2']),
													'commission_level_3' => empty($srow['commission_level_3']) ? '0' : $this->_check_numeric($srow['commission_level_3']),
													'commission_level_4' => empty($srow['commission_level_4']) ? '0' : $this->_check_numeric($srow['commission_level_4']),
													'commission_level_5' => empty($srow['commission_level_5']) ? '0' : $this->_check_numeric($srow['commission_level_5']),
													'commission_level_6' => empty($srow['commission_level_6']) ? '0' : $this->_check_numeric($srow['commission_level_6']),
													'commission_level_7' => empty($srow['commission_level_7']) ? '0' : $this->_check_numeric($srow['commission_level_7']),
													'commission_level_8' => empty($srow['commission_level_8']) ? '0' : $this->_check_numeric($srow['commission_level_8']),
													'commission_level_9' => empty($srow['commission_level_9']) ? '0' : $this->_check_numeric($srow['commission_level_9']),
													'commission_level_10' => empty($srow['commission_level_10']) ? '0' : $this->_check_numeric($srow['commission_level_10']),
													);
								//echo '<pre>'; print_r($comm_array);
								$this->db->insert('products_to_aff_groups', $comm_array);
							}
						}
					}
				}
				
				$total++;
			}
		}
		
		@unlink($file['full_path']);
		
		return $total;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _import_data2()
	{
		$this->load->helper('file');
		
		if ($this->input->post('enable_file_path') == 'no' && !empty($_FILES))
		{
			if ($_FILES['userfile']['error'] == '4')
			{
				return 'error';
				exit();
			}
			
			$config['upload_path'] = './import/products/';
			$config['allowed_types'] = 'txt|csv';
			$config['max_size']	= '0';
			$config['encrypt_name'] = true;
			$config['remove_spaces'] = true;
			
			//upload the photo
			$data = $this->uploads->_upload_file('userfile', $config);
			
			//add photo to db
			if (!empty($data['success']))
			{	
				$file = $data['info'];
		
				$data = read_file('./import/products/' . $file['file_name']);
			}
			else
			{
				echo '<div class="error" id="error-messages">' .  $data['msg'] . '</div>';
				exit();
			}
		}
		else
		{
			$data = read_file('./import/products/' . $this->input->post('file_path'));
		}
		
		$array = explode("\n", $data);
		//echo '<pre>'; print_r($array); exit();
		//SET COLUMN NUMBER
		$i = 1;
		$total = 0;
		
		switch ($this->config->item('module_data_import_mass_edit_products_delimiter'))
		{
			case 'tab':
				$separator = "\t";
			break;
			
			case 'semicolon':
				$separator = ";";
			break;
			
			default:
				$separator = ",";
			break;
		}
				
		//INSERT INTO MEMBERS TABLE
		foreach ($array as $value)
		{
			$f = explode($separator,$value);
			
			if (count($f) < '70') { continue; }
						
			$fields = array();
			
			foreach ($f as $field)
			{
				$a = $this->_string_check($field);
				
				array_push($fields, $a);
			}
			
			if ($this->config->item('module_data_import_mass_edit_products_heading_first_row') == '1')
			{
				if ($fields[0] == 'product_id' || $fields[0] == 'product_type')
				{
					continue;
				}
			}
			
			$update = false;

			//check for an sku
			if(!empty($fields[2]))
			{
				$this->db->where('product_sku', $fields[2]);
				$query = $this->db->get('products');
				
				if ($query->num_rows > 0) { $update = true; }
			}
			$pdata = array(
					
					'product_type'								=>			$this->_check_product_type($fields[1]), //physical digital membership
					'product_sku'								=>			$this->_check_product_sku($fields[2]),
					'product_status'							=>			$status = $fields[3] == '1' ? '1' : '0', 
					'product_name'								=>			$fields[4],
					'product_featured'							=> 			$featured = $fields[5] == '1' ? '1' : '0', 
					'upsell_product'							=>			'0',
					'recommended_product'						=>			$recommended = $fields[7] == '1' ? '1' : '0', 
					'product_keywords'							=>			$fields[8],
					'product_new'								=> 			$new = $fields[9] == '1' ? '1' : '0', 
					'product_trial_price'						=>			$this->_check_numeric($fields[10]),
					'product_price'								=>			empty($fields[11]) ? '0' : $this->_check_numeric($fields[11]),
					'date_added'								=>			empty($fields[12]) ? _generate_timestamp() : $this->_format_date($fields[12]),
					'date_modified'								=>			empty($fields[13]) ? _generate_timestamp() : $this->_format_date($fields[13]),
					'date_available'							=>			empty($fields[14]) ? _generate_timestamp() : $this->_format_date($fields[14]),
					'date_expires'								=>			empty($fields[15]) ? _generate_timestamp() + (3600 * 24 * 365 * 20) : $this->_format_date($fields[15]),
					'enable_product_trial'						=>			$trial = $fields[16] == '1' ? '1' : '0', 
					'product_trial_interval'					=>			$this->_check_numeric($fields[17]),
					'product_trial_interval_type'				=>			$this->_check_product_trial_type($fields[18]), //day week month year
					'recurring_onetime'							=>			$recur_onetime = $fields[19] == '1' ? '1' : '0', 
					'recurring_interval'						=>			$this->_check_numeric($fields[20]),
					'recurring_interval_type'					=>			$this->_check_product_trial_type($fields[21]), //day week month year
					'recurring_interval_ends'					=>			$this->_check_numeric($fields[22]),
					'use_video_default'							=>			$video_default = $fields[23] == '1' ? '1' : '0', 
					'download_location_1'						=>			$fields[24],
					'download_location_2'						=>			$fields[25],
					'download_location_3'						=>			$fields[26],
					'download_location_4'						=>			$fields[27],
					'download_location_5'						=>			$fields[28],
					'download_location_6'						=>			$fields[29],
					'download_location_7'						=>			$fields[30],
					'download_location_8'						=>			$fields[31],
					'download_location_9'						=>			$fields[32],
					'download_location_10'						=>			$fields[33],
					'download_expires_days'						=>			$this->_check_numeric($fields[34]),
					'max_downloads_per_user'					=>			$this->_check_numeric($fields[35]),		
					'membership_url_redirect'					=>			$fields[36],	
					'product_weight'							=>			$this->_check_numeric($fields[37]),		
					'manufacturer_id'							=>			$this->_check_numeric($fields[38]),
					'vendor_id'									=>			$this->_check_numeric($fields[39]),
					'post_purchase_module_id'					=>			$this->_check_numeric($fields[40]),
					'signup_module_id'							=>			$this->_check_numeric($fields[41]),
					'expires_module_id'							=>			$this->_check_numeric($fields[42]),
					'add_affiliate_group'						=>			$this->_check_numeric($fields[43]),
					'add_discount_group'						=>			$this->_check_numeric($fields[44]),
					'add_mailing_list'							=>			$this->_check_numeric($fields[45]),
					'product_views'								=>			$this->_check_numeric($fields[46]),
					'enable_product_inventory'					=>			$this->_check_global($fields[47]), //0 1 2
					'product_inventory'							=>			$fields[48],
					'add_cart_for_price'						=>			$add_cart_for_price = $fields[49] == '1' ? '1' : '0', 
					'login_for_price'							=>			$login_for_price = $fields[50] == '1' ? '1' : '0', 
					'min_quantity_ordered'						=>			$fields[51],
					'max_quantity_ordered'						=>			$fields[52],
					'product_overview'							=>			$fields[53],
					'product_description_1'						=>			$fields[54],
					'product_description_2'						=>			$fields[55],
					'no_commission'								=>			$no_commission = $fields[56] == '1' ? '1' : '0', 
					'enable_custom_commission'					=>			$enable_custom_commission = $fields[57] == '1' ? '1' : '0', 
					);
			
			//echo '<pre>'; print_r($fields); continue;
			if ($update == true)
			{
				$this->db->where('product_sku', $fields[2]);
				$this->db->update('products', $pdata);
				//echo $this->db->last_query();
				$this->db->select('product_id');
				$this->db->where('product_sku', $fields[2]);
				$query = $this->db->get('products');
				
				if ($query->num_rows() > 0)
				{
					$prod_array = $query->row_array();
					//print_r($prod_array);
					$id = $prod_array['product_id'];
				}
			}
			else
			{
				//echo '<pre>'; print_r($pdata); continue;
				$this->db->insert('products', $pdata);
				
				$id = $this->db->insert_id();
			}
			
			$total++;	
			
			//add product to categories
			if ($update == true)
			{
				//get the product ID by SKU
				$this->db->select('product_id');
				$this->db->where('product_sku', $fields[2]);
				$query = $this->db->get('products');
				
				$prod_array = $query->row_array();
				$id = $prod_array['product_id'];
				
				$this->db->where('product_id', $id);
				
				$this->db->delete('products_to_categories');
			}
			
			if (!empty($fields[58]))
			{
				$cat = explode('|', $fields[58]);
				
				foreach ($cat as $c)
				{
					if ($this->_check_prod_cat($c) == true)
					{
						
						$this->db->where('product_id', $id);
						$this->db->where('category_id', $c);
						$query = $this->db->get('products_to_categories');
						
						if ($query->num_rows < 1)
						{
							$pcat = array(
											'product_id' 			=> 			$id,
											'category_id'			=>			$c,			
											);
											
							$this->db->insert('products_to_categories', $pcat);
						}
					}
				}	
			}	
			else
			{
				$pcat = array(
								'product_id' 			=> 			$id,
								'category_id'			=>			'1',			
								);
								
				$this->db->insert('products_to_categories', $pcat);
			}
			
			//delete custom commissions first to reset
			$this->db->where('product_id', $id);
			$this->db->delete('products_to_aff_groups');
			
			//add custom commmissions
			if ($fields[57] == '1')
			{
				
				
				//check the affiliate group ID in $fields[59] 
				if ($this->_check_aff_group($fields[59]) == true)
				{
					//add commission levels
					$comm_array = array(
										'product_id' => $id,
										'group_id' => $fields[59],
										'commission_level_1' => empty($fields[60]) ? '0' : $this->_check_numeric($fields[60]),
										'commission_level_2' => empty($fields[61]) ? '0' : $this->_check_numeric($fields[61]),
										'commission_level_3' => empty($fields[62]) ? '0' : $this->_check_numeric($fields[62]),
										'commission_level_4' => empty($fields[63]) ? '0' : $this->_check_numeric($fields[63]),
										'commission_level_5' => empty($fields[64]) ? '0' : $this->_check_numeric($fields[64]),
										'commission_level_6' => empty($fields[65]) ? '0' : $this->_check_numeric($fields[65]),
										'commission_level_7' => empty($fields[66]) ? '0' : $this->_check_numeric($fields[66]),
										'commission_level_8' => empty($fields[67]) ? '0' : $this->_check_numeric($fields[67]),
										'commission_level_9' => empty($fields[68]) ? '0' : $this->_check_numeric($fields[68]),
										'commission_level_10' => empty($fields[69]) ? '0' : $this->_check_numeric($fields[69]),
										);
					//echo '<pre>'; print_r($comm_array);
					$this->db->insert('products_to_aff_groups', $comm_array);
				}
			}
		}
		
		@unlink($file['full_path']);
		
		return $total;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_aff_group($id = '')
	{
		$this->db->where('group_id', $id);
		$query = $this->db->get('affiliate_groups');
		
		if ($query->num_rows() > 0)
		{
			return true;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_prod_cat($id = '')
	{
		$this->db->where('category_id', $id);
		$query = $this->db->get('products_categories');
		
		if ($query->num_rows() > 0)
		{
			return true;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _string_check($id = '')
	{
		$id = str_replace('"', '', $id);
		
		return $id;
	}	
	
	// ------------------------------------------------------------------------
	
	function _check_product_type($id = '')
	{
		$id = trim($id);
		if ($id == 'physical' || $id == 'digital' || $id == 'membership')
		{
			return $id;
		}
		
		return '';
	}
	
	// ------------------------------------------------------------------------
	
	function _check_product_sku($id = '')
	{
		if (empty($id)) 
		{ 
			return _generate_random_string(6); 
		}
		
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_add_membership($id = '')
	{
		
		$this->db->where('add_to_membership', $id);
		$this->db->where('product_type', 'membership');
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			return $id;
		}
		
		return '';
	}
	
	// ------------------------------------------------------------------------
	
	function _check_numeric($id = '')
	{
		if (!is_numeric($id))
		{
			return '';
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	function _format_date($id = '')
	{
		if (empty($id))
		{
			return '';
		}
		
		$a = explode('/', $id);
		$b = mktime(12, 0, 0, $a[0],   $a[1],   $a[2]);

		return $b;
	}
	
	// ------------------------------------------------------------------------
	
	
	function _check_product_trial_type($id = '')
	{
		 //day week month year
		 if ($id != 'day' || $id != 'week' || $id != 'month' || $id != 'year')
		 {
		 	return '';
		 }
		 
		 return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	function _check_global($id = '')
	{
		if ($id != '0' || $id != '1' || $id != '2')
		{
			return '';
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	
}
?>