<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_data_import_product_images_model.php
| -------------------------------------------------------------------------     
| 
| This controller file is for functions for importing product images
|
*/


class Module_Data_Import_Product_Images_Model extends Model {

	function _install_jrox_module($id = '')
	{											
		//insert required config rows in settings table		
		$config = array(
							'settings_key'	=>	'module_data_import_product_images_use_skus',
							'settings_value'	=>	'0',
							'settings_module'	=>	'data_import',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'boolean',					
						);
		
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_data_import_product_images_delete_photos',
							'settings_value'	=>	'0',
							'settings_module'	=>	'data_import',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'boolean',					
						);
		
		//insert into settings table
		if ($this->db->insert('settings', $config))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _import_data()
	{
		//load directory helper
		$this->load->helper('directory');
		$this->load->library('image_lib', $config);
		
		$config['image_library'] = $this->config->item('sts_image_library');
		$config['quality'] = $this->config->item('images_quality');
		$config['maintain_ratio'] = $this->config->item('images_maintain_ratio');
		$config['thumb_marker'] = '_jrox';
				
		$config['width'] = $this->config->item('sts_store_image_height');
		$config['height'] = $this->config->item('sts_store_image_width');
					
		//create thumbs
		$config['create_thumb'] = ($this->config->item('sts_store_image_auto_resize') == 1 ? true : false);
		
		
		//first read all folders in /import/products/
		$map = directory_map('./import/products/');
		
		$total['products'] = 0;
		$total['images'] = 0;
		
		if (count($map) > 0)
		{
			//foreach folder check if there are any images
			foreach ($map as $k => $v)
			{
				if (is_array($v))
				{
					if (count($v) > 0)
					{
						$id = $k; //set the ID
						
						$prod_array = $this->_check_id($id);
						
						if ($prod_array != false)
						{
							$product_id = $prod_array['product_id'];
						}
						else
						{
							continue;	
						}
								
						$total['products']++;
						$product_default = 0;
						
						foreach ($v as $img)
						{
							$ext = $this->_get_extension($img);
							
							//check image type
							if ($this->_check_image_type($ext))
							{
								//generate filename
								$name = $this->_generate_filename($ext);
								
								//foreach image copy over to /images/products folder
								$src = PUBPATH . '/import/products/' . $id . '/' . $img;
								$dest = PUBPATH . '/images/products/' . $name . '.'. $ext;
								
								if (!copy($src, $dest)) {
									show_error($this->lang->line('could_not_copy_image'));
								}
								
								//foreach image check if we are resizing based on config value		
								
								if ($this->config->item('sts_store_image_auto_resize') == 1)
								{
									$config['source_image'] = $dest;
									$this->image_lib->initialize($config); 
									$this->image_lib->resize();
									$this->image_lib->clear();
								}
								
								//now add image data to product_photos table
								$parts = getimagesize($src);
								
								$insert_data = array (
														'product_id'	=> 	$product_id,
														'photo_file_name' => $name .'.' . $ext, 
														'raw_name'	=> $name,
														'file_ext'	=> "." . $ext,
														'file_type'	=>  $parts['mime'],
														'original_file_name' => $img,
														'image_resized'	=>	$this->config->item('sts_store_image_auto_resize'),
													);	
						
								$this->db->insert('products_photos', $insert_data); 
								
								//check if there is a default image set
								$photo_id = $this->db->insert_id();
								
								if ($this->_check_default_image($product_id) == false)
								{
									$default_photo = array('product_default' => '1');
									
									$this->db->where('photo_id', $photo_id);
									$this->db->update('products_photos', $default_photo);
								}
								
								$total['images']++;
							}
							
							//try to delete the image
							if ($this->config->item('module_data_import_product_images_delete_photos') == 1)
							{
								@unlink($src);
							}
						}
					}
				}	
			}
			
			return $total;
		}
	}
	
	// ------------------------------------------------------------------------
	
	function _check_default_image($id = '')
	{
		$this->db->where('product_id', $id);
		$this->db->where('product_default', '1');
		$query = $this->db->get('products_photos');
		
		if ($query->num_rows() > 0)
		{
			return true;
		}
		
		return false;
	
	}
	
	// ------------------------------------------------------------------------
	
	function _check_image_type($ext = '')
	{
		$types = explode('|' , $this->config->item('sts_store_upload_photo_types'));
		
		return (in_array($ext, $types)) ? TRUE : FALSE;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_extension($filename)
	{
		$x = explode('.', $filename);
		return strtolower(end($x));
	}	
	
	// ------------------------------------------------------------------------
	
	function _generate_filename($ext = '')
	{
		mt_srand();
		$filename = md5(uniqid(mt_rand()));
	
		if ( ! file_exists(PUBPATH . '/images/products/' .$filename))
		{
			return $filename;
		}
			
		$new_filename = '';
		for ($i = 1; $i < 100; $i++)
		{			
			if ( ! file_exists(PUBPATH . '/images/products/'.$filename.$i.$ext))
			{
				return $filename.$i;
			}
		}	
	}
	
	// ------------------------------------------------------------------------
	
	function _check_id($id = '')
	{
		if ($this->config->item('module_data_import_product_images_use_skus') == 1)
		{
			$this->db->where('product_sku', $id);
		}
		else
		{
			$this->db->where('product_id', $id);	
		}
		
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			return $query->row_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_numeric($id = '')
	{
		if (!is_numeric($id))
		{
			//return '0';
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	
}
?>