<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_data_import_products_model.php
| -------------------------------------------------------------------------     
| 
| This controller file is for functions for importing products
|
*/


class Module_Data_Import_Products_Model extends Model {

	function _install_jrox_module($id = '')
	{	
		//insert required config rows in settings table		
		$config = array(
							'settings_key'	=>	'module_data_import_products_delimiter',
							'settings_value'	=>	'comma',
							'settings_module'	=>	'data_import',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'delimiter',
							);
		
		$this->db->insert('settings', $config);					
							
		//insert required config rows in settings table		
		$config = array(
							'settings_key'	=>	'module_data_import_products_generate_new_ids',
							'settings_value'	=>	'1',
							'settings_module'	=>	'data_import',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'boolean',					
						);
		
		//insert into settings table
		if ($this->db->insert('settings', $config))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _import_data()
	{
		$this->load->helper('file');
		$this->load->library('image_lib');
		
		if ($this->input->post('enable_file_path') == 'no' && !empty($_FILES))
		{
			if ($_FILES['userfile']['error'] == '4')
			{
				return 'error';
				exit();
			}
			
			$config['upload_path'] = './import/products/';
			$config['allowed_types'] = 'txt|csv';
			$config['max_size']	= '0';
			$config['encrypt_name'] = true;
			$config['remove_spaces'] = true;
			
			//upload the photo
			$data = $this->uploads->_upload_file('userfile', $config);
			
			//add photo to db
			if (!empty($data['success']))
			{	
				$file = $data['info'];
		
				$data = read_file('./import/products/' . $file['file_name']);
			}
			else
			{
				echo '<div class="error" id="error-messages">' .  $data['msg'] . '</div>';
				exit();
			}
		}
		else
		{
			$data = read_file('./import/products/' . $this->input->post('file_path'));
		}
		
		$array = explode("\n", $data);
		//echo '<pre>'; print_r($array); exit();
		//SET COLUMN NUMBER
		$i = 1;
		$total = 0;
		
		switch ($this->config->item('module_data_import_products_delimiter'))
		{
			case 'tab':
				$separator = "\t";
			break;
			
			case 'semicolon':
				$separator = ";";
			break;
			
			default:
				$separator = ",";
			break;
		}
				
		//INSERT INTO PRODUCTS TABLE

		foreach ($array as $value)
		{
			if (empty($value)) { continue; }
			
			$f = explode($separator,$value);
						
			$fields = array();
			
			foreach ($f as $field)
			{
				$a = $this->_string_check($field);
				
				array_push($fields, trim($a));
			}
			//echo '<pre>'; print_r($fields); exit();
			if ($fields[0] == 'product_id' || $fields[0] == 'product_type')
			{
				$columns = array();
			
				foreach ($fields as $key => $row) //put all the column headers in one array first
				{
					array_push($columns, trim($row)); 
				}
				
				continue;
			}
			else
			{
				
				$srow = combine_array($columns, $fields);
			
				$pdata = array(
					'product_id'								=> 			$this->config->item('module_data_import_products_generate_new_ids') == 1 ? '' : $srow['product_id'],
					'product_type'								=>			$this->_check_product_type($srow['product_type']), //physical digital membership
					'product_sku'								=>			$this->_check_product_sku($srow['product_sku']),
					'product_status'							=>			$srow['product_status'] == '1' ? '1' : '0', 
					'product_name'								=>			empty($srow['product_name']) ? 'product ID ' . $total : $srow['product_name'],
					'product_featured'							=> 			$srow['product_featured'] == '1' ? '1' : '0', 
					'recommended_product'						=>			$srow['recommended_product'] == '1' ? '1' : '0', 
					'product_keywords'							=>			$srow['product_keywords'],
					'product_new'								=> 			$srow['product_new'] == '1' ? '1' : '0', 
					'product_trial_price'						=>			$this->_check_numeric($srow['product_trial_price']),
					'product_price'								=>			$this->_check_numeric($srow['product_price']),
					'date_added'								=>			empty($srow['date_added']) ? _generate_timestamp() : $this->_format_date($srow['date_added']),
					'date_modified'								=>			empty($srow['date_modified']) ? _generate_timestamp() : $this->_format_date($srow['date_modified']),
					'date_available'							=>			empty($srow['date_available']) ? _generate_timestamp() : $this->_format_date($srow['date_available']),
					'date_expires'								=>			empty($srow['date_expires']) ? _generate_timestamp() + (3600 * 24 * 365 * 20) : $this->_format_date($srow['date_expires']),
					'enable_product_trial'						=>			$srow['enable_product_trial'] == '1' ? '1' : '0', 
					'product_trial_interval'					=>			$this->_check_numeric($srow['product_trial_interval']),
					'product_trial_interval_type'				=>			$this->_check_product_trial_type($srow['product_trial_interval_type']), //day week month year
					'recurring_onetime'							=>			$srow['recurring_onetime'] == '1' ? '1' : '0', 
					'recurring_interval'						=>			$this->_check_numeric($srow['recurring_interval']),
					'recurring_interval_type'					=>			$this->_check_product_trial_type($srow['recurring_interval_type']), //day week month year
					'recurring_interval_ends'					=>			$this->_check_numeric($srow['recurring_interval_ends']),
					'use_video_default'							=>			$srow['use_video_default'] == '1' ? '1' : '0', 
					'download_location_1'						=>			empty($srow['download_location_1']) ? '' : $srow['download_location_1'],
					'download_location_2'						=>			empty($srow['download_location_2']) ? '' : $srow['download_location_2'],
					'download_location_3'						=>			empty($srow['download_location_3']) ? '' : $srow['download_location_3'],
					'download_location_4'						=>			empty($srow['download_location_4']) ? '' : $srow['download_location_4'],
					'download_location_5'						=>			empty($srow['download_location_5']) ? '' : $srow['download_location_5'],
					'download_location_6'						=>			empty($srow['download_location_6']) ? '' : $srow['download_location_6'],
					'download_location_7'						=>			empty($srow['download_location_7']) ? '' : $srow['download_location_7'],
					'download_location_8'						=>			empty($srow['download_location_8']) ? '' : $srow['download_location_8'],
					'download_location_9'						=>			empty($srow['download_location_9']) ? '' : $srow['download_location_9'],
					'download_location_10'						=>			empty($srow['download_location_10']) ? '' : $srow['download_location_10'],
					'download_expires_days'						=>			$this->_check_numeric($srow['download_expires_days']),
					'max_downloads_per_user'					=>			$this->_check_numeric($srow['max_downloads_per_user']),		
					'membership_url_redirect'					=>			empty($srow['membership_url_redirect']) ? $srow['membership_url_redirect'] : '',	
					'product_weight'							=>			$this->_check_numeric($srow['product_weight']),		
					'manufacturer_id'							=>			$this->_check_numeric($srow['manufacturer_id']),
					'vendor_id'									=>			$this->_check_numeric($srow['vendor_id']),
					'post_purchase_module_id'					=>			$this->_check_numeric($srow['post_purchase_module_id']),
					'signup_module_id'							=>			$this->_check_numeric($srow['signup_module_id']),
					'expires_module_id'							=>			$this->_check_numeric($srow['expires_module_id']),
					'add_affiliate_group'						=>			$this->_check_numeric($srow['add_affiliate_group']),
					'add_discount_group'						=>			$this->_check_numeric($srow['add_discount_group']),
					'add_mailing_list'							=>			$this->_check_numeric($srow['add_mailing_list']),
					'product_views'								=>			$this->_check_numeric($srow['product_views']),
					'enable_product_inventory'					=>			$this->_check_global($srow['enable_product_inventory']), //0 1 2
					'product_inventory'							=>			empty($srow['product_inventory']) ? '0' : $srow['product_inventory'],
					'add_cart_for_price'						=>			empty($srow['add_cart_for_price']) ? '0' : '1', 
					'login_for_price'							=>			empty($srow['login_for_price']) ? '0' : '1', 
					'min_quantity_ordered'						=>			$this->_check_numeric($srow['min_quantity_ordered']),
					'max_quantity_ordered'						=>			$this->_check_numeric($srow['max_quantity_ordered']),
					'product_overview'							=>			empty($srow['product_overview']) ? '' : $srow['product_overview'], 
					'product_description_1'						=>			empty($srow['product_description_1']) ? '' : $srow['product_description_1'], 
					'product_description_2'						=>			empty($srow['product_description_2']) ? '' : $srow['product_description_2'], 
					'no_commission'								=>			empty($srow['no_commission']) ? '0' : '1', 
					'enable_custom_commission'					=>			empty($srow['enable_custom_commission']) ? '0' : '1', 
					'product_sort'								=>			$this->_check_numeric($srow['product_sort']),		
					'product_title'								=>			empty($srow['product_title']) ? '' : $srow['product_title'], 
					'product_meta_description'					=>			empty($srow['product_meta_description']) ? '' : $srow['product_meta_description'], 
					'add_to_membership'							=>			$this->_check_add_membership($srow['add_to_membership']),
					);
				//echo '<pre>'; print_r($pdata); exit();
				$this->db->insert('products', $pdata);
				
				$id = $this->db->insert_id();
					
				//add product to categories
				if (!empty($srow['product_categories']))
				{
					$cat = explode('|', $srow['product_categories']);
					
					foreach ($cat as $c)
					{
						if ($this->_check_prod_cat($c) == true)
						{
							
							$pcat = array(
											'product_id' 			=> 			$id,
											'category_id'			=>			$c,			
											);
											
							$this->db->insert('products_to_categories', $pcat);
						}
					}	
				}	
				else
				{
					$pcat = array(
									'product_id' 			=> 			$id,
									'category_id'			=>			'1',			
									);
									
					$this->db->insert('products_to_categories', $pcat);
				}
				
				//add photo if available
				
				if (!empty($srow['product_images']))
				{
					$image = explode('|', $srow['product_images']);
					$t_images = 0;
					foreach ($image as $img)
					{
						if ($this->_check_prod_image($img) == true)
						{
							$image = explode('.', $img);
							mt_srand();
							$filename = md5(uniqid(mt_rand())).$this->get_extension($img); 	
							$path = $this->config->slash_item('base_physical_path') . 'images/' . $this->config->item('images_products_dir');
							if (@copy($this->config->slash_item('base_physical_path') . 'import/products/images/' . $img, $path . '/' . $filename))
							{
								$D = @getimagesize($this->config->slash_item('base_physical_path') . 'images/' . $this->config->item('images_products_dir') . '/' . $filename);
								
								if ($this->config->item('sts_store_image_auto_resize') == 1)
								{
									$config['source_image'] = './images/' . $this->config->item('images_products_dir') . '/' . $filename;
									$config['image_library'] = $this->config->item('sts_image_library');
									$config['quality'] = $this->config->item('images_quality');
									$config['maintain_ratio'] = $this->config->item('images_maintain_ratio');
									$config['thumb_marker'] = '_jrox';	
									$config['create_thumb'] = ($this->config->item('sts_store_image_auto_resize') == 1 ? true : false);
		
									$this->load->library('image_lib', $config);
									$this->image_lib->initialize($config); 
									$this->image_lib->resize();
									$this->image_lib->clear();
									
									$image = explode('.', $filename);
		
								}
								
								$insert_data = array (
													'product_id'	=> 	$id,
													'photo_file_name' => $filename, 
													'raw_name'	=>  $image[0],
													'file_ext'	=> $this->get_extension($img),
													'file_type'	=> ! isset($D['mime']) ? 'unknown' : $D['mime'],
													'original_file_name' => $img,
													'image_resized'	=>	$this->config->item('sts_store_image_auto_resize'),
													'product_default' => $t_images == '0' ? '1' : '0',
												);	
								
								$this->db->insert('products_photos', $insert_data);
							}
						}
						
						$t_images++;
					}	
				}
				
			}
			
			$total++;
		}
		
		@unlink($file['full_path']);
		
		return $total;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_prod_image($img = '')
	{
		if (file_exists($this->config->slash_item('base_physical_path') . 'import/products/images/' . $img))
		{
			//check for allowed images
			$types = explode('|', $this->config->item('sts_store_upload_photo_types'));
			foreach ($types as $val)
			{
			 	$x = $this->get_extension($img);
				
				if($val == strtolower(trim($x, ".")))
				{	
					return true;
				}
	
			}
			
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function get_extension($filename)
	{
		$x = explode('.', $filename);
		return '.'.end($x);
	}	
	
	
	// ------------------------------------------------------------------------
	
	function _check_prod_cat($id = '')
	{
		$this->db->where('category_id', $id);
		$query = $this->db->get('products_categories');
		
		if ($query->num_rows() > 0)
		{
			return true;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _string_check($id = '')
	{
		$id = str_replace('"', '', $id);
		
		return $id;
	}	
	
	// ------------------------------------------------------------------------
	
	function _check_product_type($id = '')
	{
		$id = trim($id);
		if ($id == 'physical' || $id == 'digital' || $id == 'membership')
		{
			return $id;
		}
		
		return 'physical';
	}
	
	// ------------------------------------------------------------------------
	
	function _check_product_sku($id = '')
	{
		if (empty($id)) return _generate_random_string(6);
		
		$this->db->where('product_sku', $id);
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			return _generate_random_string(6);
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_add_membership($id = '')
	{
		
		$this->db->where('add_to_membership', $id);
		$this->db->where('product_type', 'membership');
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			return $id;
		}
		
		return '0';
	}
	
	// ------------------------------------------------------------------------
	
	function _check_numeric($id = '')
	{
		if (empty($id))
		{
			return '0';	
		}
		
		if (!is_numeric($id))
		{
			return '0';
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	function _format_date($id = '')
	{
		if (empty($id))
		{
			return _generate_timestamp();
		}
		
		$a = explode('/', $id);
		$b = mktime(12, 0, 0, $a[0],   $a[1],   $a[2]);

		return $b;
	}
	
	// ------------------------------------------------------------------------
	
	
	function _check_product_trial_type($id = '')
	{
		 //day week month year
		 if ($id != 'day' || $id != 'week' || $id != 'month' || $id != 'year')
		 {
		 	return 'day';
		 }
		 
		 return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	function _check_global($id = '')
	{
		if ($id != '0' || $id != '1' || $id != '2')
		{
			return '2';
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	
	
}
?>