<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_2checkout_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for 2checkout IPN payments
|
*/

class Module_Payment_Gateway_2checkout_Model extends Model {	
 	 
	function _install_jrox_module($id = '')
	{		
			
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_2checkout_id',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_2checkout_url',
							'settings_value'	=>	'https://www.2checkout.com/checkout/purchase',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_2checkout_md5_hash',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_2checkout_enable_testing',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'4',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_2checkout_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_2checkout($data = '')
	{
		
		$array['valid'] = '2'; //1 is to run an internal function; 2 is to forward to gateway
		$array['function'] = ''; //the function to run if needed for internal processing
		$array['module_name'] = '2checkout';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _validate_payment($trans_id = '', $amount = '', $hash = '')
	{
		$key = $this->config->item('module_payment_gateway_2checkout_md5_hash');
		
		//account is in demo mode
		if ($this->config->item('module_payment_gateway_2checkout_enable_testing') == 1)
		{
			$trans_id = '1';
		}
		
		if (!empty($key))
		{
			$c = md5 ( $key . $this->config->item('module_payment_gateway_2checkout_id') . $trans_id . $amount );
			
			if (strtoupper($c) != strtoupper($hash))
			{
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($post_data = array(), $order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($post_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', '2checkout');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			'',
					  'jrox_payment_amount'				=>			$this->input->post('total', true),
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$this->input->post('order_number', true),
					  'jrox_avs_code'					=>			'',
					  'jrox_membership_payment_type'	=> 			'2checkout',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _process($type = '', $data = array())
	{
		$results = array('jrox_error' => false);
		
		//run jrox verification first
		if ($this->_validate_payment($this->input->post('order_number'), $this->input->post('total'), $this->input->post('key')) == false)
		{
			$results['jrox_error'] = true;
			$a = $this->config->item('module_payment_gateway_2checkout_md5_hash'). $this->config->item('module_payment_gateway_2checkout_id').$this->input->post('order_number'). $this->input->post('total');
			$results['jrox_error_message'] = $a . ' != '. $this->input->post('key') . ' ' . $this->lang->line('invalid_security_code');
		}
		
		//check demo
		if ($this->input->post('demo') == 'Y')
		{
			if ($this->config->item('module_payment_gateway_2checkout_enable_testing') == 0)
			{
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $this->lang->line('invalid_demo_payment_sent');
			}
		}
		
		if ($results['jrox_error'] == false)
		{
			$results['jrox_payment_type'] = 'credit';
			$results['jrox_product_type'] = 'products';	
			$results['jrox_order_data'] = $this->security_model->_get_session_id($this->input->post('order_id') . '-' . $this->input->post('member_id'));		
			
			if (!empty($results['jrox_order_data']))
			{
				$results['jrox_member_id'] = $results['jrox_order_data']['member_id'];
				
				$results['session_data'] = unserialize($results['jrox_order_data']['order_data']['session_data']);
				
				$results['jrox_payment_data'] = $this->_format_payment_data($data, $results['session_data']);
				
				$data['jrox_payment_data'] = $results['jrox_payment_data'];
			}
			else
			{
				$results['jrox_error'] = true;
			}
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_2checkout_enable_debug_email') == 1)
		{	
			$debug['post_data'] = $_POST;
			$debug['jrox_payment_data'] = $results['jrox_payment_data'];
			$this->security_model->_send_debug_email('2checkout Debug Email', $debug); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _ipn($type = '', $data = array())
	{
		$results = array('ipn_error' => false);
		
		//run ipn verification first
		if ($this->_validate_ipn($data['order_number'], $data['total'], $data['md5_hash']) == false)
		{
			$results['ipn_error'] = true;
			$results['jrox_error_message'] = $data['key'] . '!='. $this->config->item('module_payment_gateway_2checkout_md5_hash') . ' ' . $this->lang->line('invalid_security_code');
		}
		
		//check demo
		if ($this->input->post('demo') == 'Y')
		{
			if ($this->config->item('module_payment_gateway_2checkout_enable_testing') == 0)
			{
				$results['ipn_error'] = true;
				$results['jrox_error_message'] = $this->lang->line('invalid_demo_payment_sent');
			}
		}
		
		if ($results['ipn_error'] == false)
		{
			$results['jrox_product_type'] = 'products';
			
			switch ($this->input->post('message_type'))
			{
				case 'ORDER_CREATED':
				
					$results['jrox_payment_type'] = 'credit';
					
					$results['jrox_order_data'] = $this->security_model->_get_session_id($this->input->post('custom'));		
					
					if (!empty($results['jrox_order_data']))
					{
						$results['jrox_member_id'] = $results['jrox_order_data']['member_id'];
						
						$results['session_data'] = unserialize($results['jrox_order_data']['order_data']['session_data']);
						
						$results['jrox_payment_data'] = $this->_format_payment_data($data, $results['session_data']);
						
						$data['jrox_payment_data'] = $results['jrox_payment_data'];
					}
					else
					{
						$results['ipn_error'] = true;
					}
				
				break;
				
				case 'REFUND_ISSUED':
				
					//process refund
					$results['jrox_orig_trans_id'] = $this->input->post('parent_txn_id');
					$results['jrox_trans_id'] = $this->input->post('txn_id');
					$results['jrox_payment_type'] = 'refund';
					
					$order_data['invoice_notes'] = '';
					$results['jrox_payment_data'] = $this->_format_payment_data($data, $order_data);
						
					$results['data'] = $_POST;
					
				break;
				
			}
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_2checkout_enable_debug_email') == 1)
		{	
			$debug['post_data'] = $_POST;
			$debug['jrox_payment_data'] = $results['jrox_payment_data'];
			$this->security_model->_send_debug_email('2checkout Debug Email', $debug); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_fields($data = '', $type = '') 
	{
		$sdata = array(
								
				'sid'				=>		$this->config->item('module_payment_gateway_2checkout_id'),
				'c_prod'			=>		'1',
				'c_name'			=>		$this->config->item('sts_store_name') . ' ' . $this->lang->line('store_receipt'),
				'id_type'			=>		'2',
				'cart_order_id'		=>		$this->config->item('sts_store_name') . ' ' . $this->lang->line('store_receipt'),
				'c_price'			=>		$data['jrox_amount'],			
				'total'				=>		$data['jrox_amount'],			
				'sh_cost'			=>		'0',
				'member_id'			=>		$data['member_id'],
				'order_id'			=>		$this->session->userdata('session_id'),
				'jrox_product_type'	=>		$data['jrox_product_type'],

					);
		
		if (!empty($data['jrox_enable_product_trial']))
		{
			$sdata['c_price'] = $data['jrox_trial_amount'];
			$sdata['total'] = $data['jrox_trial_amount'];
		}
		
		if ($this->config->item('module_payment_gateway_2checkout_enable_testing') == 1)
		{
			$sdata['demo'] = 'Y';
		}
					
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_form_transfer($data = '')
	{	
		$sdata['form_code'] = '<p><img src="images/misc/gateways/2checkout.jpeg" alt="2checkout"/></p>
		                      <p><img src="themes/main/' . $this->config->item('layout_design_site_theme') .'/images/gateway-loader.gif" alt="" onload="document.frm.submit();"/></p>
							  <form action="' . $this->config->item('module_payment_gateway_2checkout_url') . '" method="post" name="frm">';
		
		//format the fields
		$form_data = $this->_format_fields($data, $data['jrox_product_type']);
		
		//add each field to the form		
		foreach ($form_data as $k => $v)
		{
			$sdata['form_code'] .= form_hidden($k, $v) . "\n";
		}
		
		$sdata['form_code'] .= form_submit('Submit', $this->lang->line('click_here_forwarding'));						  
								  
		$sdata['form_code'] .= '</form>';
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_2checkout($data = '')
	{
		$data['gateway_form_image'] = '<a href="https://www.2checkout.com/2co/signup?aff_id=37282" target="_blank"><img src="images/misc/gateways/2checkout.jpeg" border="0" alt=""/></a>';
			
		return $data;
	}
	
	
	
}
?>