<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_alertpay_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for alertpay IPN payments
|
*/

class Module_Payment_Gateway_Alertpay_Model extends Model {	
 	 
	function _install_jrox_module($id = '')
	{		
			
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_alertpay_email',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_alertpay_url',
							'settings_value'	=>	'https://www.alertpay.com/PayProcess.aspx',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_alertpay_currency_code',
							'settings_value'	=>	'USD',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_alertpay_disable_verification',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'4',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_alertpay_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_alertpay($data = '')
	{
		
		$array['valid'] = '2'; //1 is to run an internal function; 2 is to forward to gateway
		$array['function'] = ''; //the function to run if needed for internal processing
		$array['module_name'] = 'alertpay';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _validate_ipn($hash = '')
	{
		$key = $this->config->item('module_payment_gateway_alertpay_disable_verification');
		
		if (!empty($key))
		{
			if ($key != $hash)
			{
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($post_data = array(), $order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($post_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'alertpay');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			$order_data['invoice_notes'],
					  'jrox_payment_amount'				=>			$this->input->post('ap_totalamount', true),
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$this->input->post('ap_referencenumber', true),
					  'jrox_avs_code'					=>			'',
					  'jrox_membership_payment_type'	=> 			'alertpay',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _ipn($type = '', $data = array())
	{
		$results = array('ipn_error' => false);
		
		//run ipn verification first
		if ($this->_validate_ipn($data['ap_securitycode']) == false)
		{
			$results['ipn_error'] = true;
			$results['jrox_error_message'] =  $this->lang->line('invalid_security_code');
		}
		
		if ($results['ipn_error'] == false)
		{
			switch ($data['ap_purchasetype'])
			{
				case 'subscription':
					
					if ($data['ap_status'] == 'Subscription-Payment-Success')
					{
						$results['jrox_product_type'] = 'membership';
						$results['jrox_member_id'] = $data['apc_1'];
						$results['jrox_product_id'] = $data['apc_2'];
						
						//payment
						
						if (!empty($results['jrox_member_id']))
						{
							$results['jrox_payment_type'] = 'credit';
							$results['jrox_subscription_id'] = $data['ap_referencenumber'];
							$order_data['invoice_notes'] = '';
							$results['jrox_payment_data'] = $this->_format_payment_data($data, $order_data);
						}
						else
						{
							$results['ipn_error'] = true;
						}
					}
					else
					{
						$results['ipn_error'] = true;
					}
					
				break;
				
				default:
				
					$results['jrox_product_type'] = 'products';
				
					switch ($data['ap_status'])
					{
						case 'Success':
						
							$results['jrox_payment_type'] = 'credit';
							
							$results['jrox_order_data'] = $this->security_model->_get_session_id($this->input->post('apc_2') . ' - ' . $this->input->post('apc_1'));		
							
							if (!empty($results['jrox_order_data']))
							{
								$results['jrox_member_id'] = $results['jrox_order_data']['member_id'];
								
								$results['session_data'] = unserialize($results['jrox_order_data']['order_data']['session_data']);
								
								$results['jrox_payment_data'] = $this->_format_payment_data($data, $results['session_data']);
								
								$data['jrox_payment_data'] = $results['jrox_payment_data'];
							}
							else
							{
								$results['check_credit'] = true;
								
								$results['jrox_member_id'] = $this->input->post('apc_1');
								$order_data['invoice_notes'] = '';
								$results['jrox_payment_data'] = $this->_format_payment_data($data, $order_data);
							}
						
						break;
						
					}
					
				break;
			}
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_alertpay_enable_debug_email') == 1)
		{	
			$debug['post_data'] = $_POST;
			$debug['jrox_payment_data'] = $results['jrox_payment_data'];
			$this->security_model->_send_debug_email('AlertPay (IPN) Debug Email', $debug); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_fields($data = '', $type = '') 
	{
		if ($type != 'membership')
		{
			$sdata = array(
								
				'ap_merchant'		=>		$this->config->item('module_payment_gateway_alertpay_email'),
				'ap_returnurl'		=>		$this->config->item('checkout_url') . $this->config->slash_item('checkout_index_page') . 'thankyou/index/' . $data['payment_invoice_id'],
				'ap_cancelurl'		=>		base_url(),
				'ap_purchasetype'	=>		'item-goods',
				'ap_itemname'		=>		$this->config->item('sts_store_name') . ' ' . $this->lang->line('store_receipt'),
				'ap_itemcode'		=>		$this->session->userdata('session_id'). '-' . $data['member_id'],
				'ap_currency'		=>		$this->config->item('module_payment_gateway_alertpay_currency_code'),
				'ap_amount'			=>		$data['jrox_amount'],			
				'ap_quantity'		=>		'1',
				'apc_1'				=>		$data['member_id'],
				'apc_2'				=>		$this->session->userdata('session_id'),
				'apc_3'				=>		$data['fname'],
				'apc_4'				=>		$data['lname'],
				'ap_description'	=>		$this->config->item('sts_store_name') . ' ' . $this->lang->line('checkout_invoice'),
						  );
						  
		}
		else //set for memberships
		{
			$sdata = array(
								
				'ap_merchant'		=>		$this->config->item('module_payment_gateway_alertpay_email'),
				'ap_returnurl'		=>		$this->config->item('checkout_url') . $this->config->slash_item('checkout_index_page') . 'thankyou/membership/' . $data['pid'] . '/' . $data['payment_invoice_id'],
				'ap_cancelurl'		=>		base_url(),
				'ap_currency'		=>		$this->config->item('module_payment_gateway_alertpay_currency_code'),
				'ap_itemcode'		=>		$data['product_sku'],
				'ap_quantity'		=>		'1',
				'ap_itemname'		=> 		$data['product_name'],
				'ap_description'	=>		$data['product_name'],
				'ap_purchasetype'	=>		'subscription',
				'apc_1'				=>		$data['member_id'],
				'apc_2'				=>		$data['pid'],				
				'apc_3'				=>		$data['fname'],
				'apc_4'				=>		$data['lname'],				
			
					  );
			
			//pricing variables
			//trial periods
			
			if ($data['jrox_enable_product_trial'] == 1)
			{
				
				$sdata['ap_trialamount'] = $data['jrox_trial_amount'];
				$sdata['ap_trialperiodlength'] = $data['jrox_product_trial_interval'];
				$sdata['ap_trialtimeunit'] = $data['jrox_product_trial_interval_type'];
			}
			
			//regular amount
			$sdata['ap_amount']	= $data['jrox_amount'];
			$sdata['ap_timeunit']	= $data['jrox_recurring_interval_type'];
			$sdata['ap_periodlength']	= $data['jrox_recurring_interval'];

			if (!empty($data['jrox_recurring_interval_ends']))
			{
				$sdata['ap_periodcount'] = $data['jrox_recurring_interval_ends'];
			}			
		}
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_form_transfer($data = '')
	{	
		$sdata['form_code'] = '<p><img src="images/misc/gateways/alertpay.gif" alt="Alertpay"/></p>
		                      <p><img src="themes/main/' . $this->config->item('layout_design_site_theme') .'/images/gateway-loader.gif" alt="" onload="document.frm.submit();"/></p>
							  <form action="' . $this->config->item('module_payment_gateway_alertpay_url') . '" method="post" name="frm">';
		
		//format the fields
		$form_data = $this->_format_fields($data, $data['jrox_product_type']);
		
		//add each field to the form		
		foreach ($form_data as $k => $v)
		{
			$sdata['form_code'] .= form_hidden($k, $v) . "\n";
		}
		
		$sdata['form_code'] .= form_submit('Submit', $this->lang->line('click_here_forwarding'));						  
								  
		$sdata['form_code'] .= '</form>';
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_alertpay($data = '')
	{
		$data['gateway_form_image'] = '<a href="http://www.alertpay.com/?DsOMBDiXhZQnMZDKOxedUA%3d%3d" target="_blank"><img src="images/misc/gateways/alertpay.gif" border="0" alt=""/></a>';
			
		return $data;
	}
	
	
	
}
?>