<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_chargeback_guardian_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for authoirze.net AIM payments
|
*/

class Module_Payment_Gateway_Chargeback_Guardian_Model extends Model {
	
	function _install_jrox_module($id = '')
	{		
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_chargeback_guardian_url',
							'settings_value'	=>	'https://secure.chargebackguardiangateway.com/api/transact.php',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_chargeback_guardian_username',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_chargeback_guardian_password',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_chargeback_guardian_authorization_type',
							'settings_value'	=>	'sale',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_chargeback_guardian_require_cvv',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_chargeback_guardian_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'9',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_chargeback_guardian($data = '')
	{
		
		$rules['cg_card_name'] = 'trim|required|max_length[100]';	
		$rules['cg_card_number'] = 'trim|numeric|required|callback__verify_card_number';	
		$rules['cg_exp_month'] = 'trim|numeric|required';	
		$rules['cg_exp_year'] = 'trim|numeric|required';
		
		if ($this->config->item('module_payment_gateway_chargeback_guardian_require_cvv') == 1)
		{
			$rules['cg_card_cvv'] = 'trim|numeric|required';	
		}
		
		$this->validation->set_rules($rules);
		
		$fields['cg_card_name'] = $this->lang->line('cardholder_name');
		$fields['cg_card_number'] = $this->lang->line('cc_number');
		$fields['cg_exp_month'] = $this->lang->line('cc_month');
		$fields['cg_exp_year'] = $this->lang->line('cc_year');
		$fields['cg_card_cvv'] = $this->lang->line('cvv_code');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		$array['valid'] = '1'; //1 is to run an internal function; 2 is to forward to gateway; 3 is offline payment
		$array['function'] = '_process_guardian_payment';
		$array['module_name'] = 'chargeback_guardian';
		
		return $array; 
	}
	
	
	
	// ------------------------------------------------------------------------	
	
	function _process_guardian_payment($data = '', $invoice_id = '')
	{
		$amount = $data['jrox_amount'];
		
		//check for membership
		if ($data['jrox_product_type'] == 'membership')
		{
			if ($data['jrox_enable_product_trial'] == 1)
			{
				$amount = $data['jrox_trial_amount'];
			}
		}
		
		if ($amount > '0')
		{
			$auth_net_url = $this->config->item('module_payment_gateway_chargeback_guardian_url');
	
			$authnet_values	= array
			(
					'username' => $this->config->item('module_payment_gateway_chargeback_guardian_username'), 
					'password' => $this->config->item('module_payment_gateway_chargeback_guardian_password'),
					'type' => $this->config->item('module_payment_gateway_chargeback_guardian_authorization_type'),
					'amount' => number_format($amount, 2),
					'ccnumber' => $this->input->post('cg_card_number'),
					'ccexp' => $this->input->post('cg_exp_month').$this->input->post('cg_exp_year'),
					'payment' => 'creditcard',
					'orderid' => $invoice_id,
					'firstname' => $data['fname'],
					'lastname' => $data['lname'],
					'company' => $data['company'],
					'address1' => $data['billing_address_1'],
					'address2' => $data['billing_address_2'],
					'city' => $data['billing_city'],
					'state' => _get_region_name($data['billing_state'], 'region_code', 'region_name'),
					'zip' => $data['billing_postal_code'],
					'country' => _get_country_name($data['billing_country'], 'country_iso_code_2', 'country_id'),
					'phone' => $data['home_phone'],
					'email' => $data['primary_email'],
					'shipping_firstname' => $data['shipping_fname'],
					'shipping_lastname' => $data['shipping_lname'],
					'shipping_address1' => $data['shipping_address_1'],
					'shipping_address2' => $data['shipping_address_2'],
					'shipping_city' => $data['shipping_city'],
					'shipping_state' => _get_region_name($data['shipping_state'], 'region_code', 'region_name'),
					'shipping_zip' => $data['shipping_postal_code'],
					'shipping_country' => _get_country_name($data['shipping_country'], 'country_iso_code_2', 'country_id'),
					'orderdescription' => '',
					
					// Merchant defined variables go here
					'ipaddress' => $this->input->ip_address(),
			);
			
			if ($this->config->item('module_payment_gateway_chargeback_guardian_require_cvv') == 1)
			{
				$authnet_values["cvv"] = $this->input->post('card_cvv');
			}
			
			$fields = "";
			foreach( $authnet_values as $key => $value ) $fields .= "$key=" . urlencode( $value ) . "&";
			
			$resp = connect_curl($auth_net_url, true, $fields, 1, $this->config->item('sts_store_set_curl_timeout'));
			
			$new = explode('&', $resp);

			$results = array();
			foreach ($new as $res)
			{
				$a = explode('=', $res);
				
				$results[$a[0]] = $a[1];
			}
			
			if ($results['response'] == 1) //SUCCESS
			{
				$module_data = $this->modules->_get_module_column('module_file_name', 'chargeback_guardian');
				
				$results['jrox_error'] = false;
				$results['jrox_error_message'] = '';
				$results['jrox_payment_notes'] = '';
				$results['jrox_debug_info'] = $resp;
				$results['jrox_payment_method'] = $module_data['module_name'];
				$results['jrox_payment_amount'] = $amount;
				$results['jrox_trans_id'] = $results['transactionid'];	
				$results['jrox_avs_code'] = $results['avsresponse'];	
				$results['jrox_membership_payment_type'] = 'chargeback_guardian';
			}
			else
			{			
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $results['responsetext'];
			}
		}
		else
		{
			$results['jrox_error'] = false;
			$results['jrox_error_message'] = '';
			$results['jrox_payment_notes'] = '';
			$results['jrox_debug_info'] = '';
			$results['jrox_payment_method'] = $this->lang->line('chargeback_guardian');
			$results['jrox_payment_amount'] = '0.00';
			$results['jrox_trans_id'] = $this->lang->line('checkout_free_trial');	
			$results['jrox_avs_code'] = '';
			$results['jrox_membership_payment_type'] = 'chargeback_guardian';
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_chargeback_guardian_enable_debug_email') == 1)
		{
			$this->security_model->_send_debug_email('Chargeback Guardian Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_chargeback_guardian($data = '')
	{
		
		$month_options = _generate_months();
		$year_options = _generate_years('y');
		
		$cur_month = date('m');
		$cur_year = date('Y');
		
		
		$data['gateway_form_image'] = '<table width="100%" border="0" align="center" cellpadding="5" cellspacing="1">

             <tr>
                <td ><strong>' . $this->lang->line('cardholder_name') . ' * </strong></td>

                <td width="32%" colspan="2" ><input name="cg_card_name" type="text" id="cg_card_name" value="" size="30" maxlength="100" /></td>
                </tr>
              <tr>
                <td ><strong >' . $this->lang->line('cc_number') . ' * </strong></td>
                <td width="32%" colspan="2" ><input name="cg_card_number" type="text" id="cg_card_number" value="" size="30" maxlength="50" /></td>
                </tr>
              
              
              <tr>
                <td ><strong>' . $this->lang->line('expiration_date') . ' * </strong></td>

                <td colspan="2">' . form_dropdown('cg_exp_month', $month_options, $cur_month) . ' /  ' . form_dropdown('cg_exp_year', $year_options, $cur_year) . '
                
				                </td>
              </tr>';
         
		 
		if ($this->config->item('module_payment_gateway_chargeback_guardian_require_cvv') == 1)
		{      
        	$data['gateway_form_image'] .= '<tr>
                <td width="37%" ><strong>' . $this->lang->line('cvv_code') . ' * </strong></td>
                <td colspan="2" ><input name="cg_card_cvv" type="text" id="cg_card_cvv" value="" size="5" maxlength="5" /></td>
                </tr>';
        }   

              
          $data['gateway_form_image'] .=  '</table>';
	
		return $data;
	}
	
}
?>