<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_egold_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for egold payments
|
*/

class Module_Payment_Gateway_egold_Model extends Model {	
 	 
	function _install_jrox_module($id = '')
	{		
			
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_egold_id',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_egold_url',
							'settings_value'	=>	'https://www.e-gold.com/sci_asp/payments.asp',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_egold_secret_word',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'4',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_egold_payment_units',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_egold_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_egold($data = '')
	{
		
		$array['valid'] = '2'; //1 is to run an internal function; 2 is to forward to gateway
		$array['function'] = ''; //the function to run if needed for internal processing
		$array['module_name'] = 'egold';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _validate_ipn($hash = '')
	{		
		$key = $this->config->item('module_payment_gateway_egold_secret_word');
		
		if (!empty($key))
		{
			$egold_secret = strtoupper(md5($this->config->item('module_payment_gateway_egold_secret_word')));
			$key_compare = strtoupper(md5($_POST['PAYMENT_ID'].":".$_POST['PAYEE_ACCOUNT'].":".$_POST['PAYMENT_AMOUNT'].":".$_POST['PAYMENT_UNITS'].":".$_POST['PAYMENT_METAL_ID'].":".$_POST['PAYMENT_BATCH_NUM'].":".$_POST['PAYER_ACCOUNT'].":".$egold_secret.":".$_POST['ACTUAL_PAYMENT_OUNCES'].":".$_POST['USD_PER_OUNCE'].":".$_POST['FEEWEIGHT'].":".$_POST['TIMESTAMPGMT']));
			
			if ($key_compare != $hash)
			{
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($post_data = array(), $order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($post_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'egold');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			$order_data['invoice_notes'],
					  'jrox_payment_amount'				=>			$this->input->post('PAYMENT_AMOUNT', true),
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$this->input->post('PAYMENT_BATCH_NUM', true),
					  'jrox_avs_code'					=>			'',
					  'jrox_membership_payment_type'	=> 			'egold',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _ipn($type = '', $data = array())
	{
		$results = array('ipn_error' => false);
		
		//run ipn verification first
		if ($this->_validate_ipn($this->input->post('V2_HASH')) == false)
		{
			$results['ipn_error'] = true;
			$results['jrox_error_message'] = $this->lang->line('invalid_security_code');
		}
		
		if ($results['ipn_error'] == false)
		{
			$results['jrox_product_type'] = 'products';
			
			$results['jrox_payment_type'] = 'credit';
							
			$results['jrox_order_data'] = $this->security_model->_get_session_id($this->input->post('ORDER_ID'));		
			
			if (!empty($results['jrox_order_data']))
			{
				$results['jrox_member_id'] = $results['jrox_order_data']['member_id'];
				
				$results['session_data'] = unserialize($results['jrox_order_data']['order_data']['session_data']);
				
				$results['jrox_payment_data'] = $this->_format_payment_data($data, $results['session_data']);
				
				$data['jrox_payment_data'] = $results['jrox_payment_data'];
			}
			else
			{
				$results['ipn_error'] = true;
			}
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_egold_enable_debug_email') == 1)
		{	
			$this->security_model->_send_debug_email('eGold Payment Status Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_fields($data = '', $type = '') 
	{
		//check for membership
		$amount = $data['jrox_amount'];
		
		if ($data['jrox_product_type'] == 'membership')
		{
			if ($data['jrox_enable_product_trial'] == 1)
			{
				$amount = $data['jrox_trial_amount'];
			}
		}
		
		$sdata = array(
								
				'PAYEE_ACCOUNT'		=>		$this->config->item('module_payment_gateway_egold_id'),
				'PAYEE_NAME'		=>		$this->config->item('sts_store_name') . ' ' . $this->lang->line('checkout_invoice'),
				'PAYMENT_UNITS'		=>		$this->config->item('module_payment_gateway_egold_payment_units'),
				'PAYMENT_AMOUNT'	=>		$amount,	
				'PAYMENT_METAL_ID'	=>		'0',
				'STATUS_URL'		=>		base_url() . $this->config->item('index_page') . '/checkout/ipn/products/egold',
				'NOPAYMENT_URL'		=>		base_url(),
				'BAGGAGE_FIELDS'	=>		'ORDER_ID',
				'ORDER_ID'			=>		$this->session->userdata('session_id'). '-' . $data['member_id'],
				'PAYMENT_METHOD'	=>		'e-gold account',
					);
		
		if ($data['jrox_product_type'] == 'membership')
		{
			$sdata['PAYMENT_URL'] =	$this->config->item('checkout_url') . $this->config->slash_item('checkout_index_page') . 'thankyou/membership/' . $data['pid'] . '/' . $data['payment_invoice_id'];
		}
		else
		{
			$sdata['PAYMENT_URL'] =	$this->config->item('checkout_url') . $this->config->slash_item('checkout_index_page') . 'thankyou/index/' . $data['payment_invoice_id'];
		}
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_form_transfer($data = '')
	{	
		$sdata['form_code'] = '<p><img src="images/misc/gateways/egold.gif" alt="egold"/></p>
		                      <p><img src="themes/main/' . $this->config->item('layout_design_site_theme') .'/images/gateway-loader.gif" alt="" onload="document.frm.submit();"/></p>
							  <form action="' . $this->config->item('module_payment_gateway_egold_url') . '" method="post" name="frm">';
		
		//format the fields
		$form_data = $this->_format_fields($data, $data['jrox_product_type']);
		
		//add each field to the form		
		foreach ($form_data as $k => $v)
		{
			$sdata['form_code'] .= form_hidden($k, $v) . "\n";
		}
		
		$sdata['form_code'] .= form_submit('Submit', $this->lang->line('click_here_forwarding'));						  
								  
		$sdata['form_code'] .= '</form>';
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_egold($data = '')
	{
		$data['gateway_form_image'] = '<a href="http://www.e-gold.com/e-gold.asp?cid=3409802" target="_blank"><img src="images/misc/gateways/egold.gif" border="0" alt=""/></a>';
			
		return $data;
	}
	
	
	
}
?>