<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_eway_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for authoirze.net AIM payments
|
*/

class Module_Payment_Gateway_eway_Model extends Model {	
	
	var $myGatewayURL;
    var $myCustomerID;
    var $myTransactionData = array();
    var $myCurlPreferences = array();
	
	function _install_jrox_module($id = '')
	{		
		//check admin session
		$this->security_model->_check_admin_session();
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_eway_merchant_id',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_eway_payment_method',
							'settings_value'	=>	'REAL_TIME',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_eway_enable_testing',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'4',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_eway_require_cvv',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_eway_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_eway($data = '')
	{
		
		$rules['eway_card_name'] = 'trim|required|max_length[100]';	
		$rules['eway_card_number'] = 'trim|numeric|required|callback__verify_card_number';	
		$rules['eway_exp_month'] = 'trim|numeric|required';	
		$rules['eway_exp_year'] = 'trim|numeric|required';
		
		if ($this->config->item('module_payment_gateway_eway_require_cvv') == 1)
		{
			$rules['eway_card_cvv'] = 'trim|numeric|required';	
		}
		
		$this->validation->set_rules($rules);
		
		$fields['eway_card_name'] = $this->lang->line('cardholder_name');
		$fields['eway_card_number'] = $this->lang->line('cc_number');
		$fields['eway_exp_month'] = $this->lang->line('cc_month');
		$fields['eway_exp_year'] = $this->lang->line('cc_year');
		$fields['eway_card_cvv'] = $this->lang->line('cvv_code');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		$array['valid'] = '1'; //1 is to run an internal function; 2 is to forward to gateway; 3 is offline payment
		$array['function'] = '_process_eway_payment';
		$array['module_name'] = 'eway';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($order_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'eway');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			'',
					  'jrox_payment_amount'				=>			$order_data['x_amount'],
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$order_data['x_trans_id'],
					  'jrox_avs_code'					=>			$order_data['x_avs_code'],
					  'jrox_membership_payment_type'	=> 			'eway',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _process_eway_payment($data = '')
	{
		//define default values for eway
		define('EWAY_DEFAULT_CUSTOMER_ID', $this->config->item('module_payment_gateway_eway_merchant_id'));
		define('EWAY_DEFAULT_PAYMENT_METHOD', $this->config->item('module_payment_gateway_eway_payment_method')); // possible values are: REAL_TIME, REAL_TIME_CVN, GEO_IP_ANTI_FRAUD
	
	
		//define URLs for payment gateway
		define('EWAY_PAYMENT_LIVE_REAL_TIME', 'https://www.eway.com.au/gateway/xmlpayment.asp');
		define('EWAY_PAYMENT_LIVE_REAL_TIME_TESTING_MODE', 'https://www.eway.com.au/gateway/xmltest/testpage.asp');
		define('EWAY_PAYMENT_LIVE_REAL_TIME_CVN', 'https://www.eway.com.au/gateway_cvn/xmlpayment.asp');
		define('EWAY_PAYMENT_LIVE_REAL_TIME_CVN_TESTING_MODE', 'https://www.eway.com.au/gateway_cvn/xmltest/testpage.asp');
		define('EWAY_PAYMENT_LIVE_GEO_IP_ANTI_FRAUD', 'https://www.eway.com.au/gateway_beagle/xmlbeagle.asp');
		define('EWAY_PAYMENT_LIVE_GEO_IP_ANTI_FRAUD_TESTING_MODE', 'https://www.eway.com.au/gateway_beagle/test/xmlbeagle_test.asp'); //in testing mode process with REAL-TIME
		define('EWAY_PAYMENT_HOSTED_REAL_TIME', 'https://www.eway.com.au/gateway/payment.asp');
		define('EWAY_PAYMENT_HOSTED_REAL_TIME_TESTING_MODE', 'https://www.eway.com.au/gateway/payment.asp');
		define('EWAY_PAYMENT_HOSTED_REAL_TIME_CVN', 'https://www.eway.com.au/gateway_cvn/payment.asp');
		define('EWAY_PAYMENT_HOSTED_REAL_TIME_CVN_TESTING_MODE', 'https://www.eway.com.au/gateway_cvn/payment.asp');
		
		
		//set testing mode
		$liveGateway = $this->config->item('module_payment_gateway_eway_enable_testing') == 1 ? false : true;

		
		//set customer ID
		$this->myCustomerID = $this->config->item('module_payment_gateway_eway_merchant_id');
		
	    switch($this->config->item('module_payment_gateway_eway_payment_method')){

		    case "REAL_TIME";

		    		if($liveGateway)
		    			$this->myGatewayURL = EWAY_PAYMENT_LIVE_REAL_TIME;
		    		else
	    				$this->myGatewayURL = EWAY_PAYMENT_LIVE_REAL_TIME_TESTING_MODE;
	    		break;
	    	 case "REAL_TIME_CVN";
		    		if($liveGateway)
		    			$this->myGatewayURL = EWAY_PAYMENT_LIVE_REAL_TIME_CVN;
		    		else
	    				$this->myGatewayURL = EWAY_PAYMENT_LIVE_REAL_TIME_CVN_TESTING_MODE;
	    		break;
	    	case "GEO_IP_ANTI_FRAUD";
		    		if($liveGateway)
		    			$this->myGatewayURL = EWAY_PAYMENT_LIVE_GEO_IP_ANTI_FRAUD;
		    		else
		    			//in testing mode process with REAL-TIME
	    				$this->myGatewayURL = EWAY_PAYMENT_LIVE_GEO_IP_ANTI_FRAUD_TESTING_MODE;
	    		break;
    	}
		
		
		$amount = $data['jrox_amount'];
		
		//check for membership
		if ($data['jrox_product_type'] == 'membership')
		{
			if ($data['jrox_enable_product_trial'] == 1)
			{
				$amount = $data['jrox_trial_amount'];
			}
		}
		
		if ($amount > '0')
		{
			$this->setTransactionData("TotalAmount", ($amount * 100)); //mandatory field
			$this->setTransactionData("CustomerFirstName", $data['fname']);
			$this->setTransactionData("CustomerLastName", $data['lname']);
			$this->setTransactionData("CustomerEmail", $data['primary_email']);
			$this->setTransactionData("CustomerAddress", $data['billing_address_1']);
			$this->setTransactionData("CustomerPostcode", $data['billing_postal_code']);
			$this->setTransactionData("CustomerInvoiceDescription", $this->config->item('sts_store_name') . " " . $this->lang->line('checkout_invoice'));
			$this->setTransactionData("CustomerInvoiceRef", $this->session->userdata('userid'));
			$this->setTransactionData("CardHoldersName", $this->input->post('eway_card_name')); //mandatory field
			$this->setTransactionData("CardNumber", $this->input->post('eway_card_number')); //mandatory field
			$this->setTransactionData("CardExpiryMonth", $this->input->post('eway_exp_month')); //mandatory field
			$this->setTransactionData("CardExpiryYear", $this->input->post('eway_exp_year')); //mandatory field
			$this->setTransactionData("TrxnNumber", $this->session->userdata('userid'));
			$this->setTransactionData("Option1", $this->session->userdata('userid'));
			$this->setTransactionData("Option2", "");
			$this->setTransactionData("Option3", "");
			
			//for REAL_TIME_CVN
			if ($this->config->item('module_payment_gateway_eway_require_cvv') == 1)
			{  
				$this->setTransactionData("CVN", $this->input->post('eway_card_cvv'));
			}
			
			//for GEO_IP_ANTI_FRAUD
			$this->setTransactionData("CustomerIPAddress", $this->getVisitorIP()); //mandatory field when using Geo-IP Anti-Fraud
			$this->setTransactionData("CustomerBillingCountry", _get_country_name($data['billing_country'], 'country_iso_code_2', 'country_id')); //mandatory field when using Geo-IP Anti-Fraud
			
			
			//special preferences for php Curl
			$this->setCurlPreferences(CURLOPT_SSL_VERIFYPEER, 0);  //pass a long that is set to a zero value to stop curl from verifying the peer's certificate 
			//$this->setCurlPreferences(CURLOPT_CAINFO, "/usr/share/ssl/certs/my.cert.crt"); //Pass a filename of a file holding one or more certificates to verify the peer with. This only makes sense when used in combination with the CURLOPT_SSL_VERIFYPEER option. 
			//$this->setCurlPreferences(CURLOPT_CAPATH, "/usr/share/ssl/certs/my.cert.path");
			//$this->setCurlPreferences(CURLOPT_PROXYTYPE, CURLPROXY_HTTP); //use CURL proxy, for example godaddy.com hosting requires it
			//$this->setCurlPreferences(CURLOPT_PROXY, "http://proxy.shr.secureserver.net:3128"); //use CURL proxy, for example godaddy.com hosting requires it
			
			$ewayResponseFields = $this->doPayment();
		
			/*
			if($ewayResponseFields["EWAYTRXNSTATUS"]=="False"){
				print "Transaction Error: " . $ewayResponseFields["EWAYTRXNERROR"] . "<br>\n";		
				foreach($ewayResponseFields as $key => $value)
					print "\n<br>\$ewayResponseFields[\"$key\"] = $value";
		
			}else if($ewayResponseFields["EWAYTRXNSTATUS"]=="True"){
				print "Transaction Success: " . $ewayResponseFields["EWAYTRXNERROR"]  . "<br>\n";
				foreach($ewayResponseFields as $key => $value)
					print "\n<br>\$ewayResponseFields[\"$key\"] = $value";

			}
			*/
			
			if ($ewayResponseFields["EWAYTRXNSTATUS"] == "True") //SUCCESS
			{
				/*
				$ewayResponseFields["EWAYTRXNSTATUS"] = True
				$ewayResponseFields["EWAYTRXNNUMBER"] = 10486
				$ewayResponseFields["EWAYTRXNREFERENCE"] = 20
				$ewayResponseFields["EWAYTRXNOPTION1"] = 20
				$ewayResponseFields["EWAYAUTHCODE"] = 123456
				$ewayResponseFields["EWAYRETURNAMOUNT"] = 1000
				$ewayResponseFields["EWAYTRXNERROR"] = 00,Transaction Approved(Test CVN Gateway)
				*/
				
				$module_data = $this->modules->_get_module_column('module_file_name', 'eway');
				
				$payment_notes = '';
				foreach ($ewayResponseFields as $key => $value)
				{
					$payment_notes .= $key. ': ' . $value . "\n";
				}
					
				$results['jrox_error'] = false;
				$results['jrox_error_message'] = '';
				$results['jrox_payment_notes'] = $payment_notes;
				$results['jrox_debug_info'] = print_r($ewayResponseFields, true);
				$results['jrox_payment_method'] = $module_data['module_name'];
				$results['jrox_payment_amount'] = ($ewayResponseFields["EWAYRETURNAMOUNT"] / 100);
				$results['jrox_trans_id'] = $ewayResponseFields["EWAYTRXNNUMBER"];
				$results['jrox_avs_code'] = '';
				$results['jrox_membership_payment_type'] = 'eway';
			}
			else
			{			
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $ewayResponseFields["EWAYTRXNERROR"];
			}
		}
		else
		{
			$results['jrox_error'] = false;
			$results['jrox_error_message'] = '';
			$results['jrox_payment_notes'] = '';
			$results['jrox_debug_info'] = '';
			$results['jrox_payment_method'] = 'eWay';
			$results['jrox_payment_amount'] = '0.00';
			$results['jrox_trans_id'] = $this->lang->line('checkout_free_trial');	
			$results['jrox_avs_code'] = '';
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_eway_enable_debug_email') == 1)
		{
			$this->security_model->_send_debug_email('eWay Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_eway($data = '')
	{
		
		$month_options = _generate_months();
		$year_options = _generate_years('y');
		
		$cur_month = date('m');
		$cur_year = date('y');
		
		
		$data['gateway_form_image'] = '<table width="100%" border="0" align="center" cellpadding="5" cellspacing="1">

             <tr>
                <td ><strong>' . $this->lang->line('cardholder_name') . ' * </strong></td>

                <td width="32%" colspan="2" ><input name="eway_card_name" type="text" id="eway_card_name" value="" size="30" maxlength="100" /></td>
                </tr>
              <tr>
                <td ><strong >' . $this->lang->line('cc_number') . ' * </strong></td>
                <td width="32%" colspan="2" ><input name="eway_card_number" type="text" id="eway_card_number" value="" size="30" maxlength="50" /></td>
                </tr>
              
              
              <tr>
                <td ><strong>' . $this->lang->line('expiration_date') . ' * </strong></td>

                <td colspan="2">' . form_dropdown('eway_exp_month', $month_options, $cur_month) . ' /  ' . form_dropdown('eway_exp_year', $year_options, $cur_year) . '
                
				                </td>
              </tr>';
         
		 
		if ($this->config->item('module_payment_gateway_eway_require_cvv') == 1)
		{      
        	$data['gateway_form_image'] .= '<tr>
                <td width="37%" ><strong>' . $this->lang->line('cvv_code') . ' * </strong></td>
                <td colspan="2" ><input name="eway_card_cvv" type="text" id="eway_card_cvv" value="" size="5" maxlength="5" /></td>
                </tr>';
        }   

              
          $data['gateway_form_image'] .=  '</table>';
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	//Payment Function
	function doPayment() {
		$xmlRequest = "<ewaygateway><ewayCustomerID>" . $this->myCustomerID . "</ewayCustomerID>";
		foreach($this->myTransactionData as $key=>$value)
			$xmlRequest .= "<$key>$value</$key>";
        $xmlRequest .= "</ewaygateway>";

		$xmlResponse = $this->sendTransactionToEway($xmlRequest);

		if($xmlResponse!=""){
			$responseFields = $this->parseResponse($xmlResponse);
			return $responseFields;
		}
                else die("Error in XML response from eWAY: " + $xmlResponse);
	}

	//Send XML Transaction Data and receive XML response
	function sendTransactionToEway($xmlRequest) {
		$ch = curl_init($this->myGatewayURL);
                curl_setopt($ch, CURLOPT_POST, 1);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $xmlRequest);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        foreach($this->myCurlPreferences as $key=>$value)
        	curl_setopt($ch, $key, $value);

        $xmlResponse = curl_exec($ch);

        if(curl_errno( $ch ) == CURLE_OK)
        	return $xmlResponse;
	}
	
	
	//Parse XML response from eway and place them into an array
	function parseResponse($xmlResponse){
		$xml_parser = xml_parser_create();
		xml_parse_into_struct($xml_parser,  $xmlResponse, $xmlData, $index);
        $responseFields = array();
        foreach($xmlData as $data)
	    	if($data["level"] == 2)
			{
        		if (!empty($data['value']))
				{
					$responseFields[$data["tag"]] = $data["value"];
        		}
			}
		return $responseFields;
	}
	
	
	//Set Transaction Data
	//Possible fields: "TotalAmount", "CustomerFirstName", "CustomerLastName", "CustomerEmail", "CustomerAddress", "CustomerPostcode", "CustomerInvoiceDescription", "CustomerInvoiceRef",
	//"CardHoldersName", "CardNumber", "CardExpiryMonth", "CardExpiryYear", "TrxnNumber", "Option1", "Option2", "Option3", "CVN", "CustomerIPAddress", "CustomerBillingCountry"
	function setTransactionData($field, $value) {
		//if($field=="TotalAmount")
		//	$value = round($value*100);
		$this->myTransactionData["eway" . $field] = htmlentities(trim($value));
	}
	
	
	//receive special preferences for Curl
	function setCurlPreferences($field, $value) {
		$this->myCurlPreferences[$field] = $value;
	}
		
	
	//obtain visitor IP even if is under a proxy
	function getVisitorIP(){
		
		return $this->input->ip_address();
	}
	
}
?>