<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_goemerchant_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for GoEmerchant payments
|
*/

class Module_Payment_Gateway_Goemerchant_Model extends Model {	
	
	function _install_jrox_module($id = '')
	{		
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_goemerchant_url',
							'settings_value'	=>	'https://secure.goemerchant.com/secure/gateway/aegateway.aspx',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_goemerchant_merchant_id',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_goemerchant_transaction_key',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_goemerchant_authorization_type',
							'settings_value'	=>	'AUTH_CAPTURE',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'cc_auth_type',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_goemerchant_require_cvv',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);

		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_goemerchant_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'9',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);

		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_goemerchant($data = '')
	{
		
		$rules['go_card_name'] = 'trim|required|max_length[100]';	
		$rules['go_card_number'] = 'trim|numeric|required|callback__verify_card_number';	
		$rules['go_exp_month'] = 'trim|numeric|required';	
		$rules['go_exp_year'] = 'trim|numeric|required';
		
		if ($this->config->item('module_payment_gateway_goemerchant_require_cvv') == 1)
		{
			$rules['go_card_cvv'] = 'trim|numeric|required';	
		}
		
		$this->validation->set_rules($rules);
		
		$fields['go_card_name'] = $this->lang->line('cardholder_name');
		$fields['go_card_number'] = $this->lang->line('cc_number');
		$fields['go_exp_month'] = $this->lang->line('cc_month');
		$fields['go_exp_year'] = $this->lang->line('cc_year');
		$fields['go_card_cvv'] = $this->lang->line('cvv_code');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		$array['valid'] = '1'; //1 is to run an internal function; 2 is to forward to gateway; 3 is offline payment
		$array['function'] = '_process_goemerchant_payment';
		$array['module_name'] = 'goemerchant';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($order_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'goemerchant');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			'',
					  'jrox_payment_amount'				=>			$order_data['x_amount'],
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$order_data['x_trans_id'],
					  'jrox_avs_code'					=>			$order_data['x_avs_code'],
					  'jrox_membership_payment_type'	=> 			'goemerchant',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _ipn($type = '', $data = array())
	{
		
		if (empty($_POST)) { exit(); }

		$sdata = explode('&', $_POST);
		$results['ipn_error'] = false;
		
		foreach ($sdata as $v)
		{
			$rows = explode('=', $v);
			$results[$rows[0]] = urldecode($rows[1]);
		}
		
		//validate md5 hash
		if ($this->_validate_ipn($results['x_trans_id'], $results['x_amount'], $results['x_MD5_Hash']) == false)
		{
			$results['ipn_error'] = true;
			$results['jrox_error_message'] = $this->lang->line('invalid_security_hash');
		}
					
		$results['jrox_product_type'] = 'membership';
		
		//get the membership info via subscription id
		
		if (!empty($results['x_subscription_id']))
		{
			$membership_info = $this->members->_get_membership_subscription($results['x_subscription_id']);
			
			if (empty($membership_info)) { exit(); }
			
			$results['jrox_member_id'] = $membership_info['member_id'];
			$results['jrox_product_id'] = $membership_info['product_id'];
			
			//payment
			if (!empty($results['x_type']))
			{
				switch (strtolower($results['x_type']))
				{
					case 'auth_capture':
					case 'auth_only':		
						
						if (!empty($results['jrox_member_id']))
						{
							$results['jrox_payment_type'] = 'credit';
							$results['jrox_subscription_id'] = $results['x_subscription_id'];
							$results['jrox_payment_data'] = $this->_format_payment_data($results);
						}
						else
						{
							$results['ipn_error'] = true;
						}
					
					break;
				}
			
				//check for debug info
				if ($this->config->item('module_payment_gateway_goemerchant_enable_debug_email') == 1)
				{
					$this->security_model->_send_debug_email('Go eMerchant Recurring Billing Debug Email', $results); 
				}
			}
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _process_goemerchant_payment($data = '', $invoice_id = '')
	{
		$amount = $data['jrox_amount'];
		
		$transaction_type = $this->config->item('module_payment_gateway_goemerchant_authorization_type') == 'AUTH_ONLY' ? 'auth' : 'sale';
		
		//check for membership
		if ($data['jrox_product_type'] == 'membership')
		{
			if ($data['jrox_enable_product_trial'] == 1)
			{
				$amount = $data['jrox_trial_amount'];
			}
		}
		
		if ($amount > '0')
		{
			$auth_net_url = $this->config->item('module_payment_gateway_goemerchant_url');
	
			$authnet_values	= array
			(
					'x_version' => '1.0',
					'x_login' => $this->config->item('module_payment_gateway_goemerchant_merchant_id'), 
					'x_password' => $this->config->item('module_payment_gateway_goemerchant_transaction_key'),
					//'x_tran_key' => $this->config->item('module_payment_gateway_goemerchant_transaction_key'),
					'x_type' => $transaction_type,
					'x_invoice_num' => $invoice_id,
					'x_amount' => number_format($amount, 2),
					//x_card_name
					'x_card_num' => $this->input->post('card_number'),
					'x_exp_date' => $this->input->post('exp_month').$this->input->post('exp_year'),
					
					'x_first_name' => $data['fname'],
					'x_last_name' => $data['lname'],
					'x_company' => $data['company'],
					'x_address' => $data['billing_address_1'],
					'x_city' => $data['billing_city'],
					'x_state' => _get_region_name($data['billing_state'], 'region_code', 'region_name'),
					'x_zip' => $data['billing_postal_code'],
					'x_country' => _get_country_name($data['billing_country'], 'country_name', 'country_id'),
					'x_phone' => $data['home_phone'],
					'x_email' => $data['primary_email'],
					"x_remote_ip_address"			=> $this->input->ip_address(),
					
					'x_method' => 'CC',
					'x_cust_id' => $this->session->userdata('userid'),
					
					
					// Merchant defined variables go here
					'Date' =>  date('M d, Y h:i:s A'),
					'IP' => $this->input->ip_address(),
					'Session' => $this->config->item('enc_id'),
					
			);
			
			if ($this->config->item('module_payment_gateway_goemerchant_require_cvv') == 1)
			{
				$authnet_values["x_card_code"] = $this->input->post('card_cvv');
			}
			
			$fields = "";
			foreach( $authnet_values as $key => $value ) $fields .= "$key=" . urlencode( $value ) . "&";
			
			$resp = connect_curl($auth_net_url, true, $fields, 1, $this->config->item('sts_store_set_curl_timeout'));
			
			$results = explode(',', $resp);
			
			
			if ($results[0] == 1) //SUCCESS
			{
				$module_data = $this->modules->_get_module_column('module_file_name', 'goemerchant');
				
				$results['jrox_error'] = false;
				$results['jrox_error_message'] = '';
				$results['jrox_payment_notes'] = '';
				$results['jrox_debug_info'] = $resp;
				$results['jrox_payment_method'] = $module_data['module_name'];
				$results['jrox_payment_amount'] = $results[9];
				$results['jrox_trans_id'] = $results[6];	
				$results['jrox_avs_code'] = $results[5];
				$results['jrox_membership_payment_type'] = 'goemerchant';
			}
			else
			{			
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $results[3];
			}
		}
		else
		{
			$results['jrox_error'] = false;
			$results['jrox_error_message'] = '';
			$results['jrox_payment_notes'] = '';
			$results['jrox_debug_info'] = '';
			$results['jrox_payment_method'] = $this->lang->line('authorize_net');
			$results['jrox_payment_amount'] = '0.00';
			$results['jrox_trans_id'] = $this->lang->line('checkout_free_trial');	
			$results['jrox_avs_code'] = '';
			$results['jrox_membership_payment_type'] = 'goemerchant';
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_goemerchant_enable_debug_email') == 1)
		{
			$this->security_model->_send_debug_email('GoEmerchant Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_goemerchant($data = '')
	{
		
		$month_options = _generate_months();
		$year_options = _generate_years();
		
		$cur_month = date('m');
		$cur_year = date('Y');
		
		
		$data['gateway_form_image'] = '<table width="100%" border="0" align="center" cellpadding="5" cellspacing="1">

             <tr>
                <td ><strong>' . $this->lang->line('cardholder_name') . ' * </strong></td>

                <td width="32%" colspan="2" ><input name="go_card_name" type="text" id="go_card_name" value="" size="30" maxlength="100" /></td>
                </tr>
              <tr>
                <td ><strong >' . $this->lang->line('cc_number') . ' * </strong></td>
                <td width="32%" colspan="2" ><input name="go_card_number" type="text" id="go_card_number" value="" size="30" maxlength="50" /></td>
                </tr>
              
              
              <tr>
                <td ><strong>' . $this->lang->line('expiration_date') . ' * </strong></td>

                <td colspan="2">' . form_dropdown('go_exp_month', $month_options, $cur_month) . ' /  ' . form_dropdown('go_exp_year', $year_options, $cur_year) . '
                
				                </td>
              </tr>';
         
		 
		if ($this->config->item('module_payment_gateway_goemerchant_require_cvv') == 1)
		{      
        	$data['gateway_form_image'] .= '<tr>
                <td width="37%" ><strong>' . $this->lang->line('cvv_code') . ' * </strong></td>
                <td colspan="2" ><input name="go_card_cvv" type="text" id="go_card_cvv" value="" size="5" maxlength="5" /></td>
                </tr>';
        }   

              
          $data['gateway_form_image'] .=  '</table>';
	
		return $data;
	}
	
}
?>