<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_liberty_reserve_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for liberty_reserve IPN payments
|
*/

class Module_Payment_Gateway_liberty_reserve_Model extends Model {	
 	 
	function _install_jrox_module($id = '')
	{		
			
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_liberty_reserve_id',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_liberty_reserve_url',
							'settings_value'	=>	'https://sci.libertyreserve.com',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_liberty_reserve_secret_word',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'4',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_liberty_reserve_store_name',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_liberty_reserve_currency_code',
							'settings_value'	=>	'LRUSD',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_liberty_reserve_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'7',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_liberty_reserve($data = '')
	{
		
		$array['valid'] = '2'; //1 is to run an internal function; 2 is to forward to gateway
		$array['function'] = ''; //the function to run if needed for internal processing
		$array['module_name'] = 'liberty_reserve';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _validate_ipn($hash = '')
	{
		$secret = $this->config->item('module_payment_gateway_liberty_reserve_secret_word');
		
		if (!empty($secret))
		{
			$key = hash( 'sha256', $this->input->post('lr_paidto').':'.$this->input->post('lr_paidby').':'.$this->input->post('lr_store').':'.$this->input->post('lr_amnt').':'.$this->input->post('lr_transfer').':'.$this->input->post('lr_currency').':'.$secret);
			
			if ($key != $hash)
			{
				return false;
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($post_data = array(), $order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($post_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'liberty_reserve');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			$order_data['invoice_notes'],
					  'jrox_payment_amount'				=>			$this->input->post('lr_amnt', true),
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$this->input->post('lr_merchant_ref', true),
					  'jrox_avs_code'					=>			'',
					  'jrox_membership_payment_type'	=> 			'liberty_reserve',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _ipn($type = '', $data = array())
	{
		$results = array('ipn_error' => false);
		
		//run ipn verification first
		if ($this->_validate_ipn($this->input->post('lr_encrypted')) == false)
		{
			$results['ipn_error'] = true;
			$results['jrox_error_message'] = $this->lang->line('invalid_security_code');
		}
		
		if ($results['ipn_error'] == false)
		{
			$results['jrox_product_type'] = 'products';
			
			$results['jrox_payment_type'] = 'credit';
							
			$results['jrox_order_data'] = $this->security_model->_get_session_id($this->input->post('order_id') . '-' . $this->input->post('member_id'));		
			
			if (!empty($results['jrox_order_data']))
			{
				$results['jrox_member_id'] = $results['jrox_order_data']['member_id'];
				
				$results['session_data'] = unserialize($results['jrox_order_data']['order_data']['session_data']);
				
				$results['jrox_payment_data'] = $this->_format_payment_data($data, $results['session_data']);
				
				$data['jrox_payment_data'] = $results['jrox_payment_data'];
			}
			else
			{
				$results['check_credit'] = true;
				
				$results['jrox_member_id'] = $this->input->post('member_id');
				$order_data['invoice_notes'] = '';
				$results['jrox_payment_data'] = $this->_format_payment_data($data, $order_data);
			}
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_liberty_reserve_enable_debug_email') == 1)
		{	
			$this->security_model->_send_debug_email('Liberty Reserve Payment Status Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_fields($data = '', $type = '') 
	{
		//check for membership
		$amount = $data['jrox_amount'];
		
		if ($data['jrox_product_type'] == 'membership')
		{
			if ($data['jrox_enable_product_trial'] == 1)
			{
				$amount = $data['jrox_trial_amount'];
			}
		}
		
		$sdata = array(
								
				'lr_acc'			=>		$this->config->item('module_payment_gateway_liberty_reserve_id'),
				'lr_store'			=>		$this->config->item('module_payment_gateway_liberty_reserve_store_name'),
				'lr_comments'		=>		$this->config->item('sts_store_name') . ' ' . $this->lang->line('checkout_invoice'),
				'lr_currency'		=>		$this->config->item('module_payment_gateway_liberty_reserve_currency_code'),
				'lr_amnt'			=>		$amount,	
				'member_id'			=>		$data['member_id'],
				'order_id'			=>		$this->session->userdata('session_id'),		

					);
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_form_transfer($data = '')
	{	
		$sdata['form_code'] = '<p><img src="images/misc/gateways/liberty_reserve.gif" alt="liberty_reserve"/></p>
		                      <p><img src="themes/main/' . $this->config->item('layout_design_site_theme') .'/images/gateway-loader.gif" alt="" onload="document.frm.submit();"/></p>
							  <form action="' . $this->config->item('module_payment_gateway_liberty_reserve_url') . '" method="post" name="frm">';
		
		//format the fields
		$form_data = $this->_format_fields($data, $data['jrox_product_type']);
		
		//add each field to the form		
		foreach ($form_data as $k => $v)
		{
			$sdata['form_code'] .= form_hidden($k, $v) . "\n";
		}
		
		$sdata['form_code'] .= form_submit('Submit', $this->lang->line('click_here_forwarding'));						  
								  
		$sdata['form_code'] .= '</form>';
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_liberty_reserve($data = '')
	{
		$data['gateway_form_image'] = '<a href="http://www.libertyreserve.com/?ref=U3138375" target="_blank"><img src="images/misc/gateways/liberty_reserve.gif" border="0" alt=""/></a>';
			
		return $data;
	}
	
	
	
}
?>