<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_payjunction_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for Payjunction payments
|
*/

class Module_Payment_Gateway_Payjunction_Model extends Model {	
	
	function _install_jrox_module($id = '')
	{		
		//check admin session
		$this->security_model->_check_admin_session();
		//https://demo.payjunction.com/quick_link	
		$config = array(
							'settings_key'	=>	'module_payment_gateway_payjunction_url',
							'settings_value'	=>	'https://payjunction.com/quick_link',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_payjunction_username',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_payjunction_password',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_payjunction_transaction_type',
							'settings_value'	=>	'AUTH_CAPTURE',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'cc_auth_type',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_payjunction_require_cvv',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
				
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_payjunction($data = '')
	{
		
		$rules['pj_card_name'] = 'trim|required|max_length[100]';	
		$rules['pj_card_number'] = 'trim|numeric|required|callback__verify_card_number';	
		$rules['pj_exp_month'] = 'trim|numeric|required';	
		$rules['pj_exp_year'] = 'trim|numeric|required';
		
		if ($this->config->item('module_payment_gateway_payjunction_require_cvv') == 1)
		{
			$rules['pj_card_cvv'] = 'trim|numeric|required';	
		}
		
		$this->validation->set_rules($rules);
		
		$fields['pj_card_name'] = $this->lang->line('cardholder_name');
		$fields['pj_card_number'] = $this->lang->line('cc_number');
		$fields['pj_exp_month'] = $this->lang->line('cc_month');
		$fields['pj_exp_year'] = $this->lang->line('cc_year');
		$fields['pj_card_cvv'] = $this->lang->line('cvv_code');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		$array['valid'] = '1'; //1 is to run an internal function; 2 is to forward to gateway; 3 is offline payment
		$array['function'] = '_process_payjunction_payment';
		$array['module_name'] = 'payjunction';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _process_payjunction_payment($data = '', $invoice_id = '')
	{
		$amount = $data['jrox_amount'];
		
		if ($amount > '0')
		{
			$auth_net_url = $this->config->item('module_payment_gateway_payjunction_url');
			
			$transaction_type = $this->config->item('module_payment_gateway_payjunction_transaction_type') == 'AUTH_ONLY' ? 'AUTHORIZATION' : 'AUTHORIZATION_CAPTURE';
				
			$authnet_values	= array
			(
					'dc_logon' => $this->config->item('module_payment_gateway_payjunction_username'), 
					'dc_password' => $this->config->item('module_payment_gateway_payjunction_password'),
					'dc_transaction_type' => $transaction_type, 
					'dc_version' => '1.2',
					
					'dc_transaction_amount' => number_format($amount, 2),
					'dc_number' => $this->input->post('pj_card_number'),
					'dc_expiration_month' => $this->input->post('pj_exp_month'),
					'dc_expiration_year' => $this->input->post('pj_exp_year'),
					
					'dc_first_name' => $data['fname'],
					'dc_last_name' => $data['lname'],
					'dc_address' => $data['billing_address_1'],
					'dc_city' => $data['billing_city'],
					'dc_state' => _get_region_name($data['billing_state'], 'region_code', 'region_name'),
					'dc_zipcode' => $data['billing_postal_code'],
					'dc_country' => _get_country_name($data['billing_country'], 'country_iso_code_2', 'country_id'),

					
					// Merchant defined variables go here
					'Date' =>  date('M d, Y h:i:s A'),
					'IP' => $this->input->ip_address(),
					'Session' => $this->config->item('enc_id'),
					"customer_ip"			=> $this->input->ip_address(),
			);
			
			if ($this->config->item('module_payment_gateway_payjunction_require_cvv') == 1)
			{
				$authnet_values["dc_verification_number"] = $this->input->post('pj_card_cvv');
			}
			/*
			if ($data['jrox_product_type'] == 'membership')
			{
				$authnet_values["dc_schedule_create"] = 'true';

				if ($data['jrox_recurring_interval_type'] == 'year') 
				{ 
					$data['jrox_recurring_interval_type'] = 'month';
					$data['jrox_recurring_interval_ends'] = $data['jrox_recurring_interval_ends'] * 12; 
				}
				
				if (!empty($data['jrox_recurring_interval_ends']))
				{
					$authnet_values["dc_schedule_limit"] = $data['jrox_recurring_interval_ends'];
				}
				else
				{
					$authnet_values["dc_schedule_limit"] = '99';
				}
				
				$authnet_values["dc_schedule_periodic_number"] = $data['jrox_recurring_interval'];
				$authnet_values["dc_schedule_periodic_type"] = $data['jrox_recurring_interval_type'];
				$authnet_values["dc_schedule_start"] = date('Y-m-d');
			}
			*/
				
			$fields = "";
			foreach( $authnet_values as $key => $value ) $fields .= "$key=" . urlencode( $value ) . "&";

			$resp = connect_curl($auth_net_url, true, $fields, 1, $this->config->item('sts_store_set_curl_timeout'));
			
			if (!empty($resp))
			{
				$response = explode(chr(28), $resp);
				
				$keys = array();
				$values = array();
				
				foreach ($response as $row)
				{
					$a = explode('=', $row);	
					array_push($keys, $a[0]);
					array_push($values, $a[1]);
				}
				
				$results = array_combine($keys, $values);
				//echo '<pre>'; print_r($results); exit();
				if ($results['dc_response_code'] == '00' || $results['dc_response_code'] == '85') //SUCCESS
				{
					$module_data = $this->modules->_get_module_column('module_file_name', 'payjunction');
					
					$results['jrox_error'] = false;
					$results['jrox_error_message'] = '';
					$results['jrox_payment_notes'] = '';
					$results['jrox_debug_info'] = print_r($results, true);
					$results['jrox_payment_method'] = $module_data['module_name'];
					$results['jrox_payment_amount'] = $results['dc_base_amount'];
					$results['jrox_trans_id'] = $results['dc_transaction_id'];	
					$results['jrox_avs_code'] = $results['dc_approval_code'];
					$results['jrox_membership_payment_type'] = 'payjunction';
				}
				else
				{			
					$results['jrox_error'] = true;
					$results['jrox_error_message'] = $results['dc_response_message'];
				}
			}
			else
			{			
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $this->lang->line('could_not_connect_gateway');
			}
		}
		
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_payjunction_enable_debug_email') == 1)
		{
			$this->security_model->_send_debug_email('Payjunction Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_payjunction($data = '')
	{
		
		$month_options = _generate_months();
		$year_options = _generate_years();
		
		$cur_month = date('m');
		$cur_year = date('Y');
		
		
		$data['gateway_form_image'] = '<table width="100%" border="0" align="center" cellpadding="5" cellspacing="1">

             <tr>
                <td ><strong>' . $this->lang->line('cardholder_name') . ' * </strong></td>

                <td width="32%" colspan="2" ><input name="pj_card_name" type="text" id="pj_card_name" value="" size="30" maxlength="100" /></td>
                </tr>
              <tr>
                <td ><strong >' . $this->lang->line('cc_number') . ' * </strong></td>
                <td width="32%" colspan="2" ><input name="pj_card_number" type="text" id="pj_card_number" value="" size="30" maxlength="50" /></td>
                </tr>
              
              
              <tr>
                <td ><strong>' . $this->lang->line('expiration_date') . ' * </strong></td>

                <td colspan="2">' . form_dropdown('pj_exp_month', $month_options, $cur_month) . ' /  ' . form_dropdown('pj_exp_year', $year_options, $cur_year) . '
                
				                </td>
              </tr>';
         
		 
		if ($this->config->item('module_payment_gateway_payjunction_require_cvv') == 1)
		{      
        	$data['gateway_form_image'] .= '<tr>
                <td width="37%" ><strong>' . $this->lang->line('cvv_code') . ' * </strong></td>
                <td colspan="2" ><input name="pj_card_cvv" type="text" id="pj_card_cvv" value="" size="5" maxlength="5" /></td>
                </tr>';
        }   

              
          $data['gateway_form_image'] .=  '</table>';
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _run_recurring_payment($data = '')
	{
		$amount = $data['sub_total'];
		
		if ($amount > '0' && !empty($data['subscription_id']))
		{
			$auth_net_url = $this->config->item('module_payment_gateway_payjunction_url');
			
			$transaction_type = $this->config->item('module_payment_gateway_payjunction_transaction_type') == 'AUTH_ONLY' ? 'AUTHORIZATION' : 'AUTHORIZATION_CAPTURE';
				
			$authnet_values	= array
			(
					'dc_logon' => $this->config->item('module_payment_gateway_payjunction_username'), 
					'dc_password' => $this->config->item('module_payment_gateway_payjunction_password'),
					'dc_transaction_type' => $transaction_type, 
					'dc_version' => '1.2',
					
					'dc_transaction_amount' => number_format($amount, 2),
					'dc_transaction_id' => $data['subscription_id'],
					
					'dc_address' => $data['billing_address_1'],
					'dc_city' => $data['billing_city'],
					'dc_state' => _get_region_name($data['billing_state'], 'region_code', 'region_name'),
					'dc_zipcode' => $data['billing_postal_code'],
					'dc_country' => _get_country_name($data['billing_country'], 'country_iso_code_2', 'country_id'),
					
			);
			
			$fields = "";
			foreach( $authnet_values as $key => $value ) $fields .= "$key=" . urlencode( $value ) . "&";
			
			$resp = connect_curl($auth_net_url, true, $fields);
			
			$response = explode(chr(28), $resp);
			
			$keys = array();
			$values = array();
			
			foreach ($response as $row)
			{
				$a = explode('=', $row);	
				array_push($keys, $a[0]);
				array_push($values, $a[1]);
			}
			
			$results = array_combine($keys, $values);
			
			if ($results['dc_response_code'] == '00' || $results['dc_response_code'] == '85') //SUCCESS
			{
				$module_data = $this->modules_model->_get_module_column('module_file_name', 'payjunction');
				
				$results['jrox_error'] = false;
				$results['jrox_error_message'] = '';
				$results['jrox_payment_notes'] = '';
				$results['jrox_debug_info'] = print_r($results, true);
				$results['jrox_payment_method'] = $module_data['module_name'];
				$results['jrox_payment_amount'] = $results['dc_base_amount'];
				$results['jrox_trans_id'] = $results['dc_transaction_id'];	
				$results['jrox_avs_code'] = $results['dc_approval_code'];
				$results['jrox_membership_payment_type'] = 'payjunction';
			}
			else
			{			
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $results['dc_response_message'];
			}
		}
		
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_payjunction_enable_debug_email') == 1)
		{
			$this->security_model->_send_debug_email('Payjunction Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($order_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'payjunction');
		
		$data = array('jrox_error' 				=> 			false,
					  'jrox_error_message' 		=> 			'',
					  'jrox_payment_notes'		=>			'',
					  'jrox_payment_amount'		=>			$order_data['x_amount'],
					  'jrox_debug_info'			=>			$debug,
					  'jrox_payment_method'		=>			$module_data['module_name'],
					  'jrox_trans_id'			=>			$order_data['x_trans_id'],
					  'jrox_avs_code'			=>			$order_data['x_avs_code'],
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
}
?>