<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - payment_gateway_psigate_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for authoirze.net AIM payments
|
*/

class Module_Payment_Gateway_Psigate_Model extends Model {	
	
	function _install_jrox_module($id = '')
	{		
		//check admin session
		$this->security_model->_check_admin_session();
			
		$config = array(
							'settings_key'	=>	'module_payment_gateway_psigate_url',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'1',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_psigate_merchant_id',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'2',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_psigate_passphrase',
							'settings_value'	=>	'',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'text',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'3',
							'settings_function'	=>	'none',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_psigate_enable_testing',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'4',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_psigate_require_cvv',
							'settings_value'	=>	'1',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'5',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		$config = array(
							'settings_key'	=>	'module_payment_gateway_psigate_enable_debug_email',
							'settings_value'	=>	'0',
							'settings_module'	=>	'payment_gateway',
							'settings_type'	=>	'dropdown',
							'settings_group'	=>	$id,
							'settings_sort_order'	=>	'6',
							'settings_function'	=>	'boolean',
							);
		
		//insert into settings table
		$this->db->insert('settings', $config);
		
		
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_gateway_options_psigate($data = '')
	{
		
		$rules['psi_card_name'] = 'trim|required|max_length[100]';	
		$rules['psi_card_number'] = 'trim|numeric|required|callback__verify_card_number';	
		$rules['psi_exp_month'] = 'trim|numeric|required';	
		$rules['psi_exp_year'] = 'trim|numeric|required';
		
		if ($this->config->item('module_payment_gateway_psigate_require_cvv') == 1)
		{
			$rules['psi_card_cvv'] = 'trim|numeric|required';	
		}
		
		$this->validation->set_rules($rules);
		
		$fields['psi_card_name'] = $this->lang->line('cardholder_name');
		$fields['psi_card_number'] = $this->lang->line('cc_number');
		$fields['psi_exp_month'] = $this->lang->line('cc_month');
		$fields['psi_exp_year'] = $this->lang->line('cc_year');
		$fields['psi_card_cvv'] = $this->lang->line('cvv_code');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		$array['valid'] = '1'; //1 is to run an internal function; 2 is to forward to gateway; 3 is offline payment
		$array['function'] = '_process_psigate_payment';
		$array['module_name'] = 'psigate';
		
		return $array; 
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_payment_data($order_data = array())
	{
		//set the debug info
		$debug = '';
		foreach ($order_data as $k => $v) { $debug .= $k . ': ' . $v . "\n"; }
		
		//get the payment method name
		$module_data = $this->modules->_get_module_column('module_file_name', 'psigate');
		
		$data = array('jrox_error' 						=> 			false,
					  'jrox_error_message' 				=> 			'',
					  'jrox_payment_notes'				=>			'',
					  'jrox_payment_amount'				=>			$order_data['x_amount'],
					  'jrox_debug_info'					=>			$debug,
					  'jrox_payment_method'				=>			$module_data['module_name'],
					  'jrox_trans_id'					=>			$order_data['x_trans_id'],
					  'jrox_avs_code'					=>			$order_data['x_avs_code'],
					  'jrox_membership_payment_type'	=> 			'psigate',
					 );
	
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _process_psigate_payment($data = '')
	{
		$amount = $data['jrox_amount'];
		
		//check for membership
		if ($data['jrox_product_type'] == 'membership')
		{
			if ($data['jrox_enable_product_trial'] == 1)
			{
				$amount = $data['jrox_trial_amount'];
			}
		}
		
		if ($amount > '0')
		{
			$XPost = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>
			<Order>
			";
				
				if($this->config->item('module_payment_gateway_psigate_enable_testing') == 1)
				{
					$XPost .= "<StoreID>teststore</StoreID>
					<Passphrase>psigate1234</Passphrase>";
				} 
				else 
				{
					$XPost .= "<StoreID>".$this->config->item('module_payment_gateway_psigate_merchant_id')."</StoreID>
				<Passphrase>".$this->config->item('module_payment_gateway_psigate_passphrase')."</Passphrase>
				";
				}
				
				$XPost .= 
				"<Subtotal>".$amount."</Subtotal>
				<PaymentType>CC</PaymentType>
				<CardAction>0</CardAction>
				<CardNumber>".$this->input->post('psi_card_number')."</CardNumber>
				<CardExpMonth>".$this->input->post('psi_exp_month')."</CardExpMonth>
				<CardExpYear>".$this->input->post('psi_exp_year')."</CardExpYear>
				<CardIDCode>1</CardIDCode>";
				
				if ($this->config->item('module_payment_gateway_psigate_require_cvv') == 1)
				{
					$XPost .="<CardIDNumber>".$this->input->post('psi_card_cvv')."</CardIDNumber>";
				}
				
				$XPost .="<CustomerIP>".$this->input->ip_address()."</CustomerIP>
				<Item>
					<ItemID>".$this->config->item('sts_store_name') . " " . $this->lang->line('checkout_invoice')."</ItemID>
					<ItemDescription>" . $this->config->item('sts_store_name') . " " . $this->lang->line('checkout_invoice') . "</ItemDescription>
					<ItemQty>1</ItemQty>
					<ItemPrice>".round($amount, 2)."</ItemPrice>
				</Item>	
				<Bname>".$this->input->post('psi_card_name')."</Bname>
				<Baddress1>".$data['billing_address_1']."</Baddress1>
				<Baddress2>".$data['billing_address_2']."</Baddress2>
				<Bcity>".$data['billing_city']."</Bcity>
				<Bprovince>"._get_region_name($data['billing_state'], 'region_code', 'region_name')."</Bprovince>
				<Bpostalcode>".$data['billing_postal_code']."</Bpostalcode>
				<Bcountry>"._get_country_name($data['billing_country'], 'country_name', 'country_id')."</Bcountry>
				<Email>".$data['primary_email']."</Email>
			</Order>";
					
			if($this->config->item('module_payment_gateway_psigate_enable_testing') == 1)
			{
				$url = "https://dev.psigate.com:7989/Messenger/XMLMessenger";
			} 
			else 
			{
				$url = $this->config->item('module_payment_gateway_psigate_url');
			}
			
			$resp = connect_curl($url, true, $XPost);
			
			// use XML Parser on $result, and your set!
			
			$xml_parser = xml_parser_create();
			xml_parser_set_option($xml_parser,XML_OPTION_CASE_FOLDING,0);
			xml_parser_set_option($xml_parser,XML_OPTION_SKIP_WHITE,1);
			xml_parse_into_struct($xml_parser, $resp, $vals, $index);
			xml_parser_free($xml_parser);

			if ($vals[4]['value'] == "APPROVED") //SUCCESS
			{
				$module_data = $this->modules->_get_module_column('module_file_name', 'psigate');
				
				$payment_notes = $vals[1]['tag'] . ': ' . $vals[1]['value'] . "\n";
				$payment_notes .= $vals[2]['tag'] . ': ' . $vals[2]['value'] . "\n";
				$payment_notes .= $vals[3]['tag'] . ': ' . $vals[3]['value'] . "\n";
				$payment_notes .= $vals[4]['tag'] . ': ' . $vals[4]['value'] . "\n";
				$payment_notes .= $vals[5]['tag'] . ': ' . $vals[5]['value'] . "\n";
				$payment_notes .= $vals[10]['tag'] . ': ' . $vals[10]['value'] . "\n";
				$payment_notes .= $vals[11]['tag'] . ': ' . $vals[11]['value'] . "\n";
				$payment_notes .= $vals[12]['tag'] . ': ' . $vals[12]['value'] . "\n";
				$payment_notes .= $vals[13]['tag'] . ': ' . $vals[13]['value'] . "\n";
				$payment_notes .= $vals[15]['tag'] . ': ' . $vals[15]['value'] . "\n";
				$payment_notes .= $vals[16]['tag'] . ': ' . $vals[16]['value'] . "\n";
				$payment_notes .= $vals[17]['tag'] . ': ' . $vals[17]['value'] . "\n";
				$payment_notes .= $vals[18]['tag'] . ': ' . $vals[18]['value'] . "\n";
				$payment_notes .= $vals[20]['tag'] . ': ' . $vals[20]['value'] . "\n";
				$payment_notes .= $vals[21]['tag'] . ': ' . $vals[21]['value'] . "\n";
				$payment_notes .= $vals[22]['tag'] . ': ' . $vals[22]['value'] . "\n";
				
				$results['jrox_error'] = false;
				$results['jrox_error_message'] = '';
				$results['jrox_payment_notes'] = $payment_notes;
				$results['jrox_debug_info'] = print_r($vals, true);
				$results['jrox_payment_method'] = $module_data['module_name'];
				$results['jrox_payment_amount'] = $vals[10]['value'];
				$results['jrox_trans_id'] = $vals[2]['value'];
				$results['jrox_avs_code'] = $vals[15]['value'];
				$results['jrox_membership_payment_type'] = 'psigate';
			}
			else
			{			
				$results['jrox_error'] = true;
				$results['jrox_error_message'] = $vals[6]['value'];
			}
		}
		else
		{
			$results['jrox_error'] = false;
			$results['jrox_error_message'] = '';
			$results['jrox_payment_notes'] = '';
			$results['jrox_debug_info'] = '';
			$results['jrox_payment_method'] = $this->lang->line('psigate');
			$results['jrox_payment_amount'] = '0.00';
			$results['jrox_trans_id'] = $this->lang->line('checkout_free_trial');	
			$results['jrox_avs_code'] = '';
		}
		
		//check for debug info
		if ($this->config->item('module_payment_gateway_psigate_enable_debug_email') == 1)
		{
			$this->security_model->_send_debug_email('PSIGate Debug Email', $results); 
		}
		
		return $results;
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_gateway_form_psigate($data = '')
	{
		
		$month_options = _generate_months();
		$year_options = _generate_years('y');
		
		$cur_month = date('m');
		$cur_year = date('y');
		
		
		$data['gateway_form_image'] = '<table width="100%" border="0" align="center" cellpadding="5" cellspacing="1">

             <tr>
                <td ><strong>' . $this->lang->line('cardholder_name') . ' * </strong></td>

                <td width="32%" colspan="2" ><input name="psi_card_name" type="text" id="psi_card_name" value="" size="30" maxlength="100" /></td>
                </tr>
              <tr>
                <td ><strong >' . $this->lang->line('cc_number') . ' * </strong></td>
                <td width="32%" colspan="2" ><input name="psi_card_number" type="text" id="psi_card_number" value="" size="30" maxlength="50" /></td>
                </tr>
              
              
              <tr>
                <td ><strong>' . $this->lang->line('expiration_date') . ' * </strong></td>

                <td colspan="2">' . form_dropdown('psi_exp_month', $month_options, $cur_month) . ' /  ' . form_dropdown('psi_exp_year', $year_options, $cur_year) . '
                
				                </td>
              </tr>';
         
		 
		if ($this->config->item('module_payment_gateway_psigate_require_cvv') == 1)
		{      
        	$data['gateway_form_image'] .= '<tr>
                <td width="37%" ><strong>' . $this->lang->line('cvv_code') . ' * </strong></td>
                <td colspan="2" ><input name="psi_card_cvv" type="text" id="psi_card_cvv" value="" size="5" maxlength="5" /></td>
                </tr>';
        }   

              
          $data['gateway_form_image'] .=  '</table>';
	
		return $data;
	}
	
}
?>