<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME -product_categories_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managingproduct_categories
|
*/

class Product_Cat_Model extends Model {	
	
	function _add_category()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		if (isset($data['userfile']))
		{	
			unset($data['userfile']);
		}
		
		//insert into db
		if (!$this->db->insert('products_categories', $data))
		{
			show_error($this->lang->line('could_not_add_category'));
			
			//log error
			log_message('error', 'Could not insert category into product_categories table');
			
			return false;
		}
		else
		{
			$category_id = $this->db->insert_id();
			
			//log success
			log_message('info', 'category '. $category_id . ' inserted into product_categories table');
		}
		
		return $category_id;
	}
	
	// ------------------------------------------------------------------------
	
	function _delete_category($id = '')
	{
		if ($id == 1)
		{
			return false;
		}	
		
		//update product_categories first
		$this->db->where('category_id', $id);
		$data = array('category_id' => 1);

		if ($this->db->update('products_to_categories', $data))
		{
			//log success
			log_message('info', 'category ID #' . $id . ' updated successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_category'));
			
			//log error
			log_message('error', 'category ID #' . $id . ' could not be updated');
		}
	
		//delete photo if any
		
		//get category data
		$category_data = $this->_get_category_details($id);
		
		//check first if photo needs to be deleted
		if (!empty($category_data[0]['category_image']))
		{
			@unlink('./images/' . $this->config->item('images_products_categories_dir') . '/' . $category_data[0]['category_image']);
		}

		
		//delete category
		$this->db->where('category_id', $id);
		if ($this->db->delete('products_categories'))
		{
			
			//log success
			log_message('info', 'category ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_category'));
			
			//log error
			log_message('error', 'category ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}	

	// ------------------------------------------------------------------------
	
	function _get_category_details($id = '')
	{
		//get the data from product_categories table
		$this->db->where('category_id', $id);
		$query = $this->db->get('products_categories');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		else
		{
			return false;
		}
	}
	
	// ------------------------------------------------------------------------
	
	function _get_all_product_categories($public = false, $sort_column = '', $sort_order = '')
	{
		//get all the members from db for list view
		if (!$sort_order) $sort_order = $this->config->item('pub_dbs_cat_order');
		if (!$sort_column) $sort_column = $this->config->item('pub_dbs_cat_column');
		
		$sql = 'SELECT ' . $this->db->dbprefix('products_categories') . '.*,
				(SELECT COUNT(*) from ' . $this->db->dbprefix('products_to_categories') . ' 
				WHERE ' . $this->db->dbprefix('products_categories') . '.category_id = ' . $this->db->dbprefix('products_to_categories') . '.category_id) as total
				FROM ' . $this->db->dbprefix('products_categories');
				
		if ($public == true)
		{
			$sql .= ' WHERE ' . $this->db->dbprefix('products_categories') . '.category_status = \'1\'';
		}
				
		$sql .= ' ORDER BY ' . $this->db->dbprefix('products_categories') . '.' . $sort_column . ' ' . $sort_order;
		
		$query = $this->db->query($sql);
	
		return $query->result_array();
	}
	
	
	// ------------------------------------------------------------------------
	
	function _get_top_level_categories($id = '0', $sort_column = '', $sort_order = '')
	{
		//get all the members from db for list view
		if (!$sort_order) $sort_order = $this->config->item('pub_dbs_cat_order');
		if (!$sort_column) $sort_column = $this->config->item('pub_dbs_cat_column');
		
		$sql = 'SELECT ' . $this->db->dbprefix('products_categories') . '.*,
				(SELECT COUNT(*) from ' . $this->db->dbprefix('products_to_categories') . ' 
				WHERE ' . $this->db->dbprefix('products_categories') . '.category_id = ' . $this->db->dbprefix('products_to_categories') . '.category_id) as total
				FROM ' . $this->db->dbprefix('products_categories') . '
				WHERE ' . $this->db->dbprefix('products_categories') . '.parent_id = ' . $id . ' 
				AND ' . $this->db->dbprefix('products_categories') . '.category_status = \'1\'
				ORDER BY ' . $this->db->dbprefix('products_categories') . '.' . $sort_column . ' ' . $sort_order;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	
	
	// ------------------------------------------------------------------------
	
	function _get_product_categories($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $where = '')
	{
		//get all the categories from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_prc_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_prc_column');

		$sql = 'SELECT ' . $this->db->dbprefix('products_categories') . '.*,
				(SELECT COUNT(*) from ' . $this->db->dbprefix('products_to_categories') . ' 
				WHERE ' . $this->db->dbprefix('products_categories') . '.category_id = ' . $this->db->dbprefix('products_to_categories') . '.category_id) as total
				FROM ' . $this->db->dbprefix('products_categories');
				
		if (!empty($where))
		{
			$sql .= $where . ' ';
		}
		
		$sql .= ' ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$prod_cats = $query->result_array();
			
			return $prod_cats;
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_cat_parents($id ='', $cats = array())
	{
		$array = '';
		
		for ($i=0; $i<=count($cats); $i++)
		{
			if (!empty($cats[$i]['category_id']) && $cats[$i]['category_id'] == $id)
			{	
				$array = array(	'category_id' => $cats[$i]['category_id'],
								'category_name' => $cats[$i]['category_name'],
								'parent_id'	=> $cats[$i]['parent_id']
										);
			}
			
		}
		
		return $array;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_path($cat_id = 0, $name = '', $parent_id = 0, $cats = array(), $link = false)
	{
		//echo '<pre>'; print_r($cats); exit();
		$array = array();
		
		if ($parent_id > '0')
		{
			while ($parent_id > 0)
			{
				$cat_array = $this->_get_cat_parents($parent_id, $cats);
				array_push($array, $cat_array);
				$parent_id = $cat_array['parent_id'];
			}
		}
		
		
		
		krsort($array);
		reset($array);
		
		$path = $link == true ? '<a href="' . base_url() . '">' . $this->lang->line('home') . '</a> ' : '';
		//print_r($array); exit();
		foreach($array as $k => $v)
		{
			if ($link == true)
			{
				$path.= $this->config->item('category_path_separator').' <a href="' . base_url() . PRODUCTS_ROUTE . '/category/' . $v['category_id'] . '/' . url_title($v['category_name']) . '">' . $v['category_name'] . '</a> ';
			}
			else
			{
				$path.= $this->config->item('category_path_separator').$v['category_name'];
			}
		}

		if ($link == true)
		{
			//add the category name to the end
			$path .= $this->config->item('category_path_separator'). ' ' . $name;
		}
		else
		{
			//add the category name to the end
			$path .= $this->config->item('category_path_separator').$name;
		}
		
		return $path;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_cat_path($id = 0, $cats = '', $path = array())
	{
		$array = array_match_values($cats, 'parent_id', $id);			
		
		if (count($array) > 0 == true) 
		{
			foreach	($array as $key => $value)
			{
				$path = $this->_get_cat_path($value['category_id'], $cats);
			}
		}
		
		return $path;
	}
	
	// ------------------------------------------------------------------------

	function _select_categories($id = 0, $type = 'update_category', $multiple = false, $root = 'root', $public = false)
	{
		$cat = '';
	
		if ($type == 'update_category')
		{
			$id = 0;
		}
		
		$total = $this->_get_all_product_categories($public);		
		
		$tree = $this->_get_children($id, $total, 1, $public);
		
		if ($multiple == true)
		{
			$cat .= '<select name="parent_id" multiple="multiple">';
		}
		else
		{
			if ($public == true)
			{
				$cat .= '<select name="product_categories" id="layout_box_product_categories" onchange="document.location=\''. base_url() . PRODUCTS_ROUTE .'/category/\' + this.value">';
			
				
			}
			else
			{
				$cat .= '<select name="parent_id">';
			}
		}
		
		$cat .= "<option value='0'>".$this->lang->line($root)."</option>\n";
		$cat .= $tree;
		$cat .= '</select>';
		
		return $cat;
	}
	
	// ------------------------------------------------------------------------
	/*
	function _show_treeview($id = 0, $type = 'update_category', $multiple = false, $root = 'root', $public = false)
	{

		//$total = $this->_get_all_product_categories($public);	
		
		
		$this->db->from('products_categories');
		$this->db->where('category_status', '1');
		$this->db->order_by('category_id', 'ASC');
		$cat_query = $this->db->get();	
		
		$total = $cat_query->result_array();
		
		$tree = $this->_get_treeview($total);		
		
		return $tree;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_treeview($family = '')
	{
		
		$branches = array();
		$tree = array();
		
		foreach($family as $child) {
			extract($child);
				
			if(empty($branches[$category_id]))
				$branches[$category_id] = array($category_name);
		
			if(!empty($parent_id)) {
				if(empty($branches[$parent_id]))
					$branches[$parent_id] = array($category_name);
				$branches[$parent_id][$category_id] = &$branches[$category_id];
			}
			else $tree[$parent_id] = &$branches[$category_id];
		}
		
	
		return $branches;
	}
	*/
	// ------------------------------------------------------------------------
	
	function _get_sub_categories($id = '')
	{
		if (!$sort_order) $sort_order = $this->config->item('dbs_prc_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_prc_column');
		
		$this->db->where('parent_id', $id);
		$this->db->where('category_status', '1');
		$this->db->order_by($sort_column, $sort_order);
		$query = $this->db->get('products_categories');
		
		if ($query->num_rows() > 0)
		{
			
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_children($id = '0', $all_cats = '', $level = 1, $public = false)
	{
		
		//select all children for this level		
		$array = array_match_values($all_cats, 'parent_id', $id);
		
		$indent = (!empty($id)) ? str_repeat('&nbsp;',$level*2) : '&nbsp;' ;   

		$tree ='';

		if (count($array) > 0) 
		{			
			foreach ($array as $key => $value)
			{	
				// indent and display the title of this child
				
				if ($this->validation->parent_id == $value['category_id'])
				{
					$tree .= "<option value='" . $value['category_id'] . "' selected='selected'>".$indent.$value['category_name']."</option>\n";
				}
				else
				{
	
					if ($public == true)
					{
						/*
						if ($this->uri->segment(3) == $value['category_id'])
						{
							$tree .= "<option value='" . $value['category_id'] . "/" . url_title($value['category_name']) . "' selected='selected'>".$indent.$value['category_name']." (" . $value['total'] .")". "</option>\n";
						}
						else
						{
						
						}
						*/
						
						$tree .= "<option value='" . $value['category_id'] . "/" . url_title($value['category_name']) . "'>".$indent.$value['category_name']."</option>\n";
						
					}
					else
					{
						$tree .= "<option value='" . $value['category_id'] . "'>".$indent.$value['category_name']."</option>\n";
					}
				}
							
				$tree .= $this->_get_children($value['category_id'], $all_cats, $level+1, $public);					
			}	
		}
		
		return $tree;
	}

	// ------------------------------------------------------------------------
	
	function _update_category()
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		if (isset($data['userfile']))
		{	
			unset($data['userfile']);
		}
		
		//check if this is the default category
		if ($data['category_id'] == 1)
		{
			$data['parent_id'] = 0;
		}
		
		//check if category is the same as the parent
		if ($data['category_id'] == $data['parent_id'])
		{
			$data['parent_id'] = 0;
		}
		
		//get category data
		$category_data = $this->_get_category_details($data['category_id']);
		
		//check first if photo needs to be deleted
		if (empty($data['category_image']))
		{
			
			if (!empty($category_data[0]['category_image']))
			{
				@unlink('./images/' . $this->config->item('images_product_categories_dir') . '/' . $category_data[0]['category_image']);
			}
		}
		
		//update category data
		$this->db->where('category_id', $data['category_id']);
		
		if (!$this->db->update('products_categories', $data))
		{
			show_error($this->lang->line('could_not_update_category'));
			
			//log error
			log_message('error', 'Could not update category ID ' . $data['category_id'] . 'in products_categories table');
			
			return false;
		}
		else
		{
			
			//log success
			log_message('info', 'category ID '. $data['category_id'] . ' updated in products_categories table');
		}
		
		return $category_data[0];
	}
	
	// ------------------------------------------------------------------------	
}
?>