<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - products_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing products
|
*/

class Products_Model extends Model {	
	
	function _update_product_views($pid = '')
	{
		$this->db->select('product_views');
		$this->db->from('products');
		$this->db->where('product_id', $pid);
		$query = $this->db->get();
		
		if ($query->num_rows() > 0)
		{
			$num = $query->row();
			
			$total = $num->product_views + 1;
			
			$this->db->where('product_id', $pid);
			$this->db->update('products', array('product_views' => $total));
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _mass_update_products($name = '', $price = '', $id = '', $sort = '')
	{
		for ($i = 0; $i<=count($name); $i++)
		{
			//check if name and price is not blank
			
			if (!empty($name[$i]))
			{
				//update product
				$update = array('product_name' => trim($name[$i]),
								'product_price' => (float)trim($price[$i]),
								);
				
				if (!empty($sort))
				{
					$update['product_sort'] = trim($sort[$i]);
				}
				
				$this->db->where('product_id', $id[$i]);
				$this->db->update('products', $update);
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _mass_add_product_categories($name = '', $cat = '')
	{
		//check if category name is valid
		$this->db->where('category_name', $cat);
		$query = $this->db->get('products_categories');

		if ($query->num_rows() > 0)
		{
			$row = $query->row_array();
			
			$id = $row['category_id'];
			
			//now loop through the products
			foreach ($name as $v)
			{
				//check if name and price is not blank
				$this->db->where('product_id', $v);
				$this->db->where('category_id', $id);
				$squery = $this->db->get('products_to_categories');
				
				if ($squery->num_rows() < 1)
				{
					$insert = array('product_id' => $v,
									'category_id' => $id,
									);
					$this->db->insert('products_to_categories', $insert);
				}
			}	
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _add_download_access($pid = '', $mid = '', $expires = '', $quantity = '1')
	{
		if (empty($expires)) $expires = 365 * 5;
		
		$data = array('product_id' => $pid,
					  'member_id' => $mid,
					  'downloads' => '0',
					  'expires' => _generate_timestamp() + ( 60 * 60 * 24 * $expires ),
					 );
					 
		for ($i = 1; $i <= $quantity; $i++)
		{
			$this->db->insert('members_downloads', $data);
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_product_inventory($id = '', $qty = '')
	{
		$inv = $this->db_validation_model->_get_details('products', 'product_inventory', 'product_id', $id);

		$new_qty = $inv[0]['product_inventory'] - $qty;
		
		if ($new_qty < '0') $new_qty = '0';
		
		$data = array('product_inventory' => $new_qty);
		
		$this->db->where('product_id', $id);
		
		if ($this->db->update('products', $data))
		{
			return $new_qty;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _insert_recommended_product($pid = '', $mid = '')
	{
		//check if product is already in db
		$this->db->where('product_id', $pid);
		$this->db->where('member_id', $mid);
		$query = $this->db->get('members_recommends');
		
		if ($query->num_rows > 0) return true;
	
		$data = array('product_id' => $pid,
					  'member_id' => $mid);
					  
		if ($this->db->insert('members_recommends', $data))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_membership($id = '')
	{
		$this->db->select('*');
		$this->db->from('products');
		$this->db->where('product_id', $id);
		$this->db->where('product_status', '1');
		$this->db->where('product_type', 'membership');
		
		$query = $this->db->get();
		
		if ($query->num_rows() > 0)
		{
			return $query->row();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_membership_products($none = '', $text = '')
	{
		$this->db->select('product_id, product_name');
		$this->db->where('product_type', 'membership');
		
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
		
			$data = $query->result_array();
			$cat = format_array($data, 'product_id', 'product_name', $none, $text);
	
			return $cat;	
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_membership_details($id = '', $num_options)
	{
		$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, ' . $this->db->dbprefix('products') . '.product_id as pid, 
				' . $this->db->dbprefix('products_photos') . '.*
				FROM  ' . $this->db->dbprefix('products') . '
				LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
				AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
				WHERE ' . $this->db->dbprefix('products') . '.product_id = \'' . $id .'\'';

		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$row = $query->row_array() ;
			
			//format pricing
			if ($row['product_sale_price'] > '0')
			{
				$row['product_price'] = $row['product_sale_price'];
			}
				
			
			$row['s_product_price'] = $row['product_price'];
			
			//check the attributes
			$row['attribute_list'] = '';
			
			if (!empty($_POST['attributes']))
			{
				$attrib = $_POST['attributes'];
				
				foreach ($attrib as $k => $v)
				{
					//get the attribute values
					$attrib_data = $this->attrib->_get_attribute_details($k);
					
					//check if the attribute is a dropdown
					if ($attrib_data['attribute_type'] == 'dropdown')
					{
						//check for attribute amount
						$format = explode('|', $attrib_data['attribute_options']);
						
						foreach ($format as $option)
						{								
							
							$value = explode(':', $option);
							
							if (!empty($value))
							{
								if ($v == $value[0])
								{	
									
									//format amounts
									if ($value[1] == 'add')
									{
										$row['s_product_price'] = $row['s_product_price'] + $value[2];
									}
									elseif ($value[1] == 'sub')
									{
										$row['s_product_price'] = $row['s_product_price'] - $value[2];
									}
									
									//format weight
									if ($value[3] == 'add')
									{
										$row['total_product_weight'] = $row['total_product_weight'] + $value[4];
									}
									elseif ($value[3] == 'sub')
									{
										$row['total_product_weight'] = $row['total_product_weight'] - $value[4];
									}
									
									$row['attribute_list'] .= '<span class="jroxCartOptions"><span class="jroxBold">' . $attrib_data['attribute_name'] . '</span> - <span class="jroxOptionValue">' . $value[0] . '</span></span><br />';
								}
								
							}							
						}
					}
					else
					{
						$row['attribute_list'] .= '<span class="jroxCartOptions"><span class="jroxBold">' . $attrib_data['attribute_name'] . '</span> - <span class="jroxOptionValue">' . $v . '</span></span><br />';
					}
				}
			}
			
			//check the image
			if (empty($row['photo_file_name']))
			{
				$row['image_file'] = '<img src="' . base_url(). 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/no_photo.png" class="jroxCartNoImage"/>';
			}
			else
			{
				$row['image_file'] = _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], '', '', false, false, 'jroxCartImages');
				
			}
			
			//format links
			$row['product_link'] = base_url() . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . url_title($row['product_name']);
			
			//format the amounts
			$row['total_product_price'] = format_amounts($row['s_product_price'], $num_options);
			$row['subtotal_price'] = format_amounts($row['s_product_price'], $num_options);
	
			//echo '<pre>'; print_r($row); exit();
			return $row;
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_recommended_product($id = '')
	{
		//check if product is already in db
		$this->db->where('id', $id);
		if ($this->db->delete('members_recommends'))
		{
			return true;
		}
	
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _add_product($post_array = '') //insert the new admin into db
	{				
		
		$this->load->helper('security');
		
		$j = array();
		
		for ($i=0; $i<count($post_array['product_name']); $i++)
		{			
			if (!empty($post_array['product_name'][$i]))
			{
				$data = array(
							'product_type'	=>	xss_clean($post_array['product_type'][$i]),
							'product_sku'	=>	_generate_random_string(6),
							'product_status'	=>	'0',
							'product_name'	=>	xss_clean($post_array['product_name'][$i]),
							'product_keywords' => xss_clean($post_array['product_name'][$i]),
							'product_title' => xss_clean($post_array['product_name'][$i]),
							'product_meta_description' => xss_clean($post_array['product_name'][$i]),
							'product_new'	=> '1',
							'product_featured' => '0',
							'product_price'	=>	$post_array['product_price'][$i],
							'date_added'	=>	_generate_timestamp(),
							'date_modified'	=>	_generate_timestamp(),
							'date_available'	=>	_generate_timestamp(),
							'date_expires'	=>	 _generate_timestamp() + (3600 * 24 * 365 * 20),
							'manufacturer_id'	=>	'0',
							'vendor_id'		=> '0',
							'product_views'	=>	'0',
							'enable_product_inventory'	=>	'2',
							'product_inventory'	=>	'0',
							'no_commission'	=>	'0',
							'enable_custom_commission'=>	'0',
							'add_mailing_list' => '0',
							'recurring_interval' => '1',
							'recurring_onetime' => '0',
							'recurring_interval_type' => 'month',
							'product_featured' => !empty($post_array['featured'][$i]) ? '1' : '0',
							);
	
				if (!$this->db->insert('products', $data))
				{
					show_error($this->lang->line('could_not_add_product'));
				
					//log error
					log_message('error', 'Could not insert product into products table');
				}
				else
				{
					$product_id = $this->db->insert_id();
					
					//add to default category
					$cdata = array(	'product_id'	=>	$product_id,
								'category_id'	=>	'1',
								);
			
					$this->db->insert('products_to_categories', $cdata);
					
					array_push($j, $product_id);
					//log success
					log_message('info', 'product ID '. $product_id . ' inserted into products table');
				}
			}
		}

		return $j;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_recommended_products($id = '', $num_options = '')
	{
		$sql = 'SELECT ' . $this->db->dbprefix('members_recommends') . '.product_id as pid, ' . $this->db->dbprefix('members_recommends') . '.id as rid, 
				' . $this->db->dbprefix('products_photos') . '.*, ' . $this->db->dbprefix('products') . '.*,
				(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
				WHERE product_id = ' . $this->db->dbprefix('members_recommends') . '.product_id AND status = \'1\') as average_review
				FROM  ' . $this->db->dbprefix('members_recommends') . '					
				LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
				ON ' . $this->db->dbprefix('members_recommends') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
				AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
				LEFT JOIN ' . $this->db->dbprefix('products') . '  
				ON ' . $this->db->dbprefix('members_recommends') . '.product_id = ' . $this->db->dbprefix('products') . '.product_id 
				WHERE member_id =  \'' . $id .'\'
				GROUP BY ' . $this->db->dbprefix('members_recommends') . '.product_id 
				ORDER BY ' . $this->db->dbprefix('members_recommends') . '.product_id LIMIT 0,' . $this->config->item('maximum_recommended_products_profile_page');
					
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$array = array();
			
			foreach ($query->result_array() as $row)
			{
				if ($row['product_status'] == '0') { continue; }
				
				//check availability
				if (!empty($row['date_available']))
				{
					if ($row['date_available'] >= now()) { continue; }
				}
				
				//check expires
				if (!empty($row['date_expires']))
				{
					if ($row['date_expires'] <= now()) { continue; }
				}
				
				
				$row['product_name_url'] = url_title($row['product_name']);
				//$row['product_overview'] = word_limiter($row['product_overview'], $this->config->item('store_min_word_length_product_overview'));
				
				//format pricing
				if ($row['product_sale_price'] > '0')
				{
					$row['product_price'] = $row['product_sale_price'];
				}
				
				//check for tax zone for price
				$ztax1 = '0';
				
				if ($row['product_type'] == 'physical' && $this->config->item('product_add_tax_zone_to_price') == true && !empty($row['tax_zone']))
				{
					$this->db->where('tax_zone_id', $row['tax_zone']);
					$zquery = $this->db->get('tax_zones');
					if ($zquery->num_rows() > 0)
					{
						$zrow = $zquery->row_array();
						$ztax1 = $row['product_price'] * $zrow['tax_amount'];
						$row['product_price'] = $row['product_price'] + $ztax1;
					}
				}
				
				$row['product_price'] = format_amounts($row['product_price'], $num_options);
				
				if ($row['login_for_price'] == 1)
				{
					if (!$this->session->userdata('userid'))
					{
						$row['product_price'] = $this->lang->line('login_for_price');
					}
				}
					
				if ($row['add_cart_for_price'] == 1)
				{
					$row['product_price'] = $this->lang->line('add_cart_for_price');
				}
				
				//check the image
				if (empty($row['photo_file_name']))
				{
					$row['image_file'] = '<img src="' . base_url(). 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/no_photo.png" />';
					$row['image_file_click'] = '<a href="' . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '">' . $row['image_file'] . '</a>';
				}
				else
				{
					$row['image_file'] = _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], $height = '', $width = '');
					$row['image_file_click'] = '<a href="' . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '">' . _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], '', '', false) . '</a>';					
				}
				
				//check reviews
				if (!empty($row['average_review']))
				{
					$row['ratings'] = _show_ratings($row['average_review']);
				}
				else
				{
					$row['ratings'] = '';
				}
				
				//format add to cart links
				if ($row['product_type'] == 'membership')
				{
					$row['add_to_cart'] = $this->lang->line('buy_now');
					$row['add_to_cart_css'] = 'jroxButtonBuyNow';
				}
				else
				{
					$row['add_to_cart'] = $this->lang->line('add_to_cart');
					$row['add_to_cart_css'] = 'jroxButtonAddToCart';
				}
				
				$row['delete_link'] = '';
				if ($this->session->userdata('userid') == $id)
				{
					$row['delete_link'] = '<a href="javascript:jroxConfirmDelete(\'' . $row['rid'] . '\')" id="jroxProfileRecommendLinkDelete_' . $row['rid'] . '" class="jroxProfileRecommendDeleteLink">' . $this->lang->line('delete') . '</a>';
				}
			
							
				array_push($array, $row);		
			}
			
			return $array;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _change_status($data = '', $type = 'inactive')
	{

		foreach ($data as $id)
		{
			
			$this->db->where('product_id', $id);
			
			if ($type == 'delete')
			{
				$this->_delete_product((int)($id));
			}
			elseif ($type == 'add_featured')
			{
				//update member in db
				
				$data = array(
								'product_featured' => '1',
							);
				
				if (!$this->db->update('products', $data))
				{
					show_error($this->lang->line('could_not_update_product'));
					
					//log error
					log_message('error', 'Could not update product ID #' . $id . ' in products table');
					return false;
				}
				
				//log success
				log_message('info', 'featured stats changed for product ID# ' . $id);
			}
			elseif ($type == 'remove_featured')
			{
				//update member in db
				
				$data = array(
								'product_featured' => '0',
							);
				
				if (!$this->db->update('products', $data))
				{
					show_error($this->lang->line('could_not_update_product'));
					
					//log error
					log_message('error', 'Could not update product ID #' . $id . ' in products table');
					return false;
				}
				
				//log success
				log_message('info', 'featured stats changed for product ID# ' . $id);
			}
			else
			{
				//update member in db
				
				$data = array(
								'product_status' => $type,
							);
				
				if (!$this->db->update('products', $data))
				{
					show_error($this->lang->line('could_not_update_product'));
					
					//log error
					log_message('error', 'Could not update product ID #' . $id . ' in products table');
					return false;
				}
				
				//log success
				log_message('info', 'Status Changed for product ID# ' . $id);
			}
			
		}
		
		return true;		
	}
	
	// ------------------------------------------------------------------------	
	
	function _set_default_photo($id = '', $pid = '')
	{
		//first set all to non-default
		$data = array ('product_default'	=>	'0');
		
		$this->db->where('product_id', $pid);
		
		if ($this->db->update('products_photos', $data))
		{
			//now set one to default
			$data = array ('product_default'	=>	'1');
		
			$this->db->where('photo_id', $id);
			
			if ($this->db->update('products_photos', $data))
			{
				//log success
				log_message('info', 'photo ID #' . $id . ' updated from products_photos table');
			}
			
			return true;
		}
			
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _view_video($id = '')
	{
		$this->db->where('id', $id);
		$query = $this->db->get('products_videos');
		
		
		//return videos
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _manage_videos($id = '')
	{
		$this->load->helper('security');

		//update use video default
		$sdata = array('use_video_default' => $_POST['use_video_default']);
		$this->db->where('product_id', $id);
		$this->db->update('products', $sdata);
		
		$this->db->where('product_id', $id);
		$query = $this->db->delete('products_videos');
		
		for ($i=0; $i<=count($_POST['videos']); $i++)
		{
			if (!empty($_POST['videos'][$i]))
			{
				//first set all to non-default
				$data = array (	'product_id'	=>	$id,
								'video_name'	=>	xss_clean($_POST['video_name'][$i]),
								'video_default'	=>	$_POST['video_default'][$i],
								'use_external_embed'	=>	$_POST['use_external_embed'][$i],
								'video_description' => xss_clean($_POST['video_description'][$i]),
								'video_image' => xss_clean($_POST['video_image'][$i]),
								'video_code'	=>	htmlentities($_POST['videos'][$i])
								);
				
				$this->db->insert('products_videos', $data);
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_photo($id = '')
	{
		//delete product photos
		$this->db->where('photo_id', $id);
		$query = $this->db->get('products_photos');
		
		
		//delete photo files
		if ($query->num_rows() > 0)
		{
			$photo_data = $query->result_array();
			
			if ($photo_data[0]['photo_file_name'])
			{
				@unlink('./images/' . $this->config->item('images_products_dir') . '/' . $photo_data[0]['photo_file_name']);
				
				//delete thumbs
				if ($this->config->item('sts_store_image_auto_resize') == 1)
				{
					@unlink('./images/' . $this->config->item('images_products_dir') . '/' . $photo_data[0]['raw_name'] . '_jrox' . $photo_data[0]['file_ext']);
				}
			}
		}
		
		//delete from products_photos
		$this->db->where('photo_id', $id);			
		
		if ($this->db->delete('products_photos'))
		{
			//log success
			log_message('info', 'photo ID #' . $id . ' deleted from products_photos table');
		}
		
		return $photo_data[0]['product_id'];
	}
	
	// ------------------------------------------------------------------------	
	
	function _delete_product($id = '') //delete a product
	{
		//delete product photos
		$this->db->where('product_id', $id);
		$query = $this->db->get('products_photos');
		
		//delete photo files
		if ($query->num_rows() > 0)
		{	
			foreach ($query->result_array() as $v)
			{
				if ($v['photo_file_name'])
				{
					@unlink('./images/' . $this->config->item('images_products_dir') . '/' . $v['photo_file_name']);
					
					//delete thumbs
					if ($this->config->item('sts_store_image_auto_resize') == 1)
					{
						@unlink('./images/' . $this->config->item('images_products_dir') . '/' . $v['raw_name'] . '_jrox' . $v['file_ext']);
					}
				}
			}
		}
		
		//delete from products_photos
		$this->db->where('product_id', $id);			
		$this->db->delete('products_photos');
		
		//delete from products_reviews
		$this->db->where('product_id', $id);			
		$this->db->delete('products_reviews');
		
		//delete from products_to_attributes
		$this->db->where('product_id', $id);			
		$this->db->delete('products_to_attributes');
		
		//delete from products_to_categories
		$this->db->where('product_id', $id);			
		$this->db->delete('products_to_categories');
		
		//delete from products_to_categories
		$this->db->where('product_id', $id);			
		$this->db->delete('products_to_aff_groups');
		
		//delete from products_to_categories
		$this->db->where('product_id', $id);			
		$this->db->delete('products_to_disc_groups');
		
		//delete from products_to_categories
		$this->db->where('product_id', $id);			
		$this->db->delete('products_videos');
			
		//delete from products table
		$this->db->where('product_id', $id);		
			
		if ($this->db->delete('products'))
		{
			//log success
			log_message('info', 'product ID #' . $id . ' deleted from products table');
	
			return true;	
		}
		else
		{
			show_error($this->lang->line('could_not_delete_product'));
				
			//log error
			log_message('error', 'Could not delete product ID #' . $id . ' from products table');
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_similar_products($keywords = '', $id = '', $num_options = '', $limit = '', $type = 'similar')
	{
		
		if (empty($limit)) { $limit = $this->config->item('sts_products_number_similar_products_details_page'); }
		
		if ($type == 'similar')
		{
			if (empty($keywords)) { return false; }
			
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
					' . $this->db->dbprefix('products') . '.product_name as s_name, 
					' . $this->db->dbprefix('products') . '.product_id as s_pid, ' . $this->db->dbprefix('products_photos') . '.*,
					(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
					WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as s_review
					FROM  ' . $this->db->dbprefix('products') . '					
					LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
					AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\'';
			
			//check on product based on each keyword
			$words = explode(',', $keywords);
	
			foreach ($words as $key => $value)
			{
				$value = trim($value);
				if (!empty($value))
				{
					if ($key == '0')
					{
						$sql .= ' WHERE  ' . $this->db->dbprefix('products') . '.product_keywords LIKE \'%' . $this->input->xss_clean(addslashes($value)) . '%\'';
					}
					else
					{
						$sql .= ' OR  ' . $this->db->dbprefix('products') . '.product_keywords LIKE \'%' . $this->input->xss_clean(addslashes($value)) . '%\'';
					}
				}
			}
					
				$sql .=	' AND product_status = \'1\' GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
						  ORDER BY RAND() LIMIT 0, ' . $limit;
		
		}
		else
		{
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
					' . $this->db->dbprefix('products') . '.product_name as s_name, 
					' . $this->db->dbprefix('products') . '.product_id as s_pid, ' . $this->db->dbprefix('products_photos') . '.*,
					(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
					WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as s_review
					FROM  ' . $this->db->dbprefix('products') . '					
					LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
					AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\'
					WHERE  ' . $this->db->dbprefix('products') . '.recommended_product = \'1\'
					GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
					ORDER BY RAND() LIMIT 0, ' . $limit;
		}
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$array = array();
			
			foreach ($query->result_array() as $row)
			{
				//remove same product
				if ($row['product_status'] == '0') { continue; }
				
				if ($id == $row['s_pid']) { continue;} 
				
				if ($row['product_type'] == 'membership') { continue; }
				
				//check availability
				if (!empty($row['date_available']))
				{
					if ($row['date_available'] >= now()) { continue; }
				}
				
				//check expires
				if (!empty($row['date_expires']))
				{
					if ($row['date_expires'] <= now()) { continue; }
				}
				
				
				$row['s_product_name_url'] = url_title($row['product_name']);
				$row['s_product_overview'] = $row['product_overview'];
				
				//format pricing
				if ($row['product_sale_price'] > '0')
				{
					$row['product_price'] = $row['product_sale_price'];
				}
				
				//check for tax zone for price
				$ztax1 = '0';
				
				if ($row['product_type'] == 'physical' && $this->config->item('product_add_tax_zone_to_price') == true && !empty($row['tax_zone']))
				{
					$this->db->where('tax_zone_id', $row['tax_zone']);
					$zquery = $this->db->get('tax_zones');
					if ($zquery->num_rows() > 0)
					{
						$zrow = $zquery->row_array();
						$ztax1 = $row['product_price'] * $zrow['tax_amount'];
						$row['product_price'] = $row['product_price'] + $ztax1;
					}
				}
				
				$row['s_price'] = format_amounts($row['product_price'], $num_options);
				
				if ($row['login_for_price'] == 1)
				{
					if (!$this->session->userdata('userid'))
					{
						$row['s_price'] = $this->lang->line('login_for_price');
					}
				}
					
				if ($row['add_cart_for_price'] == 1)
				{
					$row['s_price'] = $this->lang->line('add_cart_for_price');
				}
				
				//check the image
				if (empty($row['photo_file_name']))
				{
					$row['s_image_file'] = '<img src="' . base_url(). 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/no_photo_side.png" />';
				}
				else
				{
					$row['s_image_file'] = _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], '', '', false);
					
				}
				
				//check reviews
				if (!empty($row['s_review']))
				{
					$row['s_ratings'] = _show_ratings($row['s_review']);
				}
				else
				{
					$row['s_ratings'] = '';
				}
				
				//format add to cart links
				if ($row['product_type'] == 'membership')
				{
					$row['s_add_to_cart'] = $this->lang->line('buy_now');
					$row['s_add_to_cart_css'] = 'jroxSimilarProductsBuyNow';
				}
				else
				{
					$row['s_add_to_cart'] = $this->lang->line('add_to_cart');
					$row['s_add_to_cart_css'] = 'jroxSimilarProductsAddToCart';
				}
							
				array_push($array, $row);	
			}
			
			return $array;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_product_info($id = '', $cart = false)
	{
		$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
				' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*,
				(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
				WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as average_review
				FROM  ' . $this->db->dbprefix('products') . '					
				LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
				AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
				LEFT JOIN ' . $this->db->dbprefix('products_to_categories') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_to_categories') . '.product_id 
				WHERE  ' . $this->db->dbprefix('products') . '.product_id = \'' . $id . '\'
				AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
				GROUP BY ' . $this->db->dbprefix('products') . '.product_id';
	
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$data['info'] = $query->row_array();
			
			$data['info']['show_product_overview'] = empty($data['info']['product_overview']) ? '0' : '1';
			$data['info']['show_product_description_1'] = empty($data['info']['product_description_1']) ? '0' : '1';
			$data['info']['show_product_description_2'] = empty($data['info']['product_description_2']) ? '0' : '1';
			
			if ($cart == false)
			{
				$data['videos'] = $this->_get_product_videos($id);
				$data['photos'] = $this->_get_product_photos($id);
			}
			
			return $data;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_product_videos($id = '')
	{
		$this->db->where('product_id', $id);
		$this->db->order_by('video_default', 'DESC');
		$query = $this->db->get('products_videos');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_product_photos($id = '')
	{
		$this->db->where('product_id', $id);
		$this->db->order_by('product_default', 'DESC');
		$query = $this->db->get('products_photos');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_default_photo($id = '')
	{
		$this->db->where('product_id', $id);
		$this->db->where('product_default', '1');
		
		$query = $this->db->get('products_photos');
		
		if ($query->num_rows() > 0)
		{
			return;
		}
		else
		{
			$data = array('product_default' => '1');
			$this->db->where('product_id', $id);
			$this->db->limit('1');
			$this->db->update('products_photos', $data);
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_custom_product_discount($id = '', $discount_group = '')
	{
		//copy products_to_disc_groups
		$this->db->where('product_id', $id);
		$this->db->where('group_id', $discount_group);
		$query = $this->db->get('products_to_disc_groups');
		
		if ($query->num_rows() > 0)
		{
			$row = $query->row_array();
			
			if (!empty($row['amount']))
			{
				return $row;
			}
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_product_discounts($discount_group = '1', $num_options = '', $num = false, $custom_amount = '')
	{
		//get discount group amounts
			
		$this->db->where('group_id', $discount_group);
		$query = $this->db->get('discount_groups');
		
		$row = $query->row();
		
		if (!empty($custom_amount)) { $row->discount_group_amount = $custom_amount; }

		if ($row->percentage == 1)
		{	
			if ($num == false)
			{
				if ($row->discount_group_amount > 0)
				{		
					$discount = str_replace('.', '', $row->discount_group_amount);
					
					if ($row->discount_group_amount > 1)
					{
						$discount = '100';	
					}
					
					if ($discount[0] == '0') { $discount = substr($discount, 1); }
																		  
					return $discount . '%' . ' ' .$this->lang->line('off_total_order_at_checkout');
				}
				else
				{
					return false;
				}
			}
			else
			{
				$data = array('percentage' => '1', 
							  'amount' => $row->discount_group_amount);
				return $data;
			}
		}
		else
		{
			if ($num == false)
			{
				if ($row->discount_group_amount > 0)
				{	
					return format_amounts($row->discount_group_amount, $num_options) . ' ' . $this->lang->line('off_total_order_at_checkout');
				}
				
				return false;
			}
			else
			{
				$data = array('percentage' => '0', 
							  'amount' => $row->discount_group_amount);
				return $data;
			}
		}	
		
	
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_home_products($num_options = '')
	{
		
		$order = $this->config->item('sts_products_random_home_page') == '1' ? 'RAND()' : $this->db->dbprefix('products') . '.' . $this->config->item('pub_dbs_pro_column');
		
		$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, ' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*, 
				(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
				WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as average_review
				FROM  ' . $this->db->dbprefix('products') . '
				LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
				AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
				WHERE product_featured = \'1\' AND product_status = \'1\'
				GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
				ORDER BY ' . $order . ' ' . $this->config->item('pub_dbs_pro_order') . ' LIMIT 0, ' . $this->config->item('sts_products_per_home_page');

			$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$data = array();
			
			$num_options = get_default_currency($this->config->item('sts_store_default_currency'));
			
			foreach ($query->result_array() as $row)
			{
				//check availability
				if (!empty($row['date_available']))
				{
					if ($row['date_available'] >= now()) { continue; }
				}
				
				//check expires
				if (!empty($row['date_expires']))
				{
					if ($row['date_expires'] <= now()) { continue; }
				}
				
				$row['product_name_url'] = url_title($row['product_name']);
				//$row['product_overview'] = word_limiter($row['product_overview'], $this->config->item('store_min_word_length_product_overview'));
				
				//check if we want to add tax to amount
				$ztax1 = '0';
				$ztax2 = '0';
				
				if ($this->config->item('product_add_tax_zone_to_price') == true && !empty($row['tax_zone']))
				{
					$this->db->where('tax_zone_id', $row['tax_zone']);
					$zquery = $this->db->get('tax_zones');
					if ($zquery->num_rows() > 0)
					{
						$zrow = $zquery->row_array();
						$ztax1 = $row['product_price'] * $zrow['tax_amount'];
						if ($row['product_sale_price'] > '0')
						{
							$ztax2 = $row['product_sale_price'] * $zrow['tax_amount'];
						}
					}
				}
				
				//check for trial membership pricing
				if ($row['product_type'] == 'membership' && $row['enable_product_trial'] == 1 && !empty($row['product_trial_price']))
				{
					$row['product_price'] = $row['product_trial_price'];	
				}
				
				//set the pre tax price 
				$row['pre_tax_price'] = $row['product_price'];
				$row['pre_tax_sale_price'] = $row['product_sale_price'];
				
				//now add the tax
				$row['product_price'] = $row['product_price'] + $ztax1;
				$row['tax_amount'] = $ztax1;
				
				if ($row['product_sale_price'] > '0')
				{
					$row['product_sale_price'] = $row['product_sale_price'] + $ztax2;
					$row['tax_amount'] = $ztax2;
				}
				
				
				$row['product_price'] = format_amounts($row['product_price'], $num_options);
				
				//format pricing
				if ($row['product_sale_price'] > '0')
				{
					$row['product_price'] = '<span style="text-decoration:line-through;">' . $row['product_price'] . '</span>';
					$row['product_sale_price'] = format_amounts($row['product_sale_price'], $num_options);
				}
				else
				{
					$row['product_sale_price'] = '';	
				}
				
				if ($row['login_for_price'] == 1)
				{
					if (!$this->session->userdata('userid'))
					{
						$row['product_price'] = $this->lang->line('login_for_price');
						$row['product_sale_price'] = '';	
						
					}
				}
					
				if ($row['add_cart_for_price'] == 1)
				{
					$row['product_price'] = $this->lang->line('add_cart_for_price');
					$row['product_sale_price'] = '';	
				}
				
				
				if (empty($row['photo_file_name']))
				{
					$row['image_file'] = '<img src="' . base_url(). 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/no_photo.png" />';
					$row['image_file_click'] = '<a href="' . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '">' . $row['image_file'] . '</a>';
				}
				else
				{
					$row['image_file'] = _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], $height = '', $width = '');
					$row['image_file_click'] = '<a href="' . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '">' . _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], '', '', false) . '</a>';
					
				}
				
				//check reviews
				if (!empty($row['average_review']))
				{
					$row['ratings'] = _show_ratings($row['average_review']);
				}
				else
				{
					$row['ratings'] = '';
				}
				
				//get discount amount
				$row['show_discount_amount'] = '';
				if ($this->session->userdata('m_discount_group') && $row['product_type'] != 'membership')
				{		
					$custom_discount = $this->_get_custom_product_discount($row['pid'], $this->session->userdata('m_discount_group'));
					
					$custom_amount = !empty($custom_discount) ? $custom_discount['amount'] : '';
			
					$row['show_discount_amount'] = $this->_get_product_discounts($this->session->userdata('m_discount_group'), $num_options, false, $custom_amount);
				}
						
				//check if this is a membership button
				$show_mem_button = false;
				if ($row['product_type'] == 'digital' && !empty($row['add_to_membership']) && $this->session->userdata('m_memberships'))
				{
					$mems = $this->session->userdata('m_memberships');
					
					foreach ($mems as $a)
					{
						if ($a['product_id'] == $row['add_to_membership'])
						{
							$show_mem_button = true;	
						}
					}
				}
				
				//format add to cart links
				if ($show_mem_button == true)
				{
					$row['add_to_cart'] = anchor(PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '#jroxProductDownloads', $this->lang->line('download'));
					$row['add_to_cart_css'] = 'jroxButtonAddToCart';
				}
				else
				{
					if ($row['product_type'] == 'membership')
					{
						$row['add_to_cart'] = anchor('cart/add/' . $row['pid'], $this->lang->line('buy_now'));
						$row['add_to_cart_css'] = 'jroxButtonBuyNow';
					
					}
					else
					{
						$row['add_to_cart'] = anchor('cart/add/' . $row['pid'], $this->lang->line('add_to_cart'));
						$row['add_to_cart_css'] = 'jroxButtonAddToCart';
					}
				}
				
				array_push($data, $row);		
			}
			//echo '<pre>'; print_r($data); exit(); 
			return $data;

		}
		
		return false;
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_products_per_category($category_id = 1, $limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $num_options = '', $type = '')
	{
		//get all the products from db for list view
		if (!$sort_order) $sort_order = $this->config->item('pub_dbs_pro_order');
		if (!$sort_column) $sort_column = $this->config->item('pub_dbs_pro_column');
		
		if ($type == 'search')
		{
			$category_id = str_replace(' ', '%', $category_id);
			
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
					' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*,
					(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
					WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as average_review
					FROM  ' . $this->db->dbprefix('products') . '					
					LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
					AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
					WHERE ' . $this->db->dbprefix('products') . '.product_status = \'1\'
					AND date_expires >= ' . now() . '
					AND date_available < ' . now() . '
					AND (product_name LIKE \'%' . $this->input->xss_clean(addslashes($category_id)) .'%\'
					OR product_sku LIKE \'%' . $this->input->xss_clean(addslashes($category_id)) .'%\'
					OR product_keywords LIKE \'%' . $this->input->xss_clean(addslashes($category_id)) . '%\')
					GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
					ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
			
		}
		elseif ($type == 'new')
		{
		
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
					' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*,
					(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
					WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as average_review
					FROM  ' . $this->db->dbprefix('products') . '					
					LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
					AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
					WHERE  ' . $this->db->dbprefix('products') . '.product_new = \'1\'
					AND date_expires >= ' . now() . '
					AND date_available < ' . now() . '
					AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
					GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
					ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		}
		elseif ($type == 'manufacturer')
		{
		
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
					' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*,
					(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
					WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as average_review
					FROM  ' . $this->db->dbprefix('products') . '					
					LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
					AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
					WHERE  ' . $this->db->dbprefix('products') . '.manufacturer_id = \'' . $category_id .'\'
					AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
					AND date_expires >= ' . now() . '
					AND date_available < ' . now() . '
					GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
					ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		}
		else
		{
		
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
					' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*,
					(SELECT AVG(ratings) FROM ' . $this->db->dbprefix('products_reviews') . ' 
					WHERE product_id = ' . $this->db->dbprefix('products') . '.product_id AND status = \'1\') as average_review
					FROM  ' . $this->db->dbprefix('products') . '					
					LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
					AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
					LEFT JOIN ' . $this->db->dbprefix('products_to_categories') . '  
					ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_to_categories') . '.product_id 
					WHERE category_id = \'' . $category_id .'\'
					AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
					AND date_expires >= ' . now() . '
					AND date_available < ' . now() . '
					GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
					ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		}
		
		$query = $this->db->query($sql);
			
		if ($query->num_rows() > 0)
		{
			$array = $query->result_array();
			
			$data['rows'] = array();
			
			foreach ($query->result_array() as $row)
			{
				//check availability
				if (!empty($row['date_available']))
				{
					if ($row['date_available'] >= now()) { continue; }
				}
				
				//check expires
				if (!empty($row['date_expires']))
				{
					if ($row['date_expires'] <= now()) { continue; }
				}
				
				
				$row['product_name_url'] = url_title($row['product_name']);
				//$row['product_overview'] = word_limiter($row['product_overview'], $this->config->item('store_min_word_length_product_overview'));
				
				//check if we want to add tax to amount
				$ztax1 = '0';
				$ztax2 = '0';
				
				if ($this->config->item('product_add_tax_zone_to_price') == true && !empty($row['tax_zone']))
				{
					$this->db->where('tax_zone_id', $row['tax_zone']);
					$zquery = $this->db->get('tax_zones');
					if ($zquery->num_rows() > 0)
					{
						$zrow = $zquery->row_array();
						$ztax1 = $row['product_price'] * $zrow['tax_amount'];
						if ($row['product_sale_price'] > '0')
						{
							$ztax2 = $row['product_sale_price'] * $zrow['tax_amount'];
						}
					}
				}
				
				//check for trial membership pricing
				if ($row['product_type'] == 'membership' && $row['enable_product_trial'] == 1 && !empty($row['product_trial_price']))
				{
					$row['product_price'] = $row['product_trial_price'];	
				}
				
				//set the pre tax price 
				$row['pre_tax_price'] = $row['product_price'];
				$row['pre_tax_sale_price'] = $row['product_sale_price'];
				
				//now add the tax
				$row['product_price'] = $row['product_price'] + $ztax1;
				$row['tax_amount'] = $ztax1;
				
				if ($row['product_sale_price'] > '0')
				{
					$row['product_sale_price'] = $row['product_sale_price'] + $ztax2;
					$row['tax_amount'] = $ztax2;
				}
				
				//format pricing
				$row['product_price'] = format_amounts($row['product_price'], $num_options);
				
				if ($row['product_sale_price'] > '0')
				{
					$row['product_price'] = '<span style="text-decoration:line-through;">' . $row['product_price'] . '</span>';
					$row['product_sale_price'] = format_amounts($row['product_sale_price'], $num_options);
				}
				else
				{
					$row['product_sale_price'] = '';	
				}
				
				
				
				if ($row['login_for_price'] == 1)
				{
					if (!$this->session->userdata('userid'))
					{
						$row['product_price'] = $this->lang->line('login_for_price');
						$row['product_sale_price'] = '';	
					}
				}
					
				if ($row['add_cart_for_price'] == 1)
				{
					$row['product_price'] = $this->lang->line('add_cart_for_price');
					$row['product_sale_price'] = '';	
				}
				
				//check the image
				if (empty($row['photo_file_name']))
				{
					$row['image_file'] = '<img src="' . base_url(). 'themes/main/' . $this->config->item('layout_design_site_theme') . '/images/no_photo.png" />';
					$row['image_file_click'] = '<a href="' . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '">' . $row['image_file'] . '</a>';
				}
				else
				{
					$row['image_file'] = _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], $height = '', $width = '');
					$row['image_file_click'] = '<a href="' . PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '">' . _check_image_thumbnail($this->config->item('images_products_dir'), $row, $row['image_resized'], '', '', false) . '</a>';
				}
				
				
				
				//check reviews
				if (!empty($row['average_review']))
				{
					$row['ratings'] = _show_ratings($row['average_review']);
				}
				else
				{
					$row['ratings'] = '';
				}
				
				//get discount amount
				$row['show_discount_amount'] = '';
				if ($this->session->userdata('m_discount_group') && $row['product_type'] != 'membership')
				{		
					$custom_discount = $this->_get_custom_product_discount($row['pid'], $this->session->userdata('m_discount_group'));
					
					$custom_amount = !empty($custom_discount) ? $custom_discount['amount'] : '';
			
					$row['show_discount_amount'] = $this->_get_product_discounts($this->session->userdata('m_discount_group'), $num_options, false, $custom_amount);
				}
				
				//check if this is a membership button
				$show_mem_button = false;
				if ($row['product_type'] == 'digital' && !empty($row['add_to_membership']) && $this->session->userdata('m_memberships'))
				{
					$mems = $this->session->userdata('m_memberships');
					
					foreach ($mems as $a)
					{
						if ($a['product_id'] == $row['add_to_membership'])
						{
							$show_mem_button = true;	
						}
					}
				}
				
				//format add to cart links
				if ($show_mem_button == true)
				{
					$row['add_to_cart'] = anchor(PRODUCTS_ROUTE . '/details/' . $row['pid'] . '/' . $row['product_name_url'] . '#jroxProductDownloads', $this->lang->line('download'));
					$row['add_to_cart_css'] = 'jroxButtonAddToCart';
					$row['add_quantity_to_cart'] = $row['add_to_cart'];
				}
				else
				{
					if ($row['product_type'] == 'membership')
					{
						$row['add_to_cart'] = anchor('cart/add/' . $row['pid'], $this->lang->line('buy_now'));
						$row['add_to_cart_css'] = 'jroxButtonBuyNow';
						$row['add_quantity_to_cart'] = $row['add_to_cart'];
					}
					else
					{
						$row['add_to_cart'] = anchor('cart/add/' . $row['pid'], $this->lang->line('add_to_cart'));
						$row['add_to_cart_css'] = 'jroxButtonAddToCart';
						
						$row['min_quantity'] = $row['min_quantity_ordered'] == 0 ? 1 : $row['min_quantity_ordered'];
						
						$row['add_quantity_to_cart'] = '<label for="quantity" class="jroxProductDetailsAddQuantityLabel">' . $this->lang->line('quantity') . '</label>
                    	<input name="add_item[' . $row['pid']. ']" type="text" value="' . $row['min_quantity'] . '" class="jroxProductDetailsAddQuantityInput"/>';
					}
				}
							
				array_push($data['rows'], $row);		
			}
			
			//get the number of rows
			
			if ($type == 'search')
			{
				$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
						' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*
						FROM  ' . $this->db->dbprefix('products') . '					
						LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
						ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
						AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
						WHERE ' . $this->db->dbprefix('products') . '.product_status = \'1\'
						AND date_expires >= ' . now() . '
						AND date_available < ' . now() . '
						AND (product_name LIKE \'%' . $this->input->xss_clean(addslashes($category_id)) .'%\'
						OR product_sku LIKE \'%' . $this->input->xss_clean(addslashes($category_id)) .'%\'
						OR product_keywords LIKE \'%' . $this->input->xss_clean(addslashes($category_id)) . '%\')
						GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
						ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order;
			}
			elseif ($type == 'new')
			{
			
				$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
						' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*
						FROM  ' . $this->db->dbprefix('products') . '					
						LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
						ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
						AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
						WHERE  ' . $this->db->dbprefix('products') . '.product_new = \'1\'
						AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
						AND date_expires >= ' . now() . '
						AND date_available < ' . now() . '
						GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
						ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order;
			}
			elseif ($type == 'manufacturer')
			{
			
				$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, 
						' . $this->db->dbprefix('products') . '.product_id as pid, ' . $this->db->dbprefix('products_photos') . '.*
						FROM  ' . $this->db->dbprefix('products') . '					
						LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
						ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
						AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
						WHERE  ' . $this->db->dbprefix('products') . '.manufacturer_id = \'' . $category_id .'\'
						AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
						AND date_expires >= ' . now() . '
						AND date_available < ' . now() . '
						GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
						ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order;
			
			}
			else
			{
				//get totals
				$sql = 'SELECT ' . $this->db->dbprefix('products') . '.*, ' . $this->db->dbprefix('products') . '.product_id as pid, ' . 
						$this->db->dbprefix('products_photos') . '.*
						FROM  ' . $this->db->dbprefix('products') . '					
						LEFT JOIN ' . $this->db->dbprefix('products_photos') . '  
						ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_photos') . '.product_id 
						AND ' . $this->db->dbprefix('products_photos') . '.product_default = \'1\' 
						LEFT JOIN ' . $this->db->dbprefix('products_to_categories') . '  
						ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_to_categories') . '.product_id 
						WHERE category_id = \'' . $category_id .'\'
						AND ' . $this->db->dbprefix('products') . '.product_status = \'1\'
						AND date_expires >= ' . now() . '
						AND date_available < ' . now() . '
						GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
						ORDER BY ' . $this->db->dbprefix('products') . '.' . $sort_column . ' ' . $sort_order;
			}
			
			$query = $this->db->query($sql);
			
			$data['total_rows'] = $query->num_rows();
			//echo '<pre>'; print_r($data); exit();
			return $data;
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_products($limit = 25, $offset = 0, $sort_column = '', $sort_order = '', $where_column = '', $where_value = '')
	{
		//get all the products from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_pro_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_pro_column');
		
		if ($where_column == 'category_id')
		{
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.* FROM  ' . $this->db->dbprefix('products') . '
				LEFT JOIN ' . $this->db->dbprefix('products_to_categories') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_to_categories') . '.product_id 
				WHERE ' . $where_column . ' = \'' . $where_value .'\'
				GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;

			$query = $this->db->query($sql);
			
		}
		elseif ($where_column == 'attribute_id')
		{
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.* FROM  ' . $this->db->dbprefix('products') . '
				LEFT JOIN ' . $this->db->dbprefix('products_to_attributes') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_to_attributes') . '.product_id 
				WHERE ' . $where_column . ' = \'' . $where_value .'\'
				GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;

			$query = $this->db->query($sql);
		}
		elseif ($where_column == 'search')
		{
			$sql = 'SELECT ' . $this->db->dbprefix('products') . '.* FROM  ' . $this->db->dbprefix('products') . '
				LEFT JOIN ' . $this->db->dbprefix('products_to_attributes') . '  
				ON ' . $this->db->dbprefix('products') . '.product_id = ' . $this->db->dbprefix('products_to_attributes') . '.product_id 
				WHERE product_name LIKE \'%' . $this->input->xss_clean(addslashes($where_value)) .'%\'
				OR product_sku LIKE \'%' . $this->input->xss_clean(addslashes($where_value)) .'%\'
				GROUP BY ' . $this->db->dbprefix('products') . '.product_id 
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;

			$query = $this->db->query($sql);
		}
		else
		{
			if (!empty($where_column) && !empty($where_value))
			{
				$this->db->where($where_column, $where_value);
			}
			
			$this->db->order_by($sort_column, $sort_order); 	
			$query = $this->db->get('products', $limit, $offset);
		}
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_group_pricing($data = '')
	{
		$id = (int)$this->uri->segment(4);
		
		//delete all entries in products_to_groups first
		$this->db->where('product_id', $id);
		$this->db->delete('products_to_disc_groups');
		
		foreach ($_POST as $k => $v)
		{
			
			if (preg_match('/group_amount-*/', $k)) 
			{
				$group_array = explode('-', $k);

				$data = array(
								'product_id' => $id,
								'group_id'	=> $group_array[1],
								'amount'	=>	$v
							);
				
				if (!$this->db->insert('products_to_disc_groups', $data))
				{
					show_error($this->lang->line('could_not_update_custom_group_pricing'));
					
					//log error
					log_message('error', 'Could not update products_to_disc_groups table');
					return false;
				}
			}
		}
		
		//log success
		log_message('info', 'custom group pricing changed for product ID# ' . $id);
			
		return true;	
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_discount_groups($id = '', $limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_dg_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_dg_column');

		
		$sql = 'SELECT ' . $this->db->dbprefix('discount_groups') . '.*,
				(SELECT amount from ' . $this->db->dbprefix('products_to_disc_groups') . ' 
				WHERE ' . $this->db->dbprefix('discount_groups') . '.group_id = ' . $this->db->dbprefix('products_to_disc_groups') . '.group_id 
				AND ' . $this->db->dbprefix('products_to_disc_groups') . '.product_id = \'' . $id . '\') as total
				FROM ' . $this->db->dbprefix('discount_groups') . '
				ORDER BY ' . $sort_column . ' ' . $sort_order;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _update_aff_group_pricing($gid = '', $pid = '')
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//delete all entries in products_to_groups first
		$this->db->where('product_id', $pid);
		$this->db->where('group_id', $gid);
		$this->db->delete('products_to_aff_groups');
		
		$data['product_id'] = $pid;
		$data['group_id'] = $gid;
		
		if ($this->db->insert('products_to_aff_groups', $data) == true)
		{
			//log success
			log_message('info', 'custom affiliate group pricing changed for product ID# ' . $pid);
				
			return true;	
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_affiliate_groups($id = '', $limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the affiliate groups from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_ag_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_ag_column');
		
		$sql = 'SELECT ' . $this->db->dbprefix('affiliate_groups') . '.*
				FROM ' . $this->db->dbprefix('affiliate_groups') . '
				ORDER BY ' . $sort_column . ' ' . $sort_order;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_aff_group_pricing($gid = '', $pid = '')
	{
		$this->db->where('group_id', $gid);
		$this->db->where('product_id', $pid);
		$query = $this->db->get('products_to_aff_groups');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_product_basic($id = '')
	{
		$this->db->where('product_id', $id);
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			return $query->row_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_product_details($id = '')
	{
		$x['products_attributes'] = '';
		$x['products_to_attributes'] = '';
		$x['products_to_categories'] = '';
		$x['photos'] = '';
		$x['categories'] = '';
		$x['affiliate_groups'] = '';
		$x['discount_groups'] = '';
		$x['mailing_lists'] = '';
		$x['tax_zones'] = '';
		$x['post_purchase_modules'] = '';
		$x['signup_modules'] = '';
		$x['expires_modules'] = '';
		$x['videos'] = '';
		
		//get the data from products table first
		$this->db->where('product_id', $id);
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			$x['product'] = $query->result_array();
		}
		else
		{
			return false;
		}
		
		//get product purchase modules
		$this->db->where('module_type', 'post_purchase');
		$this->db->where('module_status', '1');
		$query = $this->db->get('modules');
		if ($query->num_rows() > 0)
		{
			$post_purchase_modules = $query->result_array();
			$x['post_purchase_modules'] = format_array($post_purchase_modules, 'module_id', 'module_name', true);
		}
		
		//get signup modules
		$this->db->where('module_type', 'signup');
		$this->db->where('module_status', '1');
		$query = $this->db->get('modules');
		if ($query->num_rows() > 0)
		{
			$signup_modules = $query->result_array();
			$x['signup_modules'] = format_array($signup_modules, 'module_id', 'module_name', true);
		}
		
		//get expires modules
		$this->db->where('module_type', 'account_delete');
		$this->db->where('module_status', '1');
		$query = $this->db->get('modules');
		if ($query->num_rows() > 0)
		{
			$expires_modules = $query->result_array();
			$x['expires_modules'] = format_array($expires_modules, 'module_id', 'module_name', true);
		}
		
		//get tax zones
		$this->db->order_by('tax_zone_id', 'ASC');
		$query = $this->db->get('tax_zones');
		if ($query->num_rows() > 0)
		{
			$tax_zones = $query->result_array();
			$x['tax_zones'] = format_array($tax_zones, 'tax_zone_id', 'tax_zone_name', true);
		}
		
		//get manufacturers
		$this->db->order_by('manufacturer_id', 'ASC');
		$query = $this->db->get('manufacturers');
		if ($query->num_rows() > 0)
		{
			$manufacturers = $query->result_array();
			$x['manufacturers'] = format_array($manufacturers, 'manufacturer_id', 'manufacturer_name', true);
		}
		
		//get vendors
		$this->db->order_by('vendor_id', 'ASC');
		$query = $this->db->get('vendors');
		if ($query->num_rows() > 0)
		{
			$vendors = $query->result_array();
			$x['vendors'] = format_array($vendors, 'vendor_id', 'vendor_name', true);
		}
		
		//get affiliate groups
		$query = $this->db->get('affiliate_groups');
		if ($query->num_rows() > 0)
		{
			$affiliate_groups = $query->result_array();
			$x['affiliate_groups'] = format_array($affiliate_groups, 'group_id', 'aff_group_name', true);
		}
		
		//get discount groups
		$query = $this->db->get('discount_groups');
		if ($query->num_rows() > 0)
		{
			$discount_groups = $query->result_array();
			$x['discount_groups'] = format_array($discount_groups, 'group_id', 'discount_group_name', true);
		}
		
		//get mailing lists
		$query = $this->db->get('email_mailing_lists');
		if ($query->num_rows() > 0)
		{
			$email_mailing_lists = $query->result_array();
			$x['email_mailing_lists'] = format_array($email_mailing_lists, 'mailing_list_id', 'mailing_list_name', true);
		}
		
		//get product attributes
		$this->db->order_by('attribute_id', 'ASC');
		$query = $this->db->get('products_attributes');
		if ($query->num_rows() > 0)
		{
			$attributes = $query->result_array();
			$x['products_attributes'] = format_array($attributes, 'attribute_id', 'attribute_name');
		}		
		
		//get products TO attributes
		$this->db->where('product_id', $id);
		$query = $this->db->get('products_to_attributes');
		if ($query->num_rows() > 0)
		{
			$products_to_attributes = $query->result_array();
			$x['products_to_attributes'] = format_array($products_to_attributes, 'attribute_id');
		}
		
		//get product videos
		$this->db->where('product_id', $id);
		$this->db->order_by('product_id', 'DESC');
		$query = $this->db->get('products_videos');
		if ($query->num_rows() > 0)
		{
			$x['videos'] = $query->result_array();
		}
		
		//get product photos
		$this->db->where('product_id', $id);
		$this->db->order_by('product_default', 'DESC');
		$query = $this->db->get('products_photos');
		if ($query->num_rows() > 0)
		{
			$x['photos'] = $query->result_array();
		}
			
		//get products TO categories	
		$this->db->where('product_id', $id);
		$query = $this->db->get('products_to_categories');
		if ($query->num_rows() > 0)
		{
			$products_to_categories = $query->result_array();
			$x['products_to_categories'] = format_array($products_to_categories, 'category_id');
		}
		
		
		return $x;
	}	
	
	// ------------------------------------------------------------------------	
	
	function _clone_product($id = '')
	{
		//first copy the products table
		$this->db->where('product_id', $id);
		$query = $this->db->get('products');
		
		if ($query->num_rows() > 0)
		{
			$row = $query->row_array();
			
			//now insert the product data
			unset($row['product_id']);
			$row['product_sku'] = _generate_random_string(6);
			
			$this->db->insert('products', $row);
		
			$new_pid = $this->db->insert_id();
			
			//copy products_to_aff_groups
			$this->db->where('product_id', $id);
			$query = $this->db->get('products_to_aff_groups');
			
			if ($query->num_rows() > 0)
			{
				foreach ($query->result_array() as $srow)
				{
					unset($srow['id']);
					$srow['product_id'] = $new_pid;
					$this->db->insert('products_to_aff_groups', $srow);
				}
			}
				
			//copy products_to_attributes	
			$this->db->where('product_id', $id);
			$query = $this->db->get('products_to_attributes');
			
			if ($query->num_rows() > 0)
			{
				foreach ($query->result_array() as $srow)
				{				
					$srow['product_id'] = $new_pid;
					$this->db->insert('products_to_attributes', $srow);
				}
			}
			
			//copy products_to_categories
			$this->db->where('product_id', $id);
			$query = $this->db->get('products_to_categories');
			
			if ($query->num_rows() > 0)
			{
				foreach ($query->result_array() as $srow)
				{				
					$srow['product_id'] = $new_pid;
					$this->db->insert('products_to_categories', $srow);
				}
			}
			
			//copy products_to_disc_groups
			$this->db->where('product_id', $id);
			$query = $this->db->get('products_to_disc_groups');
			
			if ($query->num_rows() > 0)
			{
				foreach ($query->result_array() as $srow)
				{
					unset($srow['id']);
					$srow['product_id'] = $new_pid;
					$this->db->insert('products_to_disc_groups', $srow);
				}
			}

			//copy products_videos
			$this->db->where('product_id', $id);
			$query = $this->db->get('products_videos');
			
			if ($query->num_rows() > 0)
			{
				foreach ($query->result_array() as $srow)
				{
					unset($srow['id']);
					$srow['product_id'] = $new_pid;
					$this->db->insert('products_videos', $srow);
				}
			}
			
			return $new_pid;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
		
	function _update_product($id = '')
	{
		//unset the arrays
		$attributes = !empty($_POST['product_attributes']) ? $_POST['product_attributes'] : '';
		unset ($_POST['product_attributes']);
		
		$categories = !empty($_POST['product_categories']) ? $_POST['product_categories'] : '';
		unset ($_POST['product_categories']);
		
		//unset data
		unset ($_POST['folder_protection']);
		
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		
		//format date
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		switch ($fdate[0])
		{
			case 'mm/dd/yyyy':
					
				if (!empty($data['date_available']))
				{
					$avail = explode('/', $data['date_available']);
					$data['date_available'] = mktime('1','0','0', $avail[0], $avail[1], $avail[2]);
				}
				else
				{
					$data['date_available'] = _generate_timestamp() - (3600 * 24);
				}
				
				
				if (!empty($data['date_expires']))
				{
					$expires = explode('/', $data['date_expires']);
					$data['date_expires'] = mktime('1','0','0', $expires[0], $expires[1], $expires[2]);
				}
				else
				{
					$data['date_expires'] = _generate_timestamp() + (3600 * 24 * 365 * 20);
				} 
						
			break;
		}
		
		//set update date and by
		$data['date_modified'] = _generate_timestamp();
	
		//update into db
		$this->db->where('product_id', $id);
		
		//update descriptions
		$data['product_overview'] = _content_filter($data['product_overview']);
		$data['product_description_1'] = _content_filter($data['product_description_1']);
		$data['product_description_2'] = _content_filter($data['product_description_2']);
		
		if (!$this->db->update('products', $data))
		{
			show_error($this->lang->line('could_not_update_product'));
			
			//log error
			log_message('error', 'Could not update product ' . $id . 'in products table');
			
			return false;
		}
		else
		{
			
			//log success
			log_message('info', 'product ID '. $id . ' updated in products table');
		}
		
		
		//add to attributes
		
		//delete from attributes first
		$this->db->where('product_id', $id);
		$this->db->delete('products_to_attributes');
		
		//then add
		if (!empty($attributes))
		{
			foreach ($attributes as $k => $v)
			{
				$data = array(	'product_id'	=>	$id,
								'attribute_id'	=>	$v,
								);
			
				if ($this->db->insert('products_to_attributes', $data))
				{
					//log success
					log_message('info', 'product ID '. $id . ' updated in products_to_attributes table');
				}
				else
				{
					//log error
					log_message('error', 'Could not update products_to_attributes for product ID ' . $id . ' in products_to_attributes table');
				}
			}
		}
		
		//add to categories
		//delete from cat first
		$this->db->where('product_id', $id);
		$this->db->delete('products_to_categories');
		
		//set product to default category if there is none
		if (empty($categories))
		{
			//add to default category
			$categories = array('category_id'	=>	'1');
		}

		//then add
		if (!empty($categories))
		{
			foreach ($categories as $k => $v)
			{
				$data = array(	'product_id'	=>	$id,
								'category_id'	=>	$v,
								);
			
				if ($this->db->insert('products_to_categories', $data))
				{
					//log success
					log_message('info', 'product ID '. $id . ' updated in products_to_categories table');
				}
				else
				{
					//log error
					log_message('error', 'Could not update products_to_categories for product ID ' . $id . ' in products_to_categories table');
				}
			}
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
}
?>