<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - tracking_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for managing tracking
|
*/

class Tracking_Model extends Model {	
	
	function _add_tracking()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//insert into db
		if (!$this->db->insert('tracking', $data))
		{
			show_error($this->lang->line('could_not_add_tracking'));
			
			//log error
			log_message('error', 'Could not insert tracking into tracking table');
			
			return false;
		}
		else
		{
			$id = $this->db->insert_id();
			
			//log success
			log_message('info', 'tracking '. $id . ' inserted into tracking table');
		}
		
		return $id;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_referrer($url = '')
	{
		$this->db->where('referrer', $url);
		$query = $this->db->get('tracking_referrals', '1');
		
		if ($query->num_rows() > 0)
		{
			return true;	
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _prune_ad_trackers($days = '')
	{
		$time = now() - (3600 * 24 * $days);
		
		$this->db->where('date <', $time);
		$this->db->delete('tracking_referrals');
		
		return 'ad trackers pruned';
	}
	
	// ------------------------------------------------------------------------

	function _reset_tracking($id = '')
	{
		//update invoices
		$this->db->where('tracking_id', $id);
		if ($this->db->update('invoices', array('tracking_id' => '')))
		{
			//delete tracking members
			$this->db->where('tid', $id);
			if ($this->db->delete('tracking_referrals'))
			{
				//log success
				log_message('info', 'tracking urls deleted successfully');
			
			}
		}
		else
		{
			show_error($this->lang->line('could_not_delete_tracking'));
			
			//log error
			log_message('error', 'tracking ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}
		
	// ------------------------------------------------------------------------
	
	function _delete_tracking_referral($id = '')
	{
		//delete mailing list members
		$this->db->where('id', $id);
		if ($this->db->delete('tracking_referrals'))
		{
			
			//log success
			log_message('info', 'tracking urls deleted successfully');
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _delete_tracking($id = '')
	{
		
		//delete mailing list members
		$this->db->where('tid', $id);
		if ($this->db->delete('tracking_referrals'))
		{
			
			//log success
			log_message('info', 'tracking urls deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_tracking'));
			
			//log error
			log_message('error', 'tracking ID #' . $id . ' could not be deleted');
		}
		

		
		
		//delete tracking
		$this->db->where('id', $id);
		if ($this->db->delete('tracking'))
		{
			
			//log success
			log_message('info', 'tracking ID #' . $id . ' deleted successfully');
		}
		else
		{
			show_error($this->lang->line('could_not_delete_tracking'));
			
			//log error
			log_message('error', 'tracking ID #' . $id . ' could not be deleted');
		}
		
		return true;
	}	

	
	// ------------------------------------------------------------------------

	function _get_tracking_details($id = '')
	{
		//get the data from tracking table
		$this->db->where('id', $id);
		$query = $this->db->get('tracking');
		
		if ($query->num_rows() > 0)
		{
			return $query->row_array();
		}
		else
		{
			return false;
		}
	}
	
	
	// ------------------------------------------------------------------------
	
	function _get_all_tracking()
	{
		$query =$this->db->get('tracking');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_tracking($limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_trc_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_trc_column');

		$sql = 'SELECT ' . $this->db->dbprefix('tracking') . '.*,
				(SELECT COUNT(*) FROM ' . $this->db->dbprefix('tracking_referrals') . '
				WHERE ' . $this->db->dbprefix('tracking') . '.id = ' . $this->db->dbprefix('tracking_referrals') . '.tid) as clicks,
				(SELECT SUM(sub_total+tax_amount+shipping_amount-discount_amount)
				FROM ' . $this->db->dbprefix('invoices') . '
				WHERE ' . $this->db->dbprefix('invoices') . '.tracking_id = ' .  $this->db->dbprefix('tracking') . '.id) as sales
				FROM ' . $this->db->dbprefix('tracking') . '
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			
			return $query->result_array();
		}
		 
		return  false;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_tracking_referrals($id = '', $limit = 25, $offset = 0, $sort_column = '', $sort_order = '')
	{
		//get all the admins from db for list view
		if (!$sort_order) $sort_order = $this->config->item('dbs_trr_order');
		if (!$sort_column) $sort_column = $this->config->item('dbs_trr_column');

		$sql = 'SELECT ' . $this->db->dbprefix('tracking_referrals') . '.*
				FROM ' . $this->db->dbprefix('tracking_referrals') . '
				WHERE tid = ' . $id . '
				ORDER BY ' . $sort_column . ' ' . $sort_order . ' LIMIT ' . $offset. ', ' . $limit;
		
		$query = $this->db->query($sql);
		
		if ($query->num_rows() > 0)
		{
			$data['tracking'] = $query->result_array();
		
			//get totals
			$sql = 'SELECT ' . $this->db->dbprefix('tracking_referrals') . '.*
				FROM ' . $this->db->dbprefix('tracking_referrals') . '
				WHERE tid = ' . $id;
		
			$query = $this->db->query($sql);
			
			$data['totals'] = $query->num_rows();
			
			return $data;
		}
		 
		return  false;
	}

	// ------------------------------------------------------------------------
	
	function _update_tracking($id = '')
	{
		//clean the data first
		$data = $this->db_validation_model->_clean_data($_POST);
		
		//update tracking data
		$this->db->where('id', $id);
		
		if (!$this->db->update('tracking', $data))
		{
			show_error($this->lang->line('could_not_update_tracking'));
			
			//log error
			log_message('error', 'Could not update tracking ID ' . $id . 'in tracking table');
			
			return false;
		}
		else
		{
			
			//log success
			log_message('info', 'tracking ID '.$id . ' updated in tracking table');
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
}
?>