<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2010 JROX Technologies, Inc.  All Rights Reserved.    
| -------------------------------------------------------------------------                                                                        
| This script may be only used and modified in accordance to the license      
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - module_affiliate_marketing_viral_pdfs.php
| -------------------------------------------------------------------------     
| 
| This controller file is used to manage viral_pdf options
|
*/

class Module_Affiliate_Marketing_Viral_Pdfs extends Admin_Controller {
	
	function __construct()
	{
		parent::Admin_Controller();	
		
		//load viral_pdfs model
		$this->load->model('affiliate_marketing_model', 'aff');
		
		//load required model
		$this->load->model('modules/module_affiliate_marketing_viral_pdfs_model', 'viral_pdfs_model');
		
		//load css body style
		$this->config->set_item('css_body', 'GJ');
		
		//create pagination links		
		$this->config->set_item('uri', 'modules/' . $this->uri->segment(2) . '/table');
		
		//module name
		$this->config->set_item('module_name', 'module_affiliate_marketing_viral_pdfs');
		
	}
	
	// ------------------------------------------------------------------------
	
	function index()
	{
		//redirect to default view
		redirect(ADMIN_ROUTE . '/affiliate_marketing/view_affiliate_tools');
	}
	
	
	// ------------------------------------------------------------------------
	
	function add()
	{
		/*
		| -----------------------------------------
		| add a new viral_pdf
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('add_viral_pdf');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_viral_pdfs/add';
		$data['update_link'] = 'viral_pdfs';
		$data['manage_tool'] = 'manage_viral_pdf';
		$data['tool_details'] = 'viral_pdf_details';
		$data['tool_options'] = 'viral_pdf_options';
		$data['view_link'] = 'view_viral_pdfs';
		$data['view_links'] = 'view_viral_pdfs';
		$data['add_link'] = 'add';
		$data['error_string'] = '';
		
		
		//run admin validation check
		if ($this->_check_viral_pdf() == false)
		{		
			//reload add viral_pdf form
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}	
			
			//initialize HTML editor
			$options = array(	'instance'	=> 'oEdit1',
								'type' => 'content',
								'content' => html_entity_decode($this->validation->viral_pdf_body),
								'height'	=> '400',
								'width'	=> '100%',
								'editor_type'	=> 'viralpdf',
								'textarea'	=>	'viral_pdf_body',
								'tags'	=> true,
							);
			$check_editor = _initialize_html_editor($options);
		
			$data['editor'] = $check_editor['editor'];
			$data['editor_path'] = $check_editor['editor_path'];
		}
		else
		{	
			
			//if there is no error add it to the db
			if (empty($data['error_string']))
			{
				//add the viral_pdf into db
				$id = $this->viral_pdfs_model->_add_viral_pdf();		
				
				$this->session->set_flashdata('success', $this->lang->line('add_viral_pdf_success'));
					
				redirect('modules/module_affiliate_marketing_viral_pdfs/edit/' . $id);
			}
		}		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_viral_pdf', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function delete()
	{
		/*
		| --------------------------------------------
		| delete the viral_pdf from the db
	    | --------------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
	
		if ($this->aff->_delete_tool('viral_pdf', (int)($this->uri->segment(4)), 'affiliate_viral_pdfs'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect('/modules/module_affiliate_marketing_viral_pdfs/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				echo '<script>self.parent.location.reload(true);</script>';		
			}	
		}
		else
		{
			redirect(ADMIN_ROUTE);
		}
	}
	
	// ------------------------------------------------------------------------
	
	function generate()
	{
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		$this->viral_pdfs_model->_generate_viral_pdf_code((int)$this->uri->segment(4));
	}
	
	// ------------------------------------------------------------------------
	
	function edit()
	{
		/*
		| -----------------------------------------
		| update a new viral_pdf
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');

		//set page title
		$data['page_title'] = $this->lang->line('update_viral_pdf');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_viral_pdfs/edit/' . (int)$this->uri->segment(4);
		$data['update_link'] = 'viral_pdfs';
		$data['manage_tool'] = 'manage_viral_pdf';
		$data['tool_details'] = 'viral_pdf_details';
		$data['tool_options'] = 'viral_pdf_options';
		$data['view_link'] = 'view_viral_pdf';
		$data['view_links'] = 'view_viral_pdfs';
		$data['add_link'] = 'edit';
		$data['error_string'] = '';
		
		$this->validation->id = (int)$this->uri->segment(4);
		
		//run admin validation check
		if ($this->_check_viral_pdf() == false)
		{		
			//reload add viral_pdf form
			if (!empty($_POST))
			{
				$data['error_string'] = $this->validation->error_string;
			}	
			else
			{
				$mdata = $this->viral_pdfs_model->_get_viral_pdf_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['viral_pdf'] = $mdata[0];
					
				}
				else
				{
					redirect(ADMIN_ROUTE);
				}		
			}
			
			//initialize HTML editor
			$options = array(	'instance'	=> 'oEdit1',
								'type' => 'content',
								'content' => html_entity_decode($this->validation->viral_pdf_body),
								'height'	=> '400',
								'width'	=> '100%',
								'editor_type'	=> 'viralpdf',
								'textarea'	=>	'viral_pdf_body',
								'tags'	=> true,
							);
			$check_editor = _initialize_html_editor($options);
		
			$data['editor'] = $check_editor['editor'];
			$data['editor_path'] = $check_editor['editor_path'];
		}
		else
		{	
			
			
			//if there is no error update it in the db
			if (empty($data['error_string']))
			{
				//add the viral_pdf into db
				$id = $this->viral_pdfs_model->_edit_viral_pdf((int)$this->uri->segment(4));		
				
				$this->session->set_flashdata('success', $this->lang->line('update_viral_pdf_success'));
					
				redirect('/modules/module_affiliate_marketing_viral_pdfs/edit/' . $id);
			}
		}		
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_viral_pdf', $data);
	}
	
	// ------------------------------------------------------------------------
	
	function update()
	{
		/*
		| -----------------------------------------
		| add a new viral_pdf
		| -----------------------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('viral_pdf_options');
		$data['submit_url'] = base_url() . $data['site_index_page'] . 'modules/module_affiliate_marketing_viral_pdfs/update';
		$data['add_link'] = 'update_viral_pdf';
		$data['update_link'] = 'viral_pdfs';
		
		//run admin validation check
		if ($this->_check_viral_pdf_options() == false)
		{		
			//reload add viral_pdf form
			if (empty($_POST))
			{
				$mdata = $this->aff->_get_affiliate_marketing_details((int)$this->uri->segment(4));
				
				if (!empty($mdata))
				{	
					foreach ($mdata[0] as $key => $value)
					{
						$this->validation->$key = $value;
					}
					
					$data['sts_config'] = array();
					
					foreach ($mdata[0]['sts_config'] as  $v)
					{
						$this->validation->$v['settings_key'] = $v['settings_value'];
		
						array_push($data['sts_config'], $v);
					
					}
					
					//load template
					load_form('modules', 'tpl_adm_manage_affiliate_marketing_options', $data, false, false);
				}
				else
				{
					//load add viral_pdf page
					redirect();
					exit();
				}
							
			}
			else
			{				
				//ajax form
				echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			}		
		}
		else
		{	
			//update the viral_pdf into db
			$data = $this->aff->_update_options((int)$this->uri->segment(4));	

			
			//ajax message
			echo '<div class="success" onclick="self.parent.location.reload(true);" style="cursor:pointer;">' . $this->lang->line('update_options_success') . '. ' . $this->lang->line('click_to_continue') . '</div>';		
			exit();	
			
			
		}		
	}
	
	// ------------------------------------------------------------------------
	
	function view()
	{
		/*
		| -----------------------------------------
		| view viral_pdfs modules
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//set page title
		$data['page_title'] = $this->lang->line('view_viral_pdfs');
		$data['sub_title'] = $this->lang->line('manage_viral_pdfs');
		
		$data['add_link'] = 'add_viral_pdf';
		
		$data['offset'] = 0;
		$data['sort_column'] = 0;
		$data['sort_order'] = 0;
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_manage_affiliate_marketing_tools', $data);	
	}
	
	// ------------------------------------------------------------------------
	
	function table()
	{
		/*
		| ------------------------------
		| get viral_pdfs modules via ajax
		| ------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		//check for offset and sort order
		$data['offset'] = $this->uri->segment(5, 0);
		$data['sort_column'] = $this->uri->segment(7, 0);
		$data['sort_order'] = $this->uri->segment(6, 0);
		$data['next_sort_order'] = $this->uri->segment(6) == 'DESC' ? 'ASC' : 'DESC';
		$data['sort_header'] = $data['uri'] .'/' . $this->config->item('cache_bx') . '/' . $data['offset'] . '/' . $data['next_sort_order'];
		
		$data['add_link'] = 'add_viral_pdf';
		$data['table_name'] = 'affiliate_viral_pdfs';
		$data['no_tools_found'] = 'no_viral_pdfs_found';
		$data['header_name'] = 'viral_pdf_name';
		$data['height'] = '500';
		$data['width'] = '400';
		
		//check if there are any sql wheres
		$data['where_column'] = $this->uri->segment(4,0);
		$data['where_value'] =  $this->uri->segment(5,0);
		
		$data['num_options'] = get_default_currency($data['sts_store_default_currency']);
		
		//get groups
		$row = $this->viral_pdfs_model->_get_viral_pdfs($this->session->userdata('per_page'), $data['offset'], $data['sort_column'], $data['sort_order']);
		
		//add the data to the array
		$data['tools'] = $row;
		
		if (empty($row))
		{
			$row[0] = array(
						'viral_pdf_id' => 0,
						'viral_pdf_name' => $this->lang->line('no_viral_pdfs_found'),
						'viral_pdf_status' => 0,
						'clicks' => 0,
						'commissions' => 0,
						'sales' => 0,
						'sort_order' => 0,
						);
		}
		
		//set pagination
		$data['pagination'] = $this->db_validation_model->_set_pagination($data['uri'], 'affiliate_viral_pdfs', $this->session->userdata('per_page'), 5, $data['sort_order'], $data['sort_column']);
		
		//load template
		load_admin_tpl('modules', 'tpl_adm_affiliate_marketing_tools_table', $data, false, false);
	}
	
	// ------------------------------------------------------------------------
	
	function sort_order()
	{
		/*
		| ---------------------------
		| mass update group tiers
		| ---------------------------
		*/

		//set data array
		$data = $this->security_model->_load_config('admin');
	
		if ($this->_check_sort_order() == true)
		{	
			$this->aff->_change_sort_order('affiliate_viral_pdfs');
			
			//set flash data
			$this->session->set_flashdata('success', $this->lang->line('viral_pdf_updated_successfully'));
			
			echo '<script>self.parent.location.reload(true);</script>';	
		}
		else
		{
			echo '<div class="error" id="error-messages">' . $this->validation->error_string . '</div>';
			exit();
		}
	}
	
	// ------------------------------------------------------------------------
	
	
	function change_status()
	{
		/*
		| -----------------------------------------
		| change the status of the module
		| -----------------------------------------
		*/
		
		//set data array
		$data = $this->security_model->_load_config('admin');
		
		if ($this->db_validation_model->_change_status_field('affiliate_viral_pdfs', 'id', (int)$this->uri->segment(4), 'status'))
		{
			//redirect if deleting from ajax table	
			if ($this->uri->segment(5) == 2)
			{
				redirect('/modules/module_affiliate_marketing_viral_pdfs/table/' . $this->config->item('cache_bx') . '/' . $this->uri->segment(7,0) . '/' . $this->uri->segment(8,0) . '/' . $this->uri->segment(9,0) . '/' . $this->uri->segment(10,0) . '/' . $this->uri->segment(11,0));
			}
			else
			{
				//set flash data
				//$this->session->set_flashdata('success', $this->lang->line('update_modules_success'));
				
				redirect(ADMIN_ROUTE . '/modules/view_modules');
			}
		}
	}
	

	// ------------------------------------------------------------------------
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/

	// ------------------------------------------------------------------------	
	
	function _check_viral_pdf_options()
	{
		$rules['module_affiliate_marketing_viral_pdfs_paper_size'] = 'trim|required';
		$rules['module_affiliate_marketing_viral_pdfs_orientation'] = 'trim|required';
		
		$this->validation->set_rules($rules);

		//repopulate form
		$fields['module_affiliate_marketing_viral_pdfs_paper_size'] = $this->lang->line('module_affiliate_marketing_viral_pdfs_paper_size');
		$fields['module_affiliate_marketing_viral_pdfs_orientation'] = $this->lang->line('module_affiliate_marketing_viral_pdfs_orientation');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_viral_pdf()
	{
		$rules['status'] = 'trim|required|integer';
		$rules['name'] = 'trim|required|min_length[5]|max_length[50]';
		$rules['viral_pdf_title'] = 'trim|required|min_length[5]|max_length[255]';
		$rules['viral_pdf_body'] = 'trim|required|min_length[20]';
		$rules['enable_redirect'] = 'trim|integer';
		
		if ($this->input->post('enable_redirect') == 1)
		{
			$rules['redirect_custom_url'] = 'trim|required|prep_url';
		}
		
		$rules['notes'] = 'trim';
		
		$this->validation->set_rules($rules);

		//repopulate form

		$fields['status'] = $this->lang->line('status');
		$fields['name'] = $this->lang->line('viral_pdf_name');
		$fields['viral_pdf_title'] = $this->lang->line('viral_pdf_title');
		$fields['viral_pdf_body'] = $this->lang->line('viral_pdf_body');
		$fields['enable_redirect'] = $this->lang->line('enable_redirect');
		$fields['redirect_custom_url'] = $this->lang->line('redirect_custom_url');

		$fields['notes'] = $this->lang->line('notes');
		
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------
	
	function _update_viral_pdf_image($type = '', $id = '', $file_name = '')
	{
		
		if ($type == 'update')
		{
			//get the data first
			$this->db->where('id', $id);
			$query = $this->db->get('affiliate_viral_pdfs');
			
			$row = $query->result_array();
			
			if ($row[0]['viral_pdf_file_name'] != $file_name)
			{
				//delet the old viral_pdf
				
				@unlink('./images/' . $this->config->item('images_viral_pdfs_dir') . '/' . $row[0]['viral_pdf_file_name']);
		
			}	
		}
		
		//add the image to the viral_pdf
		$sdata['config'] = array(
							'table'	=>	'affiliate_viral_pdfs',
							'key'	=>	'id',
							'value' 	=>	$id,
							);
		
		$sdata['fields'] = array (
								'viral_pdf_file_name'	=> 	$file_name
								);			
		
		if ($this->uploads_model->_update_image_db($sdata))
		{
			return true;
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_sort_order()
	{
		$data = $this->db_validation_model->_clean_data($_POST);
	
		foreach ($data as $k => $v)
		{
			if (strstr($k, "tool") == true) 
			{
				$rules[$k] = 'trim|required|numeric';
				
				$opt = explode('-', $k);
				
				$fields[$k] = $this->lang->line('viral_pdf_id'). ' ' .end($opt) ;
			}
		}
		
		$this->validation->set_rules($rules);
		
		//repopulate form
		$this->validation->set_fields($fields);
			
		if ($this->validation->run() == FALSE)	
		{
			return false;
		}
		
		return true;
	}
}
?>